/// <reference types="node" />
import { DocumentNode } from 'graphql';
export declare type Maybe<T> = T | undefined;
export declare type Exact<T extends {
    [key: string]: unknown;
}> = {
    [K in keyof T]: T[K];
};
export declare type MakeOptional<T, K extends keyof T> = Omit<T, K> & {
    [SubKey in K]?: Maybe<T[SubKey]>;
};
export declare type MakeMaybe<T, K extends keyof T> = Omit<T, K> & {
    [SubKey in K]: Maybe<T[SubKey]>;
};
/** All built-in and custom scalars, mapped to their actual values */
export declare type Scalars = {
    ID: string;
    String: string;
    Boolean: boolean;
    Int: number;
    Float: number;
    /** An ISO 8601-encoded date */
    ISO8601Date: string;
    /** An ISO 8601-encoded datetime */
    ISO8601DateTime: string;
    /** Represents untyped JSON */
    JSON: any;
    Upload: {
        buffer: Buffer;
        filename: string;
        contentType: string;
    };
};
export declare type ActivityNotification = {
    __typename?: 'ActivityNotification';
    createdAt: Scalars['ISO8601DateTime'];
    id: Scalars['ID'];
    key?: Maybe<Scalars['String']>;
    notifiableId: Scalars['ID'];
    notifiableType?: Maybe<NotifiableTypeEnum>;
    openedAt?: Maybe<Scalars['ISO8601DateTime']>;
    parameters?: Maybe<Scalars['JSON']>;
    target: User;
    targetId: Scalars['ID'];
    updatedAt: Scalars['ISO8601DateTime'];
};
export declare type ActivityNotificationFilterInput = {
    id?: Maybe<FilterIdInput>;
    key?: Maybe<FilterTextInput>;
    notifiableId?: Maybe<FilterIdInput>;
    notifiableType?: Maybe<NotifiableTypeEnum>;
    targetId?: Maybe<FilterIdInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    openedAt?: Maybe<FilterDateInput>;
};
export declare type ActivityNotificationResolver = {
    __typename?: 'ActivityNotificationResolver';
    activityNotifications: Array<ActivityNotification>;
    total: Scalars['Int'];
};
export declare type ActivityNotificationSortInput = {
    id?: Maybe<SortEnum>;
    key?: Maybe<SortEnum>;
    notifiableId?: Maybe<SortEnum>;
    notifiableType?: Maybe<SortEnum>;
    targetId?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    openedAt?: Maybe<SortEnum>;
};
export declare type ActivityPoint = {
    __typename?: 'ActivityPoint';
    activityType?: Maybe<Scalars['String']>;
    createdAt: Scalars['ISO8601DateTime'];
    id: Scalars['ID'];
    points?: Maybe<Scalars['Int']>;
    tokensSpent?: Maybe<Scalars['Int']>;
    updatedAt: Scalars['ISO8601DateTime'];
    user: User;
    userId: Scalars['ID'];
};
export declare type ActivityPointFilterInput = {
    id?: Maybe<FilterIdInput>;
    userId?: Maybe<FilterNumberInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    activityType?: Maybe<FilterTextInput>;
    tokensSpent?: Maybe<FilterNumberInput>;
    points?: Maybe<FilterNumberInput>;
};
export declare type ActivityPointHighscore = {
    __typename?: 'ActivityPointHighscore';
    payable?: Maybe<Scalars['Boolean']>;
    payout?: Maybe<Scalars['Float']>;
    points?: Maybe<Scalars['Int']>;
    user: User;
};
export declare type ActivityPointHighscoreResolver = {
    __typename?: 'ActivityPointHighscoreResolver';
    highscore: Array<ActivityPointHighscore>;
    total: Scalars['Int'];
};
export declare type ActivityPointInput = {
    userId?: Maybe<Scalars['ID']>;
    activityType?: Maybe<Scalars['String']>;
    tokensSpent?: Maybe<Scalars['Int']>;
    points?: Maybe<Scalars['Int']>;
};
export declare type ActivityPointResolver = {
    __typename?: 'ActivityPointResolver';
    activityPoints: Array<ActivityPoint>;
    total: Scalars['Int'];
};
export declare type ActivityPointSortInput = {
    id?: Maybe<SortEnum>;
    userId?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    activityType?: Maybe<SortEnum>;
    tokensSpent?: Maybe<SortEnum>;
    points?: Maybe<SortEnum>;
};
/** Autogenerated input type of AddActivityPointMutation */
export declare type AddActivityPointMutationInput = {
    params: ActivityPointInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddActivityPointMutation */
export declare type AddActivityPointMutationPayload = {
    __typename?: 'AddActivityPointMutationPayload';
    activityPoint: ActivityPoint;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated input type of AddAdminUserMutation */
export declare type AddAdminUserMutationInput = {
    params: AdminUserInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddAdminUserMutation */
export declare type AddAdminUserMutationPayload = {
    __typename?: 'AddAdminUserMutationPayload';
    adminUser: AdminUser;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated input type of AddAmaSessionMutation */
export declare type AddAmaSessionMutationInput = {
    params: AmaSessionInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddAmaSessionMutation */
export declare type AddAmaSessionMutationPayload = {
    __typename?: 'AddAmaSessionMutationPayload';
    amaSession: AmaSession;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated input type of AddAnnouncementMutation */
export declare type AddAnnouncementMutationInput = {
    params: AnnouncementInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddAnnouncementMutation */
export declare type AddAnnouncementMutationPayload = {
    __typename?: 'AddAnnouncementMutationPayload';
    announcement: Announcement;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated input type of AddContentCategoryMutation */
export declare type AddContentCategoryMutationInput = {
    params: ContentCategoryInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddContentCategoryMutation */
export declare type AddContentCategoryMutationPayload = {
    __typename?: 'AddContentCategoryMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    contentCategory: ContentCategory;
};
/** Autogenerated input type of AddContentMediumMutation */
export declare type AddContentMediumMutationInput = {
    params: ContentMediumInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddContentMediumMutation */
export declare type AddContentMediumMutationPayload = {
    __typename?: 'AddContentMediumMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    contentMedium: ContentMedium;
};
/** Autogenerated input type of AddContentMutation */
export declare type AddContentMutationInput = {
    params: ContentInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddContentMutation */
export declare type AddContentMutationPayload = {
    __typename?: 'AddContentMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    content: Content;
};
/** Autogenerated input type of AddCustomNotificationMutation */
export declare type AddCustomNotificationMutationInput = {
    params: CustomNotificationInput;
    userFilter?: Maybe<UserFilterInput>;
    userSearch?: Maybe<Scalars['String']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddCustomNotificationMutation */
export declare type AddCustomNotificationMutationPayload = {
    __typename?: 'AddCustomNotificationMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    customNotification: CustomNotification;
};
/** Autogenerated input type of AddFreeTokenTriggerMutation */
export declare type AddFreeTokenTriggerMutationInput = {
    params: FreeTokenTriggerInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddFreeTokenTriggerMutation */
export declare type AddFreeTokenTriggerMutationPayload = {
    __typename?: 'AddFreeTokenTriggerMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    freeTokenTrigger: FreeTokenTrigger;
};
/** Autogenerated input type of AddGiveawayMutation */
export declare type AddGiveawayMutationInput = {
    params: GiveawayInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddGiveawayMutation */
export declare type AddGiveawayMutationPayload = {
    __typename?: 'AddGiveawayMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    giveaway: Giveaway;
};
/** Autogenerated input type of AddIdeationMissionMutation */
export declare type AddIdeationMissionMutationInput = {
    params: IdeationMissionInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddIdeationMissionMutation */
export declare type AddIdeationMissionMutationPayload = {
    __typename?: 'AddIdeationMissionMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    ideationMission: IdeationMission;
};
/** Autogenerated input type of AddMenuItemMutation */
export declare type AddMenuItemMutationInput = {
    params: MenuItemInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddMenuItemMutation */
export declare type AddMenuItemMutationPayload = {
    __typename?: 'AddMenuItemMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    menuItem: MenuItem;
};
/** Autogenerated input type of AddNftCollectionDeploymentMutation */
export declare type AddNftCollectionDeploymentMutationInput = {
    params: NftCollectionDeploymentInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddNftCollectionDeploymentMutation */
export declare type AddNftCollectionDeploymentMutationPayload = {
    __typename?: 'AddNftCollectionDeploymentMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    nftCollectionDeployment: NftCollectionDeployment;
};
/** Autogenerated input type of AddNftCollectionMutation */
export declare type AddNftCollectionMutationInput = {
    params: NftCollectionInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddNftCollectionMutation */
export declare type AddNftCollectionMutationPayload = {
    __typename?: 'AddNftCollectionMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    nftCollection: NftCollection;
};
/** Autogenerated input type of AddNftGiveawayMutation */
export declare type AddNftGiveawayMutationInput = {
    params: NftGiveawayInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddNftGiveawayMutation */
export declare type AddNftGiveawayMutationPayload = {
    __typename?: 'AddNftGiveawayMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    nftGiveaway: NftGiveaway;
};
/** Autogenerated input type of AddNftHandoutMutation */
export declare type AddNftHandoutMutationInput = {
    params: NftHandoutInput;
    userFilter?: Maybe<UserFilterInput>;
    userSearch?: Maybe<Scalars['String']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddNftHandoutMutation */
export declare type AddNftHandoutMutationPayload = {
    __typename?: 'AddNftHandoutMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    nftHandout: NftHandout;
};
/** Autogenerated input type of AddNftMediumMutation */
export declare type AddNftMediumMutationInput = {
    params: NftMediumInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddNftMediumMutation */
export declare type AddNftMediumMutationPayload = {
    __typename?: 'AddNftMediumMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    nftMedium: NftMedium;
};
/** Autogenerated input type of AddNftMutation */
export declare type AddNftMutationInput = {
    params: NftInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddNftMutation */
export declare type AddNftMutationPayload = {
    __typename?: 'AddNftMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    nft: Nft;
};
/** Autogenerated input type of AddNftTransferNetworkMutation */
export declare type AddNftTransferNetworkMutationInput = {
    params: NftTransferNetworkInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddNftTransferNetworkMutation */
export declare type AddNftTransferNetworkMutationPayload = {
    __typename?: 'AddNftTransferNetworkMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    nftTransferNetwork: NftTransferNetwork;
};
/** Autogenerated input type of AddNftsToCollectionMutation */
export declare type AddNftsToCollectionMutationInput = {
    nftFilter?: Maybe<NftFilterInput>;
    nftSearch?: Maybe<Scalars['String']>;
    collectionId: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddNftsToCollectionMutation */
export declare type AddNftsToCollectionMutationPayload = {
    __typename?: 'AddNftsToCollectionMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    nftCollection: NftCollection;
};
/** Autogenerated input type of AddProfileFieldMutation */
export declare type AddProfileFieldMutationInput = {
    params: ProfileFieldInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddProfileFieldMutation */
export declare type AddProfileFieldMutationPayload = {
    __typename?: 'AddProfileFieldMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    profileField: ProfileField;
};
/** Autogenerated input type of AddProposalPeriodMutation */
export declare type AddProposalPeriodMutationInput = {
    params: ProposalPeriodInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddProposalPeriodMutation */
export declare type AddProposalPeriodMutationPayload = {
    __typename?: 'AddProposalPeriodMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    proposalPeriod: ProposalPeriod;
};
/** Autogenerated input type of AddShopProductMutation */
export declare type AddShopProductMutationInput = {
    params: ShopProductInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddShopProductMutation */
export declare type AddShopProductMutationPayload = {
    __typename?: 'AddShopProductMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    shopProduct: ShopProduct;
};
/** Autogenerated input type of AddShopProductTierMutation */
export declare type AddShopProductTierMutationInput = {
    params: ShopProductTierInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddShopProductTierMutation */
export declare type AddShopProductTierMutationPayload = {
    __typename?: 'AddShopProductTierMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    shopProductTier: ShopProductTier;
};
/** Autogenerated input type of AddSponsorMutation */
export declare type AddSponsorMutationInput = {
    params: SponsorInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddSponsorMutation */
export declare type AddSponsorMutationPayload = {
    __typename?: 'AddSponsorMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    sponsor: Sponsor;
};
/** Autogenerated input type of AddStaticPageMutation */
export declare type AddStaticPageMutationInput = {
    params: StaticPageInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddStaticPageMutation */
export declare type AddStaticPageMutationPayload = {
    __typename?: 'AddStaticPageMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    staticPage: StaticPage;
};
/** Autogenerated input type of AddSystemSettingMutation */
export declare type AddSystemSettingMutationInput = {
    params: SystemSettingInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddSystemSettingMutation */
export declare type AddSystemSettingMutationPayload = {
    __typename?: 'AddSystemSettingMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    systemSetting: SystemSetting;
};
/** Autogenerated input type of AddTokenHandoutMutation */
export declare type AddTokenHandoutMutationInput = {
    params: TokenHandoutInput;
    userFilter?: Maybe<UserFilterInput>;
    userSearch?: Maybe<Scalars['String']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddTokenHandoutMutation */
export declare type AddTokenHandoutMutationPayload = {
    __typename?: 'AddTokenHandoutMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    tokenHandout: TokenHandout;
};
/** Autogenerated input type of AddUgcReportMutation */
export declare type AddUgcReportMutationInput = {
    params: UgcReportInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddUgcReportMutation */
export declare type AddUgcReportMutationPayload = {
    __typename?: 'AddUgcReportMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    ugcReport: UgcReport;
};
/** Autogenerated input type of AddUgcReportTypeMutation */
export declare type AddUgcReportTypeMutationInput = {
    params: UgcReportTypeInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddUgcReportTypeMutation */
export declare type AddUgcReportTypeMutationPayload = {
    __typename?: 'AddUgcReportTypeMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    ugcReportType: UgcReportTyp;
};
/** Autogenerated input type of AddUserMutation */
export declare type AddUserMutationInput = {
    params: UserInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddUserMutation */
export declare type AddUserMutationPayload = {
    __typename?: 'AddUserMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    user: User;
};
/** Autogenerated input type of AddUserOrderMutation */
export declare type AddUserOrderMutationInput = {
    params: UserOrderInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddUserOrderMutation */
export declare type AddUserOrderMutationPayload = {
    __typename?: 'AddUserOrderMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    userOrder: UserOrder;
};
/** Autogenerated input type of AddVotingMutation */
export declare type AddVotingMutationInput = {
    params: VotingInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of AddVotingMutation */
export declare type AddVotingMutationPayload = {
    __typename?: 'AddVotingMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    voting: Voting;
};
export declare type AdminProfileInput = {
    email?: Maybe<Scalars['String']>;
    password?: Maybe<Scalars['String']>;
    passwordConfirmation?: Maybe<Scalars['String']>;
    otpRequiredForLogin?: Maybe<Scalars['Boolean']>;
    useAbsoluteDates?: Maybe<Scalars['Boolean']>;
};
export declare type AdminUser = {
    __typename?: 'AdminUser';
    authorizations: Scalars['JSON'];
    confirmationSentAt?: Maybe<Scalars['ISO8601DateTime']>;
    confirmationToken?: Maybe<Scalars['String']>;
    confirmedAt?: Maybe<Scalars['ISO8601DateTime']>;
    createdAt: Scalars['ISO8601DateTime'];
    email: Scalars['String'];
    id: Scalars['ID'];
    otpRequiredForLogin?: Maybe<Scalars['Boolean']>;
    provider?: Maybe<Scalars['String']>;
    rememberCreatedAt?: Maybe<Scalars['ISO8601DateTime']>;
    resetPasswordSentAt?: Maybe<Scalars['ISO8601DateTime']>;
    resetPasswordToken?: Maybe<Scalars['String']>;
    role?: Maybe<AdminUserRoleEnum>;
    serviceToken?: Maybe<Scalars['String']>;
    tokens: Scalars['String'];
    uid?: Maybe<Scalars['String']>;
    unconfirmedEmail?: Maybe<Scalars['String']>;
    updatedAt: Scalars['ISO8601DateTime'];
    useAbsoluteDates: Scalars['Boolean'];
};
export declare type AdminUserFilterInput = {
    id?: Maybe<FilterIdInput>;
    email?: Maybe<FilterTextInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    confirmedAt?: Maybe<FilterDateInput>;
    confirmationSentAt?: Maybe<FilterDateInput>;
    resetPasswordSentAt?: Maybe<FilterDateInput>;
    otpRequiredForLogin?: Maybe<FilterNumberInput>;
    role?: Maybe<AdminUserRoleEnum>;
    provider?: Maybe<FilterTextInput>;
    uid?: Maybe<FilterTextInput>;
};
export declare type AdminUserInput = {
    email?: Maybe<Scalars['String']>;
    password?: Maybe<Scalars['String']>;
    passwordConfirmation?: Maybe<Scalars['String']>;
    provider?: Maybe<Scalars['String']>;
    uid?: Maybe<Scalars['String']>;
    role?: Maybe<AdminUserRoleEnum>;
    otpRequiredForLogin?: Maybe<Scalars['Boolean']>;
    useAbsoluteDates?: Maybe<Scalars['Boolean']>;
};
/** Autogenerated return type of AdminUserLogin */
export declare type AdminUserLoginPayload = {
    __typename?: 'AdminUserLoginPayload';
    authenticatable: AdminUser;
    credentials: Credential;
};
export declare type AdminUserResolver = {
    __typename?: 'AdminUserResolver';
    adminUsers: Array<AdminUser>;
    total: Scalars['Int'];
};
export declare enum AdminUserRoleEnum {
    Writer = "writer",
    Editor = "editor",
    Support = "support",
    Finance = "finance",
    SystemAdmin = "system_admin",
    SuperAdmin = "super_admin"
}
export declare type AdminUserSortInput = {
    id?: Maybe<SortEnum>;
    email?: Maybe<SortEnum>;
    resetPasswordToken?: Maybe<SortEnum>;
    resetPasswordSentAt?: Maybe<SortEnum>;
    rememberCreatedAt?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    otpRequiredForLogin?: Maybe<SortEnum>;
    role?: Maybe<SortEnum>;
    provider?: Maybe<SortEnum>;
    uid?: Maybe<SortEnum>;
    confirmationToken?: Maybe<SortEnum>;
    confirmedAt?: Maybe<SortEnum>;
    confirmationSentAt?: Maybe<SortEnum>;
    unconfirmedEmail?: Maybe<SortEnum>;
};
export declare type AmaQuestion = {
    __typename?: 'AmaQuestion';
    amaSession: AmaSession;
    amaSessionId: Scalars['ID'];
    audits: Array<Audit>;
    boostsAmountCache?: Maybe<Scalars['Int']>;
    comments: Array<Comment>;
    commentsCount?: Maybe<Scalars['Int']>;
    content?: Maybe<Scalars['String']>;
    createdAt: Scalars['ISO8601DateTime'];
    customTag1?: Maybe<Scalars['Boolean']>;
    customTag2?: Maybe<Scalars['Boolean']>;
    customTag3?: Maybe<Scalars['Boolean']>;
    customTag4?: Maybe<Scalars['Boolean']>;
    customTag5?: Maybe<Scalars['Boolean']>;
    id: Scalars['ID'];
    isAnswered?: Maybe<Scalars['Boolean']>;
    nfts: Array<Nft>;
    previewUrl?: Maybe<Scalars['String']>;
    reportStatus: ReportableStatusEnum;
    title: Scalars['String'];
    ugcReportTypes?: Maybe<Array<UgcReportTyp>>;
    ugcReports: Array<UgcReport>;
    ugcReportsCount: Scalars['Int'];
    updatedAt: Scalars['ISO8601DateTime'];
    user: User;
    userId: Scalars['ID'];
};
export declare type AmaQuestionFilterInput = {
    id?: Maybe<FilterIdInput>;
    title?: Maybe<FilterTextInput>;
    content?: Maybe<FilterTextInput>;
    userId?: Maybe<FilterNumberInput>;
    amaSessionId?: Maybe<FilterNumberInput>;
    commentsCount?: Maybe<FilterNumberInput>;
    boostsAmountCache?: Maybe<FilterNumberInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    isAnswered?: Maybe<Scalars['Boolean']>;
    customTag1?: Maybe<Scalars['Boolean']>;
    customTag2?: Maybe<Scalars['Boolean']>;
    customTag3?: Maybe<Scalars['Boolean']>;
    customTag4?: Maybe<Scalars['Boolean']>;
    customTag5?: Maybe<Scalars['Boolean']>;
    withReportStatus?: Maybe<Scalars['Boolean']>;
    ugcReportsCount?: Maybe<FilterNumberInput>;
    reportStatus?: Maybe<ReportableStatusEnum>;
};
export declare type AmaQuestionInput = {
    id?: Maybe<Scalars['ID']>;
    isAnswered?: Maybe<Scalars['Boolean']>;
    customTag1?: Maybe<Scalars['Boolean']>;
    customTag2?: Maybe<Scalars['Boolean']>;
    customTag3?: Maybe<Scalars['Boolean']>;
    customTag4?: Maybe<Scalars['Boolean']>;
    customTag5?: Maybe<Scalars['Boolean']>;
    reportStatus?: Maybe<ReportableStatusEnum>;
    ugcReportTypes?: Maybe<Array<Scalars['Int']>>;
};
export declare type AmaQuestionResolver = {
    __typename?: 'AmaQuestionResolver';
    amaQuestions: Array<AmaQuestion>;
    total: Scalars['Int'];
};
export declare type AmaQuestionSortInput = {
    id?: Maybe<SortEnum>;
    title?: Maybe<SortEnum>;
    content?: Maybe<SortEnum>;
    userId?: Maybe<SortEnum>;
    commentsCount?: Maybe<SortEnum>;
    boostsAmountCache?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    isAnswered?: Maybe<SortEnum>;
    customTag1?: Maybe<SortEnum>;
    customTag2?: Maybe<SortEnum>;
    customTag3?: Maybe<SortEnum>;
    customTag4?: Maybe<SortEnum>;
    customTag5?: Maybe<SortEnum>;
    ugcReportsCount?: Maybe<SortEnum>;
    reportStatus?: Maybe<SortEnumWithDefault>;
};
export declare type AmaSession = {
    __typename?: 'AmaSession';
    amaQuestions: Array<AmaQuestion>;
    amaQuestionsBoostAmounts?: Maybe<Scalars['Int']>;
    amaQuestionsCount?: Maybe<Scalars['Int']>;
    announcements: Array<Announcement>;
    availabilities?: Maybe<Array<Availability>>;
    availabilityType: AvailabilityTypeEnum;
    availableFors: Array<Scalars['String']>;
    contractAddress?: Maybe<Scalars['String']>;
    createdAt: Scalars['ISO8601DateTime'];
    creatorShare?: Maybe<Scalars['Int']>;
    distributedAt?: Maybe<Scalars['ISO8601DateTime']>;
    endsAt: Scalars['ISO8601DateTime'];
    fanvaultShare?: Maybe<Scalars['Int']>;
    heroMedium?: Maybe<ContentMedium>;
    heroMediumId?: Maybe<Scalars['ID']>;
    id: Scalars['ID'];
    onlyForAvailables?: Maybe<Scalars['Boolean']>;
    operatorShare?: Maybe<Scalars['Int']>;
    pinToTop: Scalars['Boolean'];
    previewToken?: Maybe<Scalars['String']>;
    previewUrl?: Maybe<Scalars['String']>;
    previewUrls: Array<PreviewUrl>;
    publishedAt?: Maybe<Scalars['ISO8601DateTime']>;
    requiredNfts?: Maybe<Array<Nft>>;
    requiredSubscriptions?: Maybe<Array<ShopProduct>>;
    status: AmaSessionStatusEnum;
    translations: Array<AmaSessionTranslation>;
    updatedAt: Scalars['ISO8601DateTime'];
    willBePinned: Scalars['Boolean'];
};
export declare type AmaSessionFilterInput = {
    id?: Maybe<FilterIdInput>;
    status?: Maybe<AmaSessionStatusEnum>;
    endsAt?: Maybe<FilterDateInput>;
    questionsCount?: Maybe<FilterNumberInput>;
    contractAddress?: Maybe<FilterTextInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    distributedAt?: Maybe<FilterDateInput>;
    title?: Maybe<FilterTextInput>;
    description?: Maybe<FilterTextInput>;
    slug?: Maybe<FilterTextInput>;
    preview?: Maybe<FilterTextInput>;
    publishedAt?: Maybe<FilterDateInput>;
    availableFor?: Maybe<Array<AvailabilityAvailableForEnum>>;
    onlyForAvailables?: Maybe<Scalars['Boolean']>;
    availabilityType?: Maybe<AvailabilityTypeEnum>;
};
export declare type AmaSessionInput = {
    endsAt?: Maybe<Scalars['ISO8601DateTime']>;
    heroMediumId?: Maybe<Scalars['ID']>;
    translations?: Maybe<Array<AmaSessionTranslationInput>>;
    publishedAt?: Maybe<Scalars['ISO8601DateTime']>;
    availabilities?: Maybe<Array<AvailabilityInput>>;
    onlyForAvailables?: Maybe<Scalars['Boolean']>;
    availabilityType?: Maybe<AvailabilityTypeEnum>;
    pinToTop?: Maybe<Scalars['Boolean']>;
};
export declare type AmaSessionResolver = {
    __typename?: 'AmaSessionResolver';
    amaSessions: Array<AmaSession>;
    total: Scalars['Int'];
};
export declare type AmaSessionSortInput = {
    id?: Maybe<SortEnum>;
    status?: Maybe<SortEnumWithDefault>;
    endsAt?: Maybe<SortEnum>;
    questionsCount?: Maybe<SortEnum>;
    contractAddress?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    title?: Maybe<LocalizedSorterInput>;
    description?: Maybe<LocalizedSorterInput>;
    slug?: Maybe<LocalizedSorterInput>;
    preview?: Maybe<LocalizedSorterInput>;
    publishedAt?: Maybe<SortEnum>;
    distributedAt?: Maybe<SortEnum>;
    onlyForAvailables?: Maybe<SortEnum>;
    availabilityType?: Maybe<SortEnum>;
};
export declare enum AmaSessionStatusEnum {
    Draft = "draft",
    Scheduled = "scheduled",
    Deploying = "deploying",
    Published = "published",
    Archived = "archived"
}
export declare type AmaSessionTranslation = {
    __typename?: 'AmaSessionTranslation';
    description: Scalars['String'];
    id: Scalars['ID'];
    locale: Scalars['String'];
    preview?: Maybe<Scalars['String']>;
    slug: Scalars['String'];
    title: Scalars['String'];
};
export declare type AmaSessionTranslationInput = {
    id?: Maybe<Scalars['ID']>;
    locale?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
    slug?: Maybe<Scalars['String']>;
    preview?: Maybe<Scalars['String']>;
};
export declare type Announcement = {
    __typename?: 'Announcement';
    announceableId: Scalars['ID'];
    announceableType?: Maybe<Scalars['String']>;
    createdAt: Scalars['ISO8601DateTime'];
    id: Scalars['ID'];
    translations: Array<AnnouncementTranslation>;
    updatedAt: Scalars['ISO8601DateTime'];
};
export declare type AnnouncementFilterInput = {
    id?: Maybe<FilterIdInput>;
    announceableId?: Maybe<FilterNumberInput>;
    announceableType?: Maybe<FilterTextInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
};
export declare type AnnouncementInput = {
    announceableId?: Maybe<Scalars['ID']>;
    announceableType?: Maybe<Scalars['String']>;
    translations?: Maybe<Array<AnnouncementTranslationInput>>;
};
export declare type AnnouncementResolver = {
    __typename?: 'AnnouncementResolver';
    announcements: Array<Announcement>;
    total: Scalars['Int'];
};
export declare type AnnouncementSortInput = {
    id?: Maybe<SortEnum>;
    announceableId?: Maybe<SortEnum>;
    announceableType?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    title?: Maybe<LocalizedSorterInput>;
    content?: Maybe<LocalizedSorterInput>;
};
export declare type AnnouncementTranslation = {
    __typename?: 'AnnouncementTranslation';
    content: Scalars['String'];
    id: Scalars['ID'];
    locale: Scalars['String'];
    title: Scalars['String'];
};
export declare type AnnouncementTranslationInput = {
    id?: Maybe<Scalars['ID']>;
    locale?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
    content?: Maybe<Scalars['String']>;
};
/** Autogenerated input type of ArchiveAmaSessionMutation */
export declare type ArchiveAmaSessionMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of ArchiveAmaSessionMutation */
export declare type ArchiveAmaSessionMutationPayload = {
    __typename?: 'ArchiveAmaSessionMutationPayload';
    amaSession: AmaSession;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated input type of ArchiveContentMutation */
export declare type ArchiveContentMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of ArchiveContentMutation */
export declare type ArchiveContentMutationPayload = {
    __typename?: 'ArchiveContentMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    content: Content;
};
/** Autogenerated input type of ArchiveFreeTokenTriggerMutation */
export declare type ArchiveFreeTokenTriggerMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of ArchiveFreeTokenTriggerMutation */
export declare type ArchiveFreeTokenTriggerMutationPayload = {
    __typename?: 'ArchiveFreeTokenTriggerMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    freeTokenTrigger: FreeTokenTrigger;
};
/** Autogenerated input type of ArchiveGiveawayMutation */
export declare type ArchiveGiveawayMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of ArchiveGiveawayMutation */
export declare type ArchiveGiveawayMutationPayload = {
    __typename?: 'ArchiveGiveawayMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    giveaway: Giveaway;
};
/** Autogenerated input type of ArchiveIdeationMissionMutation */
export declare type ArchiveIdeationMissionMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of ArchiveIdeationMissionMutation */
export declare type ArchiveIdeationMissionMutationPayload = {
    __typename?: 'ArchiveIdeationMissionMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    ideationMission: IdeationMission;
};
/** Autogenerated input type of ArchiveNftCollectionMutation */
export declare type ArchiveNftCollectionMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of ArchiveNftCollectionMutation */
export declare type ArchiveNftCollectionMutationPayload = {
    __typename?: 'ArchiveNftCollectionMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    nftCollection: NftCollection;
};
/** Autogenerated input type of ArchiveNftGiveawayMutation */
export declare type ArchiveNftGiveawayMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of ArchiveNftGiveawayMutation */
export declare type ArchiveNftGiveawayMutationPayload = {
    __typename?: 'ArchiveNftGiveawayMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    nftGiveaway: NftGiveaway;
};
/** Autogenerated input type of ArchiveProfileFieldMutation */
export declare type ArchiveProfileFieldMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of ArchiveProfileFieldMutation */
export declare type ArchiveProfileFieldMutationPayload = {
    __typename?: 'ArchiveProfileFieldMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    profileField: ProfileField;
};
/** Autogenerated input type of ArchiveStaticPageMutation */
export declare type ArchiveStaticPageMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of ArchiveStaticPageMutation */
export declare type ArchiveStaticPageMutationPayload = {
    __typename?: 'ArchiveStaticPageMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    staticPage: StaticPage;
};
/** Autogenerated input type of ArchiveVotingMutation */
export declare type ArchiveVotingMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of ArchiveVotingMutation */
export declare type ArchiveVotingMutationPayload = {
    __typename?: 'ArchiveVotingMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    voting: Voting;
};
export declare type Audit = {
    __typename?: 'Audit';
    auditableId: Scalars['ID'];
    auditableType?: Maybe<Scalars['String']>;
    auditedChanges: Scalars['JSON'];
    createdAt: Scalars['ISO8601DateTime'];
    id: Scalars['ID'];
    userId?: Maybe<Scalars['ID']>;
    userType?: Maybe<Scalars['String']>;
    version?: Maybe<Scalars['Int']>;
};
export declare type AvailabilitiesResource = {
    __typename?: 'AvailabilitiesResource';
    availabilityId: Scalars['ID'];
    createdAt: Scalars['ISO8601DateTime'];
    id: Scalars['ID'];
    nft?: Maybe<Nft>;
    nftId?: Maybe<Scalars['ID']>;
    shopProduct?: Maybe<ShopProduct>;
    shopProductId?: Maybe<Scalars['ID']>;
    updatedAt: Scalars['ISO8601DateTime'];
};
export declare type AvailabilitiesResourceInput = {
    id?: Maybe<Scalars['ID']>;
    nftId?: Maybe<Scalars['ID']>;
    shopProductId?: Maybe<Scalars['ID']>;
    _destroy?: Maybe<Scalars['Boolean']>;
};
export declare type Availability = {
    __typename?: 'Availability';
    availabilitiesResources?: Maybe<Array<AvailabilitiesResource>>;
    availableFor: AvailabilityAvailableForEnum;
    createdAt: Scalars['ISO8601DateTime'];
    id: Scalars['ID'];
    resourceId: Scalars['ID'];
    resourceType: Scalars['String'];
    updatedAt: Scalars['ISO8601DateTime'];
};
export declare enum AvailabilityAvailableForEnum {
    Buyer = "buyer",
    Subscriber = "subscriber",
    NftHolder = "nft_holder"
}
export declare type AvailabilityInput = {
    id?: Maybe<Scalars['ID']>;
    availableFor?: Maybe<AvailabilityAvailableForEnum>;
    _destroy?: Maybe<Scalars['Boolean']>;
    availabilitiesResources?: Maybe<Array<AvailabilitiesResourceInput>>;
};
export declare enum AvailabilityTypeEnum {
    LoggedOut = "logged_out",
    LoggedIn = "logged_in",
    TokenHolder = "token_holder",
    CombinableAvailabilities = "combinable_availabilities"
}
export declare type Balance = {
    __typename?: 'Balance';
    currency: Scalars['String'];
    value: Scalars['String'];
    var: Scalars['String'];
};
export declare type Comment = {
    __typename?: 'Comment';
    audits: Array<Audit>;
    boostsAmountCache?: Maybe<Scalars['Int']>;
    commentableId: Scalars['ID'];
    commentableTitle?: Maybe<Scalars['String']>;
    commentableType?: Maybe<CommentableTypeEnum>;
    comments: Array<Comment>;
    commentsCount?: Maybe<Scalars['Int']>;
    content?: Maybe<Scalars['String']>;
    contractAddress?: Maybe<Scalars['String']>;
    createdAt: Scalars['ISO8601DateTime'];
    creatorShare?: Maybe<Scalars['Int']>;
    disabled?: Maybe<Scalars['Boolean']>;
    fanvaultShare?: Maybe<Scalars['Int']>;
    id: Scalars['ID'];
    muted?: Maybe<Scalars['Boolean']>;
    nfts: Array<Nft>;
    operatorAddress?: Maybe<Scalars['String']>;
    operatorShare?: Maybe<Scalars['Int']>;
    previewUrl?: Maybe<Scalars['String']>;
    reportStatus: ReportableStatusEnum;
    title?: Maybe<Scalars['String']>;
    ugcReportTypes?: Maybe<Array<UgcReportTyp>>;
    ugcReports: Array<UgcReport>;
    ugcReportsCount: Scalars['Int'];
    updatedAt: Scalars['ISO8601DateTime'];
    user: User;
    userId: Scalars['ID'];
};
export declare type CommentFilterInput = {
    id?: Maybe<FilterIdInput>;
    content?: Maybe<FilterTextInput>;
    commentableId?: Maybe<FilterNumberInput>;
    commentableType?: Maybe<CommentableTypeEnum>;
    userId?: Maybe<FilterNumberInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    contractAddress?: Maybe<FilterTextInput>;
    operatorAddress?: Maybe<FilterTextInput>;
    boostsAmountCache?: Maybe<FilterNumberInput>;
    commentsCount?: Maybe<FilterNumberInput>;
    ugcReportsCount?: Maybe<FilterNumberInput>;
    reportStatus?: Maybe<ReportableStatusEnum>;
    muted?: Maybe<Scalars['Boolean']>;
    disabled?: Maybe<Scalars['Boolean']>;
    withReportStatus?: Maybe<Scalars['Boolean']>;
};
export declare type CommentInput = {
    muted?: Maybe<Scalars['Boolean']>;
    disabled?: Maybe<Scalars['Boolean']>;
    reportStatus?: Maybe<ReportableStatusEnum>;
    ugcReportTypes?: Maybe<Array<Scalars['Int']>>;
};
export declare type CommentResolver = {
    __typename?: 'CommentResolver';
    comments: Array<Comment>;
    total: Scalars['Int'];
};
export declare type CommentSortInput = {
    id?: Maybe<SortEnum>;
    content?: Maybe<SortEnum>;
    commentableId?: Maybe<SortEnum>;
    commentableType?: Maybe<SortEnum>;
    userId?: Maybe<SortEnum>;
    contractAddress?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    operatorAddress?: Maybe<SortEnum>;
    boostsAmountCache?: Maybe<SortEnum>;
    commentsCount?: Maybe<SortEnum>;
    muted?: Maybe<SortEnum>;
    disabled?: Maybe<SortEnum>;
    ugcReportsCount?: Maybe<SortEnum>;
    reportStatus?: Maybe<SortEnumWithDefault>;
};
export declare enum CommentableTypeEnum {
    Comment = "Comment",
    Content = "Content",
    GroupPost = "GroupPost",
    Idea = "Idea",
    Proposal = "Proposal",
    StaticPage = "StaticPage",
    Voting = "Voting",
    AmaQuestion = "AmaQuestion"
}
export declare type Content = {
    __typename?: 'Content';
    author?: Maybe<Scalars['String']>;
    availabilities?: Maybe<Array<Availability>>;
    availabilityType: AvailabilityTypeEnum;
    availableFors: Array<Scalars['String']>;
    boostsAmountCache?: Maybe<Scalars['Int']>;
    comments: Array<Comment>;
    commentsCount?: Maybe<Scalars['Int']>;
    contentCategory?: Maybe<ContentCategory>;
    contentCategoryId?: Maybe<Scalars['ID']>;
    contentType?: Maybe<ContentTypeEnum>;
    contractAddress?: Maybe<Scalars['String']>;
    createdAt: Scalars['ISO8601DateTime'];
    creatorShare?: Maybe<Scalars['Int']>;
    depositShare?: Maybe<Scalars['Int']>;
    fanvaultShare?: Maybe<Scalars['Int']>;
    heroMedium?: Maybe<ContentMedium>;
    heroMediumId?: Maybe<Scalars['ID']>;
    id: Scalars['ID'];
    labels: Array<ContentLabel>;
    notifyOnPublished?: Maybe<Scalars['Boolean']>;
    onlyForAvailables?: Maybe<Scalars['Boolean']>;
    operatorShare?: Maybe<Scalars['Int']>;
    pinToTop: Scalars['Boolean'];
    previewToken?: Maybe<Scalars['String']>;
    previewUrl?: Maybe<Scalars['String']>;
    previewUrls: Array<PreviewUrl>;
    publishedAt?: Maybe<Scalars['ISO8601DateTime']>;
    requiredNfts?: Maybe<Array<Nft>>;
    requiredSubscriptions?: Maybe<Array<ShopProduct>>;
    status: ContentStatusEnum;
    translations: Array<ContentTranslation>;
    unlockPrice?: Maybe<Scalars['Int']>;
    unlockerAddress?: Maybe<Scalars['String']>;
    updatedAt: Scalars['ISO8601DateTime'];
    willBePinned: Scalars['Boolean'];
};
export declare type ContentCategory = {
    __typename?: 'ContentCategory';
    contentsCount: Scalars['Int'];
    createdAt: Scalars['ISO8601DateTime'];
    id: Scalars['ID'];
    translations: Array<ContentCategoryTranslation>;
    updatedAt: Scalars['ISO8601DateTime'];
};
export declare type ContentCategoryFilterInput = {
    title?: Maybe<FilterTextInput>;
};
export declare type ContentCategoryInput = {
    translations?: Maybe<Array<ContentCategoryTranslationInput>>;
};
export declare type ContentCategoryResolver = {
    __typename?: 'ContentCategoryResolver';
    contentCategories: Array<ContentCategory>;
    total: Scalars['Int'];
};
export declare type ContentCategorySortInput = {
    id?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    title?: Maybe<LocalizedSorterInput>;
};
export declare type ContentCategoryTranslation = {
    __typename?: 'ContentCategoryTranslation';
    id: Scalars['ID'];
    locale: Scalars['String'];
    title: Scalars['String'];
};
export declare type ContentCategoryTranslationInput = {
    title: Scalars['String'];
    locale: Scalars['String'];
};
export declare type ContentFilterInput = {
    id?: Maybe<FilterIdInput>;
    author?: Maybe<FilterTextInput>;
    contentType?: Maybe<ContentTypeEnum>;
    availableFor?: Maybe<Array<AvailabilityAvailableForEnum>>;
    status?: Maybe<ContentStatusEnum>;
    publishedAt?: Maybe<FilterDateInput>;
    contentCategory?: Maybe<FilterIdInput>;
    contractAddress?: Maybe<FilterTextInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    boostsAmountCache?: Maybe<FilterNumberInput>;
    commentsCount?: Maybe<FilterNumberInput>;
    unlockPrice?: Maybe<FilterNumberInput>;
    title?: Maybe<FilterTextInput>;
    content?: Maybe<FilterTextInput>;
    slug?: Maybe<FilterTextInput>;
    preview?: Maybe<FilterTextInput>;
    labels?: Maybe<Array<ContentLabelInput>>;
    onlyForAvailables?: Maybe<Scalars['Boolean']>;
    availabilityType?: Maybe<AvailabilityTypeEnum>;
};
export declare type ContentInput = {
    author?: Maybe<Scalars['String']>;
    contentType?: Maybe<ContentTypeEnum>;
    notifyOnPublished?: Maybe<Scalars['Boolean']>;
    translations?: Maybe<Array<ContentTranslationInput>>;
    labels?: Maybe<Array<ContentLabelInput>>;
    publishedAt?: Maybe<Scalars['ISO8601DateTime']>;
    contentCategoryId?: Maybe<Scalars['ID']>;
    heroMediumId?: Maybe<Scalars['ID']>;
    unlockPrice?: Maybe<Scalars['Int']>;
    availabilities?: Maybe<Array<AvailabilityInput>>;
    onlyForAvailables?: Maybe<Scalars['Boolean']>;
    availabilityType?: Maybe<AvailabilityTypeEnum>;
    pinToTop?: Maybe<Scalars['Boolean']>;
};
export declare type ContentLabel = {
    __typename?: 'ContentLabel';
    createdAt: Scalars['ISO8601DateTime'];
    id: Scalars['ID'];
    key: Scalars['String'];
    updatedAt: Scalars['ISO8601DateTime'];
    value: Scalars['String'];
};
export declare type ContentLabelInput = {
    id?: Maybe<Scalars['ID']>;
    key: Scalars['String'];
    value: Scalars['String'];
};
export declare type ContentMediaOembedData = OembedLink | OembedPhoto | OembedRich | OembedVideo;
export declare enum ContentMediaTypeEnum {
    Image = "image",
    ExternalMedia = "external_media",
    Video = "video",
    Audio = "audio"
}
export declare type ContentMedium = {
    __typename?: 'ContentMedium';
    amaSessionsCount: Scalars['Int'];
    aspectRatio: MediaAspectRatioEnum;
    byteSize?: Maybe<Scalars['Int']>;
    contentsCount: Scalars['Int'];
    createdAt: Scalars['ISO8601DateTime'];
    customNotificationsCount: Scalars['Int'];
    dimensions?: Maybe<Scalars['JSON']>;
    externalSrc?: Maybe<Scalars['String']>;
    freeTokenTriggersCount: Scalars['Int'];
    id: Scalars['ID'];
    ideationMissionsCount: Scalars['Int'];
    image?: Maybe<Scalars['String']>;
    mediaSrc?: Maybe<Scalars['String']>;
    mediaType: ContentMediaTypeEnum;
    menuItemsCount: Scalars['Int'];
    nftCollectionsCount: Scalars['Int'];
    oembedData?: Maybe<ContentMediaOembedData>;
    original?: Maybe<Scalars['String']>;
    resourcesCount: Scalars['Int'];
    shopProductsCount: Scalars['Int'];
    threeqDimensions?: Maybe<Scalars['JSON']>;
    thumbnail?: Maybe<Scalars['String']>;
    tokenHandoutsCount: Scalars['Int'];
    translations: Array<ContentMediumTranslation>;
    updatedAt: Scalars['ISO8601DateTime'];
    votingsCount: Scalars['Int'];
};
export declare type ContentMediumFilterInput = {
    title?: Maybe<FilterTextInput>;
    subtitle?: Maybe<FilterTextInput>;
    mediaType?: Maybe<ContentMediaTypeEnum>;
    externalSrc?: Maybe<FilterTextInput>;
    aspectRatio?: Maybe<MediaAspectRatioEnum>;
};
/** Input attributes for content medium */
export declare type ContentMediumInput = {
    mediaType?: Maybe<ContentMediaTypeEnum>;
    externalSrc?: Maybe<Scalars['String']>;
    mediaSrc?: Maybe<Scalars['String']>;
    translations?: Maybe<Array<ContentMediumTranslationInput>>;
    file?: Maybe<Scalars['Upload']>;
    aspectRatio?: Maybe<MediaAspectRatioEnum>;
};
export declare type ContentMediumResolver = {
    __typename?: 'ContentMediumResolver';
    contentMedia: Array<ContentMedium>;
    total: Scalars['Int'];
};
export declare type ContentMediumSortInput = {
    id?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    title?: Maybe<LocalizedSorterInput>;
    subtitle?: Maybe<LocalizedSorterInput>;
};
export declare type ContentMediumTranslation = {
    __typename?: 'ContentMediumTranslation';
    id: Scalars['ID'];
    locale: Scalars['String'];
    subtitle?: Maybe<Scalars['String']>;
    title: Scalars['String'];
};
export declare type ContentMediumTranslationInput = {
    id?: Maybe<Scalars['ID']>;
    locale?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
    subtitle?: Maybe<Scalars['String']>;
};
export declare type ContentResolver = {
    __typename?: 'ContentResolver';
    contents: Array<Content>;
    total: Scalars['Int'];
};
export declare type ContentSortInput = {
    id?: Maybe<SortEnum>;
    author?: Maybe<SortEnum>;
    contentType?: Maybe<SortEnum>;
    status?: Maybe<SortEnum>;
    publishedAt?: Maybe<SortEnum>;
    contentCategory?: Maybe<SortEnum>;
    contractAddress?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    unlockPrice?: Maybe<SortEnum>;
    boostsAmountCache?: Maybe<SortEnum>;
    commentsCount?: Maybe<SortEnum>;
    onlyForAvailables?: Maybe<SortEnum>;
    availabilityType?: Maybe<SortEnum>;
    title?: Maybe<LocalizedSorterInput>;
    content?: Maybe<LocalizedSorterInput>;
    slug?: Maybe<LocalizedSorterInput>;
    preview?: Maybe<LocalizedSorterInput>;
};
export declare enum ContentStatusEnum {
    Draft = "draft",
    Scheduled = "scheduled",
    Deploying = "deploying",
    Published = "published",
    Archived = "archived"
}
export declare type ContentTranslation = {
    __typename?: 'ContentTranslation';
    content?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    locale: Scalars['String'];
    metaCanonicalUrl?: Maybe<Scalars['String']>;
    metaDescription?: Maybe<Scalars['String']>;
    metaNofollow?: Maybe<Scalars['Boolean']>;
    metaNoindex?: Maybe<Scalars['Boolean']>;
    metaTitle?: Maybe<Scalars['String']>;
    preview?: Maybe<Scalars['String']>;
    slug: Scalars['String'];
    title?: Maybe<Scalars['String']>;
};
export declare type ContentTranslationInput = {
    id?: Maybe<Scalars['ID']>;
    locale?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
    content?: Maybe<Scalars['String']>;
    slug?: Maybe<Scalars['String']>;
    preview?: Maybe<Scalars['String']>;
    metaTitle?: Maybe<Scalars['String']>;
    metaDescription?: Maybe<Scalars['String']>;
    metaCanonicalUrl?: Maybe<Scalars['String']>;
    metaNoindex?: Maybe<Scalars['Boolean']>;
    metaNofollow?: Maybe<Scalars['Boolean']>;
};
export declare enum ContentTypeEnum {
    Article = "article",
    Image = "image",
    Video = "video",
    Audio = "audio"
}
export declare type Credential = {
    __typename?: 'Credential';
    accessToken: Scalars['String'];
    client: Scalars['String'];
    expiry: Scalars['Int'];
    tokenType: Scalars['String'];
    uid: Scalars['String'];
};
export declare type CustomNotification = {
    __typename?: 'CustomNotification';
    createdAt: Scalars['ISO8601DateTime'];
    delayedPublicationId?: Maybe<Scalars['ID']>;
    heroMedium?: Maybe<ContentMedium>;
    heroMediumId?: Maybe<Scalars['ID']>;
    id: Scalars['ID'];
    notificationLink?: Maybe<Scalars['String']>;
    notificationsCount: Scalars['Int'];
    promptDialog?: Maybe<Scalars['Boolean']>;
    sentAt?: Maybe<Scalars['ISO8601DateTime']>;
    sponsor?: Maybe<Sponsor>;
    sponsorId?: Maybe<Scalars['ID']>;
    status: CustomNotificationStatusEnum;
    translations: Array<CustomNotificationTranslation>;
    updatedAt: Scalars['ISO8601DateTime'];
    userFilter?: Maybe<UserFilter>;
    userSearch?: Maybe<Scalars['String']>;
    users: Array<User>;
};
export declare type CustomNotificationFilterInput = {
    id?: Maybe<FilterIdInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    sentAt?: Maybe<FilterDateInput>;
    status?: Maybe<CustomNotificationStatusEnum>;
    promptDialog?: Maybe<Scalars['Boolean']>;
    sponsorId?: Maybe<FilterIdInput>;
    notificationsCount?: Maybe<FilterNumberInput>;
    delayedPublicationId?: Maybe<FilterIdInput>;
    title?: Maybe<FilterTextInput>;
    content?: Maybe<FilterTextInput>;
    message?: Maybe<FilterTextInput>;
    externalLink?: Maybe<FilterTextInput>;
};
export declare type CustomNotificationInput = {
    promptDialog?: Maybe<Scalars['Boolean']>;
    translations?: Maybe<Array<CustomNotificationTranslationInput>>;
    heroMediumId?: Maybe<Scalars['ID']>;
    sponsorId?: Maybe<Scalars['ID']>;
    notificationLink?: Maybe<Scalars['String']>;
    sentAt?: Maybe<Scalars['ISO8601DateTime']>;
};
export declare type CustomNotificationResolver = {
    __typename?: 'CustomNotificationResolver';
    customNotifications: Array<CustomNotification>;
    total: Scalars['Int'];
};
export declare type CustomNotificationSortInput = {
    id?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    sentAt?: Maybe<SortEnum>;
    promptDialog?: Maybe<SortEnum>;
    sponsorId?: Maybe<SortEnum>;
    notificationsCount?: Maybe<SortEnum>;
    title?: Maybe<LocalizedSorterInput>;
    content?: Maybe<LocalizedSorterInput>;
    message?: Maybe<LocalizedSorterInput>;
    externalLink?: Maybe<LocalizedSorterInput>;
    delayedPublicationId?: Maybe<SortEnum>;
    status?: Maybe<SortEnum>;
};
export declare enum CustomNotificationStatusEnum {
    Draft = "draft",
    Scheduled = "scheduled",
    Deploying = "deploying",
    Published = "published"
}
export declare type CustomNotificationTranslation = {
    __typename?: 'CustomNotificationTranslation';
    content?: Maybe<Scalars['String']>;
    ctaText?: Maybe<Scalars['String']>;
    externalLink?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    locale: Scalars['String'];
    message?: Maybe<Scalars['String']>;
    title: Scalars['String'];
};
export declare type CustomNotificationTranslationInput = {
    id?: Maybe<Scalars['ID']>;
    locale?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
    content?: Maybe<Scalars['String']>;
    message?: Maybe<Scalars['String']>;
    externalLink?: Maybe<Scalars['String']>;
    ctaText?: Maybe<Scalars['String']>;
};
/** Autogenerated input type of DeleteActivityPointsMutation */
export declare type DeleteActivityPointsMutationInput = {
    ids: Array<Scalars['ID']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteActivityPointsMutation */
export declare type DeleteActivityPointsMutationPayload = {
    __typename?: 'DeleteActivityPointsMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    deletedIds: Array<Scalars['ID']>;
    status: Scalars['Int'];
};
/** Autogenerated input type of DeleteAdminUserMutation */
export declare type DeleteAdminUserMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteAdminUserMutation */
export declare type DeleteAdminUserMutationPayload = {
    __typename?: 'DeleteAdminUserMutationPayload';
    adminUser: AdminUser;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated input type of DeleteAmaSessionsMutation */
export declare type DeleteAmaSessionsMutationInput = {
    ids: Array<Scalars['ID']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteAmaSessionsMutation */
export declare type DeleteAmaSessionsMutationPayload = {
    __typename?: 'DeleteAmaSessionsMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    deletedIds: Array<Scalars['ID']>;
    status: Scalars['Int'];
};
/** Autogenerated input type of DeleteAnnouncementsMutation */
export declare type DeleteAnnouncementsMutationInput = {
    ids: Array<Scalars['ID']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteAnnouncementsMutation */
export declare type DeleteAnnouncementsMutationPayload = {
    __typename?: 'DeleteAnnouncementsMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    deletedIds: Array<Scalars['ID']>;
    status: Scalars['Int'];
};
/** Autogenerated input type of DeleteContentCategoriesMutation */
export declare type DeleteContentCategoriesMutationInput = {
    ids: Array<Scalars['ID']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteContentCategoriesMutation */
export declare type DeleteContentCategoriesMutationPayload = {
    __typename?: 'DeleteContentCategoriesMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    deletedIds: Array<Scalars['ID']>;
    status: Scalars['Int'];
};
/** Autogenerated input type of DeleteContentMediaMutation */
export declare type DeleteContentMediaMutationInput = {
    ids: Array<Scalars['ID']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteContentMediaMutation */
export declare type DeleteContentMediaMutationPayload = {
    __typename?: 'DeleteContentMediaMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    deletedIds: Array<Scalars['ID']>;
    status: Scalars['Int'];
};
/** Autogenerated input type of DeleteContentsMutation */
export declare type DeleteContentsMutationInput = {
    ids: Array<Scalars['ID']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteContentsMutation */
export declare type DeleteContentsMutationPayload = {
    __typename?: 'DeleteContentsMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    deletedIds: Array<Scalars['ID']>;
    status: Scalars['Int'];
};
/** Autogenerated input type of DeleteCustomNotificationsMutation */
export declare type DeleteCustomNotificationsMutationInput = {
    ids: Array<Scalars['ID']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteCustomNotificationsMutation */
export declare type DeleteCustomNotificationsMutationPayload = {
    __typename?: 'DeleteCustomNotificationsMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    deletedIds: Array<Scalars['ID']>;
    status: Scalars['Int'];
};
/** Autogenerated input type of DeleteFreeTokenTriggersMutation */
export declare type DeleteFreeTokenTriggersMutationInput = {
    ids: Array<Scalars['ID']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteFreeTokenTriggersMutation */
export declare type DeleteFreeTokenTriggersMutationPayload = {
    __typename?: 'DeleteFreeTokenTriggersMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    deletedIds: Array<Scalars['ID']>;
    status: Scalars['Int'];
};
/** Autogenerated input type of DeleteGiveawaysMutation */
export declare type DeleteGiveawaysMutationInput = {
    ids: Array<Scalars['ID']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteGiveawaysMutation */
export declare type DeleteGiveawaysMutationPayload = {
    __typename?: 'DeleteGiveawaysMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    deletedIds: Array<Scalars['ID']>;
    status: Scalars['Int'];
};
/** Autogenerated input type of DeleteIdeationMissionsMutation */
export declare type DeleteIdeationMissionsMutationInput = {
    ids: Array<Scalars['ID']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteIdeationMissionsMutation */
export declare type DeleteIdeationMissionsMutationPayload = {
    __typename?: 'DeleteIdeationMissionsMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    deletedIds: Array<Scalars['ID']>;
    status: Scalars['Int'];
};
/** Autogenerated input type of DeleteMenuItemsMutation */
export declare type DeleteMenuItemsMutationInput = {
    ids: Array<Scalars['ID']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteMenuItemsMutation */
export declare type DeleteMenuItemsMutationPayload = {
    __typename?: 'DeleteMenuItemsMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    deletedIds: Array<Scalars['ID']>;
    status: Scalars['Int'];
};
/** Autogenerated input type of DeleteNftCollectionsMutation */
export declare type DeleteNftCollectionsMutationInput = {
    ids: Array<Scalars['ID']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteNftCollectionsMutation */
export declare type DeleteNftCollectionsMutationPayload = {
    __typename?: 'DeleteNftCollectionsMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    deletedIds: Array<Scalars['ID']>;
    status: Scalars['Int'];
};
/** Autogenerated input type of DeleteNftGiveawaysMutation */
export declare type DeleteNftGiveawaysMutationInput = {
    ids: Array<Scalars['ID']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteNftGiveawaysMutation */
export declare type DeleteNftGiveawaysMutationPayload = {
    __typename?: 'DeleteNftGiveawaysMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    deletedIds: Array<Scalars['ID']>;
    status: Scalars['Int'];
};
/** Autogenerated input type of DeleteNftHandoutsMutation */
export declare type DeleteNftHandoutsMutationInput = {
    ids: Array<Scalars['ID']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteNftHandoutsMutation */
export declare type DeleteNftHandoutsMutationPayload = {
    __typename?: 'DeleteNftHandoutsMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    deletedIds: Array<Scalars['ID']>;
    status: Scalars['Int'];
};
/** Autogenerated input type of DeleteNftMediaMutation */
export declare type DeleteNftMediaMutationInput = {
    ids: Array<Scalars['ID']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteNftMediaMutation */
export declare type DeleteNftMediaMutationPayload = {
    __typename?: 'DeleteNftMediaMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    deletedIds: Array<Scalars['ID']>;
    status: Scalars['Int'];
};
/** Autogenerated input type of DeleteNftsMutation */
export declare type DeleteNftsMutationInput = {
    ids: Array<Scalars['ID']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteNftsMutation */
export declare type DeleteNftsMutationPayload = {
    __typename?: 'DeleteNftsMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    deletedIds: Array<Scalars['ID']>;
    status: Scalars['Int'];
};
/** Autogenerated input type of DeleteProfileFieldsMutation */
export declare type DeleteProfileFieldsMutationInput = {
    ids: Array<Scalars['ID']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteProfileFieldsMutation */
export declare type DeleteProfileFieldsMutationPayload = {
    __typename?: 'DeleteProfileFieldsMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    deletedIds: Array<Scalars['ID']>;
    status: Scalars['Int'];
};
/** Autogenerated input type of DeleteProposalPeriodsMutation */
export declare type DeleteProposalPeriodsMutationInput = {
    ids: Array<Scalars['ID']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteProposalPeriodsMutation */
export declare type DeleteProposalPeriodsMutationPayload = {
    __typename?: 'DeleteProposalPeriodsMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    deletedIds: Array<Scalars['ID']>;
    status: Scalars['Int'];
};
/** Autogenerated input type of DeleteShopProductTiersMutation */
export declare type DeleteShopProductTiersMutationInput = {
    ids: Array<Scalars['ID']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteShopProductTiersMutation */
export declare type DeleteShopProductTiersMutationPayload = {
    __typename?: 'DeleteShopProductTiersMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    deletedIds: Array<Scalars['ID']>;
    status: Scalars['Int'];
};
/** Autogenerated input type of DeleteShopProductsMutation */
export declare type DeleteShopProductsMutationInput = {
    ids: Array<Scalars['ID']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteShopProductsMutation */
export declare type DeleteShopProductsMutationPayload = {
    __typename?: 'DeleteShopProductsMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    deletedIds: Array<Scalars['ID']>;
    status: Scalars['Int'];
};
/** Autogenerated input type of DeleteSponsorsMutation */
export declare type DeleteSponsorsMutationInput = {
    ids: Array<Scalars['ID']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteSponsorsMutation */
export declare type DeleteSponsorsMutationPayload = {
    __typename?: 'DeleteSponsorsMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    deletedIds: Array<Scalars['ID']>;
    status: Scalars['Int'];
};
/** Autogenerated input type of DeleteStaticPagesMutation */
export declare type DeleteStaticPagesMutationInput = {
    ids: Array<Scalars['ID']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteStaticPagesMutation */
export declare type DeleteStaticPagesMutationPayload = {
    __typename?: 'DeleteStaticPagesMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    deletedIds: Array<Scalars['ID']>;
    status: Scalars['Int'];
};
/** Autogenerated input type of DeleteSystemSettingsMutation */
export declare type DeleteSystemSettingsMutationInput = {
    ids: Array<Scalars['ID']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteSystemSettingsMutation */
export declare type DeleteSystemSettingsMutationPayload = {
    __typename?: 'DeleteSystemSettingsMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    deletedIds: Array<Scalars['ID']>;
    status: Scalars['Int'];
};
/** Autogenerated input type of DeleteTokenHandoutsMutation */
export declare type DeleteTokenHandoutsMutationInput = {
    ids: Array<Scalars['ID']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteTokenHandoutsMutation */
export declare type DeleteTokenHandoutsMutationPayload = {
    __typename?: 'DeleteTokenHandoutsMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    deletedIds: Array<Scalars['ID']>;
    status: Scalars['Int'];
};
/** Autogenerated input type of DeleteUgcReportTypesMutation */
export declare type DeleteUgcReportTypesMutationInput = {
    ids: Array<Scalars['ID']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteUgcReportTypesMutation */
export declare type DeleteUgcReportTypesMutationPayload = {
    __typename?: 'DeleteUgcReportTypesMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    deletedIds: Array<Scalars['ID']>;
    status: Scalars['Int'];
};
/** Autogenerated input type of DeleteUgcReportsMutation */
export declare type DeleteUgcReportsMutationInput = {
    ids: Array<Scalars['ID']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteUgcReportsMutation */
export declare type DeleteUgcReportsMutationPayload = {
    __typename?: 'DeleteUgcReportsMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    deletedIds: Array<Scalars['ID']>;
    status: Scalars['Int'];
};
/** Autogenerated input type of DeleteUserMutation */
export declare type DeleteUserMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteUserMutation */
export declare type DeleteUserMutationPayload = {
    __typename?: 'DeleteUserMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    user: User;
};
/** Autogenerated input type of DeleteUserOrdersMutation */
export declare type DeleteUserOrdersMutationInput = {
    ids: Array<Scalars['ID']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteUserOrdersMutation */
export declare type DeleteUserOrdersMutationPayload = {
    __typename?: 'DeleteUserOrdersMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    deletedIds: Array<Scalars['ID']>;
    status: Scalars['Int'];
};
/** Autogenerated input type of DeleteVotingsMutation */
export declare type DeleteVotingsMutationInput = {
    ids: Array<Scalars['ID']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DeleteVotingsMutation */
export declare type DeleteVotingsMutationPayload = {
    __typename?: 'DeleteVotingsMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    deletedIds: Array<Scalars['ID']>;
    status: Scalars['Int'];
};
/** Autogenerated return type of DeployCommentBoosterMutation */
export declare type DeployCommentBoosterMutationPayload = {
    __typename?: 'DeployCommentBoosterMutationPayload';
    systemSetting: SystemSetting;
};
/** Autogenerated return type of DeployContentBoosterMutation */
export declare type DeployContentBoosterMutationPayload = {
    __typename?: 'DeployContentBoosterMutationPayload';
    systemSetting: SystemSetting;
};
/** Autogenerated return type of DeployContentUnlockerMutation */
export declare type DeployContentUnlockerMutationPayload = {
    __typename?: 'DeployContentUnlockerMutationPayload';
    systemSetting: SystemSetting;
};
/** Autogenerated return type of DeployProposalBoosterMutation */
export declare type DeployProposalBoosterMutationPayload = {
    __typename?: 'DeployProposalBoosterMutationPayload';
    systemSetting: SystemSetting;
};
/** Autogenerated return type of DeployTokenContractMutation */
export declare type DeployTokenContractMutationPayload = {
    __typename?: 'DeployTokenContractMutationPayload';
    systemSetting: SystemSetting;
};
/** Autogenerated input type of DistributeAmaSessionMutation */
export declare type DistributeAmaSessionMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DistributeAmaSessionMutation */
export declare type DistributeAmaSessionMutationPayload = {
    __typename?: 'DistributeAmaSessionMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    message: Scalars['String'];
    status: Scalars['Int'];
};
/** Autogenerated return type of DistributeCommentBoosterMutation */
export declare type DistributeCommentBoosterMutationPayload = {
    __typename?: 'DistributeCommentBoosterMutationPayload';
    message: Scalars['String'];
    status: Scalars['Int'];
};
/** Autogenerated return type of DistributeContentBoosterMutation */
export declare type DistributeContentBoosterMutationPayload = {
    __typename?: 'DistributeContentBoosterMutationPayload';
    message: Scalars['String'];
    status: Scalars['Int'];
};
/** Autogenerated return type of DistributeContentUnlockerMutation */
export declare type DistributeContentUnlockerMutationPayload = {
    __typename?: 'DistributeContentUnlockerMutationPayload';
    message: Scalars['String'];
    status: Scalars['Int'];
};
/** Autogenerated input type of DistributeIdeationMissionMutation */
export declare type DistributeIdeationMissionMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DistributeIdeationMissionMutation */
export declare type DistributeIdeationMissionMutationPayload = {
    __typename?: 'DistributeIdeationMissionMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    message: Scalars['String'];
    status: Scalars['Int'];
};
/** Autogenerated return type of DistributeProposalBoosterMutation */
export declare type DistributeProposalBoosterMutationPayload = {
    __typename?: 'DistributeProposalBoosterMutationPayload';
    message: Scalars['String'];
    status: Scalars['Int'];
};
/** Autogenerated input type of DistributeVotingMutation */
export declare type DistributeVotingMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DistributeVotingMutation */
export declare type DistributeVotingMutationPayload = {
    __typename?: 'DistributeVotingMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    message: Scalars['String'];
    status: Scalars['Int'];
};
/** Autogenerated input type of DraftAmaSessionMutation */
export declare type DraftAmaSessionMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DraftAmaSessionMutation */
export declare type DraftAmaSessionMutationPayload = {
    __typename?: 'DraftAmaSessionMutationPayload';
    amaSession: AmaSession;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated input type of DraftContentMutation */
export declare type DraftContentMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DraftContentMutation */
export declare type DraftContentMutationPayload = {
    __typename?: 'DraftContentMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    content: Content;
};
/** Autogenerated input type of DraftCustomNotificationMutation */
export declare type DraftCustomNotificationMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DraftCustomNotificationMutation */
export declare type DraftCustomNotificationMutationPayload = {
    __typename?: 'DraftCustomNotificationMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    customNotification: CustomNotification;
};
/** Autogenerated input type of DraftFreeTokenTriggerMutation */
export declare type DraftFreeTokenTriggerMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DraftFreeTokenTriggerMutation */
export declare type DraftFreeTokenTriggerMutationPayload = {
    __typename?: 'DraftFreeTokenTriggerMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    freeTokenTrigger: FreeTokenTrigger;
};
/** Autogenerated input type of DraftGiveawayMutation */
export declare type DraftGiveawayMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DraftGiveawayMutation */
export declare type DraftGiveawayMutationPayload = {
    __typename?: 'DraftGiveawayMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    giveaway: Giveaway;
};
/** Autogenerated input type of DraftIdeationMissionMutation */
export declare type DraftIdeationMissionMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DraftIdeationMissionMutation */
export declare type DraftIdeationMissionMutationPayload = {
    __typename?: 'DraftIdeationMissionMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    ideationMission: IdeationMission;
};
/** Autogenerated input type of DraftNftCollectionMutation */
export declare type DraftNftCollectionMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DraftNftCollectionMutation */
export declare type DraftNftCollectionMutationPayload = {
    __typename?: 'DraftNftCollectionMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    nftCollection: NftCollection;
};
/** Autogenerated input type of DraftNftGiveawayMutation */
export declare type DraftNftGiveawayMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DraftNftGiveawayMutation */
export declare type DraftNftGiveawayMutationPayload = {
    __typename?: 'DraftNftGiveawayMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    nftGiveaway: NftGiveaway;
};
/** Autogenerated input type of DraftNftHandoutMutation */
export declare type DraftNftHandoutMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DraftNftHandoutMutation */
export declare type DraftNftHandoutMutationPayload = {
    __typename?: 'DraftNftHandoutMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    nftHandout: NftHandout;
};
/** Autogenerated input type of DraftProfileFieldMutation */
export declare type DraftProfileFieldMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DraftProfileFieldMutation */
export declare type DraftProfileFieldMutationPayload = {
    __typename?: 'DraftProfileFieldMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    profileField: ProfileField;
};
/** Autogenerated input type of DraftTokenHandoutMutation */
export declare type DraftTokenHandoutMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DraftTokenHandoutMutation */
export declare type DraftTokenHandoutMutationPayload = {
    __typename?: 'DraftTokenHandoutMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    tokenHandout: TokenHandout;
};
/** Autogenerated input type of DraftVotingMutation */
export declare type DraftVotingMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of DraftVotingMutation */
export declare type DraftVotingMutationPayload = {
    __typename?: 'DraftVotingMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    voting: Voting;
};
export declare type FanGroup = {
    __typename?: 'FanGroup';
    acceptanceStatus: FanGroupAcceptanceStatusEnum;
    accessType: FanGroupAccessTypeEnum;
    activeFanGroupUsersCount: Scalars['Int'];
    archived?: Maybe<Scalars['Boolean']>;
    audits: Array<Audit>;
    city?: Maybe<Scalars['String']>;
    country?: Maybe<Scalars['String']>;
    createdAt: Scalars['ISO8601DateTime'];
    description?: Maybe<Scalars['String']>;
    fanGroupUsers: Array<FanGroupUser>;
    fanGroupUsersCount: Scalars['Int'];
    groupAdmin: User;
    groupAdminId: Scalars['ID'];
    groupPosts: Array<GroupPost>;
    groupProfileMedium?: Maybe<UserMedium>;
    groupProfileMediumId?: Maybe<Scalars['ID']>;
    groupPurpose?: Maybe<Scalars['String']>;
    heroMedium?: Maybe<UserMedium>;
    heroMediumId?: Maybe<Scalars['ID']>;
    id: Scalars['ID'];
    invitationType: FanGroupInvitationTypeEnum;
    isVerified?: Maybe<Scalars['Boolean']>;
    name: Scalars['String'];
    pendingFanGroupUsersCount: Scalars['Int'];
    pinToTop: Scalars['Boolean'];
    postsVisibilityType: FanGroupPostsVisibilityTypeEnum;
    previewUrl: Scalars['String'];
    reportStatus: ReportableStatusEnum;
    showInFeed: Scalars['Boolean'];
    shownInFeedAt?: Maybe<Scalars['ISO8601DateTime']>;
    state?: Maybe<Scalars['String']>;
    ugcReportTypes?: Maybe<Array<UgcReportTyp>>;
    ugcReports: Array<UgcReport>;
    ugcReportsCount: Scalars['Int'];
    updatedAt: Scalars['ISO8601DateTime'];
    visibilityType: FanGroupVisibilityTypeEnum;
    willBePinned: Scalars['Boolean'];
};
export declare enum FanGroupAcceptanceStatusEnum {
    Submitted = "submitted",
    Accepted = "accepted",
    Rejected = "rejected"
}
export declare enum FanGroupAccessTypeEnum {
    PubliclyAccessible = "publicly_accessible",
    PrivatelyAccessible = "privately_accessible"
}
export declare type FanGroupFilterInput = {
    id?: Maybe<FilterIdInput>;
    name?: Maybe<FilterTextInput>;
    groupPurpose?: Maybe<FilterTextInput>;
    groupAdminId?: Maybe<FilterNumberInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    isVerified?: Maybe<Scalars['Boolean']>;
    archived?: Maybe<Scalars['Boolean']>;
    acceptanceStatus?: Maybe<FanGroupAcceptanceStatusEnum>;
    accessType?: Maybe<FanGroupAccessTypeEnum>;
    visibilityType?: Maybe<FanGroupVisibilityTypeEnum>;
    postsVisibilityType?: Maybe<FanGroupPostsVisibilityTypeEnum>;
    invitationType?: Maybe<FanGroupInvitationTypeEnum>;
    country?: Maybe<FilterTextInput>;
    state?: Maybe<FilterTextInput>;
    city?: Maybe<FilterTextInput>;
    ugcReportsCount?: Maybe<FilterNumberInput>;
    reportStatus?: Maybe<ReportableStatusEnum>;
    withReportStatus?: Maybe<Scalars['Boolean']>;
    withReportStatusOrSubmitted?: Maybe<Scalars['Boolean']>;
    fanGroupUsersCount?: Maybe<FilterNumberInput>;
    activeFanGroupUsersCount?: Maybe<FilterNumberInput>;
    pendingFanGroupUsersCount?: Maybe<FilterNumberInput>;
};
export declare type FanGroupInput = {
    isVerified?: Maybe<Scalars['Boolean']>;
    archived?: Maybe<Scalars['Boolean']>;
    acceptanceStatus?: Maybe<FanGroupAcceptanceStatusEnum>;
    reportStatus?: Maybe<ReportableStatusEnum>;
    ugcReportTypes?: Maybe<Array<Scalars['Int']>>;
    showInFeed?: Maybe<Scalars['Boolean']>;
    pinToTop?: Maybe<Scalars['Boolean']>;
};
export declare enum FanGroupInvitationTypeEnum {
    FromOwner = "from_owner",
    FromAdmin = "from_admin",
    FromMember = "from_member"
}
export declare enum FanGroupPostsVisibilityTypeEnum {
    AllUsers = "all_users",
    OnlyMembers = "only_members"
}
export declare type FanGroupResolver = {
    __typename?: 'FanGroupResolver';
    fanGroups: Array<FanGroup>;
    total: Scalars['Int'];
};
export declare type FanGroupSortInput = {
    id?: Maybe<SortEnum>;
    name?: Maybe<SortEnum>;
    groupAdminId?: Maybe<SortEnum>;
    isVerified?: Maybe<SortEnum>;
    archived?: Maybe<SortEnum>;
    acceptanceStatus?: Maybe<SortEnum>;
    country?: Maybe<SortEnum>;
    state?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    city?: Maybe<SortEnum>;
    ugcReportsCount?: Maybe<SortEnum>;
    reportStatus?: Maybe<SortEnumWithDefault>;
    fanGroupUsersCount?: Maybe<SortEnum>;
    activeFanGroupUsersCount?: Maybe<SortEnum>;
    pendingFanGroupUsersCount?: Maybe<SortEnum>;
};
export declare type FanGroupUser = {
    __typename?: 'FanGroupUser';
    activatedAt?: Maybe<Scalars['ISO8601DateTime']>;
    blockedAt?: Maybe<Scalars['ISO8601DateTime']>;
    canceledAt?: Maybe<Scalars['ISO8601DateTime']>;
    createdAt: Scalars['ISO8601DateTime'];
    fanGroup: FanGroup;
    fanGroupId: Scalars['ID'];
    id: Scalars['ID'];
    joinMessage?: Maybe<Scalars['String']>;
    leftAt?: Maybe<Scalars['ISO8601DateTime']>;
    rejectedAt?: Maybe<Scalars['ISO8601DateTime']>;
    role: FanGroupUserRoleEnum;
    status: FanGroupUserStatusEnum;
    updatedAt: Scalars['ISO8601DateTime'];
    user: User;
    userId: Scalars['ID'];
};
export declare type FanGroupUserFilterInput = {
    id?: Maybe<FilterIdInput>;
    userId?: Maybe<FilterIdInput>;
    fanGroupId?: Maybe<FilterIdInput>;
    status?: Maybe<FanGroupUserStatusEnum>;
    role?: Maybe<FanGroupUserRoleEnum>;
    activatedAt?: Maybe<FilterDateInput>;
    blockedAt?: Maybe<FilterDateInput>;
    canceledAt?: Maybe<FilterDateInput>;
    createdAt?: Maybe<FilterDateInput>;
    leftAt?: Maybe<FilterDateInput>;
    rejectedAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    displayName?: Maybe<FilterTextInput>;
};
export declare type FanGroupUserResolver = {
    __typename?: 'FanGroupUserResolver';
    fanGroupUsers: Array<FanGroupUser>;
    total: Scalars['Int'];
};
export declare enum FanGroupUserRoleEnum {
    Member = "member",
    Admin = "admin",
    Owner = "owner"
}
export declare type FanGroupUserSortInput = {
    id?: Maybe<SortEnum>;
    userId?: Maybe<SortEnum>;
    fanGroupId?: Maybe<SortEnum>;
    status?: Maybe<SortEnum>;
    role?: Maybe<SortEnum>;
    leftAt?: Maybe<SortEnum>;
    activatedAt?: Maybe<SortEnum>;
    blockedAt?: Maybe<SortEnum>;
    canceledAt?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    rejectedAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
};
export declare enum FanGroupUserStatusEnum {
    Pending = "pending",
    Active = "active",
    Rejected = "rejected",
    Canceled = "canceled",
    Left = "left",
    Blocked = "blocked"
}
export declare enum FanGroupVisibilityTypeEnum {
    PubliclyVisible = "publicly_visible",
    PrivatelyVisible = "privately_visible"
}
export declare enum FanVaultEnum {
    Weekly = "weekly",
    Monthly = "monthly",
    Yearly = "yearly"
}
export declare enum FanVaultTypeEnum {
    Weekly = "weekly",
    Monthly = "monthly",
    Yearly = "yearly"
}
export declare type FeedPin = {
    __typename?: 'FeedPin';
    createdAt: Scalars['ISO8601DateTime'];
    id: Scalars['ID'];
    isActive?: Maybe<Scalars['Boolean']>;
    pinnableId: Scalars['ID'];
    pinnableTitle: Scalars['String'];
    pinnableType: PinnableTypeEnum;
    updatedAt: Scalars['ISO8601DateTime'];
};
export declare type FilterDate = {
    __typename?: 'FilterDate';
    from?: Maybe<Scalars['String']>;
    isNotNull?: Maybe<Scalars['Boolean']>;
    isNull?: Maybe<Scalars['Boolean']>;
    until?: Maybe<Scalars['String']>;
};
export declare type FilterDateInput = {
    /** date from */
    from?: Maybe<Scalars['String']>;
    /** date until */
    until?: Maybe<Scalars['String']>;
    /** is null */
    isNull?: Maybe<Scalars['Boolean']>;
    /** is not null */
    isNotNull?: Maybe<Scalars['Boolean']>;
};
export declare type FilterForeignKeyInput = {
    /** equals */
    eq?: Maybe<Scalars['Int']>;
    /** is null */
    isNull?: Maybe<Scalars['Boolean']>;
    /** is not null */
    isNotNull?: Maybe<Scalars['Boolean']>;
};
export declare type FilterId = {
    __typename?: 'FilterId';
    eq?: Maybe<Scalars['ID']>;
    gt?: Maybe<Scalars['ID']>;
    in?: Maybe<Array<Scalars['ID']>>;
    isNotNull?: Maybe<Scalars['Boolean']>;
    isNull?: Maybe<Scalars['Boolean']>;
    lt?: Maybe<Scalars['ID']>;
    notEq?: Maybe<Scalars['ID']>;
    notIn?: Maybe<Array<Scalars['ID']>>;
};
export declare type FilterIdInput = {
    /** equals */
    eq?: Maybe<Scalars['ID']>;
    /** grater than */
    gt?: Maybe<Scalars['ID']>;
    /** lower than */
    lt?: Maybe<Scalars['ID']>;
    /** not equals */
    notEq?: Maybe<Scalars['ID']>;
    /** is null */
    isNull?: Maybe<Scalars['Boolean']>;
    /** is not null */
    isNotNull?: Maybe<Scalars['Boolean']>;
    /** is in array */
    in?: Maybe<Array<Scalars['ID']>>;
    /** is not in array */
    notIn?: Maybe<Array<Scalars['ID']>>;
};
export declare type FilterNumber = {
    __typename?: 'FilterNumber';
    eq?: Maybe<Scalars['Int']>;
    gt?: Maybe<Scalars['Int']>;
    in?: Maybe<Array<Scalars['ID']>>;
    isNotNull?: Maybe<Scalars['Boolean']>;
    isNull?: Maybe<Scalars['Boolean']>;
    lt?: Maybe<Scalars['Int']>;
    notEq?: Maybe<Scalars['Int']>;
    notIn?: Maybe<Array<Scalars['ID']>>;
};
export declare type FilterNumberInput = {
    /** equals */
    eq?: Maybe<Scalars['Int']>;
    /** grater than */
    gt?: Maybe<Scalars['Int']>;
    /** lower than */
    lt?: Maybe<Scalars['Int']>;
    /** not equals */
    notEq?: Maybe<Scalars['Int']>;
    /** is null */
    isNull?: Maybe<Scalars['Boolean']>;
    /** is not null */
    isNotNull?: Maybe<Scalars['Boolean']>;
    /** is in array */
    in?: Maybe<Array<Scalars['Int']>>;
    /** is not in array */
    notIn?: Maybe<Array<Scalars['Int']>>;
};
export declare type FilterText = {
    __typename?: 'FilterText';
    eq?: Maybe<Scalars['String']>;
    ilike?: Maybe<Scalars['String']>;
    isNotNull?: Maybe<Scalars['Boolean']>;
    isNull?: Maybe<Scalars['Boolean']>;
    like?: Maybe<Scalars['String']>;
    notIlike?: Maybe<Scalars['String']>;
    notLike?: Maybe<Scalars['String']>;
};
export declare type FilterTextInput = {
    /** equals */
    eq?: Maybe<Scalars['String']>;
    /** ilike */
    ilike?: Maybe<Scalars['String']>;
    /** like */
    like?: Maybe<Scalars['String']>;
    /** not like */
    notLike?: Maybe<Scalars['String']>;
    /** not ilike */
    notIlike?: Maybe<Scalars['String']>;
    /** is null */
    isNull?: Maybe<Scalars['Boolean']>;
    /** is not null */
    isNotNull?: Maybe<Scalars['Boolean']>;
    /** in */
    in?: Maybe<Array<Scalars['String']>>;
};
export declare type FreeTokenTrigger = {
    __typename?: 'FreeTokenTrigger';
    activeFrom: Scalars['ISO8601DateTime'];
    activeUntil?: Maybe<Scalars['ISO8601DateTime']>;
    allowNonSponsoredDialog?: Maybe<Scalars['Boolean']>;
    createdAt: Scalars['ISO8601DateTime'];
    event?: Maybe<Scalars['String']>;
    expires?: Maybe<Scalars['Boolean']>;
    heroMedium?: Maybe<ContentMedium>;
    heroMediumId?: Maybe<Scalars['ID']>;
    id: Scalars['ID'];
    mandatory?: Maybe<Scalars['Boolean']>;
    maxTimesTriggered?: Maybe<Scalars['Int']>;
    maxTokenAmount?: Maybe<Scalars['Int']>;
    promptDialog?: Maybe<Scalars['Boolean']>;
    spentTokensThreshold?: Maybe<Scalars['Int']>;
    sponsor?: Maybe<Sponsor>;
    sponsorId?: Maybe<Scalars['ID']>;
    statistics?: Maybe<FreeTokenTriggerStats>;
    status: FreeTokenTriggerStatusEnum;
    tokenAmount?: Maybe<Scalars['Int']>;
    translations: Array<FreeTokenTriggerTranslation>;
    triggerableIds?: Maybe<Array<Scalars['ID']>>;
    updatedAt: Scalars['ISO8601DateTime'];
    userLimitNumber?: Maybe<Scalars['Int']>;
    userLimitPeriod: FreeTokenTriggerUserLimitPeriodEnum;
};
export declare type FreeTokenTriggerFilterInput = {
    id?: Maybe<FilterIdInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    activeFrom?: Maybe<FilterDateInput>;
    activeUntil?: Maybe<FilterDateInput>;
    event?: Maybe<Scalars['String']>;
    tokenAmount?: Maybe<FilterNumberInput>;
    spentTokensThreshold?: Maybe<FilterNumberInput>;
    maxTokenAmount?: Maybe<FilterNumberInput>;
    maxTimesTriggered?: Maybe<FilterNumberInput>;
    promptDialog?: Maybe<Scalars['Boolean']>;
    expires?: Maybe<Scalars['Boolean']>;
    mandatory?: Maybe<Scalars['Boolean']>;
    allowNonSponsoredDialog?: Maybe<Scalars['Boolean']>;
    status?: Maybe<FreeTokenTriggerStatusEnum>;
    sponsorId?: Maybe<FilterNumberInput>;
    sponsorTitle?: Maybe<FilterTextInput>;
    sponsorMessage?: Maybe<FilterTextInput>;
    sponsorDialog?: Maybe<FilterTextInput>;
    externalLink?: Maybe<FilterTextInput>;
};
export declare type FreeTokenTriggerInput = {
    activeFrom?: Maybe<Scalars['ISO8601DateTime']>;
    activeUntil?: Maybe<Scalars['ISO8601DateTime']>;
    event?: Maybe<Scalars['String']>;
    tokenAmount?: Maybe<Scalars['Int']>;
    spentTokensThreshold?: Maybe<Scalars['Int']>;
    userLimitPeriod?: Maybe<FreeTokenTriggerUserLimitPeriodEnum>;
    userLimitNumber?: Maybe<Scalars['Int']>;
    maxTokenAmount?: Maybe<Scalars['Int']>;
    maxTimesTriggered?: Maybe<Scalars['Int']>;
    promptDialog?: Maybe<Scalars['Boolean']>;
    triggerableIds?: Maybe<Array<Scalars['ID']>>;
    expires?: Maybe<Scalars['Boolean']>;
    mandatory?: Maybe<Scalars['Boolean']>;
    allowNonSponsoredDialog?: Maybe<Scalars['Boolean']>;
    translations?: Maybe<Array<FreeTokenTriggerTranslationInput>>;
    heroMediumId?: Maybe<Scalars['ID']>;
    sponsorId?: Maybe<Scalars['ID']>;
};
export declare type FreeTokenTriggerResolver = {
    __typename?: 'FreeTokenTriggerResolver';
    freeTokenTriggers: Array<FreeTokenTrigger>;
    total: Scalars['Int'];
};
export declare type FreeTokenTriggerSortInput = {
    id?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    activeFrom?: Maybe<SortEnum>;
    activeUntil?: Maybe<SortEnum>;
    event?: Maybe<SortEnum>;
    tokenAmount?: Maybe<SortEnum>;
    promptDialog?: Maybe<SortEnum>;
    expires?: Maybe<SortEnum>;
    status?: Maybe<SortEnum>;
    sponsorTitle?: Maybe<LocalizedSorterInput>;
    sponsorMessage?: Maybe<LocalizedSorterInput>;
    sponsorDialog?: Maybe<LocalizedSorterInput>;
    externalLink?: Maybe<LocalizedSorterInput>;
};
export declare type FreeTokenTriggerStats = {
    __typename?: 'FreeTokenTriggerStats';
    active?: Maybe<Scalars['Boolean']>;
    amount?: Maybe<Scalars['Int']>;
    countTrigger?: Maybe<Scalars['Boolean']>;
    event?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    numberOfUsers?: Maybe<Scalars['Int']>;
    times?: Maybe<Scalars['Int']>;
    userIds?: Maybe<Array<Scalars['Int']>>;
};
export declare enum FreeTokenTriggerStatusEnum {
    Draft = "draft",
    Published = "published",
    Archived = "archived"
}
export declare type FreeTokenTriggerTranslation = {
    __typename?: 'FreeTokenTriggerTranslation';
    ctaText?: Maybe<Scalars['String']>;
    externalLink?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    locale: Scalars['String'];
    sponsorDialog?: Maybe<Scalars['String']>;
    sponsorMessage?: Maybe<Scalars['String']>;
    sponsorTitle: Scalars['String'];
};
export declare type FreeTokenTriggerTranslationInput = {
    id?: Maybe<Scalars['ID']>;
    locale?: Maybe<Scalars['String']>;
    sponsorTitle?: Maybe<Scalars['String']>;
    sponsorMessage?: Maybe<Scalars['String']>;
    sponsorDialog?: Maybe<Scalars['String']>;
    externalLink?: Maybe<Scalars['String']>;
    ctaText?: Maybe<Scalars['String']>;
};
export declare enum FreeTokenTriggerUserLimitPeriodEnum {
    NoLimit = "no_limit",
    ByHour = "by_hour",
    ByDay = "by_day",
    ByMonth = "by_month",
    ByLifeTime = "by_life_time"
}
/** Autogenerated input type of FundFanVaultsMutation */
export declare type FundFanVaultsMutationInput = {
    fanVault: FanVaultTypeEnum;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of FundFanVaultsMutation */
export declare type FundFanVaultsMutationPayload = {
    __typename?: 'FundFanVaultsMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    message: Scalars['String'];
    status: Scalars['Int'];
};
/** Autogenerated input type of GetMediaUploadUrlMutation */
export declare type GetMediaUploadUrlMutationInput = {
    fileName: Scalars['String'];
    fileExt: Scalars['String'];
    mediumId?: Maybe<Scalars['ID']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of GetMediaUploadUrlMutation */
export declare type GetMediaUploadUrlMutationPayload = {
    __typename?: 'GetMediaUploadUrlMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    url: Scalars['String'];
};
export declare type Giveaway = {
    __typename?: 'Giveaway';
    active?: Maybe<Scalars['Boolean']>;
    activeAndPublishedNft: Scalars['Boolean'];
    activeFrom: Scalars['ISO8601DateTime'];
    activeUntil?: Maybe<Scalars['ISO8601DateTime']>;
    amount?: Maybe<Scalars['Int']>;
    countTrigger?: Maybe<Scalars['Boolean']>;
    createdAt: Scalars['ISO8601DateTime'];
    dropRate?: Maybe<Scalars['Float']>;
    events?: Maybe<Array<Scalars['String']>>;
    expires?: Maybe<Scalars['Boolean']>;
    forceGiveaway?: Maybe<Scalars['Boolean']>;
    giveawayEventIds: Array<Scalars['ID']>;
    giveawayEvents: Array<GiveawayEvent>;
    giveawayType: GiveawayTypeEnum;
    heroMedium?: Maybe<ContentMedium>;
    heroMediumId?: Maybe<Scalars['ID']>;
    id: Scalars['ID'];
    intervalOptions?: Maybe<GiveawayIntervalOptions>;
    intervalType: GiveawayIntervalTypeEnum;
    mandatory?: Maybe<Scalars['Boolean']>;
    maxTimesTriggered?: Maybe<Scalars['Int']>;
    maxTokenAmount?: Maybe<Scalars['Int']>;
    nftIds: Array<Scalars['ID']>;
    nftStatistics?: Maybe<GiveawayStats>;
    nfts: Array<Nft>;
    numberOfUsers?: Maybe<Scalars['Int']>;
    promptDialog?: Maybe<Scalars['Boolean']>;
    skipNotification?: Maybe<Scalars['Boolean']>;
    sponsor?: Maybe<Sponsor>;
    sponsorId?: Maybe<Scalars['ID']>;
    statistics?: Maybe<GiveawayStats>;
    status: GiveawayStatusEnum;
    times?: Maybe<Scalars['Int']>;
    tokenAmount?: Maybe<Scalars['Int']>;
    tokenStatistics?: Maybe<GiveawayStats>;
    translations: Array<GiveawayTranslation>;
    updatedAt: Scalars['ISO8601DateTime'];
    userIds: Array<Scalars['ID']>;
    userLimitNumber?: Maybe<Scalars['Int']>;
    userLimitPeriod?: Maybe<GiveawayUserLimitPeriodEnum>;
    users: Array<User>;
    wasActive?: Maybe<Scalars['Boolean']>;
};
export declare type GiveawayEvent = {
    __typename?: 'GiveawayEvent';
    apiUuid?: Maybe<Scalars['String']>;
    availableFor: GiveawayEventAvailableForEnum;
    createdAt: Scalars['ISO8601DateTime'];
    eventType: TriggerEventTypeEnum;
    giveaway?: Maybe<Giveaway>;
    giveawayEventResources: Array<GiveawayEventResource>;
    giveawayId?: Maybe<Scalars['ID']>;
    id: Scalars['ID'];
    isActive?: Maybe<Scalars['Boolean']>;
    nfcUuid?: Maybe<Scalars['String']>;
    qrCodeUuid?: Maybe<Scalars['String']>;
    spentTokensThreshold?: Maybe<Scalars['Int']>;
    updatedAt: Scalars['ISO8601DateTime'];
};
export declare enum GiveawayEventAvailableForEnum {
    AllResources = "all_resources",
    SelectedResources = "selected_resources"
}
export declare type GiveawayEventInput = {
    id?: Maybe<Scalars['ID']>;
    eventType?: Maybe<TriggerEventTypeEnum>;
    giveawayEventResources?: Maybe<Array<GiveawayEventResourceInput>>;
    spentTokensThreshold?: Maybe<Scalars['Int']>;
    isActive?: Maybe<Scalars['Boolean']>;
    _destroy?: Maybe<Scalars['Boolean']>;
};
export declare type GiveawayEventResource = {
    __typename?: 'GiveawayEventResource';
    createdAt: Scalars['ISO8601DateTime'];
    giveawayEventId?: Maybe<Scalars['ID']>;
    id: Scalars['ID'];
    triggerableId: Scalars['ID'];
    triggerableType: GiveawayEventResourceTypeEnum;
    updatedAt: Scalars['ISO8601DateTime'];
};
export declare type GiveawayEventResourceInput = {
    id?: Maybe<Scalars['ID']>;
    triggerableType?: Maybe<GiveawayEventResourceTypeEnum>;
    triggerableId?: Maybe<Scalars['ID']>;
    _destroy?: Maybe<Scalars['Boolean']>;
};
export declare enum GiveawayEventResourceTypeEnum {
    Content = "Content",
    Voting = "Voting",
    AmaSession = "AmaSession",
    IdeationMission = "IdeationMission",
    Comment = "Comment",
    Proposal = "Proposal",
    FanGroup = "FanGroup",
    ShopProduct = "ShopProduct",
    Nft = "Nft",
    NftCollection = "NftCollection"
}
export declare type GiveawayFilterInput = {
    id?: Maybe<FilterIdInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    activeFrom?: Maybe<FilterDateInput>;
    activeUntil?: Maybe<FilterDateInput>;
    giveawayType?: Maybe<GiveawayTypeEnum>;
    intervalType?: Maybe<GiveawayIntervalTypeEnum>;
    status?: Maybe<GiveawayStatusEnum>;
    expires?: Maybe<Scalars['Boolean']>;
    mandatory?: Maybe<Scalars['Boolean']>;
    tokenAmount?: Maybe<FilterNumberInput>;
    maxTokenAmount?: Maybe<FilterNumberInput>;
    maxTimesTriggered?: Maybe<FilterNumberInput>;
    forceGiveaway?: Maybe<Scalars['Boolean']>;
    dropRate?: Maybe<FilterNumberInput>;
    sponsorId?: Maybe<FilterNumberInput>;
    onlyActiveAndPublishedNft?: Maybe<Scalars['Boolean']>;
    title?: Maybe<FilterTextInput>;
    message?: Maybe<FilterTextInput>;
    content?: Maybe<FilterTextInput>;
    events?: Maybe<Scalars['String']>;
};
export declare type GiveawayInput = {
    activeFrom?: Maybe<Scalars['ISO8601DateTime']>;
    activeUntil?: Maybe<Scalars['ISO8601DateTime']>;
    giveawayType?: Maybe<GiveawayTypeEnum>;
    intervalType?: Maybe<GiveawayIntervalTypeEnum>;
    intervalOptions?: Maybe<GiveawayIntervalOptionsInput>;
    expires?: Maybe<Scalars['Boolean']>;
    tokenAmount?: Maybe<Scalars['Int']>;
    maxTokenAmount?: Maybe<Scalars['Int']>;
    maxTimesTriggered?: Maybe<Scalars['Int']>;
    forceGiveaway?: Maybe<Scalars['Boolean']>;
    giveawayEvents?: Maybe<Array<GiveawayEventInput>>;
    userLimitPeriod?: Maybe<GiveawayUserLimitPeriodEnum>;
    userLimitNumber?: Maybe<Scalars['Int']>;
    dropRate?: Maybe<Scalars['Float']>;
    sponsorId?: Maybe<Scalars['ID']>;
    promptDialog?: Maybe<Scalars['Boolean']>;
    nftIds?: Maybe<Array<Scalars['ID']>>;
    translations?: Maybe<Array<GiveawayTranslationInput>>;
    heroMediumId?: Maybe<Scalars['ID']>;
    skipNotification?: Maybe<Scalars['Boolean']>;
};
export declare type GiveawayIntervalOptions = {
    __typename?: 'GiveawayIntervalOptions';
    monthly?: Maybe<GiveawayMonthlyInterval>;
    weekly?: Maybe<GiveawayWeeklyInterval>;
};
export declare type GiveawayIntervalOptionsInput = {
    weekly?: Maybe<GiveawayWeeklyIntervalInput>;
    monthly?: Maybe<GiveawayMonthlyIntervalInput>;
};
export declare enum GiveawayIntervalTypeEnum {
    NoInterval = "no_interval",
    Weekly = "weekly",
    Monthly = "monthly"
}
export declare type GiveawayMonthlyInterval = {
    __typename?: 'GiveawayMonthlyInterval';
    april?: Maybe<Scalars['Boolean']>;
    august?: Maybe<Scalars['Boolean']>;
    december?: Maybe<Scalars['Boolean']>;
    february?: Maybe<Scalars['Boolean']>;
    january?: Maybe<Scalars['Boolean']>;
    july?: Maybe<Scalars['Boolean']>;
    june?: Maybe<Scalars['Boolean']>;
    march?: Maybe<Scalars['Boolean']>;
    may?: Maybe<Scalars['Boolean']>;
    november?: Maybe<Scalars['Boolean']>;
    october?: Maybe<Scalars['Boolean']>;
    september?: Maybe<Scalars['Boolean']>;
};
export declare type GiveawayMonthlyIntervalInput = {
    january?: Maybe<Scalars['Boolean']>;
    february?: Maybe<Scalars['Boolean']>;
    march?: Maybe<Scalars['Boolean']>;
    april?: Maybe<Scalars['Boolean']>;
    may?: Maybe<Scalars['Boolean']>;
    june?: Maybe<Scalars['Boolean']>;
    july?: Maybe<Scalars['Boolean']>;
    august?: Maybe<Scalars['Boolean']>;
    september?: Maybe<Scalars['Boolean']>;
    october?: Maybe<Scalars['Boolean']>;
    november?: Maybe<Scalars['Boolean']>;
    december?: Maybe<Scalars['Boolean']>;
};
export declare type GiveawayResolver = {
    __typename?: 'GiveawayResolver';
    giveaways: Array<Giveaway>;
    total: Scalars['Int'];
};
export declare type GiveawaySortInput = {
    id?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    activeFrom?: Maybe<SortEnum>;
    activeUntil?: Maybe<SortEnum>;
    status?: Maybe<SortEnumWithDefault>;
    intervalType?: Maybe<SortEnumWithDefault>;
    expires?: Maybe<SortEnum>;
    giveawayType?: Maybe<SortEnum>;
    sponsorId?: Maybe<SortEnum>;
    promptDialog?: Maybe<SortEnum>;
    dropRate?: Maybe<SortEnum>;
    title?: Maybe<LocalizedSorterInput>;
    message?: Maybe<LocalizedSorterInput>;
    content?: Maybe<LocalizedSorterInput>;
};
export declare type GiveawayStats = {
    __typename?: 'GiveawayStats';
    active?: Maybe<Scalars['Boolean']>;
    amount?: Maybe<Scalars['Int']>;
    countTrigger?: Maybe<Scalars['Boolean']>;
    events?: Maybe<Array<Scalars['String']>>;
    numberOfUsers?: Maybe<Scalars['Int']>;
    times?: Maybe<Scalars['Int']>;
    wasActive?: Maybe<Scalars['Boolean']>;
};
export declare enum GiveawayStatusEnum {
    Draft = "draft",
    Scheduled = "scheduled",
    Deploying = "deploying",
    Published = "published",
    Paused = "paused",
    Archived = "archived"
}
export declare type GiveawayTranslation = {
    __typename?: 'GiveawayTranslation';
    content?: Maybe<Scalars['String']>;
    ctaText?: Maybe<Scalars['String']>;
    externalLink?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    locale: Scalars['String'];
    message: Scalars['String'];
    title: Scalars['String'];
};
export declare type GiveawayTranslationInput = {
    id?: Maybe<Scalars['ID']>;
    locale?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
    message?: Maybe<Scalars['String']>;
    content?: Maybe<Scalars['String']>;
    externalLink?: Maybe<Scalars['String']>;
    ctaText?: Maybe<Scalars['String']>;
};
export declare enum GiveawayTypeEnum {
    Token = "token",
    Nft = "nft"
}
export declare enum GiveawayUserLimitPeriodEnum {
    NoLimit = "no_limit",
    ByHour = "by_hour",
    ByDay = "by_day",
    ByMonth = "by_month",
    ByLifeTime = "by_life_time"
}
export declare type GiveawayWeeklyInterval = {
    __typename?: 'GiveawayWeeklyInterval';
    friday?: Maybe<Scalars['Boolean']>;
    monday?: Maybe<Scalars['Boolean']>;
    saturday?: Maybe<Scalars['Boolean']>;
    sunday?: Maybe<Scalars['Boolean']>;
    thursday?: Maybe<Scalars['Boolean']>;
    tuesday?: Maybe<Scalars['Boolean']>;
    wednesday?: Maybe<Scalars['Boolean']>;
};
export declare type GiveawayWeeklyIntervalInput = {
    monday?: Maybe<Scalars['Boolean']>;
    tuesday?: Maybe<Scalars['Boolean']>;
    wednesday?: Maybe<Scalars['Boolean']>;
    thursday?: Maybe<Scalars['Boolean']>;
    friday?: Maybe<Scalars['Boolean']>;
    saturday?: Maybe<Scalars['Boolean']>;
    sunday?: Maybe<Scalars['Boolean']>;
};
export declare type GroupPost = {
    __typename?: 'GroupPost';
    audits: Array<Audit>;
    boostsAmountCache?: Maybe<Scalars['Int']>;
    comments: Array<Comment>;
    commentsCount?: Maybe<Scalars['Int']>;
    content?: Maybe<Scalars['String']>;
    contractAddress?: Maybe<Scalars['String']>;
    createdAt: Scalars['ISO8601DateTime'];
    creatorShare?: Maybe<Scalars['Int']>;
    fanGroup: FanGroup;
    fanGroupId: Scalars['ID'];
    fanvaultShare?: Maybe<Scalars['Int']>;
    id: Scalars['ID'];
    nfts: Array<Nft>;
    operatorAddress?: Maybe<Scalars['String']>;
    operatorShare?: Maybe<Scalars['Int']>;
    previewUrl?: Maybe<Scalars['String']>;
    reportStatus: ReportableStatusEnum;
    title: Scalars['String'];
    ugcReportTypes?: Maybe<Array<UgcReportTyp>>;
    ugcReports: Array<UgcReport>;
    ugcReportsCount: Scalars['Int'];
    updatedAt: Scalars['ISO8601DateTime'];
    user: User;
    userId: Scalars['ID'];
};
export declare type GroupPostFilterInput = {
    id?: Maybe<FilterIdInput>;
    title?: Maybe<FilterTextInput>;
    content?: Maybe<FilterTextInput>;
    userId?: Maybe<FilterIdInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    contractAddress?: Maybe<FilterTextInput>;
    operatorAddress?: Maybe<FilterTextInput>;
    boostsAmountCache?: Maybe<FilterNumberInput>;
    commentsCount?: Maybe<FilterNumberInput>;
    fanGroupId?: Maybe<FilterIdInput>;
    ugcReportsCount?: Maybe<FilterNumberInput>;
    reportStatus?: Maybe<ReportableStatusEnum>;
    withReportStatus?: Maybe<Scalars['Boolean']>;
};
export declare type GroupPostInput = {
    reportStatus?: Maybe<ReportableStatusEnum>;
    ugcReportTypes?: Maybe<Array<Scalars['Int']>>;
};
export declare type GroupPostResolver = {
    __typename?: 'GroupPostResolver';
    groupPosts: Array<GroupPost>;
    total: Scalars['Int'];
};
export declare type GroupPostSortInput = {
    id?: Maybe<SortEnum>;
    title?: Maybe<SortEnum>;
    content?: Maybe<SortEnum>;
    userId?: Maybe<SortEnum>;
    clubAcceptanceStatus?: Maybe<SortEnum>;
    fanGroupId?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    commentsCount?: Maybe<SortEnum>;
    boostsAmountCache?: Maybe<SortEnum>;
    contractAddress?: Maybe<SortEnum>;
    operatorAddress?: Maybe<SortEnum>;
    ugcReportsCount?: Maybe<SortEnum>;
    reportStatus?: Maybe<SortEnumWithDefault>;
};
export declare type Idea = {
    __typename?: 'Idea';
    audits: Array<Audit>;
    boostsAmountCache?: Maybe<Scalars['Int']>;
    comments: Array<Comment>;
    commentsCount?: Maybe<Scalars['Int']>;
    content?: Maybe<Scalars['String']>;
    createdAt: Scalars['ISO8601DateTime'];
    customTag1?: Maybe<Scalars['Boolean']>;
    customTag2?: Maybe<Scalars['Boolean']>;
    customTag3?: Maybe<Scalars['Boolean']>;
    customTag4?: Maybe<Scalars['Boolean']>;
    customTag5?: Maybe<Scalars['Boolean']>;
    id: Scalars['ID'];
    ideationMission: IdeationMission;
    ideationMissionId: Scalars['ID'];
    isClubFav?: Maybe<Scalars['Boolean']>;
    isImplemented?: Maybe<Scalars['Boolean']>;
    isSelected?: Maybe<Scalars['Boolean']>;
    nfts: Array<Nft>;
    previewUrl?: Maybe<Scalars['String']>;
    reportStatus: ReportableStatusEnum;
    title: Scalars['String'];
    ugcReportTypes?: Maybe<Array<UgcReportTyp>>;
    ugcReports: Array<UgcReport>;
    ugcReportsCount: Scalars['Int'];
    updatedAt: Scalars['ISO8601DateTime'];
    user: User;
    userId: Scalars['ID'];
};
export declare type IdeaFilterInput = {
    id?: Maybe<FilterIdInput>;
    title?: Maybe<FilterTextInput>;
    content?: Maybe<FilterTextInput>;
    userId?: Maybe<FilterNumberInput>;
    ideationMissionId?: Maybe<FilterNumberInput>;
    commentsCount?: Maybe<FilterNumberInput>;
    boostsAmountCache?: Maybe<FilterNumberInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    isClubFav?: Maybe<Scalars['Boolean']>;
    isSelected?: Maybe<Scalars['Boolean']>;
    isImplemented?: Maybe<Scalars['Boolean']>;
    customTag1?: Maybe<Scalars['Boolean']>;
    customTag2?: Maybe<Scalars['Boolean']>;
    customTag3?: Maybe<Scalars['Boolean']>;
    customTag4?: Maybe<Scalars['Boolean']>;
    customTag5?: Maybe<Scalars['Boolean']>;
    withReportStatus?: Maybe<Scalars['Boolean']>;
    ugcReportsCount?: Maybe<FilterNumberInput>;
    reportStatus?: Maybe<ReportableStatusEnum>;
};
export declare type IdeaInput = {
    id?: Maybe<Scalars['ID']>;
    isClubFav?: Maybe<Scalars['Boolean']>;
    isSelected?: Maybe<Scalars['Boolean']>;
    isImplemented?: Maybe<Scalars['Boolean']>;
    customTag1?: Maybe<Scalars['Boolean']>;
    customTag2?: Maybe<Scalars['Boolean']>;
    customTag3?: Maybe<Scalars['Boolean']>;
    customTag4?: Maybe<Scalars['Boolean']>;
    customTag5?: Maybe<Scalars['Boolean']>;
    reportStatus?: Maybe<ReportableStatusEnum>;
    ugcReportTypes?: Maybe<Array<Scalars['Int']>>;
};
export declare type IdeaResolver = {
    __typename?: 'IdeaResolver';
    ideas: Array<Idea>;
    total: Scalars['Int'];
};
export declare type IdeaSortInput = {
    id?: Maybe<SortEnum>;
    title?: Maybe<SortEnum>;
    content?: Maybe<SortEnum>;
    userId?: Maybe<SortEnum>;
    commentsCount?: Maybe<SortEnum>;
    boostsAmountCache?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    isClubFav?: Maybe<SortEnum>;
    isSelected?: Maybe<SortEnum>;
    isImplemented?: Maybe<SortEnum>;
    customTag1?: Maybe<SortEnum>;
    customTag2?: Maybe<SortEnum>;
    customTag3?: Maybe<SortEnum>;
    customTag4?: Maybe<SortEnum>;
    customTag5?: Maybe<SortEnum>;
    ugcReportsCount?: Maybe<SortEnum>;
    reportStatus?: Maybe<SortEnumWithDefault>;
};
export declare type IdeationMission = {
    __typename?: 'IdeationMission';
    announcements: Array<Announcement>;
    availabilities?: Maybe<Array<Availability>>;
    availabilityType: AvailabilityTypeEnum;
    availableFors: Array<Scalars['String']>;
    contractAddress?: Maybe<Scalars['String']>;
    createdAt: Scalars['ISO8601DateTime'];
    creatorShare?: Maybe<Scalars['Int']>;
    distributedAt?: Maybe<Scalars['ISO8601DateTime']>;
    endsAt: Scalars['ISO8601DateTime'];
    fanvaultShare?: Maybe<Scalars['Int']>;
    heroMedium?: Maybe<ContentMedium>;
    heroMediumId?: Maybe<Scalars['ID']>;
    id: Scalars['ID'];
    ideas: Array<Idea>;
    ideasBoostAmounts?: Maybe<Scalars['Int']>;
    ideasCount?: Maybe<Scalars['Int']>;
    onlyForAvailables?: Maybe<Scalars['Boolean']>;
    operatorShare?: Maybe<Scalars['Int']>;
    pinToTop: Scalars['Boolean'];
    previewToken?: Maybe<Scalars['String']>;
    previewUrl?: Maybe<Scalars['String']>;
    previewUrls: Array<PreviewUrl>;
    publishedAt?: Maybe<Scalars['ISO8601DateTime']>;
    requiredNfts?: Maybe<Array<Nft>>;
    requiredSubscriptions?: Maybe<Array<ShopProduct>>;
    status: IdeationMissionStatusEnum;
    translations: Array<IdeationMissionTranslation>;
    updatedAt: Scalars['ISO8601DateTime'];
    willBePinned: Scalars['Boolean'];
};
export declare type IdeationMissionFilterInput = {
    id?: Maybe<FilterIdInput>;
    status?: Maybe<IdeationMissionStatusEnum>;
    endsAt?: Maybe<FilterDateInput>;
    ideasCount?: Maybe<FilterNumberInput>;
    contractAddress?: Maybe<FilterTextInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    distributedAt?: Maybe<FilterDateInput>;
    title?: Maybe<FilterTextInput>;
    description?: Maybe<FilterTextInput>;
    slug?: Maybe<FilterTextInput>;
    preview?: Maybe<FilterTextInput>;
    publishedAt?: Maybe<FilterDateInput>;
    availableFor?: Maybe<Array<AvailabilityAvailableForEnum>>;
    onlyForAvailables?: Maybe<Scalars['Boolean']>;
    availabilityType?: Maybe<AvailabilityTypeEnum>;
};
export declare type IdeationMissionInput = {
    endsAt?: Maybe<Scalars['ISO8601DateTime']>;
    heroMediumId?: Maybe<Scalars['ID']>;
    translations?: Maybe<Array<IdeationMissionTranslationInput>>;
    publishedAt?: Maybe<Scalars['ISO8601DateTime']>;
    availabilities?: Maybe<Array<AvailabilityInput>>;
    onlyForAvailables?: Maybe<Scalars['Boolean']>;
    availabilityType?: Maybe<AvailabilityTypeEnum>;
    pinToTop?: Maybe<Scalars['Boolean']>;
};
export declare type IdeationMissionResolver = {
    __typename?: 'IdeationMissionResolver';
    ideationMissions: Array<IdeationMission>;
    total: Scalars['Int'];
};
export declare type IdeationMissionSortInput = {
    id?: Maybe<SortEnum>;
    status?: Maybe<SortEnumWithDefault>;
    endsAt?: Maybe<SortEnum>;
    ideasCount?: Maybe<SortEnum>;
    contractAddress?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    title?: Maybe<LocalizedSorterInput>;
    description?: Maybe<LocalizedSorterInput>;
    slug?: Maybe<LocalizedSorterInput>;
    preview?: Maybe<LocalizedSorterInput>;
    publishedAt?: Maybe<SortEnum>;
    distributedAt?: Maybe<SortEnum>;
    onlyForAvailables?: Maybe<SortEnum>;
    availabilityType?: Maybe<SortEnum>;
};
export declare enum IdeationMissionStatusEnum {
    Draft = "draft",
    Scheduled = "scheduled",
    Deploying = "deploying",
    Published = "published",
    Archived = "archived"
}
export declare type IdeationMissionTranslation = {
    __typename?: 'IdeationMissionTranslation';
    description: Scalars['String'];
    id: Scalars['ID'];
    locale: Scalars['String'];
    preview?: Maybe<Scalars['String']>;
    slug: Scalars['String'];
    title: Scalars['String'];
};
export declare type IdeationMissionTranslationInput = {
    id?: Maybe<Scalars['ID']>;
    locale?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
    slug?: Maybe<Scalars['String']>;
    preview?: Maybe<Scalars['String']>;
};
/** Autogenerated input type of InviteUserMutation */
export declare type InviteUserMutationInput = {
    emailAddress: Scalars['String'];
    inviterId: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of InviteUserMutation */
export declare type InviteUserMutationPayload = {
    __typename?: 'InviteUserMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    ok: Scalars['Boolean'];
};
export declare type LocalizedSorterInput = {
    locale: Scalars['String'];
    order: SortEnum;
};
export declare enum MediaAspectRatioEnum {
    NoRatio = "no_ratio",
    SixteenNine = "sixteen_nine",
    NineSixteen = "nine_sixteen",
    OneOne = "one_one",
    FourThree = "four_three"
}
export declare type MenuItem = {
    __typename?: 'MenuItem';
    appName?: Maybe<Scalars['String']>;
    createdAt: Scalars['ISO8601DateTime'];
    heroMedium?: Maybe<ContentMedium>;
    heroMediumId?: Maybe<Scalars['ID']>;
    iconUrl?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    menuItem?: Maybe<MenuItem>;
    menuItemId?: Maybe<Scalars['ID']>;
    menuItems?: Maybe<Array<MenuItem>>;
    menuPosition: MenuPositionMenuTypeEnum;
    menuResource?: Maybe<MenuItemMenuResourceEnum>;
    menuType: MenuItemMenuTypeEnum;
    order: Scalars['Int'];
    staticPage?: Maybe<StaticPage>;
    staticPageId?: Maybe<Scalars['ID']>;
    translations: Array<MenuItemTranslation>;
    updatedAt: Scalars['ISO8601DateTime'];
};
export declare type MenuItemFilterInput = {
    id?: Maybe<FilterIdInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    menuType?: Maybe<MenuItemMenuTypeEnum>;
    menuPosition?: Maybe<MenuPositionMenuTypeEnum>;
    menuResource?: Maybe<MenuItemMenuResourceEnum>;
    order?: Maybe<Scalars['Int']>;
    staticPageId?: Maybe<FilterNumberInput>;
    heroMediumId?: Maybe<FilterNumberInput>;
    menuItemId?: Maybe<FilterNumberInput>;
    iconUrl?: Maybe<Scalars['String']>;
    appName?: Maybe<FilterTextInput>;
    navbarTitle?: Maybe<FilterTextInput>;
    headerTitle?: Maybe<FilterTextInput>;
    externalUrl?: Maybe<FilterTextInput>;
    slug?: Maybe<FilterTextInput>;
};
export declare type MenuItemInput = {
    id?: Maybe<Scalars['ID']>;
    menuType?: Maybe<MenuItemMenuTypeEnum>;
    menuPosition?: Maybe<MenuPositionMenuTypeEnum>;
    menuResource?: Maybe<MenuItemMenuResourceEnum>;
    order?: Maybe<Scalars['Int']>;
    staticPageId?: Maybe<Scalars['ID']>;
    heroMediumId?: Maybe<Scalars['ID']>;
    menuItemId?: Maybe<Scalars['ID']>;
    iconUrl?: Maybe<Scalars['String']>;
    appName?: Maybe<Scalars['String']>;
    translations?: Maybe<Array<MenuItemTranslationInput>>;
};
export declare enum MenuItemMenuResourceEnum {
    Home = "home",
    News = "news",
    Participate = "participate",
    Spaces = "spaces",
    Nfts = "nfts",
    Notifications = "notifications",
    Shop = "shop",
    Wallet = "wallet"
}
export declare enum MenuItemMenuTypeEnum {
    SinglePage = "single_page",
    Collection = "collection",
    Resource = "resource",
    Link = "link",
    AppIntegration = "app_integration",
    Iframe = "iframe"
}
export declare type MenuItemResolver = {
    __typename?: 'MenuItemResolver';
    menuItems: Array<MenuItem>;
    total: Scalars['Int'];
};
export declare type MenuItemTranslation = {
    __typename?: 'MenuItemTranslation';
    externalUrl?: Maybe<Scalars['String']>;
    headerTitle?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    locale: Scalars['String'];
    navbarTitle?: Maybe<Scalars['String']>;
    slug?: Maybe<Scalars['String']>;
};
export declare type MenuItemTranslationInput = {
    id?: Maybe<Scalars['ID']>;
    locale?: Maybe<Scalars['String']>;
    navbarTitle?: Maybe<Scalars['String']>;
    headerTitle?: Maybe<Scalars['String']>;
    externalUrl?: Maybe<Scalars['String']>;
    slug?: Maybe<Scalars['String']>;
};
export declare enum MenuPositionMenuTypeEnum {
    BottomBar = "bottom_bar",
    Sidebar = "sidebar",
    MobileBar = "mobile_bar"
}
/** Autogenerated input type of MintNftCollectionMutation */
export declare type MintNftCollectionMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of MintNftCollectionMutation */
export declare type MintNftCollectionMutationPayload = {
    __typename?: 'MintNftCollectionMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    nftCollection: NftCollection;
};
/** Autogenerated input type of MintNftMutation */
export declare type MintNftMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of MintNftMutation */
export declare type MintNftMutationPayload = {
    __typename?: 'MintNftMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    nft: Nft;
};
export declare type Mutation = {
    __typename?: 'Mutation';
    addNftsToCollection?: Maybe<AddNftsToCollectionMutationPayload>;
    adminUserLogin?: Maybe<AdminUserLoginPayload>;
    archiveAmaSession?: Maybe<ArchiveAmaSessionMutationPayload>;
    archiveContent?: Maybe<ArchiveContentMutationPayload>;
    archiveFreeTokenTrigger?: Maybe<ArchiveFreeTokenTriggerMutationPayload>;
    archiveGiveaway?: Maybe<ArchiveGiveawayMutationPayload>;
    archiveIdeationMission?: Maybe<ArchiveIdeationMissionMutationPayload>;
    archiveNftCollection?: Maybe<ArchiveNftCollectionMutationPayload>;
    archiveNftGiveaway?: Maybe<ArchiveNftGiveawayMutationPayload>;
    archiveProfileField?: Maybe<ArchiveProfileFieldMutationPayload>;
    archiveStaticPage?: Maybe<ArchiveStaticPageMutationPayload>;
    archiveVoting?: Maybe<ArchiveVotingMutationPayload>;
    createActivityPoint?: Maybe<AddActivityPointMutationPayload>;
    createAdminUser?: Maybe<AddAdminUserMutationPayload>;
    createAmaSession?: Maybe<AddAmaSessionMutationPayload>;
    createAnnouncement?: Maybe<AddAnnouncementMutationPayload>;
    createContent?: Maybe<AddContentMutationPayload>;
    createContentCategory?: Maybe<AddContentCategoryMutationPayload>;
    createContentMedium?: Maybe<AddContentMediumMutationPayload>;
    createCustomNotification?: Maybe<AddCustomNotificationMutationPayload>;
    createFreeTokenTrigger?: Maybe<AddFreeTokenTriggerMutationPayload>;
    createGiveaway?: Maybe<AddGiveawayMutationPayload>;
    createIdeationMission?: Maybe<AddIdeationMissionMutationPayload>;
    createMenuItem?: Maybe<AddMenuItemMutationPayload>;
    createNft?: Maybe<AddNftMutationPayload>;
    createNftCollection?: Maybe<AddNftCollectionMutationPayload>;
    createNftCollectionDeployment?: Maybe<AddNftCollectionDeploymentMutationPayload>;
    createNftGiveaway?: Maybe<AddNftGiveawayMutationPayload>;
    createNftHandout?: Maybe<AddNftHandoutMutationPayload>;
    createNftMedium?: Maybe<AddNftMediumMutationPayload>;
    createNftTransferNetwork?: Maybe<AddNftTransferNetworkMutationPayload>;
    createProfileField?: Maybe<AddProfileFieldMutationPayload>;
    createProposalPeriod?: Maybe<AddProposalPeriodMutationPayload>;
    createShopProduct?: Maybe<AddShopProductMutationPayload>;
    createShopProductTier?: Maybe<AddShopProductTierMutationPayload>;
    createSponsor?: Maybe<AddSponsorMutationPayload>;
    createStaticPage?: Maybe<AddStaticPageMutationPayload>;
    createSystemSetting?: Maybe<AddSystemSettingMutationPayload>;
    createTokenHandout?: Maybe<AddTokenHandoutMutationPayload>;
    createUgcReport?: Maybe<AddUgcReportMutationPayload>;
    createUgcReportType?: Maybe<AddUgcReportTypeMutationPayload>;
    createUser?: Maybe<AddUserMutationPayload>;
    createUserOrder?: Maybe<AddUserOrderMutationPayload>;
    createVoting?: Maybe<AddVotingMutationPayload>;
    deleteActivityPoints?: Maybe<DeleteActivityPointsMutationPayload>;
    deleteAdminUser?: Maybe<DeleteAdminUserMutationPayload>;
    deleteAmaSessions?: Maybe<DeleteAmaSessionsMutationPayload>;
    deleteAnnouncements?: Maybe<DeleteAnnouncementsMutationPayload>;
    deleteContentCategories?: Maybe<DeleteContentCategoriesMutationPayload>;
    deleteContentMedia?: Maybe<DeleteContentMediaMutationPayload>;
    deleteContents?: Maybe<DeleteContentsMutationPayload>;
    deleteCustomNotifications?: Maybe<DeleteCustomNotificationsMutationPayload>;
    deleteFreeTokenTriggers?: Maybe<DeleteFreeTokenTriggersMutationPayload>;
    deleteGiveaways?: Maybe<DeleteGiveawaysMutationPayload>;
    deleteIdeationMissions?: Maybe<DeleteIdeationMissionsMutationPayload>;
    deleteMenuItems?: Maybe<DeleteMenuItemsMutationPayload>;
    deleteNftCollections?: Maybe<DeleteNftCollectionsMutationPayload>;
    deleteNftGiveaways?: Maybe<DeleteNftGiveawaysMutationPayload>;
    deleteNftHandouts?: Maybe<DeleteNftHandoutsMutationPayload>;
    deleteNftMedia?: Maybe<DeleteNftMediaMutationPayload>;
    deleteNfts?: Maybe<DeleteNftsMutationPayload>;
    deleteProfileFields?: Maybe<DeleteProfileFieldsMutationPayload>;
    deleteProposalPeriods?: Maybe<DeleteProposalPeriodsMutationPayload>;
    deleteShopProductTiers?: Maybe<DeleteShopProductTiersMutationPayload>;
    deleteShopProducts?: Maybe<DeleteShopProductsMutationPayload>;
    deleteSponsors?: Maybe<DeleteSponsorsMutationPayload>;
    deleteStaticPages?: Maybe<DeleteStaticPagesMutationPayload>;
    deleteSystemSettings?: Maybe<DeleteSystemSettingsMutationPayload>;
    deleteTokenHandouts?: Maybe<DeleteTokenHandoutsMutationPayload>;
    deleteUgcReportTypes?: Maybe<DeleteUgcReportTypesMutationPayload>;
    deleteUgcReports?: Maybe<DeleteUgcReportsMutationPayload>;
    deleteUser?: Maybe<DeleteUserMutationPayload>;
    deleteUserOrders?: Maybe<DeleteUserOrdersMutationPayload>;
    deleteVotings?: Maybe<DeleteVotingsMutationPayload>;
    deployCommentBoosterContract?: Maybe<DeployCommentBoosterMutationPayload>;
    deployContentBoosterContract?: Maybe<DeployContentBoosterMutationPayload>;
    deployContentUnlockerContract?: Maybe<DeployContentUnlockerMutationPayload>;
    deployProposalBoosterContract?: Maybe<DeployProposalBoosterMutationPayload>;
    deployTokenContractMutation?: Maybe<DeployTokenContractMutationPayload>;
    distributeAmaSession?: Maybe<DistributeAmaSessionMutationPayload>;
    distributeCommentBoosterContract?: Maybe<DistributeCommentBoosterMutationPayload>;
    distributeContentBoosterContract?: Maybe<DistributeContentBoosterMutationPayload>;
    distributeContentUnlockerContract?: Maybe<DistributeContentUnlockerMutationPayload>;
    distributeIdeationMission?: Maybe<DistributeIdeationMissionMutationPayload>;
    distributeProposalBoosterContract?: Maybe<DistributeProposalBoosterMutationPayload>;
    distributeVoting?: Maybe<DistributeVotingMutationPayload>;
    draftAmaSession?: Maybe<DraftAmaSessionMutationPayload>;
    draftContent?: Maybe<DraftContentMutationPayload>;
    draftCustomNotification?: Maybe<DraftCustomNotificationMutationPayload>;
    draftFreeTokenTrigger?: Maybe<DraftFreeTokenTriggerMutationPayload>;
    draftGiveaway?: Maybe<DraftGiveawayMutationPayload>;
    draftIdeationMission?: Maybe<DraftIdeationMissionMutationPayload>;
    draftNftCollection?: Maybe<DraftNftCollectionMutationPayload>;
    draftNftGiveaway?: Maybe<DraftNftGiveawayMutationPayload>;
    draftNftHandout?: Maybe<DraftNftHandoutMutationPayload>;
    draftProfileField?: Maybe<DraftProfileFieldMutationPayload>;
    draftTokenHandout?: Maybe<DraftTokenHandoutMutationPayload>;
    draftVoting?: Maybe<DraftVotingMutationPayload>;
    fundFanVaults?: Maybe<FundFanVaultsMutationPayload>;
    getMediaUploadUrl?: Maybe<GetMediaUploadUrlMutationPayload>;
    inviteUser?: Maybe<InviteUserMutationPayload>;
    mintNft?: Maybe<MintNftMutationPayload>;
    mintNftCollection?: Maybe<MintNftCollectionMutationPayload>;
    publishAmaSession?: Maybe<PublishAmaSessionMutationPayload>;
    publishContent?: Maybe<PublishContentMutationPayload>;
    publishCustomNotification?: Maybe<PublishCustomNotificationMutationPayload>;
    publishFreeTokenTrigger?: Maybe<PublishFreeTokenTriggerMutationPayload>;
    publishGiveaway?: Maybe<PublishGiveawayMutationPayload>;
    publishIdeationMission?: Maybe<PublishIdeationMissionMutationPayload>;
    publishNftCollection?: Maybe<PublishNftCollectionMutationPayload>;
    publishNftGiveaway?: Maybe<PublishNftGiveawayMutationPayload>;
    publishNftHandout?: Maybe<PublishNftHandoutMutationPayload>;
    publishProfileField?: Maybe<PublishProfileFieldMutationPayload>;
    publishStaticPage?: Maybe<PublishStaticPageMutationPayload>;
    publishTokenHandout?: Maybe<PublishTokenHandoutMutationPayload>;
    publishVoting?: Maybe<PublishVotingMutationPayload>;
    refreshOembedData?: Maybe<RefreshOembedDataMutationPayload>;
    refundVoting?: Maybe<RefundVotingMutationPayload>;
    requestNftCollectionMetadataUri?: Maybe<RequestNftCollectionMetadataUriMutationPayload>;
    startAutomaticPeriods?: Maybe<StartAutomaticPeriodsPayload>;
    stopAutomaticPeriods?: Maybe<StopAutomaticPeriodsPayload>;
    transferNft?: Maybe<TransferNftMutationPayload>;
    triggerGiveawayEvent?: Maybe<TriggerGiveawayEventMutationPayload>;
    updateActivityPoint?: Maybe<UpdateActivityPointMutationPayload>;
    updateAdminProfile?: Maybe<UpdateAdminProfileMutationPayload>;
    updateAdminUser?: Maybe<UpdateAdminUserMutationPayload>;
    updateAmaQuestion?: Maybe<UpdateAmaQuestionMutationPayload>;
    updateAmaSession?: Maybe<UpdateAmaSessionMutationPayload>;
    updateAnnouncement?: Maybe<UpdateAnnouncementMutationPayload>;
    updateComment?: Maybe<UpdateCommentMutationPayload>;
    updateContent?: Maybe<UpdateContentMutationPayload>;
    updateContentCategory?: Maybe<UpdateContentCategoryMutationPayload>;
    updateContentMedium?: Maybe<UpdateContentMediumMutationPayload>;
    updateContentTranslation?: Maybe<UpdateContentTranslationMutationPayload>;
    updateCustomNotification?: Maybe<UpdateCustomNotificationMutationPayload>;
    updateFanGroup?: Maybe<UpdateFanGroupMutationPayload>;
    updateFreeTokenTrigger?: Maybe<UpdateFreeTokenTriggerMutationPayload>;
    updateGiveaway?: Maybe<UpdateGiveawayMutationPayload>;
    updateGroupPost?: Maybe<UpdateGroupPostMutationPayload>;
    updateIdea?: Maybe<UpdateIdeaMutationPayload>;
    updateIdeationMission?: Maybe<UpdateIdeationMissionMutationPayload>;
    updateMenuItem?: Maybe<UpdateMenuItemMutationPayload>;
    updateMenuItems?: Maybe<UpdateMenuItemsMutationPayload>;
    updateNft?: Maybe<UpdateNftMutationPayload>;
    updateNftCollection?: Maybe<UpdateNftCollectionMutationPayload>;
    updateNftCollectionDeployment?: Maybe<UpdateNftCollectionDeploymentMutationPayload>;
    updateNftGiveaway?: Maybe<UpdateNftGiveawayMutationPayload>;
    updateNftHandout?: Maybe<UpdateNftHandoutMutationPayload>;
    updateNftMedium?: Maybe<UpdateNftMediumMutationPayload>;
    updateNftTransferNetwork?: Maybe<UpdateNftTransferNetworkMutationPayload>;
    updateNftsVisibility?: Maybe<UpdateNftsVisibilityMutationPayload>;
    updateProfileField?: Maybe<UpdateProfileFieldMutationPayload>;
    updateProfileFields?: Maybe<UpdateProfileFieldsMutationPayload>;
    updateProposal?: Maybe<UpdateProposalMutationPayload>;
    updateProposalPeriod?: Maybe<UpdateProposalPeriodMutationPayload>;
    updateShopProduct?: Maybe<UpdateShopProductMutationPayload>;
    updateShopProductTier?: Maybe<UpdateShopProductTierMutationPayload>;
    updateSponsor?: Maybe<UpdateSponsorMutationPayload>;
    updateStaticPage?: Maybe<UpdateStaticPageMutationPayload>;
    updateTokenHandout?: Maybe<UpdateTokenHandoutMutationPayload>;
    updateUgcReport?: Maybe<UpdateUgcReportMutationPayload>;
    updateUgcReportType?: Maybe<UpdateUgcReportTypeMutationPayload>;
    updateUser?: Maybe<UpdateUserMutationPayload>;
    updateVoting?: Maybe<UpdateVotingMutationPayload>;
    upsertSystemSettings?: Maybe<UpsertSystemSettingsMutationPayload>;
};
export declare type MutationAddNftsToCollectionArgs = {
    input: AddNftsToCollectionMutationInput;
};
export declare type MutationAdminUserLoginArgs = {
    email: Scalars['String'];
    password: Scalars['String'];
};
export declare type MutationArchiveAmaSessionArgs = {
    input: ArchiveAmaSessionMutationInput;
};
export declare type MutationArchiveContentArgs = {
    input: ArchiveContentMutationInput;
};
export declare type MutationArchiveFreeTokenTriggerArgs = {
    input: ArchiveFreeTokenTriggerMutationInput;
};
export declare type MutationArchiveGiveawayArgs = {
    input: ArchiveGiveawayMutationInput;
};
export declare type MutationArchiveIdeationMissionArgs = {
    input: ArchiveIdeationMissionMutationInput;
};
export declare type MutationArchiveNftCollectionArgs = {
    input: ArchiveNftCollectionMutationInput;
};
export declare type MutationArchiveNftGiveawayArgs = {
    input: ArchiveNftGiveawayMutationInput;
};
export declare type MutationArchiveProfileFieldArgs = {
    input: ArchiveProfileFieldMutationInput;
};
export declare type MutationArchiveStaticPageArgs = {
    input: ArchiveStaticPageMutationInput;
};
export declare type MutationArchiveVotingArgs = {
    input: ArchiveVotingMutationInput;
};
export declare type MutationCreateActivityPointArgs = {
    input: AddActivityPointMutationInput;
};
export declare type MutationCreateAdminUserArgs = {
    input: AddAdminUserMutationInput;
};
export declare type MutationCreateAmaSessionArgs = {
    input: AddAmaSessionMutationInput;
};
export declare type MutationCreateAnnouncementArgs = {
    input: AddAnnouncementMutationInput;
};
export declare type MutationCreateContentArgs = {
    input: AddContentMutationInput;
};
export declare type MutationCreateContentCategoryArgs = {
    input: AddContentCategoryMutationInput;
};
export declare type MutationCreateContentMediumArgs = {
    input: AddContentMediumMutationInput;
};
export declare type MutationCreateCustomNotificationArgs = {
    input: AddCustomNotificationMutationInput;
};
export declare type MutationCreateFreeTokenTriggerArgs = {
    input: AddFreeTokenTriggerMutationInput;
};
export declare type MutationCreateGiveawayArgs = {
    input: AddGiveawayMutationInput;
};
export declare type MutationCreateIdeationMissionArgs = {
    input: AddIdeationMissionMutationInput;
};
export declare type MutationCreateMenuItemArgs = {
    input: AddMenuItemMutationInput;
};
export declare type MutationCreateNftArgs = {
    input: AddNftMutationInput;
};
export declare type MutationCreateNftCollectionArgs = {
    input: AddNftCollectionMutationInput;
};
export declare type MutationCreateNftCollectionDeploymentArgs = {
    input: AddNftCollectionDeploymentMutationInput;
};
export declare type MutationCreateNftGiveawayArgs = {
    input: AddNftGiveawayMutationInput;
};
export declare type MutationCreateNftHandoutArgs = {
    input: AddNftHandoutMutationInput;
};
export declare type MutationCreateNftMediumArgs = {
    input: AddNftMediumMutationInput;
};
export declare type MutationCreateNftTransferNetworkArgs = {
    input: AddNftTransferNetworkMutationInput;
};
export declare type MutationCreateProfileFieldArgs = {
    input: AddProfileFieldMutationInput;
};
export declare type MutationCreateProposalPeriodArgs = {
    input: AddProposalPeriodMutationInput;
};
export declare type MutationCreateShopProductArgs = {
    input: AddShopProductMutationInput;
};
export declare type MutationCreateShopProductTierArgs = {
    input: AddShopProductTierMutationInput;
};
export declare type MutationCreateSponsorArgs = {
    input: AddSponsorMutationInput;
};
export declare type MutationCreateStaticPageArgs = {
    input: AddStaticPageMutationInput;
};
export declare type MutationCreateSystemSettingArgs = {
    input: AddSystemSettingMutationInput;
};
export declare type MutationCreateTokenHandoutArgs = {
    input: AddTokenHandoutMutationInput;
};
export declare type MutationCreateUgcReportArgs = {
    input: AddUgcReportMutationInput;
};
export declare type MutationCreateUgcReportTypeArgs = {
    input: AddUgcReportTypeMutationInput;
};
export declare type MutationCreateUserArgs = {
    input: AddUserMutationInput;
};
export declare type MutationCreateUserOrderArgs = {
    input: AddUserOrderMutationInput;
};
export declare type MutationCreateVotingArgs = {
    input: AddVotingMutationInput;
};
export declare type MutationDeleteActivityPointsArgs = {
    input: DeleteActivityPointsMutationInput;
};
export declare type MutationDeleteAdminUserArgs = {
    input: DeleteAdminUserMutationInput;
};
export declare type MutationDeleteAmaSessionsArgs = {
    input: DeleteAmaSessionsMutationInput;
};
export declare type MutationDeleteAnnouncementsArgs = {
    input: DeleteAnnouncementsMutationInput;
};
export declare type MutationDeleteContentCategoriesArgs = {
    input: DeleteContentCategoriesMutationInput;
};
export declare type MutationDeleteContentMediaArgs = {
    input: DeleteContentMediaMutationInput;
};
export declare type MutationDeleteContentsArgs = {
    input: DeleteContentsMutationInput;
};
export declare type MutationDeleteCustomNotificationsArgs = {
    input: DeleteCustomNotificationsMutationInput;
};
export declare type MutationDeleteFreeTokenTriggersArgs = {
    input: DeleteFreeTokenTriggersMutationInput;
};
export declare type MutationDeleteGiveawaysArgs = {
    input: DeleteGiveawaysMutationInput;
};
export declare type MutationDeleteIdeationMissionsArgs = {
    input: DeleteIdeationMissionsMutationInput;
};
export declare type MutationDeleteMenuItemsArgs = {
    input: DeleteMenuItemsMutationInput;
};
export declare type MutationDeleteNftCollectionsArgs = {
    input: DeleteNftCollectionsMutationInput;
};
export declare type MutationDeleteNftGiveawaysArgs = {
    input: DeleteNftGiveawaysMutationInput;
};
export declare type MutationDeleteNftHandoutsArgs = {
    input: DeleteNftHandoutsMutationInput;
};
export declare type MutationDeleteNftMediaArgs = {
    input: DeleteNftMediaMutationInput;
};
export declare type MutationDeleteNftsArgs = {
    input: DeleteNftsMutationInput;
};
export declare type MutationDeleteProfileFieldsArgs = {
    input: DeleteProfileFieldsMutationInput;
};
export declare type MutationDeleteProposalPeriodsArgs = {
    input: DeleteProposalPeriodsMutationInput;
};
export declare type MutationDeleteShopProductTiersArgs = {
    input: DeleteShopProductTiersMutationInput;
};
export declare type MutationDeleteShopProductsArgs = {
    input: DeleteShopProductsMutationInput;
};
export declare type MutationDeleteSponsorsArgs = {
    input: DeleteSponsorsMutationInput;
};
export declare type MutationDeleteStaticPagesArgs = {
    input: DeleteStaticPagesMutationInput;
};
export declare type MutationDeleteSystemSettingsArgs = {
    input: DeleteSystemSettingsMutationInput;
};
export declare type MutationDeleteTokenHandoutsArgs = {
    input: DeleteTokenHandoutsMutationInput;
};
export declare type MutationDeleteUgcReportTypesArgs = {
    input: DeleteUgcReportTypesMutationInput;
};
export declare type MutationDeleteUgcReportsArgs = {
    input: DeleteUgcReportsMutationInput;
};
export declare type MutationDeleteUserArgs = {
    input: DeleteUserMutationInput;
};
export declare type MutationDeleteUserOrdersArgs = {
    input: DeleteUserOrdersMutationInput;
};
export declare type MutationDeleteVotingsArgs = {
    input: DeleteVotingsMutationInput;
};
export declare type MutationDistributeAmaSessionArgs = {
    input: DistributeAmaSessionMutationInput;
};
export declare type MutationDistributeIdeationMissionArgs = {
    input: DistributeIdeationMissionMutationInput;
};
export declare type MutationDistributeVotingArgs = {
    input: DistributeVotingMutationInput;
};
export declare type MutationDraftAmaSessionArgs = {
    input: DraftAmaSessionMutationInput;
};
export declare type MutationDraftContentArgs = {
    input: DraftContentMutationInput;
};
export declare type MutationDraftCustomNotificationArgs = {
    input: DraftCustomNotificationMutationInput;
};
export declare type MutationDraftFreeTokenTriggerArgs = {
    input: DraftFreeTokenTriggerMutationInput;
};
export declare type MutationDraftGiveawayArgs = {
    input: DraftGiveawayMutationInput;
};
export declare type MutationDraftIdeationMissionArgs = {
    input: DraftIdeationMissionMutationInput;
};
export declare type MutationDraftNftCollectionArgs = {
    input: DraftNftCollectionMutationInput;
};
export declare type MutationDraftNftGiveawayArgs = {
    input: DraftNftGiveawayMutationInput;
};
export declare type MutationDraftNftHandoutArgs = {
    input: DraftNftHandoutMutationInput;
};
export declare type MutationDraftProfileFieldArgs = {
    input: DraftProfileFieldMutationInput;
};
export declare type MutationDraftTokenHandoutArgs = {
    input: DraftTokenHandoutMutationInput;
};
export declare type MutationDraftVotingArgs = {
    input: DraftVotingMutationInput;
};
export declare type MutationFundFanVaultsArgs = {
    input: FundFanVaultsMutationInput;
};
export declare type MutationGetMediaUploadUrlArgs = {
    input: GetMediaUploadUrlMutationInput;
};
export declare type MutationInviteUserArgs = {
    input: InviteUserMutationInput;
};
export declare type MutationMintNftArgs = {
    input: MintNftMutationInput;
};
export declare type MutationMintNftCollectionArgs = {
    input: MintNftCollectionMutationInput;
};
export declare type MutationPublishAmaSessionArgs = {
    input: PublishAmaSessionMutationInput;
};
export declare type MutationPublishContentArgs = {
    input: PublishContentMutationInput;
};
export declare type MutationPublishCustomNotificationArgs = {
    input: PublishCustomNotificationMutationInput;
};
export declare type MutationPublishFreeTokenTriggerArgs = {
    input: PublishFreeTokenTriggerMutationInput;
};
export declare type MutationPublishGiveawayArgs = {
    input: PublishGiveawayMutationInput;
};
export declare type MutationPublishIdeationMissionArgs = {
    input: PublishIdeationMissionMutationInput;
};
export declare type MutationPublishNftCollectionArgs = {
    input: PublishNftCollectionMutationInput;
};
export declare type MutationPublishNftGiveawayArgs = {
    input: PublishNftGiveawayMutationInput;
};
export declare type MutationPublishNftHandoutArgs = {
    input: PublishNftHandoutMutationInput;
};
export declare type MutationPublishProfileFieldArgs = {
    input: PublishProfileFieldMutationInput;
};
export declare type MutationPublishStaticPageArgs = {
    input: PublishStaticPageMutationInput;
};
export declare type MutationPublishTokenHandoutArgs = {
    input: PublishTokenHandoutMutationInput;
};
export declare type MutationPublishVotingArgs = {
    input: PublishVotingMutationInput;
};
export declare type MutationRefreshOembedDataArgs = {
    input: RefreshOembedDataMutationInput;
};
export declare type MutationRefundVotingArgs = {
    input: RefundVotingMutationInput;
};
export declare type MutationRequestNftCollectionMetadataUriArgs = {
    input: RequestNftCollectionMetadataUriMutationInput;
};
export declare type MutationTransferNftArgs = {
    input: TransferNftMutationInput;
};
export declare type MutationTriggerGiveawayEventArgs = {
    input: TriggerGiveawayEventMutationInput;
};
export declare type MutationUpdateActivityPointArgs = {
    input: UpdateActivityPointMutationInput;
};
export declare type MutationUpdateAdminProfileArgs = {
    input: UpdateAdminProfileMutationInput;
};
export declare type MutationUpdateAdminUserArgs = {
    input: UpdateAdminUserMutationInput;
};
export declare type MutationUpdateAmaQuestionArgs = {
    input: UpdateAmaQuestionMutationInput;
};
export declare type MutationUpdateAmaSessionArgs = {
    input: UpdateAmaSessionMutationInput;
};
export declare type MutationUpdateAnnouncementArgs = {
    input: UpdateAnnouncementMutationInput;
};
export declare type MutationUpdateCommentArgs = {
    input: UpdateCommentMutationInput;
};
export declare type MutationUpdateContentArgs = {
    input: UpdateContentMutationInput;
};
export declare type MutationUpdateContentCategoryArgs = {
    input: UpdateContentCategoryMutationInput;
};
export declare type MutationUpdateContentMediumArgs = {
    input: UpdateContentMediumMutationInput;
};
export declare type MutationUpdateContentTranslationArgs = {
    input: UpdateContentTranslationMutationInput;
};
export declare type MutationUpdateCustomNotificationArgs = {
    input: UpdateCustomNotificationMutationInput;
};
export declare type MutationUpdateFanGroupArgs = {
    input: UpdateFanGroupMutationInput;
};
export declare type MutationUpdateFreeTokenTriggerArgs = {
    input: UpdateFreeTokenTriggerMutationInput;
};
export declare type MutationUpdateGiveawayArgs = {
    input: UpdateGiveawayMutationInput;
};
export declare type MutationUpdateGroupPostArgs = {
    input: UpdateGroupPostMutationInput;
};
export declare type MutationUpdateIdeaArgs = {
    input: UpdateIdeaMutationInput;
};
export declare type MutationUpdateIdeationMissionArgs = {
    input: UpdateIdeationMissionMutationInput;
};
export declare type MutationUpdateMenuItemArgs = {
    input: UpdateMenuItemMutationInput;
};
export declare type MutationUpdateMenuItemsArgs = {
    input: UpdateMenuItemsMutationInput;
};
export declare type MutationUpdateNftArgs = {
    input: UpdateNftMutationInput;
};
export declare type MutationUpdateNftCollectionArgs = {
    input: UpdateNftCollectionMutationInput;
};
export declare type MutationUpdateNftCollectionDeploymentArgs = {
    input: UpdateNftCollectionDeploymentMutationInput;
};
export declare type MutationUpdateNftGiveawayArgs = {
    input: UpdateNftGiveawayMutationInput;
};
export declare type MutationUpdateNftHandoutArgs = {
    input: UpdateNftHandoutMutationInput;
};
export declare type MutationUpdateNftMediumArgs = {
    input: UpdateNftMediumMutationInput;
};
export declare type MutationUpdateNftTransferNetworkArgs = {
    input: UpdateNftTransferNetworkMutationInput;
};
export declare type MutationUpdateNftsVisibilityArgs = {
    input: UpdateNftsVisibilityMutationInput;
};
export declare type MutationUpdateProfileFieldArgs = {
    input: UpdateProfileFieldMutationInput;
};
export declare type MutationUpdateProfileFieldsArgs = {
    input: UpdateProfileFieldsMutationInput;
};
export declare type MutationUpdateProposalArgs = {
    input: UpdateProposalMutationInput;
};
export declare type MutationUpdateProposalPeriodArgs = {
    input: UpdateProposalPeriodMutationInput;
};
export declare type MutationUpdateShopProductArgs = {
    input: UpdateShopProductMutationInput;
};
export declare type MutationUpdateShopProductTierArgs = {
    input: UpdateShopProductTierMutationInput;
};
export declare type MutationUpdateSponsorArgs = {
    input: UpdateSponsorMutationInput;
};
export declare type MutationUpdateStaticPageArgs = {
    input: UpdateStaticPageMutationInput;
};
export declare type MutationUpdateTokenHandoutArgs = {
    input: UpdateTokenHandoutMutationInput;
};
export declare type MutationUpdateUgcReportArgs = {
    input: UpdateUgcReportMutationInput;
};
export declare type MutationUpdateUgcReportTypeArgs = {
    input: UpdateUgcReportTypeMutationInput;
};
export declare type MutationUpdateUserArgs = {
    input: UpdateUserMutationInput;
};
export declare type MutationUpdateVotingArgs = {
    input: UpdateVotingMutationInput;
};
export declare type MutationUpsertSystemSettingsArgs = {
    input: UpsertSystemSettingsMutationInput;
};
export declare type Nft = {
    __typename?: 'Nft';
    amount: Scalars['Int'];
    amountLeft?: Maybe<Scalars['Int']>;
    collectionSponsor?: Maybe<Sponsor>;
    createdAt: Scalars['ISO8601DateTime'];
    description: Scalars['String'];
    giveaways: Array<Giveaway>;
    id: Scalars['ID'];
    mintedAt?: Maybe<Scalars['ISO8601DateTime']>;
    name: Scalars['String'];
    nftBenefits: Array<NftBenefit>;
    nftBuckets: Array<NftBucket>;
    nftCollection?: Maybe<NftCollection>;
    nftCollectionId?: Maybe<Scalars['ID']>;
    nftCollectionOrder?: Maybe<Scalars['Int']>;
    nftFixedPriceShopProducts: Array<ShopProduct>;
    nftMedium: NftMedium;
    nftMediumId: Scalars['ID'];
    nftUsers: Array<NftUser>;
    pinToTop: Scalars['Boolean'];
    rarity: Scalars['String'];
    showInFeed: Scalars['Boolean'];
    shownInFeedAt?: Maybe<Scalars['ISO8601DateTime']>;
    sponsor?: Maybe<Sponsor>;
    sponsorId?: Maybe<Scalars['ID']>;
    translations: Array<NftTranslation>;
    updatedAt: Scalars['ISO8601DateTime'];
    users: Array<User>;
    videoAutoplay: Scalars['Boolean'];
    videoLoop: Scalars['Boolean'];
    videoShowControls: Scalars['Boolean'];
    visibleInShowroom: Scalars['Boolean'];
    willBePinned: Scalars['Boolean'];
};
export declare type NftBenefit = {
    __typename?: 'NftBenefit';
    allowedRedemptionsAmount: Scalars['Int'];
    createdAt: Scalars['ISO8601DateTime'];
    id: Scalars['ID'];
    nft: Nft;
    nftBenefitRedemptions: Array<NftBenefitRedemption>;
    nftId: Scalars['ID'];
    timeOutMinutes: Scalars['Int'];
    translations: Array<NftBenefitTranslation>;
    updatedAt: Scalars['ISO8601DateTime'];
};
export declare type NftBenefitFilterInput = {
    id?: Maybe<FilterIdInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    allowedRedemptionsAmount?: Maybe<FilterNumberInput>;
    timeOutMinutes?: Maybe<FilterNumberInput>;
    nftId?: Maybe<FilterIdInput>;
    title?: Maybe<FilterTextInput>;
    description?: Maybe<FilterTextInput>;
    successMessage?: Maybe<FilterTextInput>;
};
export declare type NftBenefitInput = {
    id?: Maybe<Scalars['ID']>;
    _destroy?: Maybe<Scalars['Boolean']>;
    allowedRedemptionsAmount?: Maybe<Scalars['Int']>;
    timeOutMinutes?: Maybe<Scalars['Int']>;
    translations?: Maybe<Array<NftBenefitTranslationInput>>;
    nftId?: Maybe<Scalars['ID']>;
};
export declare type NftBenefitRedemption = {
    __typename?: 'NftBenefitRedemption';
    createdAt: Scalars['ISO8601DateTime'];
    id: Scalars['ID'];
    nftBenefit: NftBenefit;
    nftBenefitId: Scalars['ID'];
    updatedAt: Scalars['ISO8601DateTime'];
    user: User;
    userId: Scalars['ID'];
};
export declare type NftBenefitRedemptionFilterInput = {
    id?: Maybe<FilterIdInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    nftBenefitId?: Maybe<FilterIdInput>;
    nftId?: Maybe<Scalars['ID']>;
    userId?: Maybe<FilterIdInput>;
};
export declare type NftBenefitRedemptionResolver = {
    __typename?: 'NftBenefitRedemptionResolver';
    nftBenefitRedemptions: Array<NftBenefitRedemption>;
    total: Scalars['Int'];
};
export declare type NftBenefitRedemptionSortInput = {
    id?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    nftBenefitId?: Maybe<SortEnum>;
    userId?: Maybe<SortEnum>;
};
export declare type NftBenefitResolver = {
    __typename?: 'NftBenefitResolver';
    nftBenefits: Array<NftBenefit>;
    total: Scalars['Int'];
};
export declare type NftBenefitSortInput = {
    id?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    allowedRedemptionsAmount?: Maybe<SortEnum>;
    timeOutMinutes?: Maybe<SortEnum>;
    nftId?: Maybe<SortEnum>;
    title?: Maybe<LocalizedSorterInput>;
    description?: Maybe<LocalizedSorterInput>;
    successMessage?: Maybe<LocalizedSorterInput>;
};
export declare type NftBenefitTranslation = {
    __typename?: 'NftBenefitTranslation';
    description?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    locale: Scalars['String'];
    successMessage?: Maybe<Scalars['String']>;
    title: Scalars['String'];
};
export declare type NftBenefitTranslationInput = {
    id?: Maybe<Scalars['ID']>;
    locale?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
    successMessage?: Maybe<Scalars['String']>;
};
export declare type NftBucket = {
    __typename?: 'NftBucket';
    amount: Scalars['Int'];
    bucketCapacity: Scalars['Int'];
    createdAt: Scalars['ISO8601DateTime'];
    id: Scalars['ID'];
    name?: Maybe<Scalars['String']>;
    nftBucketHandouts: Array<NftBucketHandout>;
    nftBucketNfts: Array<NftBucketNft>;
    nftIds: Array<Scalars['ID']>;
    nfts: Array<Nft>;
    shopProduct: ShopProduct;
    shopProductId?: Maybe<Scalars['ID']>;
    updatedAt: Scalars['ISO8601DateTime'];
};
export declare type NftBucketCapacity = {
    __typename?: 'NftBucketCapacity';
    capacity: Scalars['Int'];
    id: Scalars['ID'];
};
export declare type NftBucketHandout = {
    __typename?: 'NftBucketHandout';
    createdAt: Scalars['ISO8601DateTime'];
    id: Scalars['ID'];
    nft: Nft;
    nftBucket: NftBucket;
    nftBucketId?: Maybe<Scalars['ID']>;
    nftId?: Maybe<Scalars['ID']>;
    updatedAt: Scalars['ISO8601DateTime'];
    user: User;
    userId?: Maybe<Scalars['ID']>;
};
export declare type NftBucketInput = {
    id?: Maybe<Scalars['ID']>;
    amount?: Maybe<Scalars['Int']>;
    name?: Maybe<Scalars['String']>;
    _destroy?: Maybe<Scalars['Boolean']>;
    nftBucketNfts?: Maybe<Array<NftBucketNftInput>>;
};
export declare type NftBucketNft = {
    __typename?: 'NftBucketNft';
    amountLimit?: Maybe<Scalars['Int']>;
    createdAt: Scalars['ISO8601DateTime'];
    id: Scalars['ID'];
    nft: Nft;
    nftBucket: NftBucket;
    nftBucketId: Scalars['ID'];
    nftId: Scalars['ID'];
    updatedAt: Scalars['ISO8601DateTime'];
};
export declare type NftBucketNftInput = {
    id?: Maybe<Scalars['ID']>;
    amountLimit?: Maybe<Scalars['Int']>;
    nftId?: Maybe<Scalars['ID']>;
    nftBucketId?: Maybe<Scalars['ID']>;
    _destroy?: Maybe<Scalars['Boolean']>;
};
export declare type NftCollection = {
    __typename?: 'NftCollection';
    contractAddress?: Maybe<Scalars['String']>;
    createdAt: Scalars['ISO8601DateTime'];
    deployments: Array<NftCollectionDeployment>;
    feeRecipient?: Maybe<Scalars['String']>;
    heroMedium?: Maybe<ContentMedium>;
    heroMediumId?: Maybe<Scalars['ID']>;
    id: Scalars['ID'];
    nftIds: Array<Scalars['ID']>;
    nfts: Array<Nft>;
    nftsCount?: Maybe<Scalars['Int']>;
    pinToTop: Scalars['Boolean'];
    previewToken?: Maybe<Scalars['String']>;
    previewUrl?: Maybe<Scalars['String']>;
    previewUrls: Array<PreviewUrl>;
    publishedAt?: Maybe<Scalars['ISO8601DateTime']>;
    sellerFeeBasisPoints?: Maybe<Scalars['Int']>;
    sponsor?: Maybe<Sponsor>;
    sponsorId?: Maybe<Scalars['ID']>;
    status: NftCollectionStatusEnum;
    tokenBaseUri?: Maybe<Scalars['String']>;
    translations: Array<NftCollectionTranslation>;
    updatedAt: Scalars['ISO8601DateTime'];
    willBePinned: Scalars['Boolean'];
};
export declare type NftCollectionDeployment = {
    __typename?: 'NftCollectionDeployment';
    active: Scalars['Boolean'];
    contractAddress: Scalars['String'];
    createdAt: Scalars['ISO8601DateTime'];
    deployed: Scalars['Boolean'];
    id: Scalars['ID'];
    nftCollection: NftCollection;
    nftCollectionId: Scalars['ID'];
    nftTransferNetwork: NftTransferNetwork;
    nftTransferNetworkId: Scalars['ID'];
    updatedAt: Scalars['ISO8601DateTime'];
};
export declare type NftCollectionDeploymentInput = {
    nftCollectionId?: Maybe<Scalars['ID']>;
    nftTransferNetworkId?: Maybe<Scalars['ID']>;
    contractAddress?: Maybe<Scalars['String']>;
    active?: Maybe<Scalars['Boolean']>;
    deployed?: Maybe<Scalars['Boolean']>;
};
export declare type NftCollectionFilterInput = {
    id?: Maybe<FilterIdInput>;
    status?: Maybe<NftCollectionStatusEnum>;
    nftsCount?: Maybe<FilterNumberInput>;
    contractAddress?: Maybe<FilterTextInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    title?: Maybe<FilterTextInput>;
    description?: Maybe<FilterTextInput>;
    slug?: Maybe<FilterTextInput>;
    preview?: Maybe<FilterTextInput>;
    publishedAt?: Maybe<FilterDateInput>;
    sponsorId?: Maybe<FilterNumberInput>;
};
export declare type NftCollectionInput = {
    heroMediumId?: Maybe<Scalars['ID']>;
    translations?: Maybe<Array<NftCollectionTranslationInput>>;
    publishedAt?: Maybe<Scalars['ISO8601DateTime']>;
    sponsorId?: Maybe<Scalars['ID']>;
    nftIds?: Maybe<Array<Scalars['ID']>>;
    pinToTop?: Maybe<Scalars['Boolean']>;
    sellerFeeBasisPoints?: Maybe<Scalars['Int']>;
    feeRecipient?: Maybe<Scalars['String']>;
};
export declare type NftCollectionResolver = {
    __typename?: 'NftCollectionResolver';
    nftCollections: Array<NftCollection>;
    total: Scalars['Int'];
};
export declare type NftCollectionSortInput = {
    id?: Maybe<SortEnum>;
    status?: Maybe<SortEnumWithDefault>;
    nftsCount?: Maybe<SortEnum>;
    contractAddress?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    title?: Maybe<LocalizedSorterInput>;
    description?: Maybe<LocalizedSorterInput>;
    slug?: Maybe<LocalizedSorterInput>;
    preview?: Maybe<LocalizedSorterInput>;
    publishedAt?: Maybe<SortEnum>;
    sponsorId?: Maybe<SortEnum>;
};
export declare enum NftCollectionStatusEnum {
    Draft = "draft",
    Scheduled = "scheduled",
    Deploying = "deploying",
    Published = "published",
    Archived = "archived"
}
export declare type NftCollectionTranslation = {
    __typename?: 'NftCollectionTranslation';
    description: Scalars['String'];
    id: Scalars['ID'];
    locale: Scalars['String'];
    preview?: Maybe<Scalars['String']>;
    slug: Scalars['String'];
    title: Scalars['String'];
};
export declare type NftCollectionTranslationInput = {
    id?: Maybe<Scalars['ID']>;
    locale?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
    slug?: Maybe<Scalars['String']>;
    preview?: Maybe<Scalars['String']>;
};
export declare type NftFilterInput = {
    id?: Maybe<FilterIdInput>;
    name?: Maybe<FilterTextInput>;
    description?: Maybe<FilterTextInput>;
    nftCollectionId?: Maybe<FilterNumberInput>;
    sponsorId?: Maybe<FilterNumberInput>;
    amount?: Maybe<FilterNumberInput>;
    amountLeft?: Maybe<FilterNumberInput>;
    nftCollectionOrder?: Maybe<FilterNumberInput>;
    mintedAt?: Maybe<FilterDateInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    visibleInShowroom?: Maybe<Scalars['Boolean']>;
};
export declare type NftGiveaway = {
    __typename?: 'NftGiveaway';
    activeAndPublished: Scalars['Boolean'];
    activeFrom: Scalars['ISO8601DateTime'];
    activeUntil?: Maybe<Scalars['ISO8601DateTime']>;
    createdAt: Scalars['ISO8601DateTime'];
    dropRate?: Maybe<Scalars['Float']>;
    events?: Maybe<Array<Scalars['String']>>;
    expires?: Maybe<Scalars['Boolean']>;
    giveawayChance?: Maybe<Scalars['Int']>;
    id: Scalars['ID'];
    nftIds: Array<Scalars['ID']>;
    nfts: Array<Nft>;
    sponsor?: Maybe<Sponsor>;
    sponsorId?: Maybe<Scalars['ID']>;
    statistics?: Maybe<NftGiveawayStats>;
    status: NftGiveawayStatusEnum;
    translations: Array<NftGiveawayTranslation>;
    updatedAt: Scalars['ISO8601DateTime'];
    userLimitNumber?: Maybe<Scalars['Int']>;
    userLimitPeriod?: Maybe<NftGiveawayUserLimitPeriodEnum>;
};
export declare type NftGiveawayFilterInput = {
    id?: Maybe<FilterIdInput>;
    dropRate?: Maybe<FilterNumberInput>;
    giveawayChance?: Maybe<FilterNumberInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    activeFrom?: Maybe<FilterDateInput>;
    activeUntil?: Maybe<FilterDateInput>;
    status?: Maybe<NftGiveawayStatusEnum>;
    expires?: Maybe<Scalars['Boolean']>;
    onlyActiveAndPublished?: Maybe<Scalars['Boolean']>;
    events?: Maybe<Scalars['String']>;
    sponsorId?: Maybe<FilterNumberInput>;
    title?: Maybe<FilterTextInput>;
    message?: Maybe<FilterTextInput>;
    content?: Maybe<FilterTextInput>;
};
export declare type NftGiveawayInput = {
    activeFrom?: Maybe<Scalars['ISO8601DateTime']>;
    activeUntil?: Maybe<Scalars['ISO8601DateTime']>;
    events?: Maybe<Array<Scalars['String']>>;
    dropRate?: Maybe<Scalars['Float']>;
    giveawayChance?: Maybe<Scalars['Int']>;
    translations?: Maybe<Array<NftGiveawayTranslationInput>>;
    sponsorId?: Maybe<Scalars['ID']>;
    nftIds?: Maybe<Array<Scalars['ID']>>;
    expires?: Maybe<Scalars['Boolean']>;
    userLimitPeriod?: Maybe<NftGiveawayUserLimitPeriodEnum>;
    userLimitNumber?: Maybe<Scalars['Int']>;
};
export declare type NftGiveawayResolver = {
    __typename?: 'NftGiveawayResolver';
    nftGiveaways: Array<NftGiveaway>;
    total: Scalars['Int'];
};
export declare type NftGiveawaySortInput = {
    id?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    activeFrom?: Maybe<SortEnum>;
    activeUntil?: Maybe<SortEnum>;
    status?: Maybe<SortEnumWithDefault>;
    expires?: Maybe<SortEnum>;
    events?: Maybe<SortEnum>;
    sponsorId?: Maybe<SortEnum>;
    dropRate?: Maybe<SortEnum>;
    giveawayChance?: Maybe<SortEnum>;
    title?: Maybe<LocalizedSorterInput>;
    message?: Maybe<LocalizedSorterInput>;
    content?: Maybe<LocalizedSorterInput>;
};
export declare type NftGiveawayStats = {
    __typename?: 'NftGiveawayStats';
    active?: Maybe<Scalars['Boolean']>;
    amount?: Maybe<Scalars['Int']>;
    countTrigger?: Maybe<Scalars['Boolean']>;
    events?: Maybe<Array<Scalars['String']>>;
    id: Scalars['ID'];
    numberOfUsers?: Maybe<Scalars['Int']>;
    times?: Maybe<Scalars['Int']>;
    wasActive?: Maybe<Scalars['Boolean']>;
};
export declare enum NftGiveawayStatusEnum {
    Draft = "draft",
    Scheduled = "scheduled",
    Deploying = "deploying",
    Published = "published",
    Paused = "paused",
    Archived = "archived"
}
export declare type NftGiveawayTranslation = {
    __typename?: 'NftGiveawayTranslation';
    content: Scalars['String'];
    ctaText?: Maybe<Scalars['String']>;
    externalLink?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    locale: Scalars['String'];
    message: Scalars['String'];
    title: Scalars['String'];
};
export declare type NftGiveawayTranslationInput = {
    id?: Maybe<Scalars['ID']>;
    locale?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
    message?: Maybe<Scalars['String']>;
    content?: Maybe<Scalars['String']>;
    externalLink?: Maybe<Scalars['String']>;
    ctaText?: Maybe<Scalars['String']>;
};
export declare enum NftGiveawayUserLimitPeriodEnum {
    NoLimit = "no_limit",
    ByHour = "by_hour",
    ByDay = "by_day",
    ByMonth = "by_month",
    ByLifeTime = "by_life_time"
}
export declare type NftHandout = {
    __typename?: 'NftHandout';
    createdAt: Scalars['ISO8601DateTime'];
    delayedPublicationJobId?: Maybe<Scalars['ID']>;
    handoutAt?: Maybe<Scalars['ISO8601DateTime']>;
    id: Scalars['ID'];
    nft: Nft;
    nftHandoutUsers: Array<NftHandoutUser>;
    nftHandoutUsersCount: Scalars['Int'];
    nftId: Scalars['ID'];
    promptDialog?: Maybe<Scalars['Boolean']>;
    skipNotification?: Maybe<Scalars['Boolean']>;
    sponsor?: Maybe<Sponsor>;
    sponsorId?: Maybe<Scalars['ID']>;
    statistics?: Maybe<NftHandoutStats>;
    status: NftHandoutStatusEnum;
    translations: Array<NftHandoutTranslation>;
    updatedAt: Scalars['ISO8601DateTime'];
    userFilter?: Maybe<UserFilter>;
    userSearch?: Maybe<Scalars['String']>;
};
export declare type NftHandoutFilterInput = {
    id?: Maybe<FilterIdInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    handoutAt?: Maybe<FilterDateInput>;
    status?: Maybe<NftHandoutStatusEnum>;
    promptDialog?: Maybe<Scalars['Boolean']>;
    sponsorId?: Maybe<FilterIdInput>;
    nftId?: Maybe<FilterIdInput>;
    delayedPublicationJobId?: Maybe<FilterIdInput>;
    title?: Maybe<FilterTextInput>;
    content?: Maybe<FilterTextInput>;
    message?: Maybe<FilterTextInput>;
    externalLink?: Maybe<FilterTextInput>;
    nftHandoutUsersCount?: Maybe<FilterNumberInput>;
};
export declare type NftHandoutInput = {
    promptDialog?: Maybe<Scalars['Boolean']>;
    translations?: Maybe<Array<NftHandoutTranslationInput>>;
    sponsorId?: Maybe<Scalars['ID']>;
    nftId?: Maybe<Scalars['ID']>;
    handoutAt?: Maybe<Scalars['ISO8601DateTime']>;
    skipNotification?: Maybe<Scalars['Boolean']>;
};
export declare type NftHandoutResolver = {
    __typename?: 'NftHandoutResolver';
    nftHandouts: Array<NftHandout>;
    total: Scalars['Int'];
};
export declare type NftHandoutSortInput = {
    id?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    handoutAt?: Maybe<SortEnum>;
    promptDialog?: Maybe<SortEnum>;
    sponsorId?: Maybe<SortEnum>;
    nftId?: Maybe<SortEnum>;
    title?: Maybe<LocalizedSorterInput>;
    content?: Maybe<LocalizedSorterInput>;
    message?: Maybe<LocalizedSorterInput>;
    externalLink?: Maybe<LocalizedSorterInput>;
    nftHandoutUsersCount?: Maybe<SortEnum>;
    delayedPublicationJobId?: Maybe<SortEnum>;
    status?: Maybe<SortEnum>;
};
export declare type NftHandoutStats = {
    __typename?: 'NftHandoutStats';
    amount?: Maybe<Scalars['Int']>;
    countTrigger?: Maybe<Scalars['Boolean']>;
    id: Scalars['ID'];
    numberOfUsers?: Maybe<Scalars['Int']>;
    times?: Maybe<Scalars['Int']>;
    userIds?: Maybe<Array<Scalars['ID']>>;
};
export declare enum NftHandoutStatusEnum {
    Draft = "draft",
    Scheduled = "scheduled",
    Deploying = "deploying",
    Published = "published"
}
export declare type NftHandoutTranslation = {
    __typename?: 'NftHandoutTranslation';
    content?: Maybe<Scalars['String']>;
    ctaText?: Maybe<Scalars['String']>;
    externalLink?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    locale: Scalars['String'];
    message?: Maybe<Scalars['String']>;
    title: Scalars['String'];
};
export declare type NftHandoutTranslationInput = {
    id?: Maybe<Scalars['ID']>;
    locale?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
    content?: Maybe<Scalars['String']>;
    message?: Maybe<Scalars['String']>;
    externalLink?: Maybe<Scalars['String']>;
    ctaText?: Maybe<Scalars['String']>;
};
export declare type NftHandoutUser = {
    __typename?: 'NftHandoutUser';
    createdAt: Scalars['ISO8601DateTime'];
    id: Scalars['ID'];
    nftHandout: NftHandout;
    nftHandoutId: Scalars['ID'];
    updatedAt: Scalars['ISO8601DateTime'];
    user: User;
    userId: Scalars['ID'];
};
export declare type NftHandoutUserFilterInput = {
    id?: Maybe<FilterIdInput>;
    userId?: Maybe<FilterIdInput>;
    nftHandoutId?: Maybe<FilterIdInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
};
export declare type NftHandoutUserResolver = {
    __typename?: 'NftHandoutUserResolver';
    nftHandoutUsers: Array<NftHandoutUser>;
    total: Scalars['Int'];
};
export declare type NftHandoutUserSortInput = {
    id?: Maybe<SortEnum>;
    userId?: Maybe<SortEnum>;
    nftHandoutId?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
};
export declare type NftInput = {
    nftCollectionId?: Maybe<Scalars['ID']>;
    name?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
    amount?: Maybe<Scalars['Int']>;
    nftMediumId?: Maybe<Scalars['ID']>;
    sponsorId?: Maybe<Scalars['ID']>;
    visibleInShowroom?: Maybe<Scalars['Boolean']>;
    showInFeed?: Maybe<Scalars['Boolean']>;
    translations?: Maybe<Array<NftTranslationInput>>;
    videoLoop?: Maybe<Scalars['Boolean']>;
    videoAutoplay?: Maybe<Scalars['Boolean']>;
    videoShowControls?: Maybe<Scalars['Boolean']>;
    pinToTop?: Maybe<Scalars['Boolean']>;
    nftBenefits?: Maybe<Array<NftBenefitInput>>;
    nftCollectionOrder?: Maybe<Scalars['Int']>;
};
export declare enum NftMediaTypeEnum {
    Image = "image",
    Video = "video"
}
export declare type NftMedium = {
    __typename?: 'NftMedium';
    aspectRatio: MediaAspectRatioEnum;
    createdAt: Scalars['ISO8601DateTime'];
    dimensions?: Maybe<Scalars['JSON']>;
    fileName: Scalars['String'];
    id: Scalars['ID'];
    image?: Maybe<Scalars['String']>;
    mediaSrc?: Maybe<Scalars['String']>;
    mediaType: NftMediaTypeEnum;
    nftsCount: Scalars['Int'];
    original?: Maybe<Scalars['String']>;
    threeqDimensions?: Maybe<Scalars['JSON']>;
    thumbnail?: Maybe<Scalars['String']>;
    updatedAt: Scalars['ISO8601DateTime'];
};
export declare type NftMediumFilterInput = {
    mediaType?: Maybe<NftMediaTypeEnum>;
    fileName?: Maybe<FilterTextInput>;
    nftsCount?: Maybe<FilterNumberInput>;
    aspectRatio?: Maybe<MediaAspectRatioEnum>;
};
/** Input attributes for content medium */
export declare type NftMediumInput = {
    mediaType?: Maybe<NftMediaTypeEnum>;
    mediaSrc?: Maybe<Scalars['String']>;
    fileName: Scalars['String'];
    file?: Maybe<Scalars['Upload']>;
    aspectRatio?: Maybe<MediaAspectRatioEnum>;
};
export declare type NftMediumResolver = {
    __typename?: 'NftMediumResolver';
    nftMedia: Array<NftMedium>;
    total: Scalars['Int'];
};
export declare type NftMediumSortInput = {
    id?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    fileName?: Maybe<SortEnum>;
};
export declare type NftRarity = {
    __typename?: 'NftRarity';
    maxAmount: Scalars['Int'];
    minAmount: Scalars['Int'];
    rarity: Scalars['String'];
    rarityFactor: Scalars['Float'];
};
export declare type NftResolver = {
    __typename?: 'NftResolver';
    nfts: Array<Nft>;
    total: Scalars['Int'];
};
export declare type NftSortInput = {
    id?: Maybe<SortEnum>;
    mintedAt?: Maybe<SortEnum>;
    amount?: Maybe<SortEnum>;
    amountLeft?: Maybe<SortEnum>;
    nftCollectionOrder?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    name?: Maybe<SortEnum>;
    description?: Maybe<SortEnum>;
    sponsorId?: Maybe<SortEnum>;
    visibleInShowroom?: Maybe<SortEnum>;
};
export declare type NftTransferNetwork = {
    __typename?: 'NftTransferNetwork';
    active: Scalars['Boolean'];
    blockExplorerUrl?: Maybe<Scalars['String']>;
    blockchainUrl: Scalars['String'];
    chainId: Scalars['Int'];
    createdAt: Scalars['ISO8601DateTime'];
    id: Scalars['ID'];
    name: Scalars['String'];
    nativeCurrencyParams?: Maybe<Scalars['JSON']>;
    updatedAt: Scalars['ISO8601DateTime'];
    walletBlockchainUrl?: Maybe<Scalars['String']>;
};
export declare type NftTransferNetworkFilterInput = {
    name?: Maybe<FilterTextInput>;
    chainId?: Maybe<FilterNumberInput>;
    active?: Maybe<Scalars['Boolean']>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
};
/** Input attributes for NftTransferNetwork */
export declare type NftTransferNetworkInput = {
    name: Scalars['String'];
    chainId: Scalars['Int'];
    blockchainUrl: Scalars['String'];
    walletBlockchainUrl?: Maybe<Scalars['String']>;
    blockExplorerUrl?: Maybe<Scalars['String']>;
    nativeCurrencyParams?: Maybe<Scalars['JSON']>;
    active: Scalars['Boolean'];
};
export declare type NftTransferNetworkResolver = {
    __typename?: 'NftTransferNetworkResolver';
    nftTransferNetworks: Array<NftTransferNetwork>;
    total: Scalars['Int'];
};
export declare type NftTransferNetworkSortInput = {
    id?: Maybe<SortEnum>;
    name?: Maybe<SortEnum>;
    chainId?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
};
export declare type NftTranslation = {
    __typename?: 'NftTranslation';
    ctaText?: Maybe<Scalars['String']>;
    extendedInfo?: Maybe<Scalars['String']>;
    externalLink?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    locale: Scalars['String'];
};
export declare type NftTranslationInput = {
    id?: Maybe<Scalars['ID']>;
    locale?: Maybe<Scalars['String']>;
    extendedInfo?: Maybe<Scalars['String']>;
    externalLink?: Maybe<Scalars['String']>;
    ctaText?: Maybe<Scalars['String']>;
};
export declare type NftUser = {
    __typename?: 'NftUser';
    amount: Scalars['Int'];
    amountBurnt: Scalars['Int'];
    amountFrozen: Scalars['Int'];
    createdAt: Scalars['ISO8601DateTime'];
    id: Scalars['ID'];
    nft: Nft;
    nftId: Scalars['ID'];
    publiclyVisible?: Maybe<Scalars['Boolean']>;
    updatedAt: Scalars['ISO8601DateTime'];
    user: User;
    userId: Scalars['ID'];
};
export declare type NftUserFilterInput = {
    id?: Maybe<FilterIdInput>;
    userId?: Maybe<FilterIdInput>;
    nftId?: Maybe<FilterIdInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
};
export declare type NftUserResolver = {
    __typename?: 'NftUserResolver';
    nftUsers: Array<NftUser>;
    total: Scalars['Int'];
};
export declare type NftUserSortInput = {
    id?: Maybe<SortEnum>;
    userId?: Maybe<SortEnum>;
    nftId?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
};
export declare enum NotifiableTypeEnum {
    CustomNotification = "CustomNotification"
}
export declare type OembedLink = {
    __typename?: 'OembedLink';
    authorName?: Maybe<Scalars['String']>;
    authorUrl?: Maybe<Scalars['String']>;
    providerName?: Maybe<Scalars['String']>;
    providerUrl?: Maybe<Scalars['String']>;
    thumbnailHeight?: Maybe<Scalars['String']>;
    thumbnailUrl?: Maybe<Scalars['String']>;
    thumbnailWidth?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
    type: Scalars['String'];
    version?: Maybe<Scalars['String']>;
};
export declare type OembedPhoto = {
    __typename?: 'OembedPhoto';
    authorName?: Maybe<Scalars['String']>;
    authorUrl?: Maybe<Scalars['String']>;
    height?: Maybe<Scalars['Int']>;
    providerName?: Maybe<Scalars['String']>;
    providerUrl?: Maybe<Scalars['String']>;
    thumbnailHeight?: Maybe<Scalars['String']>;
    thumbnailUrl?: Maybe<Scalars['String']>;
    thumbnailWidth?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
    type: Scalars['String'];
    url: Scalars['String'];
    version?: Maybe<Scalars['String']>;
    width?: Maybe<Scalars['Int']>;
};
export declare type OembedRich = {
    __typename?: 'OembedRich';
    authorName?: Maybe<Scalars['String']>;
    authorUrl?: Maybe<Scalars['String']>;
    height?: Maybe<Scalars['Int']>;
    html: Scalars['String'];
    providerName?: Maybe<Scalars['String']>;
    providerUrl?: Maybe<Scalars['String']>;
    thumbnailHeight?: Maybe<Scalars['String']>;
    thumbnailUrl?: Maybe<Scalars['String']>;
    thumbnailWidth?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
    type: Scalars['String'];
    version?: Maybe<Scalars['String']>;
    width?: Maybe<Scalars['Int']>;
};
export declare type OembedVideo = {
    __typename?: 'OembedVideo';
    authorName?: Maybe<Scalars['String']>;
    authorUrl?: Maybe<Scalars['String']>;
    height?: Maybe<Scalars['Int']>;
    html: Scalars['String'];
    providerName?: Maybe<Scalars['String']>;
    providerUrl?: Maybe<Scalars['String']>;
    thumbnailHeight?: Maybe<Scalars['String']>;
    thumbnailUrl?: Maybe<Scalars['String']>;
    thumbnailWidth?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
    type: Scalars['String'];
    version?: Maybe<Scalars['String']>;
    width?: Maybe<Scalars['Int']>;
};
export declare type Payment = {
    __typename?: 'Payment';
    additionalData?: Maybe<Scalars['String']>;
    amount?: Maybe<Scalars['Float']>;
    createdAt: Scalars['ISO8601DateTime'];
    id: Scalars['ID'];
    paymentData?: Maybe<Scalars['String']>;
    provider?: Maybe<Scalars['String']>;
    responseCode?: Maybe<Scalars['String']>;
    status?: Maybe<Scalars['String']>;
    transactionId?: Maybe<Scalars['ID']>;
    updatedAt: Scalars['ISO8601DateTime'];
    userOrder: UserOrder;
    userOrderId: Scalars['ID'];
};
export declare enum PinnableTypeEnum {
    AmaSession = "AmaSession",
    Content = "Content",
    FanGroup = "FanGroup",
    IdeationMission = "IdeationMission",
    Nft = "Nft",
    NftCollection = "NftCollection",
    Voting = "Voting"
}
export declare type PreviewUrl = {
    __typename?: 'PreviewUrl';
    locale: Scalars['String'];
    url: Scalars['String'];
};
export declare type ProfileField = {
    __typename?: 'ProfileField';
    createdAt: Scalars['ISO8601DateTime'];
    formKey: Scalars['String'];
    id: Scalars['ID'];
    inputType: ProfileFieldInputTypeEnum;
    isMulti: Scalars['Boolean'];
    order?: Maybe<Scalars['Int']>;
    profileFieldOptions: Array<ProfileFieldOption>;
    publiclyVisible: Scalars['Boolean'];
    status: ProfileFieldStatusEnum;
    translations: Array<ProfileFieldTranslation>;
    updatedAt: Scalars['ISO8601DateTime'];
};
export declare type ProfileFieldFilterInput = {
    id?: Maybe<FilterIdInput>;
    inputType?: Maybe<ProfileFieldInputTypeEnum>;
    status?: Maybe<ProfileFieldStatusEnum>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    name?: Maybe<FilterTextInput>;
    hint?: Maybe<FilterTextInput>;
    order?: Maybe<FilterNumberInput>;
    isMulti?: Maybe<Scalars['Boolean']>;
    publiclyVisible?: Maybe<Scalars['Boolean']>;
    formKey?: Maybe<Scalars['String']>;
};
export declare type ProfileFieldInput = {
    id?: Maybe<Scalars['ID']>;
    inputType?: Maybe<ProfileFieldInputTypeEnum>;
    translations?: Maybe<Array<ProfileFieldTranslationInput>>;
    profileFieldOptions?: Maybe<Array<ProfileFieldOptionInput>>;
    order?: Maybe<Scalars['Int']>;
    isMulti?: Maybe<Scalars['Boolean']>;
    publiclyVisible?: Maybe<Scalars['Boolean']>;
    formKey?: Maybe<Scalars['String']>;
};
export declare enum ProfileFieldInputTypeEnum {
    Text = "text",
    Number = "number",
    Selection = "selection",
    Radio = "radio",
    Checkbox = "checkbox",
    Switch = "switch",
    Date = "date",
    Url = "url"
}
export declare type ProfileFieldOption = {
    __typename?: 'ProfileFieldOption';
    createdAt: Scalars['ISO8601DateTime'];
    id: Scalars['ID'];
    order?: Maybe<Scalars['Int']>;
    profileField: ProfileField;
    profileFieldId: Scalars['ID'];
    translations: Array<ProfileFieldOptionTranslation>;
    updatedAt: Scalars['ISO8601DateTime'];
    value?: Maybe<Scalars['String']>;
};
export declare type ProfileFieldOptionFilterInput = {
    id?: Maybe<FilterIdInput>;
    profileFieldId?: Maybe<FilterIdInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    label?: Maybe<FilterTextInput>;
    order?: Maybe<FilterNumberInput>;
    value?: Maybe<Scalars['String']>;
};
export declare type ProfileFieldOptionInput = {
    id?: Maybe<Scalars['ID']>;
    profileFieldId?: Maybe<Scalars['ID']>;
    translations?: Maybe<Array<ProfileFieldOptionTranslationInput>>;
    order?: Maybe<Scalars['Int']>;
    value?: Maybe<Scalars['String']>;
    _destroy?: Maybe<Scalars['Boolean']>;
};
export declare type ProfileFieldOptionResolver = {
    __typename?: 'ProfileFieldOptionResolver';
    profileFieldOptions: Array<ProfileFieldOption>;
    total: Scalars['Int'];
};
export declare type ProfileFieldOptionSortInput = {
    id?: Maybe<SortEnum>;
    value?: Maybe<SortEnum>;
    order?: Maybe<SortEnum>;
    profileFieldId?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    label?: Maybe<LocalizedSorterInput>;
};
export declare type ProfileFieldOptionTranslation = {
    __typename?: 'ProfileFieldOptionTranslation';
    id: Scalars['ID'];
    label: Scalars['String'];
    locale: Scalars['String'];
};
export declare type ProfileFieldOptionTranslationInput = {
    id?: Maybe<Scalars['ID']>;
    locale?: Maybe<Scalars['String']>;
    label?: Maybe<Scalars['String']>;
};
export declare type ProfileFieldResolver = {
    __typename?: 'ProfileFieldResolver';
    profileFields: Array<ProfileField>;
    total: Scalars['Int'];
};
export declare type ProfileFieldSortInput = {
    id?: Maybe<SortEnum>;
    inputType?: Maybe<SortEnum>;
    status?: Maybe<SortEnum>;
    order?: Maybe<SortEnum>;
    isMulti?: Maybe<SortEnum>;
    publiclyVisible?: Maybe<SortEnum>;
    formKey?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    name?: Maybe<LocalizedSorterInput>;
    hint?: Maybe<LocalizedSorterInput>;
};
export declare enum ProfileFieldStatusEnum {
    Draft = "draft",
    Published = "published",
    Archived = "archived"
}
export declare type ProfileFieldTranslation = {
    __typename?: 'ProfileFieldTranslation';
    hint?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    locale: Scalars['String'];
    name: Scalars['String'];
};
export declare type ProfileFieldTranslationInput = {
    id?: Maybe<Scalars['ID']>;
    locale?: Maybe<Scalars['String']>;
    name?: Maybe<Scalars['String']>;
    hint?: Maybe<Scalars['String']>;
};
export declare type Proposal = {
    __typename?: 'Proposal';
    announcements: Array<Announcement>;
    audits: Array<Audit>;
    boostsAmountCache?: Maybe<Scalars['Int']>;
    clubAcceptanceStatus: ProposalClubAcceptanceStatusEnum;
    comments: Array<Comment>;
    commentsCount?: Maybe<Scalars['Int']>;
    content?: Maybe<Scalars['String']>;
    contractAddress?: Maybe<Scalars['String']>;
    createdAt: Scalars['ISO8601DateTime'];
    creatorShare?: Maybe<Scalars['Int']>;
    fanvaultShare?: Maybe<Scalars['Int']>;
    id: Scalars['ID'];
    nfts: Array<Nft>;
    operatorAddress?: Maybe<Scalars['String']>;
    operatorShare?: Maybe<Scalars['Int']>;
    previewUrl?: Maybe<Scalars['String']>;
    proposalPeriod: ProposalPeriod;
    proposalPeriodId: Scalars['ID'];
    reportStatus: ReportableStatusEnum;
    title: Scalars['String'];
    ugcReportTypes?: Maybe<Array<UgcReportTyp>>;
    ugcReports: Array<UgcReport>;
    ugcReportsCount: Scalars['Int'];
    updatedAt: Scalars['ISO8601DateTime'];
    user: User;
    userId: Scalars['ID'];
};
export declare enum ProposalClubAcceptanceStatusEnum {
    Submitted = "submitted",
    Active = "active",
    Expired = "expired",
    Successfull = "successfull",
    Rejected = "rejected",
    Accepted = "accepted",
    Implemented = "implemented"
}
export declare type ProposalFilterInput = {
    id?: Maybe<FilterIdInput>;
    title?: Maybe<FilterTextInput>;
    content?: Maybe<FilterTextInput>;
    userId?: Maybe<FilterIdInput>;
    clubAcceptanceStatus?: Maybe<ProposalClubAcceptanceStatusEnum>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    contractAddress?: Maybe<FilterTextInput>;
    operatorAddress?: Maybe<FilterTextInput>;
    boostsAmountCache?: Maybe<FilterNumberInput>;
    commentsCount?: Maybe<FilterNumberInput>;
    proposalPeriodId?: Maybe<FilterIdInput>;
    ugcReportsCount?: Maybe<FilterNumberInput>;
    reportStatus?: Maybe<ReportableStatusEnum>;
    withReportStatus?: Maybe<Scalars['Boolean']>;
};
export declare type ProposalInput = {
    clubAcceptanceStatus?: Maybe<ProposalClubAcceptanceStatusEnum>;
    reportStatus?: Maybe<ReportableStatusEnum>;
    ugcReportTypes?: Maybe<Array<Scalars['Int']>>;
};
export declare type ProposalPeriod = {
    __typename?: 'ProposalPeriod';
    awarded?: Maybe<Scalars['Int']>;
    createdAt: Scalars['ISO8601DateTime'];
    endDate: Scalars['ISO8601DateTime'];
    generationType: ProposalPeriodGenerationTypeEnum;
    id: Scalars['ID'];
    periodType: ProposalPeriodPeriodTypeEnum;
    proposals: Array<Proposal>;
    proposalsCount?: Maybe<Scalars['Int']>;
    startDate: Scalars['ISO8601DateTime'];
    title?: Maybe<Scalars['String']>;
    updatedAt: Scalars['ISO8601DateTime'];
};
export declare type ProposalPeriodFilterInput = {
    id?: Maybe<FilterIdInput>;
    title?: Maybe<FilterTextInput>;
    startDate?: Maybe<FilterDateInput>;
    endDate?: Maybe<FilterDateInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    awarded?: Maybe<FilterNumberInput>;
    proposalsCount?: Maybe<FilterNumberInput>;
    generationType?: Maybe<ProposalPeriodGenerationTypeEnum>;
};
export declare enum ProposalPeriodGenerationTypeEnum {
    Manual = "manual",
    Automatic = "automatic"
}
export declare type ProposalPeriodInput = {
    title?: Maybe<Scalars['String']>;
    startDate?: Maybe<Scalars['ISO8601DateTime']>;
    endDate?: Maybe<Scalars['ISO8601DateTime']>;
    awarded?: Maybe<Scalars['Int']>;
};
export declare enum ProposalPeriodPeriodTypeEnum {
    New = "new",
    Past = "past",
    Current = "current",
    Upcoming = "upcoming"
}
export declare type ProposalPeriodResolver = {
    __typename?: 'ProposalPeriodResolver';
    proposalPeriods: Array<ProposalPeriod>;
    total: Scalars['Int'];
};
export declare type ProposalPeriodSortInput = {
    id?: Maybe<SortEnum>;
    title?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    startDate?: Maybe<SortEnum>;
    endDate?: Maybe<SortEnum>;
    awarded?: Maybe<SortEnum>;
    proposalsCount?: Maybe<SortEnum>;
    generationType?: Maybe<SortEnum>;
};
export declare type ProposalResolver = {
    __typename?: 'ProposalResolver';
    proposals: Array<Proposal>;
    total: Scalars['Int'];
};
export declare type ProposalSortInput = {
    id?: Maybe<SortEnum>;
    title?: Maybe<SortEnum>;
    content?: Maybe<SortEnum>;
    userId?: Maybe<SortEnum>;
    clubAcceptanceStatus?: Maybe<SortEnum>;
    proposalPeriodId?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    commentsCount?: Maybe<SortEnum>;
    boostsAmountCache?: Maybe<SortEnum>;
    contractAddress?: Maybe<SortEnum>;
    operatorAddress?: Maybe<SortEnum>;
    ugcReportsCount?: Maybe<SortEnum>;
    reportStatus?: Maybe<SortEnumWithDefault>;
};
/** Autogenerated input type of PublishAmaSessionMutation */
export declare type PublishAmaSessionMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of PublishAmaSessionMutation */
export declare type PublishAmaSessionMutationPayload = {
    __typename?: 'PublishAmaSessionMutationPayload';
    amaSession: AmaSession;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated input type of PublishContentMutation */
export declare type PublishContentMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of PublishContentMutation */
export declare type PublishContentMutationPayload = {
    __typename?: 'PublishContentMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    content: Content;
};
/** Autogenerated input type of PublishCustomNotificationMutation */
export declare type PublishCustomNotificationMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of PublishCustomNotificationMutation */
export declare type PublishCustomNotificationMutationPayload = {
    __typename?: 'PublishCustomNotificationMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    customNotification: CustomNotification;
};
/** Autogenerated input type of PublishFreeTokenTriggerMutation */
export declare type PublishFreeTokenTriggerMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of PublishFreeTokenTriggerMutation */
export declare type PublishFreeTokenTriggerMutationPayload = {
    __typename?: 'PublishFreeTokenTriggerMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    freeTokenTrigger: FreeTokenTrigger;
};
/** Autogenerated input type of PublishGiveawayMutation */
export declare type PublishGiveawayMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of PublishGiveawayMutation */
export declare type PublishGiveawayMutationPayload = {
    __typename?: 'PublishGiveawayMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    giveaway: Giveaway;
};
/** Autogenerated input type of PublishIdeationMissionMutation */
export declare type PublishIdeationMissionMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of PublishIdeationMissionMutation */
export declare type PublishIdeationMissionMutationPayload = {
    __typename?: 'PublishIdeationMissionMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    ideationMission: IdeationMission;
};
/** Autogenerated input type of PublishNftCollectionMutation */
export declare type PublishNftCollectionMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of PublishNftCollectionMutation */
export declare type PublishNftCollectionMutationPayload = {
    __typename?: 'PublishNftCollectionMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    nftCollection: NftCollection;
};
/** Autogenerated input type of PublishNftGiveawayMutation */
export declare type PublishNftGiveawayMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of PublishNftGiveawayMutation */
export declare type PublishNftGiveawayMutationPayload = {
    __typename?: 'PublishNftGiveawayMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    nftGiveaway: NftGiveaway;
};
/** Autogenerated input type of PublishNftHandoutMutation */
export declare type PublishNftHandoutMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of PublishNftHandoutMutation */
export declare type PublishNftHandoutMutationPayload = {
    __typename?: 'PublishNftHandoutMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    nftHandout: NftHandout;
};
/** Autogenerated input type of PublishProfileFieldMutation */
export declare type PublishProfileFieldMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of PublishProfileFieldMutation */
export declare type PublishProfileFieldMutationPayload = {
    __typename?: 'PublishProfileFieldMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    profileField: ProfileField;
};
/** Autogenerated input type of PublishStaticPageMutation */
export declare type PublishStaticPageMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of PublishStaticPageMutation */
export declare type PublishStaticPageMutationPayload = {
    __typename?: 'PublishStaticPageMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    staticPage: StaticPage;
};
/** Autogenerated input type of PublishTokenHandoutMutation */
export declare type PublishTokenHandoutMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of PublishTokenHandoutMutation */
export declare type PublishTokenHandoutMutationPayload = {
    __typename?: 'PublishTokenHandoutMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    tokenHandout: TokenHandout;
};
/** Autogenerated input type of PublishVotingMutation */
export declare type PublishVotingMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of PublishVotingMutation */
export declare type PublishVotingMutationPayload = {
    __typename?: 'PublishVotingMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    voting: Voting;
};
export declare type Query = {
    __typename?: 'Query';
    /** Show activity_notification */
    activityNotification: ActivityNotification;
    /** List of all the activity_notifications */
    activityNotifications: ActivityNotificationResolver;
    /** Find a activity_point by ID */
    activityPoint: ActivityPoint;
    /** List of all the activity_points */
    activityPoints: ActivityPointResolver;
    /** List of activity_points highscores */
    activityPointsHighscore: ActivityPointHighscoreResolver;
    /** Show admin_user */
    adminUser: AdminUser;
    adminUserConfirmAccount: AdminUser;
    /** List of all the admin_users */
    adminUsers: AdminUserResolver;
    /** Show ama_question */
    amaQuestion: AmaQuestion;
    /** List of all the ama_questions */
    amaQuestions: AmaQuestionResolver;
    /** Show ama_session */
    amaSession: AmaSession;
    /** List of all the ama_sessions */
    amaSessions: AmaSessionResolver;
    /** Show announcement */
    announcement: Announcement;
    /** List of all the announcements */
    announcements: AnnouncementResolver;
    /** Show comment */
    comment: Comment;
    /** List of all the comments */
    comments: CommentResolver;
    /** Show content */
    content: Content;
    /** List of all the content categories */
    contentCategories: ContentCategoryResolver;
    /** Show content_category */
    contentCategory: ContentCategory;
    /** List of all the content media */
    contentMedia: ContentMediumResolver;
    /** Show content_medium */
    contentMedium: ContentMedium;
    /** List of all the contents */
    contents: ContentResolver;
    /** Show custom_notification */
    customNotification: CustomNotification;
    /** List of all the custom_notifications */
    customNotifications: CustomNotificationResolver;
    /** Show fan_group */
    fanGroup: FanGroup;
    /** Show fan_group_user */
    fanGroupUser: FanGroupUser;
    /** List of all the fan_group_users */
    fanGroupUsers: FanGroupUserResolver;
    /** List of all the fan_groups */
    fanGroups: FanGroupResolver;
    /** Show token_trigger */
    freeTokenTrigger: FreeTokenTrigger;
    /** List of available events for token triggers */
    freeTokenTriggerEvents: Array<TriggerEvent>;
    /** List of all the free_token_triggers */
    freeTokenTriggers: FreeTokenTriggerResolver;
    /** Show giveaway */
    giveaway: Giveaway;
    /** List of all the giveaways */
    giveaways: GiveawayResolver;
    /** Show group_post */
    groupPost: GroupPost;
    /** List of all the group_posts */
    groupPosts: GroupPostResolver;
    /** Show idea */
    idea: Idea;
    /** List of all the ideas */
    ideas: IdeaResolver;
    /** Show ideation_mission */
    ideationMission: IdeationMission;
    /** List of all the ideation_missions */
    ideationMissions: IdeationMissionResolver;
    /** Get current admin */
    me: AdminUser;
    /** Find a menu_item by ID */
    menuItem: MenuItem;
    /** List of all the menu_items */
    menuItems: MenuItemResolver;
    /** Show nft */
    nft: Nft;
    /** Show nft_benefit */
    nftBenefit: NftBenefit;
    /** List of all the nft_benefit_redemptions */
    nftBenefitRedemptions: NftBenefitRedemptionResolver;
    /** List of all the nft_benefits */
    nftBenefits: NftBenefitResolver;
    /** Show nft_collection */
    nftCollection: NftCollection;
    /** List of all the nft_collections */
    nftCollections: NftCollectionResolver;
    /** Show token_trigger */
    nftGiveaway: NftGiveaway;
    /** List of available events for nft giveaways */
    nftGiveawayEvents: Array<TriggerEvent>;
    /** List of all the nft_giveaways */
    nftGiveaways: NftGiveawayResolver;
    /** Show nft_handout */
    nftHandout: NftHandout;
    /** Show nft_handout_user */
    nftHandoutUser: NftHandoutUser;
    /** List of all the nft_handout_users */
    nftHandoutUsers: NftHandoutUserResolver;
    /** List of all the nft_handouts */
    nftHandouts: NftHandoutResolver;
    /** List of all the NFT media */
    nftMedia: NftMediumResolver;
    /** Show nft_medium */
    nftMedium: NftMedium;
    /** List of current rarities */
    nftRarities: Array<NftRarity>;
    /** Show nft_transfer_network */
    nftTransferNetwork: NftTransferNetwork;
    /** List of all the nft_transfer_networks */
    nftTransferNetworks: NftTransferNetworkResolver;
    /** List of all the nft_users */
    nftUsers: NftUserResolver;
    /** List of all the nfts */
    nfts: NftResolver;
    /** Currently pinned item */
    pinnedItem?: Maybe<FeedPin>;
    /** Show profile field */
    profileField: ProfileField;
    /** Show profile field */
    profileFieldOption: ProfileFieldOption;
    /** List of all the profile_field_options */
    profileFieldOptions: ProfileFieldOptionResolver;
    /** List of all the profile_fields */
    profileFields: ProfileFieldResolver;
    /** Show proposal */
    proposal: Proposal;
    /** Show proposal_period */
    proposalPeriod: ProposalPeriod;
    /** List of all the proposal_periods */
    proposalPeriods: ProposalPeriodResolver;
    /** List of all the proposals */
    proposals: ProposalResolver;
    /** Show Restrictions of this platform */
    restrictions: Restrictions;
    /** List of all the sales statitstics */
    salesStatistics: SalesStatisticResolver;
    /** Show shop_product */
    shopProduct: ShopProduct;
    /** Show shop_product_tier */
    shopProductTier: ShopProductTier;
    /** List of all the shop_product_tiers */
    shopProductTiers: ShopProductTierResolver;
    /** List of all the shop_products */
    shopProducts: ShopProductResolver;
    /** Show sponsor */
    sponsor: Sponsor;
    /** Show sponsor statistics */
    sponsorStatistics: SponsorStatsCollection;
    /** List of all the sponsors */
    sponsors: SponsorResolver;
    /** Show content */
    staticPage: StaticPage;
    /** List of all the static_pages */
    staticPages: StaticPageResolver;
    /** Show setting */
    systemSetting: SystemSetting;
    /** Get system settings */
    systemSettings: SystemSettingsResolver;
    /** Show token_handout */
    tokenHandout: TokenHandout;
    /** Show token_handout_user */
    tokenHandoutUser: TokenHandoutUser;
    /** List of all the token_handout_users */
    tokenHandoutUsers: TokenHandoutUserResolver;
    /** List of all the token_handouts */
    tokenHandouts: TokenHandoutResolver;
    /** List of all the token statitstics by month */
    tokenStatistics: TokenStatistic;
    /** Show transaction */
    transaction: Transaction;
    /** List of all the transactions */
    transactions: TransactionResolver;
    /** List of available events for giveaways */
    triggerEvents: Array<TriggerEvent>;
    /** Find a ugc_report by ID */
    ugcReport: UgcReport;
    /** Find a ugc_report_type by ID */
    ugcReportType: UgcReportTyp;
    /** List of all the ugc_report_types */
    ugcReportTypes: UgcReportTypeResolver;
    /** List of all the ugc_reports */
    ugcReports: UgcReportResolver;
    /** Show user */
    user: User;
    /** Show user by uid */
    userByUid: User;
    /** Returns user device type statistics */
    userDeviceStatistics: UserDeviceStatistics;
    /** List of all the user_giveaways */
    userGiveaways: UserGiveawayResolver;
    /** List of all the user categories */
    userMedia: UserMediumResolver;
    /** Show user_medium */
    userMedium: UserMedium;
    /** Show user_order */
    userOrder: UserOrder;
    /** List of all the user_orders */
    userOrders: UserOrderResolver;
    /** Show user_profile_field */
    userProfileField: UserProfileField;
    /** List of all the user_profile_fields */
    userProfileFields: UserProfileFieldResolver;
    /** List of all the users */
    users: UserResolver;
    /** Show voting */
    voting: Voting;
    /** List of all the votings */
    votings: VotingResolver;
};
export declare type QueryActivityNotificationArgs = {
    id: Scalars['ID'];
};
export declare type QueryActivityNotificationsArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<ActivityNotificationFilterInput>;
    sort?: Maybe<ActivityNotificationSortInput>;
};
export declare type QueryActivityPointArgs = {
    id: Scalars['ID'];
};
export declare type QueryActivityPointsArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<ActivityPointFilterInput>;
    sort?: Maybe<ActivityPointSortInput>;
};
export declare type QueryActivityPointsHighscoreArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    fanVault: FanVaultEnum;
};
export declare type QueryAdminUserArgs = {
    id: Scalars['ID'];
};
export declare type QueryAdminUserConfirmAccountArgs = {
    confirmationToken: Scalars['String'];
    redirectUrl: Scalars['String'];
};
export declare type QueryAdminUsersArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<AdminUserFilterInput>;
    sort?: Maybe<AdminUserSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryAmaQuestionArgs = {
    id: Scalars['ID'];
};
export declare type QueryAmaQuestionsArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<AmaQuestionFilterInput>;
    sort?: Maybe<AmaQuestionSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryAmaSessionArgs = {
    id: Scalars['ID'];
};
export declare type QueryAmaSessionsArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<AmaSessionFilterInput>;
    sort?: Maybe<AmaSessionSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryAnnouncementArgs = {
    id: Scalars['ID'];
};
export declare type QueryAnnouncementsArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<AnnouncementFilterInput>;
    sort?: Maybe<AnnouncementSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryCommentArgs = {
    id: Scalars['ID'];
};
export declare type QueryCommentsArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<CommentFilterInput>;
    sort?: Maybe<CommentSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryContentArgs = {
    id: Scalars['ID'];
};
export declare type QueryContentCategoriesArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<ContentCategoryFilterInput>;
    sort?: Maybe<ContentCategorySortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryContentCategoryArgs = {
    id: Scalars['ID'];
};
export declare type QueryContentMediaArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<ContentMediumFilterInput>;
    sort?: Maybe<ContentMediumSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryContentMediumArgs = {
    id: Scalars['ID'];
};
export declare type QueryContentsArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<ContentFilterInput>;
    sort?: Maybe<ContentSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryCustomNotificationArgs = {
    id: Scalars['ID'];
};
export declare type QueryCustomNotificationsArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<CustomNotificationFilterInput>;
    sort?: Maybe<CustomNotificationSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryFanGroupArgs = {
    id: Scalars['ID'];
};
export declare type QueryFanGroupUserArgs = {
    id: Scalars['ID'];
};
export declare type QueryFanGroupUsersArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<FanGroupUserFilterInput>;
    sort?: Maybe<FanGroupUserSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryFanGroupsArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<FanGroupFilterInput>;
    sort?: Maybe<FanGroupSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryFreeTokenTriggerArgs = {
    id: Scalars['ID'];
};
export declare type QueryFreeTokenTriggersArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<FreeTokenTriggerFilterInput>;
    sort?: Maybe<FreeTokenTriggerSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryGiveawayArgs = {
    id: Scalars['ID'];
};
export declare type QueryGiveawaysArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<GiveawayFilterInput>;
    sort?: Maybe<GiveawaySortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryGroupPostArgs = {
    id: Scalars['ID'];
};
export declare type QueryGroupPostsArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<GroupPostFilterInput>;
    sort?: Maybe<GroupPostSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryIdeaArgs = {
    id: Scalars['ID'];
};
export declare type QueryIdeasArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<IdeaFilterInput>;
    sort?: Maybe<IdeaSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryIdeationMissionArgs = {
    id: Scalars['ID'];
};
export declare type QueryIdeationMissionsArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<IdeationMissionFilterInput>;
    sort?: Maybe<IdeationMissionSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryMenuItemArgs = {
    id: Scalars['ID'];
};
export declare type QueryMenuItemsArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<MenuItemFilterInput>;
};
export declare type QueryNftArgs = {
    id: Scalars['ID'];
};
export declare type QueryNftBenefitArgs = {
    id: Scalars['ID'];
};
export declare type QueryNftBenefitRedemptionsArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<NftBenefitRedemptionFilterInput>;
    sort?: Maybe<NftBenefitRedemptionSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryNftBenefitsArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<NftBenefitFilterInput>;
    sort?: Maybe<NftBenefitSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryNftCollectionArgs = {
    id: Scalars['ID'];
};
export declare type QueryNftCollectionsArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<NftCollectionFilterInput>;
    sort?: Maybe<NftCollectionSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryNftGiveawayArgs = {
    id: Scalars['ID'];
};
export declare type QueryNftGiveawaysArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<NftGiveawayFilterInput>;
    sort?: Maybe<NftGiveawaySortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryNftHandoutArgs = {
    id: Scalars['ID'];
};
export declare type QueryNftHandoutUserArgs = {
    id: Scalars['ID'];
};
export declare type QueryNftHandoutUsersArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<NftHandoutUserFilterInput>;
    sort?: Maybe<NftHandoutUserSortInput>;
};
export declare type QueryNftHandoutsArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<NftHandoutFilterInput>;
    sort?: Maybe<NftHandoutSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryNftMediaArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<NftMediumFilterInput>;
    sort?: Maybe<NftMediumSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryNftMediumArgs = {
    id: Scalars['ID'];
};
export declare type QueryNftTransferNetworkArgs = {
    id: Scalars['ID'];
};
export declare type QueryNftTransferNetworksArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<NftTransferNetworkFilterInput>;
    sort?: Maybe<NftTransferNetworkSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryNftUsersArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<NftUserFilterInput>;
    sort?: Maybe<NftUserSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryNftsArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<NftFilterInput>;
    sort?: Maybe<NftSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryProfileFieldArgs = {
    id: Scalars['ID'];
};
export declare type QueryProfileFieldOptionArgs = {
    id: Scalars['ID'];
};
export declare type QueryProfileFieldOptionsArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<ProfileFieldOptionFilterInput>;
    sort?: Maybe<ProfileFieldOptionSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryProfileFieldsArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<ProfileFieldFilterInput>;
    sort?: Maybe<ProfileFieldSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryProposalArgs = {
    id: Scalars['ID'];
};
export declare type QueryProposalPeriodArgs = {
    id: Scalars['ID'];
};
export declare type QueryProposalPeriodsArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<ProposalPeriodFilterInput>;
    sort?: Maybe<ProposalPeriodSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryProposalsArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<ProposalFilterInput>;
    sort?: Maybe<ProposalSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryShopProductArgs = {
    id: Scalars['ID'];
};
export declare type QueryShopProductTierArgs = {
    id: Scalars['ID'];
};
export declare type QueryShopProductTiersArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<ShopProductTierFilterInput>;
    sort?: Maybe<ShopProductTierSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryShopProductsArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<ShopProductFilterInput>;
    sort?: Maybe<ShopProductSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QuerySponsorArgs = {
    id: Scalars['ID'];
};
export declare type QuerySponsorStatisticsArgs = {
    id: Scalars['ID'];
    filter?: Maybe<SponsorStatisticsFilterInput>;
};
export declare type QuerySponsorsArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<SponsorFilterInput>;
    sort?: Maybe<SponsorSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryStaticPageArgs = {
    id: Scalars['ID'];
};
export declare type QueryStaticPagesArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<StaticPageFilterInput>;
    sort?: Maybe<StaticPageSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QuerySystemSettingArgs = {
    id: Scalars['ID'];
};
export declare type QueryTokenHandoutArgs = {
    id: Scalars['ID'];
};
export declare type QueryTokenHandoutUserArgs = {
    id: Scalars['ID'];
};
export declare type QueryTokenHandoutUsersArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<TokenHandoutUserFilterInput>;
    sort?: Maybe<TokenHandoutUserSortInput>;
};
export declare type QueryTokenHandoutsArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<TokenHandoutFilterInput>;
    sort?: Maybe<TokenHandoutSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryTransactionArgs = {
    id: Scalars['ID'];
};
export declare type QueryTransactionsArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<TransactionFilterInput>;
    sort?: Maybe<TransactionSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryUgcReportArgs = {
    id: Scalars['ID'];
};
export declare type QueryUgcReportTypeArgs = {
    id: Scalars['ID'];
};
export declare type QueryUgcReportTypesArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<UgcReportTypeFilterInput>;
    sort?: Maybe<UgcReportTypeSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryUgcReportsArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<UgcReportFilterInput>;
    sort?: Maybe<UgcReportSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryUserArgs = {
    id: Scalars['ID'];
};
export declare type QueryUserByUidArgs = {
    uid: Scalars['ID'];
    provider: Scalars['String'];
};
export declare type QueryUserGiveawaysArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<UserGiveawayFilterInput>;
    sort?: Maybe<UserGiveawaySortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryUserMediaArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<UserMediumFilterInput>;
    sort?: Maybe<UserMediumSortInput>;
};
export declare type QueryUserMediumArgs = {
    id: Scalars['ID'];
};
export declare type QueryUserOrderArgs = {
    id: Scalars['ID'];
};
export declare type QueryUserOrdersArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<UserOrderFilterInput>;
    sort?: Maybe<UserOrderSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryUserProfileFieldArgs = {
    id: Scalars['ID'];
};
export declare type QueryUserProfileFieldsArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<UserProfileFieldFilterInput>;
    sort?: Maybe<UserProfileFieldSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryUsersArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<UserFilterInput>;
    sort?: Maybe<UserSortInput>;
    search?: Maybe<Scalars['String']>;
};
export declare type QueryVotingArgs = {
    id: Scalars['ID'];
};
export declare type QueryVotingsArgs = {
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    ids?: Maybe<Array<Scalars['ID']>>;
    filter?: Maybe<VotingFilterInput>;
    sort?: Maybe<VotingSortInput>;
    search?: Maybe<Scalars['String']>;
};
/** Autogenerated input type of RefreshOembedDataMutation */
export declare type RefreshOembedDataMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of RefreshOembedDataMutation */
export declare type RefreshOembedDataMutationPayload = {
    __typename?: 'RefreshOembedDataMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    contentMedium: ContentMedium;
};
/** Autogenerated input type of RefundVotingMutation */
export declare type RefundVotingMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of RefundVotingMutation */
export declare type RefundVotingMutationPayload = {
    __typename?: 'RefundVotingMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    message: Scalars['String'];
    status: Scalars['Int'];
};
export declare enum ReportableStatusEnum {
    Unreported = "unreported",
    Reported = "reported",
    UnderReview = "under_review",
    ReviewRequested = "review_requested",
    Cleared = "cleared",
    Hidden = "hidden"
}
/** Autogenerated input type of RequestNftCollectionMetadataUriMutation */
export declare type RequestNftCollectionMetadataUriMutationInput = {
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of RequestNftCollectionMetadataUriMutation */
export declare type RequestNftCollectionMetadataUriMutationPayload = {
    __typename?: 'RequestNftCollectionMetadataUriMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    metadataUri: Scalars['String'];
};
export declare type Restrictions = {
    __typename?: 'Restrictions';
    allowAppStore: Scalars['Boolean'];
    allowBrandControl: Scalars['Boolean'];
    allowConnectAnalytics: Scalars['Boolean'];
    allowCustomDomain: Scalars['Boolean'];
    allowMultiLanguage: Scalars['Boolean'];
    allowNativeApp: Scalars['Boolean'];
    allowPayments: Scalars['Boolean'];
    allowRightsManagement: Scalars['Boolean'];
    maxRegisteredUsers?: Maybe<Scalars['Int']>;
};
export declare type SalesStatistic = {
    __typename?: 'SalesStatistic';
    orderedAfter: Scalars['ISO8601DateTime'];
    orders: Array<UserOrder>;
    ordersNum: Scalars['Int'];
    ordersValue: Scalars['Float'];
};
export declare type SalesStatisticResolver = {
    __typename?: 'SalesStatisticResolver';
    monthly: SalesStatistic;
    mtd: SalesStatistic;
    weekly: SalesStatistic;
    wtd: SalesStatistic;
    yearly: SalesStatistic;
    ytd: SalesStatistic;
};
export declare type ShopProduct = {
    __typename?: 'ShopProduct';
    amountRefunded: Scalars['Int'];
    amountSold: Scalars['Int'];
    amountSoldInFiat: Scalars['Int'];
    amountSoldInTokens: Scalars['Int'];
    androidPrice?: Maybe<Scalars['Float']>;
    androidPriceTier?: Maybe<ShopProductTier>;
    androidPriceTierId?: Maybe<Scalars['ID']>;
    androidSku?: Maybe<Scalars['String']>;
    androidTargetVisible?: Maybe<Scalars['Boolean']>;
    bucketsCapacity: Array<NftBucketCapacity>;
    createdAt: Scalars['ISO8601DateTime'];
    id: Scalars['ID'];
    iosPrice?: Maybe<Scalars['Float']>;
    iosPriceTier?: Maybe<ShopProductTier>;
    iosPriceTierId?: Maybe<Scalars['ID']>;
    iosSku?: Maybe<Scalars['String']>;
    iosTargetVisible?: Maybe<Scalars['Boolean']>;
    isAndroid: Scalars['Boolean'];
    isIos: Scalars['Boolean'];
    isWeb: Scalars['Boolean'];
    maxPerDay?: Maybe<Scalars['Int']>;
    maxPerDayReached: Scalars['Boolean'];
    maxSellable?: Maybe<Scalars['Int']>;
    nft?: Maybe<Nft>;
    nftBuckets: Array<NftBucket>;
    nftBucketsCount: Scalars['Int'];
    nftId?: Maybe<Scalars['ID']>;
    nftOutOfStock: Scalars['Boolean'];
    productMedium?: Maybe<ContentMedium>;
    productMediumId?: Maybe<Scalars['ID']>;
    productType: ShopProductProductTypeEnum;
    tokenPrice?: Maybe<Scalars['Int']>;
    tokens?: Maybe<Scalars['Int']>;
    tokensBonus?: Maybe<Scalars['Int']>;
    translations: Array<ShopProductTranslation>;
    updatedAt: Scalars['ISO8601DateTime'];
    userOrders: Array<UserOrder>;
    userOrdersCount: Scalars['Int'];
    webPrice?: Maybe<Scalars['Float']>;
    webPriceTier?: Maybe<ShopProductTier>;
    webPriceTierId?: Maybe<Scalars['ID']>;
    webSku?: Maybe<Scalars['String']>;
    webTargetVisible?: Maybe<Scalars['Boolean']>;
};
export declare type ShopProductFilterInput = {
    id?: Maybe<FilterIdInput>;
    productType?: Maybe<ShopProductProductTypeEnum>;
    targetShop?: Maybe<ShopProductTargetShopEnum>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    tokens?: Maybe<FilterNumberInput>;
    tokensBonus?: Maybe<FilterNumberInput>;
    webPrice?: Maybe<FilterNumberInput>;
    androidPrice?: Maybe<FilterNumberInput>;
    iosPrice?: Maybe<FilterNumberInput>;
    webSku?: Maybe<FilterTextInput>;
    androidSku?: Maybe<FilterTextInput>;
    iosSku?: Maybe<FilterTextInput>;
    title?: Maybe<FilterTextInput>;
    description?: Maybe<FilterTextInput>;
    webTargetVisible?: Maybe<Scalars['Boolean']>;
    androidTargetVisible?: Maybe<Scalars['Boolean']>;
    iosTargetVisible?: Maybe<Scalars['Boolean']>;
    nftBucketsCount?: Maybe<FilterNumberInput>;
    tokenPrice?: Maybe<FilterNumberInput>;
    maxSellable?: Maybe<FilterNumberInput>;
    nftOutOfStock?: Maybe<Scalars['Boolean']>;
    nftId?: Maybe<FilterNumberInput>;
    tierId?: Maybe<Scalars['ID']>;
    webPriceTierId?: Maybe<FilterIdInput>;
    androidPriceTierId?: Maybe<FilterIdInput>;
    iosPriceTierId?: Maybe<FilterIdInput>;
    visibleInAnyTarget?: Maybe<Scalars['Boolean']>;
};
export declare type ShopProductInput = {
    productType?: Maybe<ShopProductProductTypeEnum>;
    tokens?: Maybe<Scalars['Int']>;
    tokensBonus?: Maybe<Scalars['Int']>;
    webPrice?: Maybe<Scalars['Float']>;
    androidPrice?: Maybe<Scalars['Float']>;
    iosPrice?: Maybe<Scalars['Float']>;
    webSku?: Maybe<Scalars['String']>;
    androidSku?: Maybe<Scalars['String']>;
    iosSku?: Maybe<Scalars['String']>;
    translations?: Maybe<Array<ShopProductTranslationInput>>;
    nftBuckets?: Maybe<Array<NftBucketInput>>;
    webTargetVisible?: Maybe<Scalars['Boolean']>;
    androidTargetVisible?: Maybe<Scalars['Boolean']>;
    iosTargetVisible?: Maybe<Scalars['Boolean']>;
    productMediumId?: Maybe<Scalars['ID']>;
    nftId?: Maybe<Scalars['ID']>;
    webPriceTierId?: Maybe<Scalars['ID']>;
    androidPriceTierId?: Maybe<Scalars['ID']>;
    iosPriceTierId?: Maybe<Scalars['ID']>;
    maxSellable?: Maybe<Scalars['Int']>;
    tokenPrice?: Maybe<Scalars['Int']>;
    maxPerDay?: Maybe<Scalars['Int']>;
};
export declare enum ShopProductProductTypeEnum {
    SingleItem = "single_item",
    Subscription = "subscription",
    NftFixedPrice = "nft_fixed_price",
    NftPackage = "nft_package"
}
export declare type ShopProductResolver = {
    __typename?: 'ShopProductResolver';
    shopProducts: Array<ShopProduct>;
    total: Scalars['Int'];
};
export declare type ShopProductSortInput = {
    id?: Maybe<SortEnum>;
    productType?: Maybe<SortEnum>;
    targetShop?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    tokens?: Maybe<SortEnum>;
    tokensBonus?: Maybe<SortEnum>;
    webPrice?: Maybe<SortEnum>;
    androidPrice?: Maybe<SortEnum>;
    iosPrice?: Maybe<SortEnum>;
    userOrdersCount?: Maybe<SortEnum>;
    webSku?: Maybe<SortEnum>;
    androidSku?: Maybe<SortEnum>;
    iosSku?: Maybe<SortEnum>;
    title?: Maybe<LocalizedSorterInput>;
    description?: Maybe<LocalizedSorterInput>;
    webTargetVisible?: Maybe<SortEnum>;
    androidTargetVisible?: Maybe<SortEnum>;
    iosTargetVisible?: Maybe<SortEnum>;
    nftOutOfStock?: Maybe<SortEnum>;
    maxSellable?: Maybe<SortEnum>;
    tokenPrice?: Maybe<SortEnum>;
    webPriceTierId?: Maybe<SortEnum>;
    androidPriceTierId?: Maybe<SortEnum>;
    iosPriceTierId?: Maybe<SortEnum>;
    nftId?: Maybe<SortEnum>;
};
export declare enum ShopProductTargetShopEnum {
    Web = "web",
    Ios = "ios",
    Android = "android"
}
export declare type ShopProductTier = {
    __typename?: 'ShopProductTier';
    androidProductsCount: Scalars['Int'];
    createdAt: Scalars['ISO8601DateTime'];
    id: Scalars['ID'];
    iosProductsCount: Scalars['Int'];
    name: Scalars['String'];
    price: Scalars['Float'];
    shopProductsCount: Scalars['Int'];
    sku?: Maybe<Scalars['String']>;
    targetShop?: Maybe<ShopProductTargetShopEnum>;
    updatedAt: Scalars['ISO8601DateTime'];
    webProductsCount: Scalars['Int'];
};
export declare type ShopProductTierFilterInput = {
    id?: Maybe<FilterIdInput>;
    targetShop?: Maybe<ShopProductTargetShopEnum>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    price?: Maybe<FilterNumberInput>;
    sku?: Maybe<FilterTextInput>;
    name?: Maybe<FilterTextInput>;
};
export declare type ShopProductTierInput = {
    targetShop?: Maybe<ShopProductTargetShopEnum>;
    price?: Maybe<Scalars['Float']>;
    sku?: Maybe<Scalars['String']>;
    name?: Maybe<Scalars['String']>;
};
export declare type ShopProductTierResolver = {
    __typename?: 'ShopProductTierResolver';
    shopProductTiers: Array<ShopProductTier>;
    total: Scalars['Int'];
};
export declare type ShopProductTierSortInput = {
    id?: Maybe<SortEnum>;
    targetShop?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    price?: Maybe<SortEnum>;
    sku?: Maybe<SortEnum>;
    name?: Maybe<SortEnum>;
};
export declare type ShopProductTranslation = {
    __typename?: 'ShopProductTranslation';
    content?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    locale: Scalars['String'];
    successMessage?: Maybe<Scalars['String']>;
    title: Scalars['String'];
};
export declare type ShopProductTranslationInput = {
    id?: Maybe<Scalars['ID']>;
    locale?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
    description?: Maybe<Scalars['String']>;
    content?: Maybe<Scalars['String']>;
    successMessage?: Maybe<Scalars['String']>;
};
export declare enum SortEnum {
    Asc = "asc",
    Desc = "desc"
}
export declare enum SortEnumWithDefault {
    Asc = "asc",
    Desc = "desc",
    Default = "default"
}
export declare type Sponsor = {
    __typename?: 'Sponsor';
    createdAt: Scalars['ISO8601DateTime'];
    customNotificationsStatistics?: Maybe<SponsorStats>;
    giveaways?: Maybe<Array<Giveaway>>;
    id: Scalars['ID'];
    name: Scalars['String'];
    nftGiveawaysStatistics?: Maybe<SponsorStats>;
    nftHandoutsStatistics?: Maybe<SponsorStats>;
    tokenGiveawaysStatistics?: Maybe<SponsorStats>;
    tokenHandoutsStatistics?: Maybe<SponsorStats>;
    updatedAt: Scalars['ISO8601DateTime'];
};
export declare type SponsorFilterInput = {
    id?: Maybe<FilterIdInput>;
    name?: Maybe<FilterTextInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
};
export declare type SponsorInput = {
    name?: Maybe<Scalars['String']>;
};
export declare type SponsorResolver = {
    __typename?: 'SponsorResolver';
    sponsors: Array<Sponsor>;
    total: Scalars['Int'];
};
export declare type SponsorSortInput = {
    id?: Maybe<SortEnum>;
    name?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
};
export declare type SponsorStatisticsFilterInput = {
    period?: Maybe<FilterDateInput>;
};
export declare type SponsorStats = {
    __typename?: 'SponsorStats';
    totalActive?: Maybe<Scalars['Int']>;
    totalAmount: Scalars['Int'];
    totalCount: Scalars['Int'];
    totalTimes: Scalars['Int'];
    uniqueSponsorUsers?: Maybe<Scalars['Int']>;
};
export declare type SponsorStatsCollection = {
    __typename?: 'SponsorStatsCollection';
    customNotificationsStatistics: SponsorStats;
    nftGiveawaysStatistics: SponsorStats;
    nftHandoutsStatistics: SponsorStats;
    tokenGiveawaysStatistics: SponsorStats;
    tokenHandoutsStatistics: SponsorStats;
};
/** Autogenerated return type of StartAutomaticPeriods */
export declare type StartAutomaticPeriodsPayload = {
    __typename?: 'StartAutomaticPeriodsPayload';
    message: Scalars['String'];
    status: Scalars['Int'];
};
export declare type StaticPage = {
    __typename?: 'StaticPage';
    availabilities?: Maybe<Array<Availability>>;
    availabilityType: AvailabilityTypeEnum;
    availableFors: Array<Scalars['String']>;
    comments: Array<Comment>;
    commentsCount?: Maybe<Scalars['Int']>;
    createdAt: Scalars['ISO8601DateTime'];
    id: Scalars['ID'];
    isCommentable: Scalars['Boolean'];
    menuItemId?: Maybe<Scalars['ID']>;
    onlyForAvailables?: Maybe<Scalars['Boolean']>;
    previewToken?: Maybe<Scalars['String']>;
    previewUrl?: Maybe<Scalars['String']>;
    previewUrls: Array<PreviewUrl>;
    requiredNfts?: Maybe<Array<Nft>>;
    requiredSubscriptions?: Maybe<Array<ShopProduct>>;
    status: StaticPageStatusEnum;
    translations: Array<StaticPageTranslation>;
    updatedAt: Scalars['ISO8601DateTime'];
};
export declare type StaticPageFilterInput = {
    id?: Maybe<FilterIdInput>;
    availableFor?: Maybe<Array<AvailabilityAvailableForEnum>>;
    status?: Maybe<StaticPageStatusEnum>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    title?: Maybe<FilterTextInput>;
    body?: Maybe<FilterTextInput>;
    slug?: Maybe<FilterTextInput>;
    menuItemId?: Maybe<FilterForeignKeyInput>;
    commentsCount?: Maybe<FilterNumberInput>;
    isCommentable?: Maybe<Scalars['Boolean']>;
    onlyForAvailables?: Maybe<Scalars['Boolean']>;
    availabilityType?: Maybe<AvailabilityTypeEnum>;
};
export declare type StaticPageInput = {
    translations?: Maybe<Array<StaticPageTranslationInput>>;
    isCommentable?: Maybe<Scalars['Boolean']>;
    availabilities?: Maybe<Array<AvailabilityInput>>;
    onlyForAvailables?: Maybe<Scalars['Boolean']>;
    availabilityType?: Maybe<AvailabilityTypeEnum>;
};
export declare type StaticPageResolver = {
    __typename?: 'StaticPageResolver';
    staticPages: Array<StaticPage>;
    total: Scalars['Int'];
};
export declare type StaticPageSortInput = {
    id?: Maybe<SortEnum>;
    status?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    title?: Maybe<LocalizedSorterInput>;
    body?: Maybe<LocalizedSorterInput>;
    slug?: Maybe<LocalizedSorterInput>;
    commentsCount?: Maybe<SortEnum>;
    onlyForAvailables?: Maybe<SortEnum>;
    availabilityType?: Maybe<SortEnum>;
};
export declare enum StaticPageStatusEnum {
    Draft = "draft",
    Published = "published",
    Archived = "archived"
}
export declare type StaticPageTranslation = {
    __typename?: 'StaticPageTranslation';
    body?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    locale: Scalars['String'];
    metaDescription?: Maybe<Scalars['String']>;
    metaTitle?: Maybe<Scalars['String']>;
    slug: Scalars['String'];
    title?: Maybe<Scalars['String']>;
};
export declare type StaticPageTranslationInput = {
    id?: Maybe<Scalars['ID']>;
    locale?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
    body?: Maybe<Scalars['String']>;
    slug?: Maybe<Scalars['String']>;
    metaTitle?: Maybe<Scalars['String']>;
    metaDescription?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of StopAutomaticPeriods */
export declare type StopAutomaticPeriodsPayload = {
    __typename?: 'StopAutomaticPeriodsPayload';
    message: Scalars['String'];
    status: Scalars['Int'];
};
export declare type SystemSetting = {
    __typename?: 'SystemSetting';
    value: Scalars['String'];
    var: Scalars['String'];
};
export declare type SystemSettingInput = {
    /** variable */
    var?: Maybe<Scalars['String']>;
    /** value */
    value?: Maybe<Scalars['String']>;
};
export declare type SystemSettingsGroup = {
    __typename?: 'SystemSettingsGroup';
    balances: Array<Balance>;
    settings: Array<SystemSetting>;
};
export declare type SystemSettingsResolver = {
    __typename?: 'SystemSettingsResolver';
    amaSessionSettings: SystemSettingsGroup;
    apDistributionSettings: SystemSettingsGroup;
    commentBoosterSettings: SystemSettingsGroup;
    contactAddressSettings: SystemSettingsGroup;
    contentBoosterSettings: SystemSettingsGroup;
    contentUnlockerSettings: SystemSettingsGroup;
    fanGroupSettings: SystemSettingsGroup;
    fanVaultSettings: SystemSettingsGroup;
    friendsInviteSettings: SystemSettingsGroup;
    generalSettings: SystemSettingsGroup;
    groupPostBoosterSettings: SystemSettingsGroup;
    ideationMissionSettings: SystemSettingsGroup;
    nfcSettings: SystemSettingsGroup;
    proposalBoosterSettings: SystemSettingsGroup;
    proposalPeriodSettings: SystemSettingsGroup;
    shopSettings: SystemSettingsGroup;
    tokenContractSettings: SystemSettingsGroup;
    votingBoosterSettings: SystemSettingsGroup;
};
export declare type TokenHandout = {
    __typename?: 'TokenHandout';
    attempts?: Maybe<Scalars['Int']>;
    createdAt: Scalars['ISO8601DateTime'];
    delayedPublicationJobId?: Maybe<Scalars['ID']>;
    handoutAt?: Maybe<Scalars['ISO8601DateTime']>;
    heroMedium?: Maybe<ContentMedium>;
    heroMediumId?: Maybe<Scalars['ID']>;
    id: Scalars['ID'];
    promptDialog?: Maybe<Scalars['Boolean']>;
    skipNotification?: Maybe<Scalars['Boolean']>;
    sponsor?: Maybe<Sponsor>;
    sponsorId?: Maybe<Scalars['ID']>;
    statistics?: Maybe<TokenHandoutStats>;
    status: TokenHandoutStatusEnum;
    tokenAmount?: Maybe<Scalars['Int']>;
    tokenHandoutUsers: Array<TokenHandoutUser>;
    tokenHandoutUsersCount: Scalars['Int'];
    translations: Array<TokenHandoutTranslation>;
    updatedAt: Scalars['ISO8601DateTime'];
    userFilter?: Maybe<UserFilter>;
    userSearch?: Maybe<Scalars['String']>;
};
export declare type TokenHandoutFilterInput = {
    id?: Maybe<FilterIdInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    handoutAt?: Maybe<FilterDateInput>;
    status?: Maybe<TokenHandoutStatusEnum>;
    tokenAmount?: Maybe<FilterNumberInput>;
    promptDialog?: Maybe<Scalars['Boolean']>;
    sponsorId?: Maybe<FilterIdInput>;
    delayedPublicationJobId?: Maybe<FilterIdInput>;
    title?: Maybe<FilterTextInput>;
    content?: Maybe<FilterTextInput>;
    message?: Maybe<FilterTextInput>;
    externalLink?: Maybe<FilterTextInput>;
    tokenHandoutUsersCount?: Maybe<FilterNumberInput>;
};
export declare type TokenHandoutInput = {
    tokenAmount?: Maybe<Scalars['Int']>;
    promptDialog?: Maybe<Scalars['Boolean']>;
    translations?: Maybe<Array<TokenHandoutTranslationInput>>;
    heroMediumId?: Maybe<Scalars['ID']>;
    sponsorId?: Maybe<Scalars['ID']>;
    handoutAt?: Maybe<Scalars['ISO8601DateTime']>;
    skipNotification?: Maybe<Scalars['Boolean']>;
};
export declare type TokenHandoutResolver = {
    __typename?: 'TokenHandoutResolver';
    tokenHandouts: Array<TokenHandout>;
    total: Scalars['Int'];
};
export declare type TokenHandoutSortInput = {
    id?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    handoutAt?: Maybe<SortEnum>;
    tokenAmount?: Maybe<SortEnum>;
    promptDialog?: Maybe<SortEnum>;
    sponsorId?: Maybe<SortEnum>;
    title?: Maybe<LocalizedSorterInput>;
    content?: Maybe<LocalizedSorterInput>;
    message?: Maybe<LocalizedSorterInput>;
    externalLink?: Maybe<LocalizedSorterInput>;
    tokenHandoutUsersCount?: Maybe<SortEnum>;
    delayedPublicationJobId?: Maybe<SortEnum>;
    status?: Maybe<SortEnum>;
};
export declare type TokenHandoutStats = {
    __typename?: 'TokenHandoutStats';
    amount?: Maybe<Scalars['Int']>;
    countTrigger?: Maybe<Scalars['Boolean']>;
    id: Scalars['ID'];
    numberOfUsers?: Maybe<Scalars['Int']>;
    times?: Maybe<Scalars['Int']>;
    userIds?: Maybe<Array<Scalars['ID']>>;
};
export declare enum TokenHandoutStatusEnum {
    Draft = "draft",
    Scheduled = "scheduled",
    Deploying = "deploying",
    Published = "published"
}
export declare type TokenHandoutTranslation = {
    __typename?: 'TokenHandoutTranslation';
    content?: Maybe<Scalars['String']>;
    ctaText?: Maybe<Scalars['String']>;
    externalLink?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    locale: Scalars['String'];
    message?: Maybe<Scalars['String']>;
    title: Scalars['String'];
};
export declare type TokenHandoutTranslationInput = {
    id?: Maybe<Scalars['ID']>;
    locale?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
    content?: Maybe<Scalars['String']>;
    message?: Maybe<Scalars['String']>;
    externalLink?: Maybe<Scalars['String']>;
    ctaText?: Maybe<Scalars['String']>;
};
export declare type TokenHandoutUser = {
    __typename?: 'TokenHandoutUser';
    createdAt: Scalars['ISO8601DateTime'];
    id: Scalars['ID'];
    tokenHandout: TokenHandout;
    tokenHandoutId: Scalars['ID'];
    updatedAt: Scalars['ISO8601DateTime'];
    user: User;
    userId: Scalars['ID'];
};
export declare type TokenHandoutUserFilterInput = {
    id?: Maybe<FilterIdInput>;
    userId?: Maybe<FilterIdInput>;
    tokenHandoutId?: Maybe<FilterIdInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
};
export declare type TokenHandoutUserResolver = {
    __typename?: 'TokenHandoutUserResolver';
    tokenHandoutUsers: Array<TokenHandoutUser>;
    total: Scalars['Int'];
};
export declare type TokenHandoutUserSortInput = {
    id?: Maybe<SortEnum>;
    userId?: Maybe<SortEnum>;
    tokenHandoutId?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
};
export declare type TokenStatistic = {
    __typename?: 'TokenStatistic';
    endDate: Scalars['ISO8601Date'];
    months: Array<TokenStatisticMonth>;
    startDate: Scalars['ISO8601Date'];
    tokenIncluded: Scalars['Float'];
    tokenUsed: Scalars['Float'];
};
export declare type TokenStatisticMonth = {
    __typename?: 'TokenStatisticMonth';
    month: Scalars['Int'];
    tokenBalance: Scalars['Float'];
    tokenIncluded: Scalars['Float'];
    tokenUsed: Scalars['Float'];
    transactionCount: Scalars['Int'];
    year: Scalars['Int'];
};
export declare type Transactable = AmaQuestion | AmaSession | Comment | Content | Giveaway | GroupPost | Idea | IdeationMission | Proposal | ShopProduct | TokenHandout | Voting;
export declare type Transaction = {
    __typename?: 'Transaction';
    amount?: Maybe<Scalars['Float']>;
    blockNumber?: Maybe<Scalars['String']>;
    contractName?: Maybe<Scalars['String']>;
    createdAt: Scalars['ISO8601DateTime'];
    eventName?: Maybe<Scalars['String']>;
    from?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    info?: Maybe<Scalars['JSON']>;
    nftCount?: Maybe<Scalars['Int']>;
    nfts: Array<Nft>;
    option?: Maybe<Scalars['Int']>;
    to?: Maybe<Scalars['String']>;
    tokenContract?: Maybe<Scalars['String']>;
    transactable?: Maybe<Transactable>;
    transactableType?: Maybe<Scalars['String']>;
    txHash?: Maybe<Scalars['String']>;
    txStatus?: Maybe<TransactionStatusEnum>;
    updatedAt: Scalars['ISO8601DateTime'];
    user: User;
    userId: Scalars['ID'];
};
export declare type TransactionFilterInput = {
    id?: Maybe<FilterIdInput>;
    txHash?: Maybe<FilterTextInput>;
    blockNumber?: Maybe<FilterTextInput>;
    from?: Maybe<FilterTextInput>;
    to?: Maybe<FilterTextInput>;
    amount?: Maybe<FilterNumberInput>;
    contractName?: Maybe<FilterTextInput>;
    eventName?: Maybe<FilterTextInput>;
    info?: Maybe<FilterTextInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    option?: Maybe<FilterNumberInput>;
    userId?: Maybe<FilterIdInput>;
    txStatus?: Maybe<TransactionStatusEnum>;
    transactableType?: Maybe<FilterTextInput>;
    tokenContract?: Maybe<FilterTextInput>;
};
export declare type TransactionResolver = {
    __typename?: 'TransactionResolver';
    total: Scalars['Int'];
    transactions: Array<Transaction>;
};
export declare type TransactionSortInput = {
    id?: Maybe<SortEnum>;
    txHash?: Maybe<SortEnum>;
    blockNumber?: Maybe<SortEnum>;
    from?: Maybe<SortEnum>;
    to?: Maybe<SortEnum>;
    amount?: Maybe<SortEnum>;
    contractName?: Maybe<SortEnum>;
    eventName?: Maybe<SortEnum>;
    info?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    option?: Maybe<SortEnum>;
    userId?: Maybe<SortEnum>;
    txStatus?: Maybe<SortEnum>;
    transactableType?: Maybe<SortEnum>;
    tokenContract?: Maybe<SortEnum>;
};
export declare enum TransactionStatusEnum {
    Pending = "pending",
    Complete = "complete",
    Failed = "failed"
}
/** Autogenerated input type of TransferNftMutation */
export declare type TransferNftMutationInput = {
    id: Scalars['ID'];
    userId: Scalars['ID'];
    amount: Scalars['Int'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of TransferNftMutation */
export declare type TransferNftMutationPayload = {
    __typename?: 'TransferNftMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    nft: Nft;
};
export declare type TriggerEvent = {
    __typename?: 'TriggerEvent';
    forResource?: Maybe<GiveawayEventResourceTypeEnum>;
    forceGiveaway?: Maybe<Scalars['Boolean']>;
    name: TriggerEventTypeEnum;
    priority?: Maybe<Scalars['String']>;
    supportsThreshold: Scalars['Boolean'];
    supportsUserLimit: Scalars['Boolean'];
};
export declare enum TriggerEventTypeEnum {
    NewUserWelcome = "new_user_welcome",
    UserOpensApp = "user_opens_app",
    UserInvites = "user_invites",
    UserIsInvited = "user_is_invited",
    BaseProfileCompleted = "base_profile_completed",
    CustomProfileCompleted = "custom_profile_completed",
    ContentBoost = "content_boost",
    ContentUnlock = "content_unlock",
    VotingPublished = "voting_published",
    VotingTokenless = "voting_tokenless",
    VotingTokenbasedFixed = "voting_tokenbased_fixed",
    VotingTokenbasedVariable = "voting_tokenbased_variable",
    IdeaStatusSelected = "idea_status_selected",
    IdeaStatusImplemented = "idea_status_implemented",
    IdeaStatusClubFav = "idea_status_club_fav",
    IdeaCreated = "idea_created",
    IdeaBoost = "idea_boost",
    IdeaBoostReceived = "idea_boost_received",
    CommentCreated = "comment_created",
    CommentBoost = "comment_boost",
    CommentBoostReceived = "comment_boost_received",
    ProposalCreated = "proposal_created",
    ProposalBoost = "proposal_boost",
    ProposalBoostReceived = "proposal_boost_received",
    ProposalStatusAccepted = "proposal_status_accepted",
    ProposalStatusImplemented = "proposal_status_implemented",
    ProposalStatusSuccessfull = "proposal_status_successfull",
    AmaQuestionCreated = "ama_question_created",
    AmaQuestionBoost = "ama_question_boost",
    AmaQuestionBoostReceived = "ama_question_boost_received",
    AmaQuestionStatusAnswered = "ama_question_status_answered",
    GroupCreated = "group_created",
    GroupJoined = "group_joined",
    GroupPostCreated = "group_post_created",
    GroupPostBoost = "group_post_boost",
    GroupPostBoostReceived = "group_post_boost_received",
    SubscriptionRenewed = "subscription_renewed",
    NftProductBought = "nft_product_bought",
    TokenPackageBought = "token_package_bought",
    NftPackageBought = "nft_package_bought",
    NftCollectionCompleted = "nft_collection_completed",
    UserScansQrCode = "user_scans_qr_code",
    UserScansNfc = "user_scans_nfc",
    ApiTriggered = "api_triggered"
}
/** Autogenerated input type of TriggerGiveawayEventMutation */
export declare type TriggerGiveawayEventMutationInput = {
    apiUuid: Scalars['ID'];
    userFilter?: Maybe<UserFilterInput>;
    userSearch?: Maybe<Scalars['String']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of TriggerGiveawayEventMutation */
export declare type TriggerGiveawayEventMutationPayload = {
    __typename?: 'TriggerGiveawayEventMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    giveaway: Giveaway;
};
export declare type UgcReport = {
    __typename?: 'UgcReport';
    createdAt: Scalars['ISO8601DateTime'];
    id: Scalars['ID'];
    reportableId: Scalars['ID'];
    reportableTitle?: Maybe<Scalars['String']>;
    reportableType?: Maybe<UgcReportableTypeEnum>;
    status: UgcReportStatusEnum;
    ugcReportTypes: Array<UgcReportTyp>;
    updatedAt: Scalars['ISO8601DateTime'];
    user: User;
    userId: Scalars['ID'];
};
export declare type UgcReportFilterInput = {
    id?: Maybe<FilterIdInput>;
    reportableId?: Maybe<FilterNumberInput>;
    reportableType?: Maybe<UgcReportableTypeEnum>;
    userId?: Maybe<FilterNumberInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    status?: Maybe<UgcReportStatusEnum>;
};
export declare type UgcReportInput = {
    reportableId?: Maybe<Scalars['ID']>;
    reportableType?: Maybe<UgcReportableTypeEnum>;
    userId?: Maybe<Scalars['ID']>;
    status?: Maybe<UgcReportStatusEnum>;
};
export declare type UgcReportResolver = {
    __typename?: 'UgcReportResolver';
    total: Scalars['Int'];
    ugcReports: Array<UgcReport>;
};
export declare type UgcReportSortInput = {
    id?: Maybe<SortEnum>;
    reportableId?: Maybe<SortEnum>;
    reportableType?: Maybe<SortEnum>;
    userId?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    status?: Maybe<SortEnum>;
};
export declare enum UgcReportStatusEnum {
    Opened = "opened",
    Closed = "closed"
}
export declare type UgcReportTyp = {
    __typename?: 'UgcReportTyp';
    createdAt: Scalars['ISO8601DateTime'];
    hidingTolerance?: Maybe<Scalars['Int']>;
    id: Scalars['ID'];
    order?: Maybe<Scalars['Int']>;
    translations: Array<UgcReportTypeTranslation>;
    updatedAt: Scalars['ISO8601DateTime'];
};
export declare type UgcReportTypeFilterInput = {
    id?: Maybe<FilterIdInput>;
    hidingTolerance?: Maybe<FilterNumberInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    title?: Maybe<FilterTextInput>;
    text?: Maybe<FilterTextInput>;
};
export declare type UgcReportTypeInput = {
    id?: Maybe<Scalars['ID']>;
    hidingTolerance?: Maybe<Scalars['Int']>;
    order?: Maybe<Scalars['Int']>;
    translations?: Maybe<Array<UgcReportTypeTranslationInput>>;
};
export declare type UgcReportTypeResolver = {
    __typename?: 'UgcReportTypeResolver';
    total: Scalars['Int'];
    ugcReportTypes: Array<UgcReportTyp>;
};
export declare type UgcReportTypeSortInput = {
    id?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    hidingTolerance?: Maybe<SortEnum>;
    order?: Maybe<SortEnum>;
    title?: Maybe<LocalizedSorterInput>;
    text?: Maybe<LocalizedSorterInput>;
};
export declare type UgcReportTypeTranslation = {
    __typename?: 'UgcReportTypeTranslation';
    id: Scalars['ID'];
    locale: Scalars['String'];
    text?: Maybe<Scalars['String']>;
    title: Scalars['String'];
};
export declare type UgcReportTypeTranslationInput = {
    id?: Maybe<Scalars['ID']>;
    locale?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
    text?: Maybe<Scalars['String']>;
};
export declare enum UgcReportableTypeEnum {
    Comment = "Comment",
    Idea = "Idea",
    Proposal = "Proposal",
    FanGroup = "FanGroup",
    GroupPost = "GroupPost",
    User = "User",
    AmaQuestion = "AmaQuestion"
}
/** Autogenerated input type of UpdateActivityPointMutation */
export declare type UpdateActivityPointMutationInput = {
    params: ActivityPointInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateActivityPointMutation */
export declare type UpdateActivityPointMutationPayload = {
    __typename?: 'UpdateActivityPointMutationPayload';
    activityPoint: ActivityPoint;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated input type of UpdateAdminProfileMutation */
export declare type UpdateAdminProfileMutationInput = {
    params: AdminProfileInput;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateAdminProfileMutation */
export declare type UpdateAdminProfileMutationPayload = {
    __typename?: 'UpdateAdminProfileMutationPayload';
    adminUser: AdminUser;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated input type of UpdateAdminUserMutation */
export declare type UpdateAdminUserMutationInput = {
    params: AdminUserInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateAdminUserMutation */
export declare type UpdateAdminUserMutationPayload = {
    __typename?: 'UpdateAdminUserMutationPayload';
    adminUser: AdminUser;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated input type of UpdateAmaQuestionMutation */
export declare type UpdateAmaQuestionMutationInput = {
    params: AmaQuestionInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateAmaQuestionMutation */
export declare type UpdateAmaQuestionMutationPayload = {
    __typename?: 'UpdateAmaQuestionMutationPayload';
    amaQuestion: AmaQuestion;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated input type of UpdateAmaSessionMutation */
export declare type UpdateAmaSessionMutationInput = {
    params: AmaSessionInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateAmaSessionMutation */
export declare type UpdateAmaSessionMutationPayload = {
    __typename?: 'UpdateAmaSessionMutationPayload';
    amaSession: AmaSession;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated input type of UpdateAnnouncementMutation */
export declare type UpdateAnnouncementMutationInput = {
    params: AnnouncementInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateAnnouncementMutation */
export declare type UpdateAnnouncementMutationPayload = {
    __typename?: 'UpdateAnnouncementMutationPayload';
    announcement: Announcement;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated input type of UpdateCommentMutation */
export declare type UpdateCommentMutationInput = {
    params: CommentInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateCommentMutation */
export declare type UpdateCommentMutationPayload = {
    __typename?: 'UpdateCommentMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    comment: Comment;
};
/** Autogenerated input type of UpdateContentCategoryMutation */
export declare type UpdateContentCategoryMutationInput = {
    params: ContentCategoryInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateContentCategoryMutation */
export declare type UpdateContentCategoryMutationPayload = {
    __typename?: 'UpdateContentCategoryMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    contentCategory: ContentCategory;
};
/** Autogenerated input type of UpdateContentMediumMutation */
export declare type UpdateContentMediumMutationInput = {
    params: ContentMediumInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateContentMediumMutation */
export declare type UpdateContentMediumMutationPayload = {
    __typename?: 'UpdateContentMediumMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    contentMedium: ContentMedium;
};
/** Autogenerated input type of UpdateContentMutation */
export declare type UpdateContentMutationInput = {
    params: ContentInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateContentMutation */
export declare type UpdateContentMutationPayload = {
    __typename?: 'UpdateContentMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    content: Content;
};
/** Autogenerated input type of UpdateContentTranslationMutation */
export declare type UpdateContentTranslationMutationInput = {
    params: ContentTranslationInput;
    id: Scalars['ID'];
    locale: Scalars['String'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateContentTranslationMutation */
export declare type UpdateContentTranslationMutationPayload = {
    __typename?: 'UpdateContentTranslationMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    content: Content;
};
/** Autogenerated input type of UpdateCustomNotificationMutation */
export declare type UpdateCustomNotificationMutationInput = {
    params: CustomNotificationInput;
    id: Scalars['ID'];
    userFilter?: Maybe<UserFilterInput>;
    userSearch?: Maybe<Scalars['String']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateCustomNotificationMutation */
export declare type UpdateCustomNotificationMutationPayload = {
    __typename?: 'UpdateCustomNotificationMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    customNotification: CustomNotification;
};
/** Autogenerated input type of UpdateFanGroupMutation */
export declare type UpdateFanGroupMutationInput = {
    params: FanGroupInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateFanGroupMutation */
export declare type UpdateFanGroupMutationPayload = {
    __typename?: 'UpdateFanGroupMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    fanGroup: FanGroup;
};
/** Autogenerated input type of UpdateFreeTokenTriggerMutation */
export declare type UpdateFreeTokenTriggerMutationInput = {
    params: FreeTokenTriggerInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateFreeTokenTriggerMutation */
export declare type UpdateFreeTokenTriggerMutationPayload = {
    __typename?: 'UpdateFreeTokenTriggerMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    freeTokenTrigger: FreeTokenTrigger;
};
/** Autogenerated input type of UpdateGiveawayMutation */
export declare type UpdateGiveawayMutationInput = {
    params: GiveawayInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateGiveawayMutation */
export declare type UpdateGiveawayMutationPayload = {
    __typename?: 'UpdateGiveawayMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    giveaway: Giveaway;
};
/** Autogenerated input type of UpdateGroupPostMutation */
export declare type UpdateGroupPostMutationInput = {
    params: GroupPostInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateGroupPostMutation */
export declare type UpdateGroupPostMutationPayload = {
    __typename?: 'UpdateGroupPostMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    groupPost: GroupPost;
};
/** Autogenerated input type of UpdateIdeaMutation */
export declare type UpdateIdeaMutationInput = {
    params: IdeaInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateIdeaMutation */
export declare type UpdateIdeaMutationPayload = {
    __typename?: 'UpdateIdeaMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    idea: Idea;
};
/** Autogenerated input type of UpdateIdeationMissionMutation */
export declare type UpdateIdeationMissionMutationInput = {
    params: IdeationMissionInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateIdeationMissionMutation */
export declare type UpdateIdeationMissionMutationPayload = {
    __typename?: 'UpdateIdeationMissionMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    ideationMission: IdeationMission;
};
/** Autogenerated input type of UpdateMenuItemMutation */
export declare type UpdateMenuItemMutationInput = {
    params: MenuItemInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateMenuItemMutation */
export declare type UpdateMenuItemMutationPayload = {
    __typename?: 'UpdateMenuItemMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    menuItem: MenuItem;
};
/** Autogenerated input type of UpdateMenuItemsMutation */
export declare type UpdateMenuItemsMutationInput = {
    params: Array<MenuItemInput>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateMenuItemsMutation */
export declare type UpdateMenuItemsMutationPayload = {
    __typename?: 'UpdateMenuItemsMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    menuItems: Array<MenuItem>;
};
/** Autogenerated input type of UpdateNftCollectionDeploymentMutation */
export declare type UpdateNftCollectionDeploymentMutationInput = {
    params: NftCollectionDeploymentInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateNftCollectionDeploymentMutation */
export declare type UpdateNftCollectionDeploymentMutationPayload = {
    __typename?: 'UpdateNftCollectionDeploymentMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    nftCollectionDeployment: NftCollectionDeployment;
};
/** Autogenerated input type of UpdateNftCollectionMutation */
export declare type UpdateNftCollectionMutationInput = {
    params: NftCollectionInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateNftCollectionMutation */
export declare type UpdateNftCollectionMutationPayload = {
    __typename?: 'UpdateNftCollectionMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    nftCollection: NftCollection;
};
/** Autogenerated input type of UpdateNftGiveawayMutation */
export declare type UpdateNftGiveawayMutationInput = {
    params: NftGiveawayInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateNftGiveawayMutation */
export declare type UpdateNftGiveawayMutationPayload = {
    __typename?: 'UpdateNftGiveawayMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    nftGiveaway: NftGiveaway;
};
/** Autogenerated input type of UpdateNftHandoutMutation */
export declare type UpdateNftHandoutMutationInput = {
    params: NftHandoutInput;
    id: Scalars['ID'];
    userFilter?: Maybe<UserFilterInput>;
    userSearch?: Maybe<Scalars['String']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateNftHandoutMutation */
export declare type UpdateNftHandoutMutationPayload = {
    __typename?: 'UpdateNftHandoutMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    nftHandout: NftHandout;
};
/** Autogenerated input type of UpdateNftMediumMutation */
export declare type UpdateNftMediumMutationInput = {
    params: NftMediumInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateNftMediumMutation */
export declare type UpdateNftMediumMutationPayload = {
    __typename?: 'UpdateNftMediumMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    nftMedium: NftMedium;
};
/** Autogenerated input type of UpdateNftMutation */
export declare type UpdateNftMutationInput = {
    params: NftInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateNftMutation */
export declare type UpdateNftMutationPayload = {
    __typename?: 'UpdateNftMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    nft: Nft;
};
/** Autogenerated input type of UpdateNftTransferNetworkMutation */
export declare type UpdateNftTransferNetworkMutationInput = {
    params: NftTransferNetworkInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateNftTransferNetworkMutation */
export declare type UpdateNftTransferNetworkMutationPayload = {
    __typename?: 'UpdateNftTransferNetworkMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    nftTransferNetwork: NftTransferNetwork;
};
/** Autogenerated input type of UpdateNftsVisibilityMutation */
export declare type UpdateNftsVisibilityMutationInput = {
    nftFilter?: Maybe<NftFilterInput>;
    nftSearch?: Maybe<Scalars['String']>;
    visible: Scalars['Boolean'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateNftsVisibilityMutation */
export declare type UpdateNftsVisibilityMutationPayload = {
    __typename?: 'UpdateNftsVisibilityMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    status: Scalars['Int'];
    updatedIds: Array<Scalars['ID']>;
};
/** Autogenerated input type of UpdateProfileFieldMutation */
export declare type UpdateProfileFieldMutationInput = {
    params: ProfileFieldInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateProfileFieldMutation */
export declare type UpdateProfileFieldMutationPayload = {
    __typename?: 'UpdateProfileFieldMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    profileField: ProfileField;
};
/** Autogenerated input type of UpdateProfileFieldsMutation */
export declare type UpdateProfileFieldsMutationInput = {
    params: Array<ProfileFieldInput>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateProfileFieldsMutation */
export declare type UpdateProfileFieldsMutationPayload = {
    __typename?: 'UpdateProfileFieldsMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    profileFields: Array<ProfileField>;
};
/** Autogenerated input type of UpdateProposalMutation */
export declare type UpdateProposalMutationInput = {
    params: ProposalInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateProposalMutation */
export declare type UpdateProposalMutationPayload = {
    __typename?: 'UpdateProposalMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    proposal: Proposal;
};
/** Autogenerated input type of UpdateProposalPeriodMutation */
export declare type UpdateProposalPeriodMutationInput = {
    params: ProposalPeriodInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateProposalPeriodMutation */
export declare type UpdateProposalPeriodMutationPayload = {
    __typename?: 'UpdateProposalPeriodMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    proposalPeriod: ProposalPeriod;
};
/** Autogenerated input type of UpdateShopProductMutation */
export declare type UpdateShopProductMutationInput = {
    params: ShopProductInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateShopProductMutation */
export declare type UpdateShopProductMutationPayload = {
    __typename?: 'UpdateShopProductMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    shopProduct: ShopProduct;
};
/** Autogenerated input type of UpdateShopProductTierMutation */
export declare type UpdateShopProductTierMutationInput = {
    params: ShopProductTierInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateShopProductTierMutation */
export declare type UpdateShopProductTierMutationPayload = {
    __typename?: 'UpdateShopProductTierMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    shopProductTier: ShopProductTier;
};
/** Autogenerated input type of UpdateSponsorMutation */
export declare type UpdateSponsorMutationInput = {
    params: SponsorInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateSponsorMutation */
export declare type UpdateSponsorMutationPayload = {
    __typename?: 'UpdateSponsorMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    sponsor: Sponsor;
};
/** Autogenerated input type of UpdateStaticPageMutation */
export declare type UpdateStaticPageMutationInput = {
    params: StaticPageInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateStaticPageMutation */
export declare type UpdateStaticPageMutationPayload = {
    __typename?: 'UpdateStaticPageMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    staticPage: StaticPage;
};
/** Autogenerated input type of UpdateTokenHandoutMutation */
export declare type UpdateTokenHandoutMutationInput = {
    params: TokenHandoutInput;
    id: Scalars['ID'];
    userFilter?: Maybe<UserFilterInput>;
    userSearch?: Maybe<Scalars['String']>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateTokenHandoutMutation */
export declare type UpdateTokenHandoutMutationPayload = {
    __typename?: 'UpdateTokenHandoutMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    tokenHandout: TokenHandout;
};
/** Autogenerated input type of UpdateUgcReportMutation */
export declare type UpdateUgcReportMutationInput = {
    params: UgcReportInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateUgcReportMutation */
export declare type UpdateUgcReportMutationPayload = {
    __typename?: 'UpdateUgcReportMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    ugcReport: UgcReport;
};
/** Autogenerated input type of UpdateUgcReportTypeMutation */
export declare type UpdateUgcReportTypeMutationInput = {
    params: UgcReportTypeInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateUgcReportTypeMutation */
export declare type UpdateUgcReportTypeMutationPayload = {
    __typename?: 'UpdateUgcReportTypeMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    ugcReportType: UgcReportTyp;
};
/** Autogenerated input type of UpdateUserMutation */
export declare type UpdateUserMutationInput = {
    params: UserInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateUserMutation */
export declare type UpdateUserMutationPayload = {
    __typename?: 'UpdateUserMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    user: User;
};
/** Autogenerated input type of UpdateVotingMutation */
export declare type UpdateVotingMutationInput = {
    params: VotingInput;
    id: Scalars['ID'];
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpdateVotingMutation */
export declare type UpdateVotingMutationPayload = {
    __typename?: 'UpdateVotingMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    voting: Voting;
};
/** Autogenerated input type of UpsertSystemSettingsMutation */
export declare type UpsertSystemSettingsMutationInput = {
    params: Array<SystemSettingInput>;
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
};
/** Autogenerated return type of UpsertSystemSettingsMutation */
export declare type UpsertSystemSettingsMutationPayload = {
    __typename?: 'UpsertSystemSettingsMutationPayload';
    /** A unique identifier for the client performing the mutation. */
    clientMutationId?: Maybe<Scalars['String']>;
    systemSettings: Array<SystemSetting>;
};
export declare type User = {
    __typename?: 'User';
    allowPasswordChange?: Maybe<Scalars['Boolean']>;
    audits: Array<Audit>;
    avatar?: Maybe<UserMedium>;
    avatarId?: Maybe<Scalars['ID']>;
    biography?: Maybe<Scalars['String']>;
    birthdate?: Maybe<Scalars['ISO8601Date']>;
    blockedUsers: Array<User>;
    blockingUsers: Array<User>;
    city?: Maybe<Scalars['String']>;
    confirmationSentAt?: Maybe<Scalars['ISO8601DateTime']>;
    confirmationToken?: Maybe<Scalars['String']>;
    confirmedAt?: Maybe<Scalars['ISO8601DateTime']>;
    country?: Maybe<Scalars['String']>;
    countryName?: Maybe<Scalars['String']>;
    createdAt: Scalars['ISO8601DateTime'];
    currentBalance: Balance;
    currentEthBalance: Balance;
    deviceTypes?: Maybe<Array<Scalars['String']>>;
    displayName: Scalars['String'];
    email: Scalars['String'];
    fanGroupUsers: Array<FanGroupUser>;
    fastbillId?: Maybe<Scalars['String']>;
    gender?: Maybe<Scalars['String']>;
    heroMedium?: Maybe<UserMedium>;
    heroMediumId?: Maybe<Scalars['ID']>;
    id: Scalars['ID'];
    initiallyFundedAt?: Maybe<Scalars['ISO8601DateTime']>;
    lastDayActive?: Maybe<Scalars['ISO8601Date']>;
    locale: Scalars['String'];
    nftBenefits: Array<NftBenefit>;
    nftUsers: Array<NftUser>;
    nfts: Array<Nft>;
    notificationToken?: Maybe<Scalars['String']>;
    passedTutorials?: Maybe<Scalars['String']>;
    phoneNumber?: Maybe<Scalars['String']>;
    previewUrl: Scalars['String'];
    provider: Scalars['String'];
    rememberCreatedAt?: Maybe<Scalars['ISO8601DateTime']>;
    reportStatus: ReportableStatusEnum;
    resetPasswordSentAt?: Maybe<Scalars['ISO8601DateTime']>;
    resetPasswordToken?: Maybe<Scalars['String']>;
    slug: Scalars['String'];
    state?: Maybe<Scalars['String']>;
    stateName?: Maybe<Scalars['String']>;
    status: UserStatusEnum;
    subscriptionAutorenewalActive?: Maybe<Scalars['Boolean']>;
    subscriptionCurrentUserOrder?: Maybe<UserOrder>;
    subscriptionCurrentUserOrderId?: Maybe<Scalars['ID']>;
    subscriptionProduct?: Maybe<ShopProduct>;
    subscriptionProductId?: Maybe<Scalars['ID']>;
    subscriptionValidUntil?: Maybe<Scalars['ISO8601DateTime']>;
    tokens?: Maybe<Scalars['String']>;
    ugcReportTypes?: Maybe<Array<UgcReportTyp>>;
    ugcReports: Array<UgcReport>;
    ugcReportsCount: Scalars['Int'];
    uid: Scalars['String'];
    unconfirmedEmail?: Maybe<Scalars['String']>;
    updatedAt: Scalars['ISO8601DateTime'];
    userOrders?: Maybe<Array<UserOrder>>;
    userProfileFields: Array<UserProfileField>;
    verified: Scalars['Boolean'];
    verifiedAt?: Maybe<Scalars['ISO8601DateTime']>;
    walletAddress?: Maybe<Scalars['String']>;
    website?: Maybe<Scalars['String']>;
    welcomedAt?: Maybe<Scalars['ISO8601DateTime']>;
};
export declare type UserDeviceStatistics = {
    __typename?: 'UserDeviceStatistics';
    androidUsers: Scalars['Int'];
    iosAndAndroidUsers: Scalars['Int'];
    iosUsers: Scalars['Int'];
    pwaOrWebUsers: Scalars['Int'];
    total: Scalars['Int'];
};
export declare type UserFilter = {
    __typename?: 'UserFilter';
    allowPasswordChange?: Maybe<FilterNumber>;
    biography?: Maybe<FilterText>;
    birthdate?: Maybe<FilterDate>;
    city?: Maybe<FilterText>;
    confirmationSentAt?: Maybe<FilterDate>;
    confirmationToken?: Maybe<FilterText>;
    confirmedAt?: Maybe<FilterDate>;
    country?: Maybe<FilterText>;
    createdAt?: Maybe<FilterDate>;
    displayName?: Maybe<FilterText>;
    email?: Maybe<FilterText>;
    fastbillId?: Maybe<FilterText>;
    gender?: Maybe<FilterText>;
    id?: Maybe<FilterId>;
    initiallyFundedAt?: Maybe<FilterDate>;
    locale?: Maybe<Scalars['String']>;
    nftId?: Maybe<FilterId>;
    notificationToken?: Maybe<FilterText>;
    rememberCreatedAt?: Maybe<FilterDate>;
    reportStatus?: Maybe<ReportableStatusEnum>;
    resetPasswordSentAt?: Maybe<FilterDate>;
    resetPasswordToken?: Maybe<FilterText>;
    slug?: Maybe<FilterText>;
    state?: Maybe<FilterText>;
    status?: Maybe<UserStatusEnum>;
    tokens?: Maybe<FilterText>;
    ugcReportsCount?: Maybe<FilterNumber>;
    uid?: Maybe<FilterText>;
    unconfirmedEmail?: Maybe<FilterText>;
    updatedAt?: Maybe<FilterDate>;
    verified?: Maybe<Scalars['Boolean']>;
    verifiedAt?: Maybe<FilterDate>;
    walletAddress?: Maybe<FilterText>;
    website?: Maybe<FilterText>;
    welcomedAt?: Maybe<FilterDate>;
    withReportStatus?: Maybe<Scalars['Boolean']>;
};
export declare type UserFilterInput = {
    id?: Maybe<FilterIdInput>;
    status?: Maybe<UserStatusEnum>;
    displayName?: Maybe<FilterTextInput>;
    email?: Maybe<FilterTextInput>;
    locale?: Maybe<Scalars['String']>;
    uid?: Maybe<FilterTextInput>;
    country?: Maybe<FilterTextInput>;
    state?: Maybe<FilterTextInput>;
    city?: Maybe<FilterTextInput>;
    gender?: Maybe<FilterTextInput>;
    biography?: Maybe<FilterTextInput>;
    website?: Maybe<FilterTextInput>;
    slug?: Maybe<FilterTextInput>;
    birthdate?: Maybe<FilterDateInput>;
    walletAddress?: Maybe<FilterTextInput>;
    initiallyFundedAt?: Maybe<FilterDateInput>;
    resetPasswordToken?: Maybe<FilterTextInput>;
    resetPasswordSentAt?: Maybe<FilterDateInput>;
    allowPasswordChange?: Maybe<FilterNumberInput>;
    rememberCreatedAt?: Maybe<FilterDateInput>;
    confirmationToken?: Maybe<FilterTextInput>;
    confirmedAt?: Maybe<FilterDateInput>;
    confirmationSentAt?: Maybe<FilterDateInput>;
    unconfirmedEmail?: Maybe<FilterTextInput>;
    tokens?: Maybe<FilterTextInput>;
    notificationToken?: Maybe<FilterTextInput>;
    fastbillId?: Maybe<FilterTextInput>;
    welcomedAt?: Maybe<FilterDateInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    ugcReportsCount?: Maybe<FilterNumberInput>;
    reportStatus?: Maybe<ReportableStatusEnum>;
    withReportStatus?: Maybe<Scalars['Boolean']>;
    verified?: Maybe<Scalars['Boolean']>;
    verifiedAt?: Maybe<FilterDateInput>;
    nftId?: Maybe<FilterIdInput>;
    fanGroupId?: Maybe<FilterIdInput>;
};
export declare type UserGiveaway = {
    __typename?: 'UserGiveaway';
    createdAt: Scalars['ISO8601DateTime'];
    giveaway: Giveaway;
    giveawayEvent: GiveawayEvent;
    giveawayId: Scalars['ID'];
    id: Scalars['ID'];
    nft?: Maybe<Nft>;
    nftId?: Maybe<Scalars['ID']>;
    tokens?: Maybe<Scalars['Int']>;
    updatedAt: Scalars['ISO8601DateTime'];
    user: User;
    userId: Scalars['ID'];
};
export declare type UserGiveawayFilterInput = {
    id?: Maybe<FilterIdInput>;
    userId?: Maybe<FilterIdInput>;
    giveawayId?: Maybe<FilterIdInput>;
    nftId?: Maybe<FilterIdInput>;
    events?: Maybe<Scalars['String']>;
    tokens?: Maybe<FilterNumberInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
};
export declare type UserGiveawayResolver = {
    __typename?: 'UserGiveawayResolver';
    total: Scalars['Int'];
    userGiveaways: Array<UserGiveaway>;
};
export declare type UserGiveawaySortInput = {
    id?: Maybe<SortEnum>;
    userId?: Maybe<SortEnum>;
    nftId?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
};
export declare type UserInput = {
    status?: Maybe<UserStatusEnum>;
    displayName?: Maybe<Scalars['String']>;
    email?: Maybe<Scalars['String']>;
    locale?: Maybe<Scalars['String']>;
    provider?: Maybe<Scalars['String']>;
    uid?: Maybe<Scalars['String']>;
    passedTutorials?: Maybe<Scalars['String']>;
    walletAddress?: Maybe<Scalars['String']>;
    initiallyFundedAt?: Maybe<Scalars['ISO8601DateTime']>;
    resetPasswordToken?: Maybe<Scalars['String']>;
    resetPasswordSentAt?: Maybe<Scalars['ISO8601DateTime']>;
    allowPasswordChange?: Maybe<Scalars['Int']>;
    rememberCreatedAt?: Maybe<Scalars['ISO8601DateTime']>;
    confirmationToken?: Maybe<Scalars['String']>;
    confirmedAt?: Maybe<Scalars['ISO8601DateTime']>;
    confirmationSentAt?: Maybe<Scalars['ISO8601DateTime']>;
    unconfirmedEmail?: Maybe<Scalars['String']>;
    tokens?: Maybe<Scalars['String']>;
    notificationToken?: Maybe<Scalars['String']>;
    fastbillId?: Maybe<Scalars['String']>;
    welcomedAt?: Maybe<Scalars['ISO8601DateTime']>;
    subscriptionAutorenewalActive?: Maybe<Scalars['Boolean']>;
    reportStatus?: Maybe<ReportableStatusEnum>;
    ugcReportTypes?: Maybe<Array<Scalars['Int']>>;
    verified?: Maybe<Scalars['Boolean']>;
};
export declare enum UserMediaTypeEnum {
    Image = "image",
    ExternalMedia = "external_media",
    Video = "video",
    Audio = "audio"
}
export declare type UserMedium = {
    __typename?: 'UserMedium';
    createdAt: Scalars['ISO8601DateTime'];
    fanGroupProfilesCount: Scalars['Int'];
    fanGroupsCount: Scalars['Int'];
    id: Scalars['ID'];
    image?: Maybe<Scalars['String']>;
    mediaType: UserMediaTypeEnum;
    original?: Maybe<Scalars['String']>;
    resourcesCount: Scalars['Int'];
    thumbnail?: Maybe<Scalars['String']>;
    updatedAt: Scalars['ISO8601DateTime'];
};
export declare type UserMediumFilterInput = {
    mediaType?: Maybe<UserMediaTypeEnum>;
};
export declare type UserMediumResolver = {
    __typename?: 'UserMediumResolver';
    total: Scalars['Int'];
    userMedia: Array<UserMedium>;
};
export declare type UserMediumSortInput = {
    id?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
};
export declare type UserOrder = {
    __typename?: 'UserOrder';
    createdAt: Scalars['ISO8601DateTime'];
    id: Scalars['ID'];
    invoiceId?: Maybe<Scalars['String']>;
    invoiceSentAt?: Maybe<Scalars['ISO8601DateTime']>;
    nftCount?: Maybe<Scalars['Int']>;
    nfts: Array<Nft>;
    orderFulfilledAt?: Maybe<Scalars['ISO8601DateTime']>;
    orderId: Scalars['String'];
    paymentProvider?: Maybe<Scalars['String']>;
    paymentState?: Maybe<Scalars['String']>;
    paymentTransactionId?: Maybe<Scalars['String']>;
    payments: Array<Payment>;
    shopProduct: ShopProduct;
    shopProductId: Scalars['ID'];
    status?: Maybe<UserOrderStatusEnum>;
    tokenAmount?: Maybe<Scalars['Int']>;
    total?: Maybe<Scalars['Float']>;
    updatedAt: Scalars['ISO8601DateTime'];
    user: User;
    userId: Scalars['ID'];
};
export declare type UserOrderFilterInput = {
    id?: Maybe<FilterIdInput>;
    shopProductId?: Maybe<Scalars['ID']>;
    userId?: Maybe<FilterIdInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    paymentProvider?: Maybe<FilterTextInput>;
    paymentTransactionId?: Maybe<FilterTextInput>;
    paymentState?: Maybe<FilterTextInput>;
    status?: Maybe<UserOrderStatusEnum>;
    total?: Maybe<FilterNumberInput>;
    tokenAmount?: Maybe<FilterNumberInput>;
    orderFulfilledAt?: Maybe<FilterDateInput>;
    invoiceId?: Maybe<FilterTextInput>;
    invoiceSentAt?: Maybe<FilterDateInput>;
    orderId?: Maybe<FilterTextInput>;
};
export declare type UserOrderInput = {
    shopProductId?: Maybe<Scalars['ID']>;
    userId?: Maybe<Scalars['ID']>;
    paymentProvider?: Maybe<Scalars['String']>;
    paymentTransactionId?: Maybe<Scalars['String']>;
    paymentState?: Maybe<Scalars['String']>;
    status?: Maybe<UserOrderStatusEnum>;
    total?: Maybe<Scalars['Float']>;
    tokenAmount?: Maybe<Scalars['Int']>;
    orderFulfilledAt?: Maybe<Scalars['ISO8601DateTime']>;
    invoiceId?: Maybe<Scalars['String']>;
    invoiceSentAt?: Maybe<Scalars['ISO8601DateTime']>;
};
export declare type UserOrderResolver = {
    __typename?: 'UserOrderResolver';
    total: Scalars['Int'];
    userOrders: Array<UserOrder>;
};
export declare type UserOrderSortInput = {
    id?: Maybe<SortEnum>;
    shopProductId?: Maybe<SortEnum>;
    userId?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    paymentProvider?: Maybe<SortEnum>;
    paymentTransactionId?: Maybe<SortEnum>;
    paymentState?: Maybe<SortEnum>;
    status?: Maybe<SortEnum>;
    total?: Maybe<SortEnum>;
    tokenAmount?: Maybe<SortEnum>;
    orderFulfilledAt?: Maybe<SortEnum>;
    invoiceId?: Maybe<SortEnum>;
    invoiceSentAt?: Maybe<SortEnum>;
    orderId?: Maybe<SortEnum>;
};
export declare enum UserOrderStatusEnum {
    Complete = "complete",
    Payment = "payment",
    Cancel = "cancel",
    Authorized = "authorized",
    Refunded = "refunded"
}
export declare type UserProfileField = {
    __typename?: 'UserProfileField';
    createdAt: Scalars['ISO8601DateTime'];
    id: Scalars['ID'];
    profileField: ProfileField;
    profileFieldId: Scalars['ID'];
    updatedAt: Scalars['ISO8601DateTime'];
    user: User;
    userId: Scalars['ID'];
    userPubliclyVisible?: Maybe<Scalars['Boolean']>;
    value?: Maybe<Scalars['String']>;
    valueType: UserProfileFieldValueTypeEnum;
};
export declare type UserProfileFieldFilterInput = {
    id?: Maybe<FilterIdInput>;
    value?: Maybe<FilterTextInput>;
    valueType?: Maybe<UserProfileFieldValueTypeEnum>;
    userId?: Maybe<FilterNumberInput>;
    profileFieldId?: Maybe<FilterNumberInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    userPubliclyVisible?: Maybe<Scalars['Boolean']>;
};
export declare type UserProfileFieldResolver = {
    __typename?: 'UserProfileFieldResolver';
    total: Scalars['Int'];
    userProfileFields: Array<UserProfileField>;
};
export declare type UserProfileFieldSortInput = {
    id?: Maybe<SortEnum>;
    value?: Maybe<SortEnum>;
    valueType?: Maybe<SortEnum>;
    userId?: Maybe<SortEnum>;
    profileFieldId?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    userPubliclyVisible?: Maybe<SortEnum>;
};
export declare enum UserProfileFieldValueTypeEnum {
    Text = "text",
    Number = "number",
    ProfileFieldOption = "profile_field_option",
    Switch = "switch",
    Date = "date",
    Url = "url"
}
export declare type UserResolver = {
    __typename?: 'UserResolver';
    total: Scalars['Int'];
    users: Array<User>;
};
export declare type UserSortInput = {
    id?: Maybe<SortEnum>;
    status?: Maybe<SortEnum>;
    displayName?: Maybe<SortEnum>;
    email?: Maybe<SortEnum>;
    gender?: Maybe<SortEnum>;
    country?: Maybe<SortEnum>;
    state?: Maybe<SortEnum>;
    city?: Maybe<SortEnum>;
    biography?: Maybe<SortEnum>;
    website?: Maybe<SortEnum>;
    birthdate?: Maybe<SortEnum>;
    lastDayActive?: Maybe<SortEnum>;
    slug?: Maybe<SortEnum>;
    locale?: Maybe<SortEnum>;
    provider?: Maybe<SortEnum>;
    uid?: Maybe<SortEnum>;
    passedTutorials?: Maybe<SortEnum>;
    walletAddress?: Maybe<SortEnum>;
    initiallyFundedAt?: Maybe<SortEnum>;
    resetPasswordToken?: Maybe<SortEnum>;
    resetPasswordSentAt?: Maybe<SortEnum>;
    allowPasswordChange?: Maybe<SortEnum>;
    rememberCreatedAt?: Maybe<SortEnum>;
    confirmationToken?: Maybe<SortEnum>;
    confirmedAt?: Maybe<SortEnum>;
    confirmationSentAt?: Maybe<SortEnum>;
    unconfirmedEmail?: Maybe<SortEnum>;
    tokens?: Maybe<SortEnum>;
    notificationToken?: Maybe<SortEnum>;
    fastbillId?: Maybe<SortEnum>;
    welcomedAt?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    ugcReportsCount?: Maybe<SortEnum>;
    reportStatus?: Maybe<SortEnumWithDefault>;
    verifiedAt?: Maybe<SortEnum>;
};
export declare enum UserStatusEnum {
    Unlocked = "unlocked",
    Locked = "locked",
    Banned = "banned"
}
export declare type Voting = {
    __typename?: 'Voting';
    availabilities?: Maybe<Array<Availability>>;
    availabilityType: AvailabilityTypeEnum;
    availableFors: Array<Scalars['String']>;
    comments: Array<Comment>;
    commentsCount?: Maybe<Scalars['Int']>;
    contractAddress?: Maybe<Scalars['String']>;
    createdAt: Scalars['ISO8601DateTime'];
    creatorShare?: Maybe<Scalars['Int']>;
    depositShare?: Maybe<Scalars['Int']>;
    distributedAt?: Maybe<Scalars['ISO8601DateTime']>;
    endsAt: Scalars['ISO8601DateTime'];
    fanvaultShare?: Maybe<Scalars['Int']>;
    heroMedium?: Maybe<ContentMedium>;
    heroMediumId?: Maybe<Scalars['ID']>;
    id: Scalars['ID'];
    notifiedEndsSoonAt?: Maybe<Scalars['ISO8601DateTime']>;
    onlyForAvailables?: Maybe<Scalars['Boolean']>;
    operatorShare?: Maybe<Scalars['Int']>;
    pinToTop: Scalars['Boolean'];
    previewToken?: Maybe<Scalars['String']>;
    previewUrl?: Maybe<Scalars['String']>;
    previewUrls: Array<PreviewUrl>;
    publishedAt?: Maybe<Scalars['ISO8601DateTime']>;
    requiredNfts?: Maybe<Array<Nft>>;
    requiredSubscriptions?: Maybe<Array<ShopProduct>>;
    status: VotingStatusEnum;
    tokenFixedAmount?: Maybe<Scalars['Int']>;
    tokenMax?: Maybe<Scalars['Int']>;
    tokenMin?: Maybe<Scalars['Int']>;
    transferredDepositsAt?: Maybe<Scalars['ISO8601DateTime']>;
    translations: Array<VotingTranslation>;
    unlocksTokensAt?: Maybe<Scalars['ISO8601DateTime']>;
    updatedAt: Scalars['ISO8601DateTime'];
    votingOptions?: Maybe<Array<VotingOption>>;
    votingType?: Maybe<VotingTypeEnum>;
    willBePinned: Scalars['Boolean'];
};
export declare type VotingFilterInput = {
    id?: Maybe<FilterIdInput>;
    status?: Maybe<VotingStatusEnum>;
    votingType?: Maybe<VotingTypeEnum>;
    endsAt?: Maybe<FilterDateInput>;
    createdAt?: Maybe<FilterDateInput>;
    updatedAt?: Maybe<FilterDateInput>;
    contractAddress?: Maybe<FilterTextInput>;
    tokenFixedAmount?: Maybe<FilterNumberInput>;
    tokenMin?: Maybe<FilterNumberInput>;
    tokenMax?: Maybe<FilterNumberInput>;
    distributedAt?: Maybe<FilterDateInput>;
    transferredDepositsAt?: Maybe<FilterDateInput>;
    unlocksTokensAt?: Maybe<FilterDateInput>;
    notifiedEndsSoonAt?: Maybe<FilterDateInput>;
    commentsCount?: Maybe<FilterNumberInput>;
    title?: Maybe<FilterTextInput>;
    content?: Maybe<FilterTextInput>;
    publishedAt?: Maybe<FilterDateInput>;
    availableFor?: Maybe<Array<AvailabilityAvailableForEnum>>;
    onlyForAvailables?: Maybe<Scalars['Boolean']>;
    availabilityType?: Maybe<AvailabilityTypeEnum>;
};
export declare type VotingInput = {
    votingType?: Maybe<VotingTypeEnum>;
    endsAt?: Maybe<Scalars['ISO8601DateTime']>;
    tokenFixedAmount?: Maybe<Scalars['Int']>;
    tokenMin?: Maybe<Scalars['Int']>;
    tokenMax?: Maybe<Scalars['Int']>;
    heroMediumId?: Maybe<Scalars['ID']>;
    translations?: Maybe<Array<VotingTranslationInput>>;
    votingOptions?: Maybe<Array<VotingOptionInput>>;
    publishedAt?: Maybe<Scalars['ISO8601DateTime']>;
    availabilities?: Maybe<Array<AvailabilityInput>>;
    onlyForAvailables?: Maybe<Scalars['Boolean']>;
    availabilityType?: Maybe<AvailabilityTypeEnum>;
    pinToTop?: Maybe<Scalars['Boolean']>;
};
export declare type VotingOption = {
    __typename?: 'VotingOption';
    boostsAmountCache?: Maybe<Scalars['Int']>;
    createdAt: Scalars['ISO8601DateTime'];
    id: Scalars['ID'];
    translations: Array<VotingOptionTranslation>;
    updatedAt: Scalars['ISO8601DateTime'];
    votedTokensCount: Scalars['Int'];
    votedUsersCount: Scalars['Int'];
    votesCount: Scalars['Int'];
    votingId: Scalars['ID'];
};
export declare type VotingOptionInput = {
    id?: Maybe<Scalars['ID']>;
    votingId?: Maybe<Scalars['ID']>;
    translations?: Maybe<Array<VotingOptionTranslationInput>>;
    _destroy?: Maybe<Scalars['Boolean']>;
};
export declare type VotingOptionTranslation = {
    __typename?: 'VotingOptionTranslation';
    id: Scalars['ID'];
    locale: Scalars['String'];
    title: Scalars['String'];
};
export declare type VotingOptionTranslationInput = {
    id?: Maybe<Scalars['ID']>;
    locale?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
};
export declare type VotingResolver = {
    __typename?: 'VotingResolver';
    total: Scalars['Int'];
    votings: Array<Voting>;
};
export declare type VotingSortInput = {
    id?: Maybe<SortEnum>;
    votingType?: Maybe<SortEnum>;
    status?: Maybe<SortEnum>;
    endsAt?: Maybe<SortEnum>;
    createdAt?: Maybe<SortEnum>;
    updatedAt?: Maybe<SortEnum>;
    contractAddress?: Maybe<SortEnum>;
    tokenFixedAmount?: Maybe<SortEnum>;
    tokenMin?: Maybe<SortEnum>;
    tokenMax?: Maybe<SortEnum>;
    distributedAt?: Maybe<SortEnum>;
    transferredDepositsAt?: Maybe<SortEnum>;
    unlocksTokensAt?: Maybe<SortEnum>;
    notifiedEndsSoonAt?: Maybe<SortEnum>;
    commentsCount?: Maybe<SortEnum>;
    title?: Maybe<LocalizedSorterInput>;
    content?: Maybe<LocalizedSorterInput>;
    publishedAt?: Maybe<SortEnum>;
    onlyForAvailables?: Maybe<SortEnum>;
    availabilityType?: Maybe<SortEnum>;
};
export declare enum VotingStatusEnum {
    Draft = "draft",
    Scheduled = "scheduled",
    Deploying = "deploying",
    Published = "published",
    Archived = "archived"
}
export declare type VotingTranslation = {
    __typename?: 'VotingTranslation';
    content?: Maybe<Scalars['String']>;
    id: Scalars['ID'];
    locale: Scalars['String'];
    title?: Maybe<Scalars['String']>;
};
export declare type VotingTranslationInput = {
    id?: Maybe<Scalars['ID']>;
    locale?: Maybe<Scalars['String']>;
    title?: Maybe<Scalars['String']>;
    content?: Maybe<Scalars['String']>;
};
export declare enum VotingTypeEnum {
    Tokenless = "tokenless",
    TokenbasedFixed = "tokenbased_fixed",
    TokenbasedVariable = "tokenbased_variable"
}
export declare type ActivityNotificationFragment = {
    __typename?: 'ActivityNotification';
} & Pick<ActivityNotification, 'id' | 'createdAt' | 'updatedAt' | 'openedAt' | 'notifiableId' | 'notifiableType'> & {
    target: {
        __typename?: 'User';
    } & UserLightFragment;
};
export declare type GetActivityNotificationsQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<ActivityNotificationFilterInput>;
    sort?: Maybe<ActivityNotificationSortInput>;
}>;
export declare type GetActivityNotificationsQuery = {
    __typename?: 'Query';
} & {
    activityNotifications: {
        __typename?: 'ActivityNotificationResolver';
    } & Pick<ActivityNotificationResolver, 'total'> & {
        activityNotifications: Array<{
            __typename?: 'ActivityNotification';
        } & ActivityNotificationFragment>;
    };
};
export declare type AdminUserFragment = {
    __typename?: 'AdminUser';
} & Pick<AdminUser, 'id' | 'uid' | 'createdAt' | 'updatedAt' | 'email' | 'unconfirmedEmail' | 'authorizations' | 'confirmedAt' | 'confirmationToken' | 'confirmationSentAt' | 'otpRequiredForLogin' | 'rememberCreatedAt' | 'resetPasswordToken' | 'resetPasswordSentAt' | 'provider' | 'role' | 'useAbsoluteDates'>;
export declare type CreateAdminUserMutationVariables = Exact<{
    params: AdminUserInput;
}>;
export declare type CreateAdminUserMutation = {
    __typename?: 'Mutation';
} & {
    createAdminUser?: Maybe<{
        __typename?: 'AddAdminUserMutationPayload';
    } & {
        adminUser: {
            __typename?: 'AdminUser';
        } & AdminUserFragment;
    }>;
};
export declare type DeleteAdminUserMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type DeleteAdminUserMutation = {
    __typename?: 'Mutation';
} & {
    deleteAdminUser?: Maybe<{
        __typename?: 'DeleteAdminUserMutationPayload';
    } & {
        adminUser: {
            __typename?: 'AdminUser';
        } & AdminUserFragment;
    }>;
};
export declare type UpdateAdminUserMutationVariables = Exact<{
    id: Scalars['ID'];
    params: AdminUserInput;
}>;
export declare type UpdateAdminUserMutation = {
    __typename?: 'Mutation';
} & {
    updateAdminUser?: Maybe<{
        __typename?: 'UpdateAdminUserMutationPayload';
    } & {
        adminUser: {
            __typename?: 'AdminUser';
        } & AdminUserFragment;
    }>;
};
export declare type GetAdminUserQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetAdminUserQuery = {
    __typename?: 'Query';
} & {
    adminUser: {
        __typename?: 'AdminUser';
    } & AdminUserFragment;
};
export declare type GetAdminUsersQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<AdminUserFilterInput>;
    sort?: Maybe<AdminUserSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetAdminUsersQuery = {
    __typename?: 'Query';
} & {
    adminUsers: {
        __typename?: 'AdminUserResolver';
    } & Pick<AdminUserResolver, 'total'> & {
        adminUsers: Array<{
            __typename?: 'AdminUser';
        } & AdminUserFragment>;
    };
};
export declare type AnnouncementTranslationFragment = {
    __typename?: 'AnnouncementTranslation';
} & Pick<AnnouncementTranslation, 'id' | 'locale' | 'title' | 'content'>;
export declare type AnnouncementFragment = {
    __typename?: 'Announcement';
} & Pick<Announcement, 'id' | 'createdAt' | 'updatedAt' | 'announceableId' | 'announceableType'> & {
    translations: Array<{
        __typename?: 'AnnouncementTranslation';
    } & AnnouncementTranslationFragment>;
};
export declare type CreateAnnouncementMutationVariables = Exact<{
    params: AnnouncementInput;
}>;
export declare type CreateAnnouncementMutation = {
    __typename?: 'Mutation';
} & {
    createAnnouncement?: Maybe<{
        __typename?: 'AddAnnouncementMutationPayload';
    } & {
        announcement: {
            __typename?: 'Announcement';
        } & AnnouncementFragment;
    }>;
};
export declare type DeleteAnnouncementsMutationVariables = Exact<{
    ids: Array<Scalars['ID']> | Scalars['ID'];
}>;
export declare type DeleteAnnouncementsMutation = {
    __typename?: 'Mutation';
} & {
    deleteAnnouncements?: Maybe<{
        __typename?: 'DeleteAnnouncementsMutationPayload';
    } & Pick<DeleteAnnouncementsMutationPayload, 'deletedIds' | 'status'>>;
};
export declare type UpdateAnnouncementMutationVariables = Exact<{
    id: Scalars['ID'];
    params: AnnouncementInput;
}>;
export declare type UpdateAnnouncementMutation = {
    __typename?: 'Mutation';
} & {
    updateAnnouncement?: Maybe<{
        __typename?: 'UpdateAnnouncementMutationPayload';
    } & {
        announcement: {
            __typename?: 'Announcement';
        } & AnnouncementFragment;
    }>;
};
export declare type GetAnnouncementQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetAnnouncementQuery = {
    __typename?: 'Query';
} & {
    announcement: {
        __typename?: 'Announcement';
    } & AnnouncementFragment;
};
export declare type AuditLightFragment = {
    __typename?: 'Audit';
} & Pick<Audit, 'id' | 'version' | 'createdAt' | 'userId' | 'userType'>;
export declare type AuditFragment = {
    __typename?: 'Audit';
} & Pick<Audit, 'auditedChanges' | 'auditableId' | 'auditableType'> & AuditLightFragment;
export declare type LoginMutationVariables = Exact<{
    email: Scalars['String'];
    password: Scalars['String'];
}>;
export declare type LoginMutation = {
    __typename?: 'Mutation';
} & {
    adminUserLogin?: Maybe<{
        __typename?: 'AdminUserLoginPayload';
    } & {
        authenticatable: {
            __typename?: 'AdminUser';
        } & Pick<AdminUser, 'serviceToken'> & AdminUserFragment;
        credentials: {
            __typename?: 'Credential';
        } & Pick<Credential, 'accessToken' | 'client' | 'expiry' | 'tokenType' | 'uid'>;
    }>;
};
export declare type AvailabilityFragment = {
    __typename?: 'Availability';
} & Pick<Availability, 'availableFor' | 'createdAt' | 'id' | 'resourceId' | 'resourceType' | 'updatedAt'> & {
    availabilitiesResources?: Maybe<Array<{
        __typename?: 'AvailabilitiesResource';
    } & Pick<AvailabilitiesResource, 'availabilityId' | 'id' | 'createdAt' | 'updatedAt' | 'nftId' | 'shopProductId'>>>;
};
export declare type ContentCategoryFragment = {
    __typename?: 'ContentCategory';
} & Pick<ContentCategory, 'id' | 'createdAt' | 'updatedAt' | 'contentsCount'> & {
    translations: Array<{
        __typename?: 'ContentCategoryTranslation';
    } & Pick<ContentCategoryTranslation, 'id' | 'locale' | 'title'>>;
};
export declare type ContentForSelectFragment = {
    __typename?: 'Content';
} & Pick<Content, 'id'> & {
    translations: Array<{
        __typename?: 'ContentTranslation';
    } & Pick<ContentTranslation, 'id' | 'locale' | 'title'>>;
};
export declare type ContentLightFragment = {
    __typename?: 'Content';
} & Pick<Content, 'id' | 'author' | 'status' | 'commentsCount' | 'contentType' | 'createdAt' | 'updatedAt' | 'publishedAt' | 'heroMediumId' | 'boostsAmountCache' | 'contentCategoryId'> & {
    translations: Array<{
        __typename?: 'ContentTranslation';
    } & Pick<ContentTranslation, 'id' | 'locale' | 'title'>>;
    heroMedium?: Maybe<{
        __typename?: 'ContentMedium';
    } & ContentMediumFragment>;
    contentCategory?: Maybe<{
        __typename?: 'ContentCategory';
    } & ContentCategoryFragment>;
};
export declare type ContentTranslationFragment = {
    __typename?: 'ContentTranslation';
} & Pick<ContentTranslation, 'id' | 'title' | 'preview' | 'content' | 'metaTitle' | 'metaDescription' | 'slug' | 'locale' | 'metaCanonicalUrl' | 'metaNoindex' | 'metaNofollow'>;
export declare type ContentFragment = {
    __typename?: 'Content';
} & Pick<Content, 'depositShare' | 'contractAddress' | 'unlockerAddress' | 'unlockPrice' | 'fanvaultShare' | 'operatorShare' | 'previewToken' | 'previewUrl' | 'boostsAmountCache' | 'notifyOnPublished' | 'onlyForAvailables' | 'availabilityType' | 'pinToTop' | 'willBePinned'> & {
    previewUrls: Array<{
        __typename?: 'PreviewUrl';
    } & PreviewUrlFragment>;
    comments: Array<{
        __typename?: 'Comment';
    } & CommentFragment>;
    translations: Array<{
        __typename?: 'ContentTranslation';
    } & ContentTranslationFragment>;
    availabilities?: Maybe<Array<{
        __typename?: 'Availability';
    } & AvailabilityFragment>>;
} & ContentLightFragment;
export declare type ArchiveContentMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type ArchiveContentMutation = {
    __typename?: 'Mutation';
} & {
    archiveContent?: Maybe<{
        __typename?: 'ArchiveContentMutationPayload';
    } & {
        content: {
            __typename?: 'Content';
        } & ContentFragment;
    }>;
};
export declare type CreateContentCategoryMutationVariables = Exact<{
    params: ContentCategoryInput;
}>;
export declare type CreateContentCategoryMutation = {
    __typename?: 'Mutation';
} & {
    createContentCategory?: Maybe<{
        __typename?: 'AddContentCategoryMutationPayload';
    } & {
        contentCategory: {
            __typename?: 'ContentCategory';
        } & ContentCategoryFragment;
    }>;
};
export declare type CreateContentMutationVariables = Exact<{
    params: ContentInput;
}>;
export declare type CreateContentMutation = {
    __typename?: 'Mutation';
} & {
    createContent?: Maybe<{
        __typename?: 'AddContentMutationPayload';
    } & {
        content: {
            __typename?: 'Content';
        } & ContentFragment;
    }>;
};
export declare type DeleteContentCategoriesMutationVariables = Exact<{
    ids: Array<Scalars['ID']> | Scalars['ID'];
}>;
export declare type DeleteContentCategoriesMutation = {
    __typename?: 'Mutation';
} & {
    deleteContentCategories?: Maybe<{
        __typename?: 'DeleteContentCategoriesMutationPayload';
    } & Pick<DeleteContentCategoriesMutationPayload, 'deletedIds' | 'status'>>;
};
export declare type DeleteContentsMutationVariables = Exact<{
    ids: Array<Scalars['ID']> | Scalars['ID'];
}>;
export declare type DeleteContentsMutation = {
    __typename?: 'Mutation';
} & {
    deleteContents?: Maybe<{
        __typename?: 'DeleteContentsMutationPayload';
    } & Pick<DeleteContentsMutationPayload, 'deletedIds' | 'status'>>;
};
export declare type DraftContentMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type DraftContentMutation = {
    __typename?: 'Mutation';
} & {
    draftContent?: Maybe<{
        __typename?: 'DraftContentMutationPayload';
    } & {
        content: {
            __typename?: 'Content';
        } & ContentFragment;
    }>;
};
export declare type PublishContentMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type PublishContentMutation = {
    __typename?: 'Mutation';
} & {
    publishContent?: Maybe<{
        __typename?: 'PublishContentMutationPayload';
    } & {
        content: {
            __typename?: 'Content';
        } & ContentFragment;
    }>;
};
export declare type UpdateContentCategoryMutationVariables = Exact<{
    id: Scalars['ID'];
    params: ContentCategoryInput;
}>;
export declare type UpdateContentCategoryMutation = {
    __typename?: 'Mutation';
} & {
    updateContentCategory?: Maybe<{
        __typename?: 'UpdateContentCategoryMutationPayload';
    } & {
        contentCategory: {
            __typename?: 'ContentCategory';
        } & ContentCategoryFragment;
    }>;
};
export declare type UpdateContentMutationVariables = Exact<{
    id: Scalars['ID'];
    params: ContentInput;
}>;
export declare type UpdateContentMutation = {
    __typename?: 'Mutation';
} & {
    updateContent?: Maybe<{
        __typename?: 'UpdateContentMutationPayload';
    } & {
        content: {
            __typename?: 'Content';
        } & ContentFragment;
    }>;
};
export declare type GetContentCategoriesQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<ContentCategoryFilterInput>;
    sort?: Maybe<ContentCategorySortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetContentCategoriesQuery = {
    __typename?: 'Query';
} & {
    contentCategories: {
        __typename?: 'ContentCategoryResolver';
    } & Pick<ContentCategoryResolver, 'total'> & {
        contentCategories: Array<{
            __typename?: 'ContentCategory';
        } & ContentCategoryFragment>;
    };
};
export declare type GetContentCategoryQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetContentCategoryQuery = {
    __typename?: 'Query';
} & {
    contentCategory: {
        __typename?: 'ContentCategory';
    } & ContentCategoryFragment;
};
export declare type GetContentQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetContentQuery = {
    __typename?: 'Query';
} & {
    content: {
        __typename?: 'Content';
    } & ContentFragment;
};
export declare type GetContentsForSelectQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filterTitle?: Maybe<FilterTextInput>;
    sort?: Maybe<ContentSortInput>;
    selectedIds: Array<Scalars['ID']> | Scalars['ID'];
}>;
export declare type GetContentsForSelectQuery = {
    __typename?: 'Query';
} & {
    contents: {
        __typename?: 'ContentResolver';
    } & Pick<ContentResolver, 'total'> & {
        contents: Array<{
            __typename?: 'Content';
        } & ContentForSelectFragment>;
    };
    selectedContents: {
        __typename?: 'ContentResolver';
    } & Pick<ContentResolver, 'total'> & {
        contents: Array<{
            __typename?: 'Content';
        } & ContentForSelectFragment>;
    };
};
export declare type GetContentsQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<ContentFilterInput>;
    sort?: Maybe<ContentSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetContentsQuery = {
    __typename?: 'Query';
} & {
    contents: {
        __typename?: 'ContentResolver';
    } & Pick<ContentResolver, 'total'> & {
        contents: Array<{
            __typename?: 'Content';
        } & ContentLightFragment>;
    };
};
export declare type CustomNotificationLightFragment = {
    __typename?: 'CustomNotification';
} & Pick<CustomNotification, 'id' | 'createdAt' | 'updatedAt' | 'sentAt' | 'promptDialog' | 'status' | 'heroMediumId' | 'sponsorId' | 'notificationsCount'> & {
    heroMedium?: Maybe<{
        __typename?: 'ContentMedium';
    } & ContentMediumFragment>;
    translations: Array<{
        __typename?: 'CustomNotificationTranslation';
    } & Pick<CustomNotificationTranslation, 'id' | 'locale' | 'title'>>;
    sponsor?: Maybe<{
        __typename?: 'Sponsor';
    } & Pick<Sponsor, 'id' | 'name'>>;
};
export declare type CustomNotificationTranslationFragment = {
    __typename?: 'CustomNotificationTranslation';
} & Pick<CustomNotificationTranslation, 'id' | 'locale' | 'title' | 'message' | 'content' | 'externalLink' | 'ctaText'>;
export declare type CustomNotificationFragment = {
    __typename?: 'CustomNotification';
} & Pick<CustomNotification, 'userSearch'> & {
    translations: Array<{
        __typename?: 'CustomNotificationTranslation';
    } & CustomNotificationTranslationFragment>;
    userFilter?: Maybe<{
        __typename?: 'UserFilter';
    } & UserFilterFragment>;
} & CustomNotificationLightFragment;
export declare type CreateCustomNotificationMutationVariables = Exact<{
    params: CustomNotificationInput;
    userFilter: UserFilterInput;
    userSearch?: Maybe<Scalars['String']>;
}>;
export declare type CreateCustomNotificationMutation = {
    __typename?: 'Mutation';
} & {
    createCustomNotification?: Maybe<{
        __typename?: 'AddCustomNotificationMutationPayload';
    } & {
        customNotification: {
            __typename?: 'CustomNotification';
        } & CustomNotificationFragment;
    }>;
};
export declare type DeleteCustomNotificationsMutationVariables = Exact<{
    ids: Array<Scalars['ID']> | Scalars['ID'];
}>;
export declare type DeleteCustomNotificationsMutation = {
    __typename?: 'Mutation';
} & {
    deleteCustomNotifications?: Maybe<{
        __typename?: 'DeleteCustomNotificationsMutationPayload';
    } & Pick<DeleteCustomNotificationsMutationPayload, 'status' | 'deletedIds'>>;
};
export declare type DraftCustomNotificationMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type DraftCustomNotificationMutation = {
    __typename?: 'Mutation';
} & {
    draftCustomNotification?: Maybe<{
        __typename?: 'DraftCustomNotificationMutationPayload';
    } & {
        customNotification: {
            __typename?: 'CustomNotification';
        } & CustomNotificationFragment;
    }>;
};
export declare type PublishCustomNotificationMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type PublishCustomNotificationMutation = {
    __typename?: 'Mutation';
} & {
    publishCustomNotification?: Maybe<{
        __typename?: 'PublishCustomNotificationMutationPayload';
    } & {
        customNotification: {
            __typename?: 'CustomNotification';
        } & CustomNotificationFragment;
    }>;
};
export declare type UpdateCustomNotificationMutationVariables = Exact<{
    id: Scalars['ID'];
    params: CustomNotificationInput;
    userFilter?: Maybe<UserFilterInput>;
    userSearch?: Maybe<Scalars['String']>;
}>;
export declare type UpdateCustomNotificationMutation = {
    __typename?: 'Mutation';
} & {
    updateCustomNotification?: Maybe<{
        __typename?: 'UpdateCustomNotificationMutationPayload';
    } & {
        customNotification: {
            __typename?: 'CustomNotification';
        } & CustomNotificationFragment;
    }>;
};
export declare type GetCustomNotificationQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetCustomNotificationQuery = {
    __typename?: 'Query';
} & {
    customNotification: {
        __typename?: 'CustomNotification';
    } & CustomNotificationFragment;
};
export declare type GetCustomNotificationsQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<CustomNotificationFilterInput>;
    sort?: Maybe<CustomNotificationSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetCustomNotificationsQuery = {
    __typename?: 'Query';
} & {
    customNotifications: {
        __typename?: 'CustomNotificationResolver';
    } & Pick<CustomNotificationResolver, 'total'> & {
        customNotifications: Array<{
            __typename?: 'CustomNotification';
        } & CustomNotificationLightFragment>;
    };
};
export declare type FeedPinFragment = {
    __typename?: 'FeedPin';
} & Pick<FeedPin, 'id' | 'createdAt' | 'isActive' | 'pinnableId' | 'updatedAt' | 'pinnableTitle' | 'pinnableType'>;
export declare type GetPinnedItemQueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type GetPinnedItemQuery = {
    __typename?: 'Query';
} & {
    pinnedItem?: Maybe<{
        __typename?: 'FeedPin';
    } & FeedPinFragment>;
};
export declare type GiveawayEventFragment = {
    __typename?: 'GiveawayEvent';
} & Pick<GiveawayEvent, 'id' | 'availableFor' | 'eventType' | 'spentTokensThreshold' | 'qrCodeUuid' | 'nfcUuid' | 'apiUuid'> & {
    giveawayEventResources: Array<{
        __typename?: 'GiveawayEventResource';
    } & Pick<GiveawayEventResource, 'id' | 'triggerableId' | 'triggerableType'>>;
};
export declare type GiveawayLightFragment = {
    __typename?: 'Giveaway';
} & Pick<Giveaway, 'id' | 'createdAt' | 'updatedAt' | 'activeFrom' | 'activeUntil' | 'expires' | 'heroMediumId' | 'sponsorId' | 'status' | 'userLimitNumber' | 'userLimitPeriod' | 'dropRate' | 'nftIds' | 'mandatory' | 'maxTimesTriggered' | 'maxTokenAmount' | 'tokenAmount' | 'giveawayType' | 'intervalType'> & {
    sponsor?: Maybe<{
        __typename?: 'Sponsor';
    } & Pick<Sponsor, 'id' | 'name'>>;
    heroMedium?: Maybe<{
        __typename?: 'ContentMedium';
    } & ContentMediumFragment>;
    translations: Array<{
        __typename?: 'GiveawayTranslation';
    } & Pick<GiveawayTranslation, 'id' | 'locale' | 'title'>>;
    nfts: Array<{
        __typename?: 'Nft';
    } & Pick<Nft, 'id' | 'name' | 'sponsorId'> & {
        collectionSponsor?: Maybe<{
            __typename?: 'Sponsor';
        } & Pick<Sponsor, 'id' | 'name'>>;
    }>;
    giveawayEvents: Array<{
        __typename?: 'GiveawayEvent';
    } & Pick<GiveawayEvent, 'id' | 'eventType'>>;
    intervalOptions?: Maybe<{
        __typename?: 'GiveawayIntervalOptions';
    } & {
        weekly?: Maybe<{
            __typename?: 'GiveawayWeeklyInterval';
        } & Pick<GiveawayWeeklyInterval, 'monday' | 'tuesday' | 'wednesday' | 'thursday' | 'friday' | 'saturday' | 'sunday'>>;
        monthly?: Maybe<{
            __typename?: 'GiveawayMonthlyInterval';
        } & Pick<GiveawayMonthlyInterval, 'january' | 'february' | 'march' | 'april' | 'may' | 'june' | 'july' | 'august' | 'september' | 'october' | 'november' | 'december'>>;
    }>;
    statistics?: Maybe<{
        __typename?: 'GiveawayStats';
    } & Pick<GiveawayStats, 'active' | 'countTrigger' | 'events' | 'numberOfUsers' | 'times' | 'wasActive'>>;
    nftStatistics?: Maybe<{
        __typename?: 'GiveawayStats';
    } & Pick<GiveawayStats, 'active' | 'amount' | 'numberOfUsers' | 'times'>>;
    tokenStatistics?: Maybe<{
        __typename?: 'GiveawayStats';
    } & Pick<GiveawayStats, 'active' | 'amount' | 'numberOfUsers' | 'times'>>;
};
export declare type GiveawayFragment = {
    __typename?: 'Giveaway';
} & Pick<Giveaway, 'activeAndPublishedNft' | 'forceGiveaway' | 'promptDialog' | 'skipNotification'> & {
    translations: Array<{
        __typename?: 'GiveawayTranslation';
    } & Pick<GiveawayTranslation, 'id' | 'locale' | 'title' | 'content' | 'message' | 'externalLink' | 'ctaText'>>;
    giveawayEvents: Array<{
        __typename?: 'GiveawayEvent';
    } & GiveawayEventFragment>;
    nftStatistics?: Maybe<{
        __typename?: 'GiveawayStats';
    } & Pick<GiveawayStats, 'active' | 'amount' | 'countTrigger' | 'events' | 'numberOfUsers' | 'times' | 'wasActive'>>;
    tokenStatistics?: Maybe<{
        __typename?: 'GiveawayStats';
    } & Pick<GiveawayStats, 'active' | 'amount' | 'countTrigger' | 'events' | 'numberOfUsers' | 'times' | 'wasActive'>>;
} & GiveawayLightFragment;
export declare type ArchiveGiveawayMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type ArchiveGiveawayMutation = {
    __typename?: 'Mutation';
} & {
    archiveGiveaway?: Maybe<{
        __typename?: 'ArchiveGiveawayMutationPayload';
    } & {
        giveaway: {
            __typename?: 'Giveaway';
        } & GiveawayFragment;
    }>;
};
export declare type CreateGiveawayMutationVariables = Exact<{
    params: GiveawayInput;
}>;
export declare type CreateGiveawayMutation = {
    __typename?: 'Mutation';
} & {
    createGiveaway?: Maybe<{
        __typename?: 'AddGiveawayMutationPayload';
    } & {
        giveaway: {
            __typename?: 'Giveaway';
        } & GiveawayFragment;
    }>;
};
export declare type DeleteGiveawaysMutationVariables = Exact<{
    ids: Array<Scalars['ID']> | Scalars['ID'];
}>;
export declare type DeleteGiveawaysMutation = {
    __typename?: 'Mutation';
} & {
    deleteGiveaways?: Maybe<{
        __typename?: 'DeleteGiveawaysMutationPayload';
    } & Pick<DeleteGiveawaysMutationPayload, 'deletedIds' | 'status'>>;
};
export declare type DraftGiveawayMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type DraftGiveawayMutation = {
    __typename?: 'Mutation';
} & {
    draftGiveaway?: Maybe<{
        __typename?: 'DraftGiveawayMutationPayload';
    } & {
        giveaway: {
            __typename?: 'Giveaway';
        } & GiveawayFragment;
    }>;
};
export declare type PublishGiveawayMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type PublishGiveawayMutation = {
    __typename?: 'Mutation';
} & {
    publishGiveaway?: Maybe<{
        __typename?: 'PublishGiveawayMutationPayload';
    } & {
        giveaway: {
            __typename?: 'Giveaway';
        } & GiveawayFragment;
    }>;
};
export declare type UpdateGiveawayMutationVariables = Exact<{
    id: Scalars['ID'];
    params: GiveawayInput;
}>;
export declare type UpdateGiveawayMutation = {
    __typename?: 'Mutation';
} & {
    updateGiveaway?: Maybe<{
        __typename?: 'UpdateGiveawayMutationPayload';
    } & {
        giveaway: {
            __typename?: 'Giveaway';
        } & GiveawayFragment;
    }>;
};
export declare type GetActiveAndPublishedNftGiveawaysQueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type GetActiveAndPublishedNftGiveawaysQuery = {
    __typename?: 'Query';
} & {
    giveaways: {
        __typename?: 'GiveawayResolver';
    } & Pick<GiveawayResolver, 'total'>;
};
export declare type GetGiveawayQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetGiveawayQuery = {
    __typename?: 'Query';
} & {
    giveaway: {
        __typename?: 'Giveaway';
    } & GiveawayFragment;
};
export declare type GetGiveawaysQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<GiveawayFilterInput>;
    sort?: Maybe<GiveawaySortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetGiveawaysQuery = {
    __typename?: 'Query';
} & {
    giveaways: {
        __typename?: 'GiveawayResolver';
    } & Pick<GiveawayResolver, 'total'> & {
        giveaways: Array<{
            __typename?: 'Giveaway';
        } & GiveawayFragment>;
    };
};
export declare type GetMeQueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type GetMeQuery = {
    __typename?: 'Query';
} & {
    me: {
        __typename?: 'AdminUser';
    } & AdminUserFragment;
};
export declare type ContentMediumFragment = {
    __typename?: 'ContentMedium';
} & Pick<ContentMedium, 'id' | 'createdAt' | 'updatedAt' | 'mediaType' | 'image' | 'original' | 'thumbnail' | 'externalSrc' | 'mediaSrc' | 'freeTokenTriggersCount' | 'resourcesCount' | 'contentsCount' | 'votingsCount' | 'menuItemsCount' | 'ideationMissionsCount' | 'amaSessionsCount' | 'nftCollectionsCount' | 'tokenHandoutsCount' | 'shopProductsCount' | 'customNotificationsCount' | 'aspectRatio' | 'dimensions' | 'threeqDimensions'> & {
    oembedData?: Maybe<({
        __typename?: 'OembedLink';
    } & OembedLinkFragment) | ({
        __typename?: 'OembedPhoto';
    } & OembedPhotoFragment) | ({
        __typename?: 'OembedRich';
    } & OembedRichFragment) | ({
        __typename?: 'OembedVideo';
    } & OembedVideoFragment)>;
    translations: Array<{
        __typename?: 'ContentMediumTranslation';
    } & Pick<ContentMediumTranslation, 'id' | 'locale' | 'title' | 'subtitle'>>;
};
export declare type OembedLinkFragment = {
    __typename?: 'OembedLink';
} & Pick<OembedLink, 'version' | 'title' | 'authorName' | 'authorUrl' | 'providerName' | 'providerUrl' | 'thumbnailUrl' | 'thumbnailWidth' | 'thumbnailHeight' | 'type'>;
export declare type OembedPhotoFragment = {
    __typename?: 'OembedPhoto';
} & Pick<OembedPhoto, 'version' | 'title' | 'authorName' | 'authorUrl' | 'providerName' | 'providerUrl' | 'thumbnailUrl' | 'thumbnailWidth' | 'thumbnailHeight' | 'type' | 'url' | 'width' | 'height'>;
export declare type OembedRichFragment = {
    __typename?: 'OembedRich';
} & Pick<OembedRich, 'version' | 'title' | 'authorName' | 'authorUrl' | 'providerName' | 'providerUrl' | 'thumbnailUrl' | 'thumbnailWidth' | 'thumbnailHeight' | 'type' | 'html' | 'width' | 'height'>;
export declare type OembedVideoFragment = {
    __typename?: 'OembedVideo';
} & Pick<OembedVideo, 'version' | 'title' | 'authorName' | 'authorUrl' | 'providerName' | 'providerUrl' | 'thumbnailUrl' | 'thumbnailWidth' | 'thumbnailHeight' | 'type' | 'html' | 'width' | 'height'>;
export declare type CreateContentMediumMutationVariables = Exact<{
    params: ContentMediumInput;
}>;
export declare type CreateContentMediumMutation = {
    __typename?: 'Mutation';
} & {
    createContentMedium?: Maybe<{
        __typename?: 'AddContentMediumMutationPayload';
    } & {
        contentMedium: {
            __typename?: 'ContentMedium';
        } & ContentMediumFragment;
    }>;
};
export declare type DeleteContentMediaMutationVariables = Exact<{
    ids: Array<Scalars['ID']> | Scalars['ID'];
}>;
export declare type DeleteContentMediaMutation = {
    __typename?: 'Mutation';
} & {
    deleteContentMedia?: Maybe<{
        __typename?: 'DeleteContentMediaMutationPayload';
    } & Pick<DeleteContentMediaMutationPayload, 'deletedIds' | 'status'>>;
};
export declare type RefreshOembedDataMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type RefreshOembedDataMutation = {
    __typename?: 'Mutation';
} & {
    refreshOembedData?: Maybe<{
        __typename?: 'RefreshOembedDataMutationPayload';
    } & {
        contentMedium: {
            __typename?: 'ContentMedium';
        } & ContentMediumFragment;
    }>;
};
export declare type UpdateContentMediumMutationVariables = Exact<{
    id: Scalars['ID'];
    params: ContentMediumInput;
}>;
export declare type UpdateContentMediumMutation = {
    __typename?: 'Mutation';
} & {
    updateContentMedium?: Maybe<{
        __typename?: 'UpdateContentMediumMutationPayload';
    } & {
        contentMedium: {
            __typename?: 'ContentMedium';
        } & ContentMediumFragment;
    }>;
};
export declare type GetMediaUploadUrlMutationVariables = Exact<{
    fileName: Scalars['String'];
    fileExt: Scalars['String'];
    mediumId?: Maybe<Scalars['ID']>;
}>;
export declare type GetMediaUploadUrlMutation = {
    __typename?: 'Mutation';
} & {
    getMediaUploadUrl?: Maybe<{
        __typename?: 'GetMediaUploadUrlMutationPayload';
    } & Pick<GetMediaUploadUrlMutationPayload, 'url'>>;
};
export declare type GetContentMediaQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<ContentMediumFilterInput>;
    sort?: Maybe<ContentMediumSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetContentMediaQuery = {
    __typename?: 'Query';
} & {
    contentMedia: {
        __typename?: 'ContentMediumResolver';
    } & Pick<ContentMediumResolver, 'total'> & {
        contentMedia: Array<{
            __typename?: 'ContentMedium';
        } & ContentMediumFragment>;
    };
};
export declare type GetContentMediumQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetContentMediumQuery = {
    __typename?: 'Query';
} & {
    contentMedium: {
        __typename?: 'ContentMedium';
    } & ContentMediumFragment;
};
export declare type MenuItemBasicFragment = {
    __typename?: 'MenuItem';
} & Pick<MenuItem, 'id' | 'createdAt' | 'updatedAt' | 'heroMediumId' | 'iconUrl' | 'menuPosition' | 'menuType' | 'menuResource' | 'order' | 'staticPageId' | 'appName'> & {
    heroMedium?: Maybe<{
        __typename?: 'ContentMedium';
    } & ContentMediumFragment>;
    staticPage?: Maybe<{
        __typename?: 'StaticPage';
    } & Pick<StaticPage, 'id' | 'status'> & {
        previewUrls: Array<{
            __typename?: 'PreviewUrl';
        } & PreviewUrlFragment>;
        translations: Array<{
            __typename?: 'StaticPageTranslation';
        } & Pick<StaticPageTranslation, 'id' | 'locale' | 'title' | 'slug'>>;
    }>;
    translations: Array<{
        __typename?: 'MenuItemTranslation';
    } & MenuItemTranslationFragment>;
};
export declare type MenuItemChildFragment = {
    __typename?: 'MenuItem';
} & Pick<MenuItem, 'menuItemId'> & {
    menuItem?: Maybe<{
        __typename?: 'MenuItem';
    } & MenuItemParentFragment>;
} & MenuItemBasicFragment;
export declare type MenuItemParentFragment = {
    __typename?: 'MenuItem';
} & MenuItemBasicFragment;
export declare type MenuItemTranslationFragment = {
    __typename?: 'MenuItemTranslation';
} & Pick<MenuItemTranslation, 'id' | 'locale' | 'slug' | 'externalUrl' | 'headerTitle' | 'navbarTitle'>;
export declare type MenuItemFragment = {
    __typename?: 'MenuItem';
} & Pick<MenuItem, 'menuItemId'> & {
    menuItem?: Maybe<{
        __typename?: 'MenuItem';
    } & MenuItemParentFragment>;
    menuItems?: Maybe<Array<{
        __typename?: 'MenuItem';
    } & MenuItemChildFragment>>;
} & MenuItemBasicFragment;
export declare type CreateMenuItemMutationVariables = Exact<{
    params: MenuItemInput;
}>;
export declare type CreateMenuItemMutation = {
    __typename?: 'Mutation';
} & {
    createMenuItem?: Maybe<{
        __typename?: 'AddMenuItemMutationPayload';
    } & {
        menuItem: {
            __typename?: 'MenuItem';
        } & MenuItemFragment;
    }>;
};
export declare type DeleteMenuItemsMutationVariables = Exact<{
    ids: Array<Scalars['ID']> | Scalars['ID'];
}>;
export declare type DeleteMenuItemsMutation = {
    __typename?: 'Mutation';
} & {
    deleteMenuItems?: Maybe<{
        __typename?: 'DeleteMenuItemsMutationPayload';
    } & Pick<DeleteMenuItemsMutationPayload, 'deletedIds' | 'status'>>;
};
export declare type UpdateMenuItemMutationVariables = Exact<{
    id: Scalars['ID'];
    params: MenuItemInput;
}>;
export declare type UpdateMenuItemMutation = {
    __typename?: 'Mutation';
} & {
    updateMenuItem?: Maybe<{
        __typename?: 'UpdateMenuItemMutationPayload';
    } & {
        menuItem: {
            __typename?: 'MenuItem';
        } & MenuItemFragment;
    }>;
};
export declare type UpdateMenuItemsMutationVariables = Exact<{
    params: Array<MenuItemInput> | MenuItemInput;
}>;
export declare type UpdateMenuItemsMutation = {
    __typename?: 'Mutation';
} & {
    updateMenuItems?: Maybe<{
        __typename?: 'UpdateMenuItemsMutationPayload';
    } & {
        menuItems: Array<{
            __typename?: 'MenuItem';
        } & MenuItemFragment>;
    }>;
};
export declare type GetMenuItemsQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<MenuItemFilterInput>;
}>;
export declare type GetMenuItemsQuery = {
    __typename?: 'Query';
} & {
    menuItems: {
        __typename?: 'MenuItemResolver';
    } & Pick<MenuItemResolver, 'total'> & {
        menuItems: Array<{
            __typename?: 'MenuItem';
        } & MenuItemFragment>;
    };
};
export declare type AmaQuestionLightFragment = {
    __typename?: 'AmaQuestion';
} & Pick<AmaQuestion, 'boostsAmountCache' | 'commentsCount' | 'content' | 'createdAt' | 'customTag1' | 'customTag2' | 'customTag3' | 'customTag4' | 'customTag5' | 'id' | 'amaSessionId' | 'isAnswered' | 'title' | 'updatedAt' | 'ugcReportsCount' | 'reportStatus'> & {
    amaSession: {
        __typename?: 'AmaSession';
    } & Pick<AmaSession, 'id'> & {
        translations: Array<{
            __typename?: 'AmaSessionTranslation';
        } & AmaSessionTranslationFragment>;
    };
    user: {
        __typename?: 'User';
    } & UserLightFragment;
};
export declare type AmaQuestionFragment = {
    __typename?: 'AmaQuestion';
} & Pick<AmaQuestion, 'previewUrl'> & {
    comments: Array<{
        __typename?: 'Comment';
    } & CommentFragment>;
    amaSession: {
        __typename?: 'AmaSession';
    } & AmaSessionLightFragment;
    ugcReportTypes?: Maybe<Array<{
        __typename?: 'UgcReportTyp';
    } & UgcReportTypeFragment>>;
    ugcReports: Array<{
        __typename?: 'UgcReport';
    } & UgcReportFragment>;
    audits: Array<{
        __typename?: 'Audit';
    } & AuditFragment>;
    nfts: Array<{
        __typename?: 'Nft';
    } & NftLightFragment>;
} & AmaQuestionLightFragment;
export declare type CommentLightFragment = {
    __typename?: 'Comment';
} & Pick<Comment, 'id' | 'title' | 'content' | 'createdAt' | 'updatedAt' | 'muted' | 'commentableId' | 'commentableTitle' | 'commentableType' | 'commentsCount' | 'boostsAmountCache' | 'ugcReportsCount' | 'reportStatus'> & {
    user: {
        __typename?: 'User';
    } & Pick<User, 'id' | 'displayName' | 'verified'>;
    nfts: Array<{
        __typename?: 'Nft';
    } & Pick<Nft, 'id' | 'name'> & {
        nftMedium: {
            __typename?: 'NftMedium';
        } & NftMediumFragment;
    }>;
};
export declare type CommentFragment = {
    __typename?: 'Comment';
} & Pick<Comment, 'id' | 'title' | 'content' | 'createdAt' | 'updatedAt' | 'muted' | 'commentableId' | 'commentableTitle' | 'commentableType' | 'commentsCount' | 'boostsAmountCache' | 'contractAddress' | 'creatorShare' | 'fanvaultShare' | 'operatorAddress' | 'operatorShare' | 'reportStatus' | 'ugcReportsCount' | 'previewUrl'> & {
    comments: Array<{
        __typename?: 'Comment';
    } & CommentLightFragment>;
    ugcReportTypes?: Maybe<Array<{
        __typename?: 'UgcReportTyp';
    } & UgcReportTypeFragment>>;
    ugcReports: Array<{
        __typename?: 'UgcReport';
    } & UgcReportFragment>;
    audits: Array<{
        __typename?: 'Audit';
    } & AuditFragment>;
    user: {
        __typename?: 'User';
    } & Pick<User, 'id' | 'displayName' | 'verified'>;
    nfts: Array<{
        __typename?: 'Nft';
    } & NftLightFragment>;
};
export declare type FanGroupForSelectFragment = {
    __typename?: 'FanGroup';
} & Pick<FanGroup, 'id' | 'name'>;
export declare type FanGroupLightFragment = {
    __typename?: 'FanGroup';
} & Pick<FanGroup, 'id' | 'name' | 'city' | 'state' | 'country' | 'createdAt' | 'updatedAt' | 'groupPurpose' | 'groupAdminId' | 'isVerified' | 'archived' | 'acceptanceStatus' | 'heroMediumId' | 'groupProfileMediumId' | 'reportStatus' | 'ugcReportsCount' | 'activeFanGroupUsersCount' | 'pendingFanGroupUsersCount' | 'accessType' | 'postsVisibilityType' | 'visibilityType'> & {
    groupAdmin: {
        __typename?: 'User';
    } & UserLightFragment;
    heroMedium?: Maybe<{
        __typename?: 'UserMedium';
    } & UserMediumFragment>;
    groupProfileMedium?: Maybe<{
        __typename?: 'UserMedium';
    } & UserMediumFragment>;
};
export declare type FanGroupUserFragment = {
    __typename?: 'FanGroupUser';
} & Pick<FanGroupUser, 'id' | 'createdAt' | 'updatedAt' | 'leftAt' | 'blockedAt' | 'rejectedAt' | 'canceledAt' | 'activatedAt' | 'status' | 'role' | 'userId' | 'fanGroupId'> & {
    user: {
        __typename?: 'User';
    } & UserLightFragment;
};
export declare type FanGroupFragment = {
    __typename?: 'FanGroup';
} & Pick<FanGroup, 'description' | 'previewUrl' | 'showInFeed' | 'shownInFeedAt' | 'willBePinned' | 'pinToTop'> & {
    audits: Array<{
        __typename?: 'Audit';
    } & AuditFragment>;
    ugcReportTypes?: Maybe<Array<{
        __typename?: 'UgcReportTyp';
    } & UgcReportTypeFragment>>;
    ugcReports: Array<{
        __typename?: 'UgcReport';
    } & UgcReportFragment>;
} & FanGroupLightFragment;
export declare type GroupPostLightFragment = {
    __typename?: 'GroupPost';
} & Pick<GroupPost, 'id' | 'createdAt' | 'updatedAt' | 'boostsAmountCache' | 'userId' | 'content' | 'contractAddress' | 'creatorShare' | 'fanGroupId' | 'fanvaultShare' | 'operatorAddress' | 'operatorShare' | 'reportStatus' | 'title' | 'ugcReportsCount'> & {
    user: {
        __typename?: 'User';
    } & UserLightFragment;
    fanGroup: {
        __typename?: 'FanGroup';
    } & Pick<FanGroup, 'id' | 'name'>;
};
export declare type GroupPostFragment = {
    __typename?: 'GroupPost';
} & Pick<GroupPost, 'previewUrl' | 'commentsCount'> & {
    audits: Array<{
        __typename?: 'Audit';
    } & AuditFragment>;
    ugcReportTypes?: Maybe<Array<{
        __typename?: 'UgcReportTyp';
    } & UgcReportTypeFragment>>;
    ugcReports: Array<{
        __typename?: 'UgcReport';
    } & UgcReportFragment>;
    comments: Array<{
        __typename?: 'Comment';
    } & CommentLightFragment>;
    nfts: Array<{
        __typename?: 'Nft';
    } & NftLightFragment>;
} & GroupPostLightFragment;
export declare type IdeaLightFragment = {
    __typename?: 'Idea';
} & Pick<Idea, 'boostsAmountCache' | 'commentsCount' | 'content' | 'createdAt' | 'customTag1' | 'customTag2' | 'customTag3' | 'customTag4' | 'customTag5' | 'id' | 'ideationMissionId' | 'isClubFav' | 'isImplemented' | 'isSelected' | 'title' | 'updatedAt' | 'ugcReportsCount' | 'reportStatus'> & {
    ideationMission: {
        __typename?: 'IdeationMission';
    } & Pick<IdeationMission, 'id'> & {
        translations: Array<{
            __typename?: 'IdeationMissionTranslation';
        } & IdeationMissionTranslationFragment>;
    };
    user: {
        __typename?: 'User';
    } & UserLightFragment;
};
export declare type IdeaFragment = {
    __typename?: 'Idea';
} & Pick<Idea, 'boostsAmountCache' | 'commentsCount' | 'content' | 'createdAt' | 'customTag1' | 'customTag2' | 'customTag3' | 'customTag4' | 'customTag5' | 'id' | 'ideationMissionId' | 'isClubFav' | 'isImplemented' | 'isSelected' | 'title' | 'updatedAt' | 'reportStatus' | 'ugcReportsCount' | 'previewUrl'> & {
    comments: Array<{
        __typename?: 'Comment';
    } & CommentFragment>;
    ideationMission: {
        __typename?: 'IdeationMission';
    } & IdeationMissionLightFragment;
    ugcReportTypes?: Maybe<Array<{
        __typename?: 'UgcReportTyp';
    } & UgcReportTypeFragment>>;
    ugcReports: Array<{
        __typename?: 'UgcReport';
    } & UgcReportFragment>;
    audits: Array<{
        __typename?: 'Audit';
    } & AuditFragment>;
    user: {
        __typename?: 'User';
    } & UserLightFragment;
    nfts: Array<{
        __typename?: 'Nft';
    } & NftLightFragment>;
};
export declare type ProposalLightFragment = {
    __typename?: 'Proposal';
} & Pick<Proposal, 'id' | 'title' | 'createdAt' | 'updatedAt' | 'clubAcceptanceStatus' | 'boostsAmountCache' | 'ugcReportsCount' | 'reportStatus' | 'content' | 'contractAddress' | 'creatorShare' | 'fanvaultShare' | 'operatorAddress' | 'operatorShare' | 'commentsCount'> & {
    user: {
        __typename?: 'User';
    } & Pick<User, 'id' | 'displayName' | 'verified'>;
    proposalPeriod: {
        __typename?: 'ProposalPeriod';
    } & ProposalPeriodLightFragment;
};
export declare type ProposalPeriodLightFragment = {
    __typename?: 'ProposalPeriod';
} & Pick<ProposalPeriod, 'id' | 'title' | 'awarded' | 'createdAt' | 'updatedAt' | 'startDate' | 'endDate' | 'proposalsCount' | 'generationType' | 'periodType'>;
export declare type ProposalPeriodFragment = {
    __typename?: 'ProposalPeriod';
} & {
    proposals: Array<{
        __typename?: 'Proposal';
    } & ProposalLightFragment>;
} & ProposalPeriodLightFragment;
export declare type ProposalFragment = {
    __typename?: 'Proposal';
} & Pick<Proposal, 'id' | 'title' | 'createdAt' | 'updatedAt' | 'clubAcceptanceStatus' | 'boostsAmountCache' | 'content' | 'contractAddress' | 'creatorShare' | 'fanvaultShare' | 'operatorAddress' | 'operatorShare' | 'reportStatus' | 'ugcReportsCount' | 'commentsCount' | 'previewUrl'> & {
    ugcReportTypes?: Maybe<Array<{
        __typename?: 'UgcReportTyp';
    } & UgcReportTypeFragment>>;
    ugcReports: Array<{
        __typename?: 'UgcReport';
    } & UgcReportFragment>;
    audits: Array<{
        __typename?: 'Audit';
    } & AuditFragment>;
    user: {
        __typename?: 'User';
    } & Pick<User, 'id' | 'displayName' | 'verified'>;
    proposalPeriod: {
        __typename?: 'ProposalPeriod';
    } & ProposalPeriodLightFragment;
    comments: Array<{
        __typename?: 'Comment';
    } & CommentFragment>;
    announcements: Array<{
        __typename?: 'Announcement';
    } & AnnouncementFragment>;
    nfts: Array<{
        __typename?: 'Nft';
    } & NftLightFragment>;
};
export declare type UgcReportFragment = {
    __typename?: 'UgcReport';
} & Pick<UgcReport, 'id' | 'createdAt' | 'updatedAt' | 'reportableId' | 'reportableType' | 'reportableTitle' | 'status'> & {
    ugcReportTypes: Array<{
        __typename?: 'UgcReportTyp';
    } & UgcReportTypeFragment>;
    user: {
        __typename?: 'User';
    } & Pick<User, 'id' | 'displayName' | 'verified'>;
};
export declare type CreateProposalPeriodMutationVariables = Exact<{
    params: ProposalPeriodInput;
}>;
export declare type CreateProposalPeriodMutation = {
    __typename?: 'Mutation';
} & {
    createProposalPeriod?: Maybe<{
        __typename?: 'AddProposalPeriodMutationPayload';
    } & {
        proposalPeriod: {
            __typename?: 'ProposalPeriod';
        } & ProposalPeriodFragment;
    }>;
};
export declare type DeleteProposalPeriodsMutationVariables = Exact<{
    ids: Array<Scalars['ID']> | Scalars['ID'];
}>;
export declare type DeleteProposalPeriodsMutation = {
    __typename?: 'Mutation';
} & {
    deleteProposalPeriods?: Maybe<{
        __typename?: 'DeleteProposalPeriodsMutationPayload';
    } & Pick<DeleteProposalPeriodsMutationPayload, 'deletedIds' | 'status'>>;
};
export declare type UpdateAmaQuestionMutationVariables = Exact<{
    id: Scalars['ID'];
    params: AmaQuestionInput;
}>;
export declare type UpdateAmaQuestionMutation = {
    __typename?: 'Mutation';
} & {
    updateAmaQuestion?: Maybe<{
        __typename?: 'UpdateAmaQuestionMutationPayload';
    } & {
        amaQuestion: {
            __typename?: 'AmaQuestion';
        } & AmaQuestionFragment;
    }>;
};
export declare type UpdateCommentMutationVariables = Exact<{
    id: Scalars['ID'];
    params: CommentInput;
}>;
export declare type UpdateCommentMutation = {
    __typename?: 'Mutation';
} & {
    updateComment?: Maybe<{
        __typename?: 'UpdateCommentMutationPayload';
    } & {
        comment: {
            __typename?: 'Comment';
        } & CommentFragment;
    }>;
};
export declare type UpdateFanGroupMutationVariables = Exact<{
    id: Scalars['ID'];
    params: FanGroupInput;
}>;
export declare type UpdateFanGroupMutation = {
    __typename?: 'Mutation';
} & {
    updateFanGroup?: Maybe<{
        __typename?: 'UpdateFanGroupMutationPayload';
    } & {
        fanGroup: {
            __typename?: 'FanGroup';
        } & FanGroupFragment;
    }>;
};
export declare type UpdateGroupPostMutationVariables = Exact<{
    id: Scalars['ID'];
    params: GroupPostInput;
}>;
export declare type UpdateGroupPostMutation = {
    __typename?: 'Mutation';
} & {
    updateGroupPost?: Maybe<{
        __typename?: 'UpdateGroupPostMutationPayload';
    } & {
        groupPost: {
            __typename?: 'GroupPost';
        } & GroupPostFragment;
    }>;
};
export declare type UpdateIdeaMutationVariables = Exact<{
    id: Scalars['ID'];
    params: IdeaInput;
}>;
export declare type UpdateIdeaMutation = {
    __typename?: 'Mutation';
} & {
    updateIdea?: Maybe<{
        __typename?: 'UpdateIdeaMutationPayload';
    } & {
        idea: {
            __typename?: 'Idea';
        } & IdeaFragment;
    }>;
};
export declare type UpdateProposalPeriodMutationVariables = Exact<{
    id: Scalars['ID'];
    params: ProposalPeriodInput;
}>;
export declare type UpdateProposalPeriodMutation = {
    __typename?: 'Mutation';
} & {
    updateProposalPeriod?: Maybe<{
        __typename?: 'UpdateProposalPeriodMutationPayload';
    } & {
        proposalPeriod: {
            __typename?: 'ProposalPeriod';
        } & ProposalPeriodFragment;
    }>;
};
export declare type UpdateProposalMutationVariables = Exact<{
    id: Scalars['ID'];
    params: ProposalInput;
}>;
export declare type UpdateProposalMutation = {
    __typename?: 'Mutation';
} & {
    updateProposal?: Maybe<{
        __typename?: 'UpdateProposalMutationPayload';
    } & {
        proposal: {
            __typename?: 'Proposal';
        } & ProposalFragment;
    }>;
};
export declare type GetAmaQuestionQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetAmaQuestionQuery = {
    __typename?: 'Query';
} & {
    amaQuestion: {
        __typename?: 'AmaQuestion';
    } & AmaQuestionFragment;
};
export declare type GetAmaQuestionsQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<AmaQuestionFilterInput>;
    sort?: Maybe<AmaQuestionSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetAmaQuestionsQuery = {
    __typename?: 'Query';
} & {
    amaQuestions: {
        __typename?: 'AmaQuestionResolver';
    } & Pick<AmaQuestionResolver, 'total'> & {
        amaQuestions: Array<{
            __typename?: 'AmaQuestion';
        } & AmaQuestionLightFragment>;
    };
};
export declare type GetCommentQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetCommentQuery = {
    __typename?: 'Query';
} & {
    comment: {
        __typename?: 'Comment';
    } & {
        comments: Array<{
            __typename?: 'Comment';
        } & CommentFragment>;
    } & CommentFragment;
};
export declare type GetCommentsQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<CommentFilterInput>;
    sort?: Maybe<CommentSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetCommentsQuery = {
    __typename?: 'Query';
} & {
    comments: {
        __typename?: 'CommentResolver';
    } & Pick<CommentResolver, 'total'> & {
        comments: Array<{
            __typename?: 'Comment';
        } & CommentLightFragment>;
    };
};
export declare type GetFanGroupUsersQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<FanGroupUserFilterInput>;
    sort?: Maybe<FanGroupUserSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetFanGroupUsersQuery = {
    __typename?: 'Query';
} & {
    fanGroupUsers: {
        __typename?: 'FanGroupUserResolver';
    } & Pick<FanGroupUserResolver, 'total'> & {
        fanGroupUsers: Array<{
            __typename?: 'FanGroupUser';
        } & FanGroupUserFragment>;
    };
};
export declare type GetFanGroupQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetFanGroupQuery = {
    __typename?: 'Query';
} & {
    fanGroup: {
        __typename?: 'FanGroup';
    } & FanGroupFragment;
};
export declare type GetFanGroupsForSelectQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filterTitle?: Maybe<FilterTextInput>;
    sort?: Maybe<FanGroupSortInput>;
    selectedIds: Array<Scalars['ID']> | Scalars['ID'];
}>;
export declare type GetFanGroupsForSelectQuery = {
    __typename?: 'Query';
} & {
    fanGroups: {
        __typename?: 'FanGroupResolver';
    } & Pick<FanGroupResolver, 'total'> & {
        fanGroups: Array<{
            __typename?: 'FanGroup';
        } & FanGroupForSelectFragment>;
    };
    selectedFanGroups: {
        __typename?: 'FanGroupResolver';
    } & Pick<FanGroupResolver, 'total'> & {
        fanGroups: Array<{
            __typename?: 'FanGroup';
        } & FanGroupForSelectFragment>;
    };
};
export declare type GetFanGroupsQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<FanGroupFilterInput>;
    sort?: Maybe<FanGroupSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetFanGroupsQuery = {
    __typename?: 'Query';
} & {
    fanGroups: {
        __typename?: 'FanGroupResolver';
    } & Pick<FanGroupResolver, 'total'> & {
        fanGroups: Array<{
            __typename?: 'FanGroup';
        } & FanGroupLightFragment>;
    };
};
export declare type GetGroupPostQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetGroupPostQuery = {
    __typename?: 'Query';
} & {
    groupPost: {
        __typename?: 'GroupPost';
    } & GroupPostFragment;
};
export declare type GetGroupPostsQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<GroupPostFilterInput>;
    sort?: Maybe<GroupPostSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetGroupPostsQuery = {
    __typename?: 'Query';
} & {
    groupPosts: {
        __typename?: 'GroupPostResolver';
    } & Pick<GroupPostResolver, 'total'> & {
        groupPosts: Array<{
            __typename?: 'GroupPost';
        } & GroupPostFragment>;
    };
};
export declare type GetIdeaQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetIdeaQuery = {
    __typename?: 'Query';
} & {
    idea: {
        __typename?: 'Idea';
    } & IdeaFragment;
};
export declare type GetIdeasQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<IdeaFilterInput>;
    sort?: Maybe<IdeaSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetIdeasQuery = {
    __typename?: 'Query';
} & {
    ideas: {
        __typename?: 'IdeaResolver';
    } & Pick<IdeaResolver, 'total'> & {
        ideas: Array<{
            __typename?: 'Idea';
        } & IdeaLightFragment>;
    };
};
export declare type GetProposalPeriodQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetProposalPeriodQuery = {
    __typename?: 'Query';
} & {
    proposalPeriod: {
        __typename?: 'ProposalPeriod';
    } & ProposalPeriodFragment;
};
export declare type GetProposalPeriodsQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<ProposalPeriodFilterInput>;
    sort?: Maybe<ProposalPeriodSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetProposalPeriodsQuery = {
    __typename?: 'Query';
} & {
    proposalPeriods: {
        __typename?: 'ProposalPeriodResolver';
    } & Pick<ProposalPeriodResolver, 'total'> & {
        proposalPeriods: Array<{
            __typename?: 'ProposalPeriod';
        } & ProposalPeriodLightFragment>;
    };
};
export declare type GetProposalQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetProposalQuery = {
    __typename?: 'Query';
} & {
    proposal: {
        __typename?: 'Proposal';
    } & ProposalFragment;
};
export declare type GetProposalsQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<ProposalFilterInput>;
    sort?: Maybe<ProposalSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetProposalsQuery = {
    __typename?: 'Query';
} & {
    proposals: {
        __typename?: 'ProposalResolver';
    } & Pick<ProposalResolver, 'total'> & {
        proposals: Array<{
            __typename?: 'Proposal';
        } & ProposalLightFragment>;
    };
};
export declare type GetUgcReportMetasQueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type GetUgcReportMetasQuery = {
    __typename?: 'Query';
} & {
    commentsReported: {
        __typename?: 'CommentResolver';
    } & Pick<CommentResolver, 'total'>;
    commentsUnderReview: {
        __typename?: 'CommentResolver';
    } & Pick<CommentResolver, 'total'>;
    proposalsReported: {
        __typename?: 'ProposalResolver';
    } & Pick<ProposalResolver, 'total'>;
    proposalsUnderReview: {
        __typename?: 'ProposalResolver';
    } & Pick<ProposalResolver, 'total'>;
    amaQuestionsReported: {
        __typename?: 'AmaQuestionResolver';
    } & Pick<AmaQuestionResolver, 'total'>;
    amaQuestionsUnderReview: {
        __typename?: 'AmaQuestionResolver';
    } & Pick<AmaQuestionResolver, 'total'>;
    ideasReported: {
        __typename?: 'IdeaResolver';
    } & Pick<IdeaResolver, 'total'>;
    ideasUnderReview: {
        __typename?: 'IdeaResolver';
    } & Pick<IdeaResolver, 'total'>;
    fanGroupsReported: {
        __typename?: 'FanGroupResolver';
    } & Pick<FanGroupResolver, 'total'>;
    fanGroupsUnderReview: {
        __typename?: 'FanGroupResolver';
    } & Pick<FanGroupResolver, 'total'>;
    fanGroupsSubmitted: {
        __typename?: 'FanGroupResolver';
    } & Pick<FanGroupResolver, 'total'>;
    groupPostsReported: {
        __typename?: 'GroupPostResolver';
    } & Pick<GroupPostResolver, 'total'>;
    groupPostsUnderReview: {
        __typename?: 'GroupPostResolver';
    } & Pick<GroupPostResolver, 'total'>;
    usersReported: {
        __typename?: 'UserResolver';
    } & Pick<UserResolver, 'total'>;
    usersUnderReview: {
        __typename?: 'UserResolver';
    } & Pick<UserResolver, 'total'>;
};
export declare type GetUgcReportQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetUgcReportQuery = {
    __typename?: 'Query';
} & {
    ugcReport: {
        __typename?: 'UgcReport';
    } & UgcReportFragment;
};
export declare type GetUgcReportsQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<UgcReportFilterInput>;
    sort?: Maybe<UgcReportSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetUgcReportsQuery = {
    __typename?: 'Query';
} & {
    ugcReports: {
        __typename?: 'UgcReportResolver';
    } & Pick<UgcReportResolver, 'total'> & {
        ugcReports: Array<{
            __typename?: 'UgcReport';
        } & UgcReportFragment>;
    };
};
export declare type NftBenefitRedemptionFragment = {
    __typename?: 'NftBenefitRedemption';
} & Pick<NftBenefitRedemption, 'id' | 'createdAt' | 'updatedAt' | 'userId'> & {
    nftBenefit: {
        __typename?: 'NftBenefit';
    } & Pick<NftBenefit, 'id'> & {
        nft: {
            __typename?: 'Nft';
        } & NftLightFragment;
    };
    user: {
        __typename?: 'User';
    } & UserLightFragment;
};
export declare type GetNftBenefitRedemptionsQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<NftBenefitRedemptionFilterInput>;
    sort?: Maybe<NftBenefitRedemptionSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetNftBenefitRedemptionsQuery = {
    __typename?: 'Query';
} & {
    nftBenefitRedemptions: {
        __typename?: 'NftBenefitRedemptionResolver';
    } & Pick<NftBenefitRedemptionResolver, 'total'> & {
        nftBenefitRedemptions: Array<{
            __typename?: 'NftBenefitRedemption';
        } & NftBenefitRedemptionFragment>;
    };
};
export declare type NftHandoutLightFragment = {
    __typename?: 'NftHandout';
} & Pick<NftHandout, 'id' | 'createdAt' | 'updatedAt' | 'handoutAt' | 'promptDialog' | 'skipNotification' | 'status' | 'nftId' | 'sponsorId' | 'nftHandoutUsersCount'> & {
    translations: Array<{
        __typename?: 'NftHandoutTranslation';
    } & Pick<NftHandoutTranslation, 'id' | 'locale' | 'title'>>;
    sponsor?: Maybe<{
        __typename?: 'Sponsor';
    } & Pick<Sponsor, 'id' | 'name'>>;
    nft: {
        __typename?: 'Nft';
    } & NftLightFragment;
    statistics?: Maybe<{
        __typename?: 'NftHandoutStats';
    } & Pick<NftHandoutStats, 'amount' | 'countTrigger' | 'id' | 'numberOfUsers' | 'times'>>;
};
export declare type NftHandoutTranslationFragment = {
    __typename?: 'NftHandoutTranslation';
} & Pick<NftHandoutTranslation, 'id' | 'locale' | 'title' | 'message' | 'content' | 'externalLink' | 'ctaText'>;
export declare type NftHandoutUserFragment = {
    __typename?: 'NftHandoutUser';
} & Pick<NftHandoutUser, 'id' | 'createdAt' | 'updatedAt' | 'userId' | 'nftHandoutId'> & {
    user: {
        __typename?: 'User';
    } & UserLightFragment;
};
export declare type NftHandoutFragment = {
    __typename?: 'NftHandout';
} & Pick<NftHandout, 'userSearch'> & {
    translations: Array<{
        __typename?: 'NftHandoutTranslation';
    } & NftHandoutTranslationFragment>;
    userFilter?: Maybe<{
        __typename?: 'UserFilter';
    } & UserFilterFragment>;
} & NftHandoutLightFragment;
export declare type CreateNftHandoutMutationVariables = Exact<{
    params: NftHandoutInput;
    userFilter: UserFilterInput;
    userSearch?: Maybe<Scalars['String']>;
}>;
export declare type CreateNftHandoutMutation = {
    __typename?: 'Mutation';
} & {
    createNftHandout?: Maybe<{
        __typename?: 'AddNftHandoutMutationPayload';
    } & {
        nftHandout: {
            __typename?: 'NftHandout';
        } & NftHandoutFragment;
    }>;
};
export declare type DeleteNftHandoutsMutationVariables = Exact<{
    ids: Array<Scalars['ID']> | Scalars['ID'];
}>;
export declare type DeleteNftHandoutsMutation = {
    __typename?: 'Mutation';
} & {
    deleteNftHandouts?: Maybe<{
        __typename?: 'DeleteNftHandoutsMutationPayload';
    } & Pick<DeleteNftHandoutsMutationPayload, 'status' | 'deletedIds'>>;
};
export declare type DraftNftHandoutMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type DraftNftHandoutMutation = {
    __typename?: 'Mutation';
} & {
    draftNftHandout?: Maybe<{
        __typename?: 'DraftNftHandoutMutationPayload';
    } & {
        nftHandout: {
            __typename?: 'NftHandout';
        } & NftHandoutFragment;
    }>;
};
export declare type PublishNftHandoutMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type PublishNftHandoutMutation = {
    __typename?: 'Mutation';
} & {
    publishNftHandout?: Maybe<{
        __typename?: 'PublishNftHandoutMutationPayload';
    } & {
        nftHandout: {
            __typename?: 'NftHandout';
        } & NftHandoutFragment;
    }>;
};
export declare type UpdateNftHandoutMutationVariables = Exact<{
    id: Scalars['ID'];
    params: NftHandoutInput;
    userFilter?: Maybe<UserFilterInput>;
    userSearch?: Maybe<Scalars['String']>;
}>;
export declare type UpdateNftHandoutMutation = {
    __typename?: 'Mutation';
} & {
    updateNftHandout?: Maybe<{
        __typename?: 'UpdateNftHandoutMutationPayload';
    } & {
        nftHandout: {
            __typename?: 'NftHandout';
        } & NftHandoutFragment;
    }>;
};
export declare type GetNftHandoutUsersQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<NftHandoutUserFilterInput>;
    sort?: Maybe<NftHandoutUserSortInput>;
}>;
export declare type GetNftHandoutUsersQuery = {
    __typename?: 'Query';
} & {
    nftHandoutUsers: {
        __typename?: 'NftHandoutUserResolver';
    } & Pick<NftHandoutUserResolver, 'total'> & {
        nftHandoutUsers: Array<{
            __typename?: 'NftHandoutUser';
        } & NftHandoutUserFragment>;
    };
};
export declare type GetNftHandoutQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetNftHandoutQuery = {
    __typename?: 'Query';
} & {
    nftHandout: {
        __typename?: 'NftHandout';
    } & NftHandoutFragment;
};
export declare type GetNftHandoutsQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<NftHandoutFilterInput>;
    sort?: Maybe<NftHandoutSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetNftHandoutsQuery = {
    __typename?: 'Query';
} & {
    nftHandouts: {
        __typename?: 'NftHandoutResolver';
    } & Pick<NftHandoutResolver, 'total'> & {
        nftHandouts: Array<{
            __typename?: 'NftHandout';
        } & NftHandoutLightFragment>;
    };
};
export declare type NftTransferNetworkFragment = {
    __typename?: 'NftTransferNetwork';
} & Pick<NftTransferNetwork, 'id' | 'name' | 'chainId' | 'blockchainUrl' | 'walletBlockchainUrl' | 'blockExplorerUrl' | 'nativeCurrencyParams' | 'active' | 'createdAt' | 'updatedAt'>;
export declare type CreateNftTransferNetworkMutationVariables = Exact<{
    params: NftTransferNetworkInput;
}>;
export declare type CreateNftTransferNetworkMutation = {
    __typename?: 'Mutation';
} & {
    createNftTransferNetwork?: Maybe<{
        __typename?: 'AddNftTransferNetworkMutationPayload';
    } & {
        nftTransferNetwork: {
            __typename?: 'NftTransferNetwork';
        } & NftTransferNetworkFragment;
    }>;
};
export declare type UpdateNftTransferNetworkMutationVariables = Exact<{
    id: Scalars['ID'];
    params: NftTransferNetworkInput;
}>;
export declare type UpdateNftTransferNetworkMutation = {
    __typename?: 'Mutation';
} & {
    updateNftTransferNetwork?: Maybe<{
        __typename?: 'UpdateNftTransferNetworkMutationPayload';
    } & {
        nftTransferNetwork: {
            __typename?: 'NftTransferNetwork';
        } & NftTransferNetworkFragment;
    }>;
};
export declare type GetNftTransferNetworkQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetNftTransferNetworkQuery = {
    __typename?: 'Query';
} & {
    nftTransferNetwork: {
        __typename?: 'NftTransferNetwork';
    } & NftTransferNetworkFragment;
};
export declare type GetNftTransferNetworksQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<NftTransferNetworkFilterInput>;
    sort?: Maybe<NftTransferNetworkSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetNftTransferNetworksQuery = {
    __typename?: 'Query';
} & {
    nftTransferNetworks: {
        __typename?: 'NftTransferNetworkResolver';
    } & Pick<NftTransferNetworkResolver, 'total'> & {
        nftTransferNetworks: Array<{
            __typename?: 'NftTransferNetwork';
        } & NftTransferNetworkFragment>;
    };
};
export declare type NftUserFragment = {
    __typename?: 'NftUser';
} & Pick<NftUser, 'amount' | 'amountFrozen' | 'amountBurnt' | 'createdAt' | 'id' | 'nftId' | 'publiclyVisible' | 'userId'> & {
    user: {
        __typename?: 'User';
    } & Pick<User, 'id' | 'displayName' | 'verified'>;
};
export declare type GetNftUsersQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<NftUserFilterInput>;
    sort?: Maybe<NftUserSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetNftUsersQuery = {
    __typename?: 'Query';
} & {
    nftUsers: {
        __typename?: 'NftUserResolver';
    } & Pick<NftUserResolver, 'total'> & {
        nftUsers: Array<{
            __typename?: 'NftUser';
        } & NftUserFragment>;
    };
};
export declare type NftBenefitFragment = {
    __typename?: 'NftBenefit';
} & Pick<NftBenefit, 'id' | 'allowedRedemptionsAmount' | 'timeOutMinutes'> & {
    translations: Array<{
        __typename?: 'NftBenefitTranslation';
    } & Pick<NftBenefitTranslation, 'id' | 'locale' | 'title' | 'description' | 'successMessage'>>;
};
export declare type NftCollectionDeploymentFragment = {
    __typename?: 'NftCollectionDeployment';
} & Pick<NftCollectionDeployment, 'id' | 'contractAddress' | 'nftCollectionId' | 'nftTransferNetworkId' | 'deployed' | 'active' | 'createdAt' | 'updatedAt'> & {
    nftTransferNetwork: {
        __typename?: 'NftTransferNetwork';
    } & NftTransferNetworkFragment;
};
export declare type NftCollectionForSelectFragment = {
    __typename?: 'NftCollection';
} & Pick<NftCollection, 'id' | 'sponsorId'> & {
    translations: Array<{
        __typename?: 'NftCollectionTranslation';
    } & Pick<NftCollectionTranslation, 'id' | 'locale' | 'title'>>;
    sponsor?: Maybe<{
        __typename?: 'Sponsor';
    } & Pick<Sponsor, 'id' | 'name'>>;
    nfts: Array<{
        __typename?: 'Nft';
    } & Pick<Nft, 'id' | 'name'>>;
};
export declare type NftCollectionFragment = {
    __typename?: 'NftCollection';
} & Pick<NftCollection, 'id' | 'contractAddress' | 'createdAt' | 'nftIds' | 'nftsCount' | 'heroMediumId' | 'previewToken' | 'previewUrl' | 'publishedAt' | 'status' | 'tokenBaseUri' | 'updatedAt' | 'sponsorId' | 'pinToTop' | 'willBePinned' | 'sellerFeeBasisPoints' | 'feeRecipient'> & {
    heroMedium?: Maybe<{
        __typename?: 'ContentMedium';
    } & ContentMediumFragment>;
    previewUrls: Array<{
        __typename?: 'PreviewUrl';
    } & PreviewUrlFragment>;
    translations: Array<{
        __typename?: 'NftCollectionTranslation';
    } & NftCollectionTranslationFragment>;
    sponsor?: Maybe<{
        __typename?: 'Sponsor';
    } & Pick<Sponsor, 'id' | 'name'>>;
};
export declare type NftCollectionTranslationFragment = {
    __typename?: 'NftCollectionTranslation';
} & Pick<NftCollectionTranslation, 'id' | 'locale' | 'title' | 'slug' | 'description' | 'preview'>;
export declare type NftForSelectFragment = {
    __typename?: 'Nft';
} & Pick<Nft, 'id' | 'name' | 'sponsorId'> & {
    collectionSponsor?: Maybe<{
        __typename?: 'Sponsor';
    } & Pick<Sponsor, 'id' | 'name'>>;
    sponsor?: Maybe<{
        __typename?: 'Sponsor';
    } & Pick<Sponsor, 'id' | 'name'>>;
};
export declare type NftLightFragment = {
    __typename?: 'Nft';
} & Pick<Nft, 'id' | 'createdAt' | 'updatedAt' | 'amount' | 'amountLeft' | 'nftMediumId' | 'mintedAt' | 'name' | 'description' | 'rarity' | 'nftCollectionId' | 'sponsorId' | 'visibleInShowroom' | 'showInFeed' | 'shownInFeedAt' | 'nftCollectionOrder'> & {
    nftMedium: {
        __typename?: 'NftMedium';
    } & NftMediumFragment;
    nftCollection?: Maybe<{
        __typename?: 'NftCollection';
    } & Pick<NftCollection, 'id'> & {
        translations: Array<{
            __typename?: 'NftCollectionTranslation';
        } & Pick<NftCollectionTranslation, 'id' | 'locale' | 'title'>>;
    }>;
    collectionSponsor?: Maybe<{
        __typename?: 'Sponsor';
    } & Pick<Sponsor, 'id' | 'name'>>;
    sponsor?: Maybe<{
        __typename?: 'Sponsor';
    } & Pick<Sponsor, 'id' | 'name'>>;
    translations: Array<{
        __typename?: 'NftTranslation';
    } & Pick<NftTranslation, 'id' | 'locale' | 'extendedInfo' | 'externalLink' | 'ctaText'>>;
};
export declare type NftMediumFragment = {
    __typename?: 'NftMedium';
} & Pick<NftMedium, 'id' | 'createdAt' | 'updatedAt' | 'mediaType' | 'mediaSrc' | 'image' | 'original' | 'thumbnail' | 'nftsCount' | 'fileName' | 'aspectRatio' | 'dimensions' | 'threeqDimensions'>;
export declare type NftRarityFragment = {
    __typename?: 'NftRarity';
} & Pick<NftRarity, 'maxAmount' | 'minAmount' | 'rarity' | 'rarityFactor'>;
export declare type NftFragment = {
    __typename?: 'Nft';
} & Pick<Nft, 'videoAutoplay' | 'videoLoop' | 'videoShowControls' | 'pinToTop' | 'willBePinned'> & {
    nftBuckets: Array<{
        __typename?: 'NftBucket';
    } & Pick<NftBucket, 'id' | 'name'> & {
        shopProduct: {
            __typename?: 'ShopProduct';
        } & ShopProductMinimumFragment;
    }>;
    giveaways: Array<{
        __typename?: 'Giveaway';
    } & GiveawayLightFragment>;
    nftFixedPriceShopProducts: Array<{
        __typename?: 'ShopProduct';
    } & ShopProductLightFragment>;
    nftBenefits: Array<{
        __typename?: 'NftBenefit';
    } & NftBenefitFragment>;
} & NftLightFragment;
export declare type AddNftsToCollectionMutationVariables = Exact<{
    collectionId: Scalars['ID'];
    nftFilter?: Maybe<NftFilterInput>;
    nftSearch?: Maybe<Scalars['String']>;
}>;
export declare type AddNftsToCollectionMutation = {
    __typename?: 'Mutation';
} & {
    addNftsToCollection?: Maybe<{
        __typename?: 'AddNftsToCollectionMutationPayload';
    } & {
        nftCollection: {
            __typename?: 'NftCollection';
        } & NftCollectionFragment;
    }>;
};
export declare type ArchiveNftCollectionMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type ArchiveNftCollectionMutation = {
    __typename?: 'Mutation';
} & {
    archiveNftCollection?: Maybe<{
        __typename?: 'ArchiveNftCollectionMutationPayload';
    } & {
        nftCollection: {
            __typename?: 'NftCollection';
        } & NftCollectionFragment;
    }>;
};
export declare type CreateNftCollectionDeploymentMutationVariables = Exact<{
    params: NftCollectionDeploymentInput;
}>;
export declare type CreateNftCollectionDeploymentMutation = {
    __typename?: 'Mutation';
} & {
    createNftCollectionDeployment?: Maybe<{
        __typename?: 'AddNftCollectionDeploymentMutationPayload';
    } & {
        nftCollectionDeployment: {
            __typename?: 'NftCollectionDeployment';
        } & NftCollectionDeploymentFragment;
    }>;
};
export declare type CreateNftCollectionMutationVariables = Exact<{
    params: NftCollectionInput;
}>;
export declare type CreateNftCollectionMutation = {
    __typename?: 'Mutation';
} & {
    createNftCollection?: Maybe<{
        __typename?: 'AddNftCollectionMutationPayload';
    } & {
        nftCollection: {
            __typename?: 'NftCollection';
        } & NftCollectionFragment;
    }>;
};
export declare type CreateNftMediumMutationVariables = Exact<{
    params: NftMediumInput;
}>;
export declare type CreateNftMediumMutation = {
    __typename?: 'Mutation';
} & {
    createNftMedium?: Maybe<{
        __typename?: 'AddNftMediumMutationPayload';
    } & {
        nftMedium: {
            __typename?: 'NftMedium';
        } & NftMediumFragment;
    }>;
};
export declare type CreateNftMutationVariables = Exact<{
    params: NftInput;
}>;
export declare type CreateNftMutation = {
    __typename?: 'Mutation';
} & {
    createNft?: Maybe<{
        __typename?: 'AddNftMutationPayload';
    } & {
        nft: {
            __typename?: 'Nft';
        } & NftFragment;
    }>;
};
export declare type DeleteNftCollectionsMutationVariables = Exact<{
    ids: Array<Scalars['ID']> | Scalars['ID'];
}>;
export declare type DeleteNftCollectionsMutation = {
    __typename?: 'Mutation';
} & {
    deleteNftCollections?: Maybe<{
        __typename?: 'DeleteNftCollectionsMutationPayload';
    } & Pick<DeleteNftCollectionsMutationPayload, 'deletedIds' | 'status'>>;
};
export declare type DeleteNftMediaMutationVariables = Exact<{
    ids: Array<Scalars['ID']> | Scalars['ID'];
}>;
export declare type DeleteNftMediaMutation = {
    __typename?: 'Mutation';
} & {
    deleteNftMedia?: Maybe<{
        __typename?: 'DeleteNftMediaMutationPayload';
    } & Pick<DeleteNftMediaMutationPayload, 'deletedIds' | 'status'>>;
};
export declare type DeleteNftsMutationVariables = Exact<{
    ids: Array<Scalars['ID']> | Scalars['ID'];
}>;
export declare type DeleteNftsMutation = {
    __typename?: 'Mutation';
} & {
    deleteNfts?: Maybe<{
        __typename?: 'DeleteNftsMutationPayload';
    } & Pick<DeleteNftsMutationPayload, 'deletedIds' | 'status'>>;
};
export declare type MintNftCollectionMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type MintNftCollectionMutation = {
    __typename?: 'Mutation';
} & {
    mintNftCollection?: Maybe<{
        __typename?: 'MintNftCollectionMutationPayload';
    } & {
        nftCollection: {
            __typename?: 'NftCollection';
        } & NftCollectionFragment;
    }>;
};
export declare type MintNftMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type MintNftMutation = {
    __typename?: 'Mutation';
} & {
    mintNft?: Maybe<{
        __typename?: 'MintNftMutationPayload';
    } & {
        nft: {
            __typename?: 'Nft';
        } & NftFragment;
    }>;
};
export declare type PublishNftCollectionMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type PublishNftCollectionMutation = {
    __typename?: 'Mutation';
} & {
    publishNftCollection?: Maybe<{
        __typename?: 'PublishNftCollectionMutationPayload';
    } & {
        nftCollection: {
            __typename?: 'NftCollection';
        } & NftCollectionFragment;
    }>;
};
export declare type RequestNftCollectionMetadataUriMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type RequestNftCollectionMetadataUriMutation = {
    __typename?: 'Mutation';
} & {
    requestNftCollectionMetadataUri?: Maybe<{
        __typename?: 'RequestNftCollectionMetadataUriMutationPayload';
    } & Pick<RequestNftCollectionMetadataUriMutationPayload, 'metadataUri'>>;
};
export declare type UpdateNftCollectionDeploymentMutationVariables = Exact<{
    id: Scalars['ID'];
    params: NftCollectionDeploymentInput;
}>;
export declare type UpdateNftCollectionDeploymentMutation = {
    __typename?: 'Mutation';
} & {
    updateNftCollectionDeployment?: Maybe<{
        __typename?: 'UpdateNftCollectionDeploymentMutationPayload';
    } & {
        nftCollectionDeployment: {
            __typename?: 'NftCollectionDeployment';
        } & NftCollectionDeploymentFragment;
    }>;
};
export declare type UpdateNftCollectionMutationVariables = Exact<{
    id: Scalars['ID'];
    params: NftCollectionInput;
}>;
export declare type UpdateNftCollectionMutation = {
    __typename?: 'Mutation';
} & {
    updateNftCollection?: Maybe<{
        __typename?: 'UpdateNftCollectionMutationPayload';
    } & {
        nftCollection: {
            __typename?: 'NftCollection';
        } & NftCollectionFragment;
    }>;
};
export declare type UpdateNftMediumMutationVariables = Exact<{
    id: Scalars['ID'];
    params: NftMediumInput;
}>;
export declare type UpdateNftMediumMutation = {
    __typename?: 'Mutation';
} & {
    updateNftMedium?: Maybe<{
        __typename?: 'UpdateNftMediumMutationPayload';
    } & {
        nftMedium: {
            __typename?: 'NftMedium';
        } & NftMediumFragment;
    }>;
};
export declare type UpdateNftMutationVariables = Exact<{
    id: Scalars['ID'];
    params: NftInput;
}>;
export declare type UpdateNftMutation = {
    __typename?: 'Mutation';
} & {
    updateNft?: Maybe<{
        __typename?: 'UpdateNftMutationPayload';
    } & {
        nft: {
            __typename?: 'Nft';
        } & NftFragment;
    }>;
};
export declare type UpdateNftsVisibilityMutationVariables = Exact<{
    visible: Scalars['Boolean'];
    nftFilter?: Maybe<NftFilterInput>;
    nftSearch?: Maybe<Scalars['String']>;
}>;
export declare type UpdateNftsVisibilityMutation = {
    __typename?: 'Mutation';
} & {
    updateNftsVisibility?: Maybe<{
        __typename?: 'UpdateNftsVisibilityMutationPayload';
    } & Pick<UpdateNftsVisibilityMutationPayload, 'updatedIds' | 'status'>>;
};
export declare type GetNftCollectionQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetNftCollectionQuery = {
    __typename?: 'Query';
} & {
    nftCollection: {
        __typename?: 'NftCollection';
    } & {
        deployments: Array<{
            __typename?: 'NftCollectionDeployment';
        } & NftCollectionDeploymentFragment>;
    } & NftCollectionFragment;
};
export declare type GetNftCollectionsForSelectQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filterTitle?: Maybe<FilterTextInput>;
    sort?: Maybe<NftCollectionSortInput>;
    selectedIds: Array<Scalars['ID']> | Scalars['ID'];
}>;
export declare type GetNftCollectionsForSelectQuery = {
    __typename?: 'Query';
} & {
    nftCollections: {
        __typename?: 'NftCollectionResolver';
    } & Pick<NftCollectionResolver, 'total'> & {
        nftCollections: Array<{
            __typename?: 'NftCollection';
        } & NftCollectionForSelectFragment>;
    };
    selectedNftCollections: {
        __typename?: 'NftCollectionResolver';
    } & Pick<NftCollectionResolver, 'total'> & {
        nftCollections: Array<{
            __typename?: 'NftCollection';
        } & NftCollectionForSelectFragment>;
    };
};
export declare type GetNftCollectionsQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<NftCollectionFilterInput>;
    sort?: Maybe<NftCollectionSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetNftCollectionsQuery = {
    __typename?: 'Query';
} & {
    nftCollections: {
        __typename?: 'NftCollectionResolver';
    } & Pick<NftCollectionResolver, 'total'> & {
        nftCollections: Array<{
            __typename?: 'NftCollection';
        } & NftCollectionFragment>;
    };
};
export declare type GetNftMediaQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<NftMediumFilterInput>;
    sort?: Maybe<NftMediumSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetNftMediaQuery = {
    __typename?: 'Query';
} & {
    nftMedia: {
        __typename?: 'NftMediumResolver';
    } & Pick<NftMediumResolver, 'total'> & {
        nftMedia: Array<{
            __typename?: 'NftMedium';
        } & NftMediumFragment>;
    };
};
export declare type GetNftMediumQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetNftMediumQuery = {
    __typename?: 'Query';
} & {
    nftMedium: {
        __typename?: 'NftMedium';
    } & NftMediumFragment;
};
export declare type GetNftRaritiesQueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type GetNftRaritiesQuery = {
    __typename?: 'Query';
} & {
    nftRarities: Array<{
        __typename?: 'NftRarity';
    } & NftRarityFragment>;
};
export declare type GetNftQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetNftQuery = {
    __typename?: 'Query';
} & {
    nft: {
        __typename?: 'Nft';
    } & NftFragment;
};
export declare type GetNftsForSelectQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<NftFilterInput>;
    sort?: Maybe<NftSortInput>;
}>;
export declare type GetNftsForSelectQuery = {
    __typename?: 'Query';
} & {
    nfts: {
        __typename?: 'NftResolver';
    } & Pick<NftResolver, 'total'> & {
        nfts: Array<{
            __typename?: 'Nft';
        } & NftForSelectFragment>;
    };
};
export declare type GetNftsQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<NftFilterInput>;
    sort?: Maybe<NftSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetNftsQuery = {
    __typename?: 'Query';
} & {
    nfts: {
        __typename?: 'NftResolver';
    } & Pick<NftResolver, 'total'> & {
        nfts: Array<{
            __typename?: 'Nft';
        } & NftLightFragment>;
    };
};
export declare type AmaSessionForSelectFragment = {
    __typename?: 'AmaSession';
} & Pick<AmaSession, 'id'> & {
    translations: Array<{
        __typename?: 'AmaSessionTranslation';
    } & Pick<AmaSessionTranslation, 'id' | 'locale' | 'title'>>;
};
export declare type AmaSessionLightFragment = {
    __typename?: 'AmaSession';
} & Pick<AmaSession, 'id' | 'createdAt' | 'updatedAt' | 'endsAt' | 'heroMediumId' | 'amaQuestionsCount' | 'amaQuestionsBoostAmounts' | 'status' | 'publishedAt' | 'distributedAt'> & {
    heroMedium?: Maybe<{
        __typename?: 'ContentMedium';
    } & ContentMediumFragment>;
    translations: Array<{
        __typename?: 'AmaSessionTranslation';
    } & AmaSessionTranslationFragment>;
};
export declare type AmaSessionTranslationFragment = {
    __typename?: 'AmaSessionTranslation';
} & Pick<AmaSessionTranslation, 'id' | 'locale' | 'title' | 'slug' | 'preview' | 'description'>;
export declare type AmaSessionFragment = {
    __typename?: 'AmaSession';
} & Pick<AmaSession, 'previewToken' | 'previewUrl' | 'operatorShare' | 'creatorShare' | 'fanvaultShare' | 'contractAddress' | 'onlyForAvailables' | 'availabilityType' | 'pinToTop' | 'willBePinned'> & {
    amaQuestions: Array<{
        __typename?: 'AmaQuestion';
    } & AmaQuestionFragment>;
    announcements: Array<{
        __typename?: 'Announcement';
    } & AnnouncementFragment>;
    previewUrls: Array<{
        __typename?: 'PreviewUrl';
    } & PreviewUrlFragment>;
    availabilities?: Maybe<Array<{
        __typename?: 'Availability';
    } & AvailabilityFragment>>;
} & AmaSessionLightFragment;
export declare type IdeationMissionForSelectFragment = {
    __typename?: 'IdeationMission';
} & Pick<IdeationMission, 'id'> & {
    translations: Array<{
        __typename?: 'IdeationMissionTranslation';
    } & Pick<IdeationMissionTranslation, 'id' | 'locale' | 'title'>>;
};
export declare type IdeationMissionLightFragment = {
    __typename?: 'IdeationMission';
} & Pick<IdeationMission, 'id' | 'createdAt' | 'updatedAt' | 'endsAt' | 'heroMediumId' | 'ideasCount' | 'ideasBoostAmounts' | 'status' | 'publishedAt' | 'distributedAt'> & {
    heroMedium?: Maybe<{
        __typename?: 'ContentMedium';
    } & ContentMediumFragment>;
    translations: Array<{
        __typename?: 'IdeationMissionTranslation';
    } & IdeationMissionTranslationFragment>;
};
export declare type IdeationMissionTranslationFragment = {
    __typename?: 'IdeationMissionTranslation';
} & Pick<IdeationMissionTranslation, 'id' | 'locale' | 'title' | 'slug' | 'preview' | 'description'>;
export declare type IdeationMissionFragment = {
    __typename?: 'IdeationMission';
} & Pick<IdeationMission, 'previewToken' | 'previewUrl' | 'operatorShare' | 'creatorShare' | 'fanvaultShare' | 'contractAddress' | 'onlyForAvailables' | 'availabilityType' | 'pinToTop' | 'willBePinned'> & {
    ideas: Array<{
        __typename?: 'Idea';
    } & IdeaFragment>;
    announcements: Array<{
        __typename?: 'Announcement';
    } & AnnouncementFragment>;
    previewUrls: Array<{
        __typename?: 'PreviewUrl';
    } & PreviewUrlFragment>;
    availabilities?: Maybe<Array<{
        __typename?: 'Availability';
    } & AvailabilityFragment>>;
} & IdeationMissionLightFragment;
export declare type VotingForSelectFragment = {
    __typename?: 'Voting';
} & Pick<Voting, 'id'> & {
    translations: Array<{
        __typename?: 'VotingTranslation';
    } & Pick<VotingTranslation, 'id' | 'locale' | 'title'>>;
};
export declare type VotingLightFragment = {
    __typename?: 'Voting';
} & Pick<Voting, 'id' | 'createdAt' | 'updatedAt' | 'publishedAt' | 'commentsCount' | 'votingType' | 'status' | 'endsAt' | 'heroMediumId' | 'contractAddress' | 'creatorShare' | 'depositShare' | 'distributedAt' | 'unlocksTokensAt' | 'fanvaultShare' | 'operatorShare' | 'notifiedEndsSoonAt' | 'transferredDepositsAt' | 'tokenFixedAmount' | 'tokenMax' | 'tokenMin' | 'previewUrl'> & {
    heroMedium?: Maybe<{
        __typename?: 'ContentMedium';
    } & ContentMediumFragment>;
    translations: Array<{
        __typename?: 'VotingTranslation';
    } & VotingTranslationFragment>;
};
export declare type VotingTranslationFragment = {
    __typename?: 'VotingTranslation';
} & Pick<VotingTranslation, 'id' | 'locale' | 'content' | 'title'>;
export declare type VotingOptionFragment = {
    __typename?: 'VotingOption';
} & Pick<VotingOption, 'id' | 'createdAt' | 'updatedAt' | 'boostsAmountCache' | 'votesCount' | 'votedTokensCount' | 'votedUsersCount' | 'votingId'> & {
    translations: Array<{
        __typename?: 'VotingOptionTranslation';
    } & VotingOptionTranslationFragment>;
};
export declare type VotingOptionTranslationFragment = {
    __typename?: 'VotingOptionTranslation';
} & Pick<VotingOptionTranslation, 'id' | 'locale' | 'title'>;
export declare type VotingFragment = {
    __typename?: 'Voting';
} & Pick<Voting, 'onlyForAvailables' | 'availabilityType' | 'pinToTop' | 'willBePinned'> & {
    previewUrls: Array<{
        __typename?: 'PreviewUrl';
    } & PreviewUrlFragment>;
    comments: Array<{
        __typename?: 'Comment';
    } & CommentFragment>;
    votingOptions?: Maybe<Array<{
        __typename?: 'VotingOption';
    } & VotingOptionFragment>>;
    availabilities?: Maybe<Array<{
        __typename?: 'Availability';
    } & AvailabilityFragment>>;
} & VotingLightFragment;
export declare type ArchiveAmaSessionMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type ArchiveAmaSessionMutation = {
    __typename?: 'Mutation';
} & {
    archiveAmaSession?: Maybe<{
        __typename?: 'ArchiveAmaSessionMutationPayload';
    } & {
        amaSession: {
            __typename?: 'AmaSession';
        } & AmaSessionFragment;
    }>;
};
export declare type ArchiveIdeationMissionMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type ArchiveIdeationMissionMutation = {
    __typename?: 'Mutation';
} & {
    archiveIdeationMission?: Maybe<{
        __typename?: 'ArchiveIdeationMissionMutationPayload';
    } & {
        ideationMission: {
            __typename?: 'IdeationMission';
        } & IdeationMissionFragment;
    }>;
};
export declare type ArchiveVotingMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type ArchiveVotingMutation = {
    __typename?: 'Mutation';
} & {
    archiveVoting?: Maybe<{
        __typename?: 'ArchiveVotingMutationPayload';
    } & {
        voting: {
            __typename?: 'Voting';
        } & VotingFragment;
    }>;
};
export declare type CreateAmaSessionMutationVariables = Exact<{
    params: AmaSessionInput;
}>;
export declare type CreateAmaSessionMutation = {
    __typename?: 'Mutation';
} & {
    createAmaSession?: Maybe<{
        __typename?: 'AddAmaSessionMutationPayload';
    } & {
        amaSession: {
            __typename?: 'AmaSession';
        } & AmaSessionFragment;
    }>;
};
export declare type CreateIdeationMissionMutationVariables = Exact<{
    params: IdeationMissionInput;
}>;
export declare type CreateIdeationMissionMutation = {
    __typename?: 'Mutation';
} & {
    createIdeationMission?: Maybe<{
        __typename?: 'AddIdeationMissionMutationPayload';
    } & {
        ideationMission: {
            __typename?: 'IdeationMission';
        } & IdeationMissionFragment;
    }>;
};
export declare type CreateVotingMutationVariables = Exact<{
    params: VotingInput;
}>;
export declare type CreateVotingMutation = {
    __typename?: 'Mutation';
} & {
    createVoting?: Maybe<{
        __typename?: 'AddVotingMutationPayload';
    } & {
        voting: {
            __typename?: 'Voting';
        } & VotingFragment;
    }>;
};
export declare type DeleteAmaSessionsMutationVariables = Exact<{
    ids: Array<Scalars['ID']> | Scalars['ID'];
}>;
export declare type DeleteAmaSessionsMutation = {
    __typename?: 'Mutation';
} & {
    deleteAmaSessions?: Maybe<{
        __typename?: 'DeleteAmaSessionsMutationPayload';
    } & Pick<DeleteAmaSessionsMutationPayload, 'deletedIds' | 'status'>>;
};
export declare type DeleteIdeationMissionsMutationVariables = Exact<{
    ids: Array<Scalars['ID']> | Scalars['ID'];
}>;
export declare type DeleteIdeationMissionsMutation = {
    __typename?: 'Mutation';
} & {
    deleteIdeationMissions?: Maybe<{
        __typename?: 'DeleteIdeationMissionsMutationPayload';
    } & Pick<DeleteIdeationMissionsMutationPayload, 'deletedIds' | 'status'>>;
};
export declare type DeleteVotingsMutationVariables = Exact<{
    ids: Array<Scalars['ID']> | Scalars['ID'];
}>;
export declare type DeleteVotingsMutation = {
    __typename?: 'Mutation';
} & {
    deleteVotings?: Maybe<{
        __typename?: 'DeleteVotingsMutationPayload';
    } & Pick<DeleteVotingsMutationPayload, 'deletedIds' | 'status'>>;
};
export declare type DistributeVotingMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type DistributeVotingMutation = {
    __typename?: 'Mutation';
} & {
    distributeVoting?: Maybe<{
        __typename?: 'DistributeVotingMutationPayload';
    } & Pick<DistributeVotingMutationPayload, 'message' | 'status'>>;
};
export declare type DraftAmaSessionMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type DraftAmaSessionMutation = {
    __typename?: 'Mutation';
} & {
    draftAmaSession?: Maybe<{
        __typename?: 'DraftAmaSessionMutationPayload';
    } & {
        amaSession: {
            __typename?: 'AmaSession';
        } & AmaSessionFragment;
    }>;
};
export declare type DraftIdeationMissionMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type DraftIdeationMissionMutation = {
    __typename?: 'Mutation';
} & {
    draftIdeationMission?: Maybe<{
        __typename?: 'DraftIdeationMissionMutationPayload';
    } & {
        ideationMission: {
            __typename?: 'IdeationMission';
        } & IdeationMissionFragment;
    }>;
};
export declare type DraftVotingMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type DraftVotingMutation = {
    __typename?: 'Mutation';
} & {
    draftVoting?: Maybe<{
        __typename?: 'DraftVotingMutationPayload';
    } & {
        voting: {
            __typename?: 'Voting';
        } & VotingFragment;
    }>;
};
export declare type PublishAmaSessionMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type PublishAmaSessionMutation = {
    __typename?: 'Mutation';
} & {
    publishAmaSession?: Maybe<{
        __typename?: 'PublishAmaSessionMutationPayload';
    } & {
        amaSession: {
            __typename?: 'AmaSession';
        } & AmaSessionFragment;
    }>;
};
export declare type PublishIdeationMissionMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type PublishIdeationMissionMutation = {
    __typename?: 'Mutation';
} & {
    publishIdeationMission?: Maybe<{
        __typename?: 'PublishIdeationMissionMutationPayload';
    } & {
        ideationMission: {
            __typename?: 'IdeationMission';
        } & IdeationMissionFragment;
    }>;
};
export declare type PublishVotingMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type PublishVotingMutation = {
    __typename?: 'Mutation';
} & {
    publishVoting?: Maybe<{
        __typename?: 'PublishVotingMutationPayload';
    } & {
        voting: {
            __typename?: 'Voting';
        } & VotingFragment;
    }>;
};
export declare type RefundVotingMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type RefundVotingMutation = {
    __typename?: 'Mutation';
} & {
    refundVoting?: Maybe<{
        __typename?: 'RefundVotingMutationPayload';
    } & Pick<RefundVotingMutationPayload, 'message' | 'status'>>;
};
export declare type UpdateAmaSessionMutationVariables = Exact<{
    id: Scalars['ID'];
    params: AmaSessionInput;
}>;
export declare type UpdateAmaSessionMutation = {
    __typename?: 'Mutation';
} & {
    updateAmaSession?: Maybe<{
        __typename?: 'UpdateAmaSessionMutationPayload';
    } & {
        amaSession: {
            __typename?: 'AmaSession';
        } & AmaSessionFragment;
    }>;
};
export declare type UpdateIdeationMissionMutationVariables = Exact<{
    id: Scalars['ID'];
    params: IdeationMissionInput;
}>;
export declare type UpdateIdeationMissionMutation = {
    __typename?: 'Mutation';
} & {
    updateIdeationMission?: Maybe<{
        __typename?: 'UpdateIdeationMissionMutationPayload';
    } & {
        ideationMission: {
            __typename?: 'IdeationMission';
        } & IdeationMissionFragment;
    }>;
};
export declare type UpdateVotingMutationVariables = Exact<{
    id: Scalars['ID'];
    params: VotingInput;
}>;
export declare type UpdateVotingMutation = {
    __typename?: 'Mutation';
} & {
    updateVoting?: Maybe<{
        __typename?: 'UpdateVotingMutationPayload';
    } & {
        voting: {
            __typename?: 'Voting';
        } & VotingFragment;
    }>;
};
export declare type GetAmaSessionQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetAmaSessionQuery = {
    __typename?: 'Query';
} & {
    amaSession: {
        __typename?: 'AmaSession';
    } & AmaSessionFragment;
};
export declare type GetAmaSessionsForSelectQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filterTitle?: Maybe<FilterTextInput>;
    sort?: Maybe<AmaSessionSortInput>;
    selectedIds: Array<Scalars['ID']> | Scalars['ID'];
}>;
export declare type GetAmaSessionsForSelectQuery = {
    __typename?: 'Query';
} & {
    amaSessions: {
        __typename?: 'AmaSessionResolver';
    } & Pick<AmaSessionResolver, 'total'> & {
        amaSessions: Array<{
            __typename?: 'AmaSession';
        } & AmaSessionForSelectFragment>;
    };
    selectedAmaSessions: {
        __typename?: 'AmaSessionResolver';
    } & Pick<AmaSessionResolver, 'total'> & {
        amaSessions: Array<{
            __typename?: 'AmaSession';
        } & AmaSessionForSelectFragment>;
    };
};
export declare type GetAmaSessionsQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<AmaSessionFilterInput>;
    sort?: Maybe<AmaSessionSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetAmaSessionsQuery = {
    __typename?: 'Query';
} & {
    amaSessions: {
        __typename?: 'AmaSessionResolver';
    } & Pick<AmaSessionResolver, 'total'> & {
        amaSessions: Array<{
            __typename?: 'AmaSession';
        } & AmaSessionLightFragment>;
    };
};
export declare type GetIdeationMissionQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetIdeationMissionQuery = {
    __typename?: 'Query';
} & {
    ideationMission: {
        __typename?: 'IdeationMission';
    } & IdeationMissionFragment;
};
export declare type GetIdeationMissionsForSelectQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filterTitle?: Maybe<FilterTextInput>;
    sort?: Maybe<IdeationMissionSortInput>;
    selectedIds: Array<Scalars['ID']> | Scalars['ID'];
}>;
export declare type GetIdeationMissionsForSelectQuery = {
    __typename?: 'Query';
} & {
    ideationMissions: {
        __typename?: 'IdeationMissionResolver';
    } & Pick<IdeationMissionResolver, 'total'> & {
        ideationMissions: Array<{
            __typename?: 'IdeationMission';
        } & IdeationMissionForSelectFragment>;
    };
    selectedIdeationMissions: {
        __typename?: 'IdeationMissionResolver';
    } & Pick<IdeationMissionResolver, 'total'> & {
        ideationMissions: Array<{
            __typename?: 'IdeationMission';
        } & IdeationMissionForSelectFragment>;
    };
};
export declare type GetIdeationMissionsQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<IdeationMissionFilterInput>;
    sort?: Maybe<IdeationMissionSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetIdeationMissionsQuery = {
    __typename?: 'Query';
} & {
    ideationMissions: {
        __typename?: 'IdeationMissionResolver';
    } & Pick<IdeationMissionResolver, 'total'> & {
        ideationMissions: Array<{
            __typename?: 'IdeationMission';
        } & IdeationMissionLightFragment>;
    };
};
export declare type GetVotingQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetVotingQuery = {
    __typename?: 'Query';
} & {
    voting: {
        __typename?: 'Voting';
    } & VotingFragment;
};
export declare type GetVotingsForSelectQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filterTitle?: Maybe<FilterTextInput>;
    sort?: Maybe<VotingSortInput>;
    selectedIds: Array<Scalars['ID']> | Scalars['ID'];
}>;
export declare type GetVotingsForSelectQuery = {
    __typename?: 'Query';
} & {
    votings: {
        __typename?: 'VotingResolver';
    } & Pick<VotingResolver, 'total'> & {
        votings: Array<{
            __typename?: 'Voting';
        } & VotingForSelectFragment>;
    };
    selectedVotings: {
        __typename?: 'VotingResolver';
    } & Pick<VotingResolver, 'total'> & {
        votings: Array<{
            __typename?: 'Voting';
        } & VotingForSelectFragment>;
    };
};
export declare type GetVotingsQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<VotingFilterInput>;
    sort?: Maybe<VotingSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetVotingsQuery = {
    __typename?: 'Query';
} & {
    votings: {
        __typename?: 'VotingResolver';
    } & Pick<VotingResolver, 'total'> & {
        votings: Array<{
            __typename?: 'Voting';
        } & VotingLightFragment>;
    };
};
export declare type PreviewUrlFragment = {
    __typename?: 'PreviewUrl';
} & Pick<PreviewUrl, 'url' | 'locale'>;
export declare type UgcReportTypeFragment = {
    __typename?: 'UgcReportTyp';
} & Pick<UgcReportTyp, 'id' | 'createdAt' | 'updatedAt' | 'hidingTolerance' | 'order'> & {
    translations: Array<{
        __typename?: 'UgcReportTypeTranslation';
    } & Pick<UgcReportTypeTranslation, 'text' | 'title' | 'locale' | 'id'>>;
};
export declare type CreateUgcReportTypeMutationVariables = Exact<{
    params: UgcReportTypeInput;
}>;
export declare type CreateUgcReportTypeMutation = {
    __typename?: 'Mutation';
} & {
    createUgcReportType?: Maybe<{
        __typename?: 'AddUgcReportTypeMutationPayload';
    } & {
        ugcReportType: {
            __typename?: 'UgcReportTyp';
        } & UgcReportTypeFragment;
    }>;
};
export declare type UpdateUgcReportTypeMutationVariables = Exact<{
    id: Scalars['ID'];
    params: UgcReportTypeInput;
}>;
export declare type UpdateUgcReportTypeMutation = {
    __typename?: 'Mutation';
} & {
    updateUgcReportType?: Maybe<{
        __typename?: 'UpdateUgcReportTypeMutationPayload';
    } & {
        ugcReportType: {
            __typename?: 'UgcReportTyp';
        } & UgcReportTypeFragment;
    }>;
};
export declare type GetUgcReportTypeQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetUgcReportTypeQuery = {
    __typename?: 'Query';
} & {
    ugcReportType: {
        __typename?: 'UgcReportTyp';
    } & UgcReportTypeFragment;
};
export declare type GetUgcReportTypesQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<UgcReportTypeFilterInput>;
    sort?: Maybe<UgcReportTypeSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetUgcReportTypesQuery = {
    __typename?: 'Query';
} & {
    ugcReportTypes: {
        __typename?: 'UgcReportTypeResolver';
    } & Pick<UgcReportTypeResolver, 'total'> & {
        ugcReportTypes: Array<{
            __typename?: 'UgcReportTyp';
        } & UgcReportTypeFragment>;
    };
};
export declare type RestrictionsFragment = {
    __typename?: 'Restrictions';
} & Pick<Restrictions, 'allowAppStore' | 'allowBrandControl' | 'allowConnectAnalytics' | 'allowCustomDomain' | 'allowMultiLanguage' | 'allowNativeApp' | 'allowPayments' | 'allowRightsManagement' | 'maxRegisteredUsers'>;
export declare type GetRestrictionsQueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type GetRestrictionsQuery = {
    __typename?: 'Query';
} & {
    restrictions: {
        __typename?: 'Restrictions';
    } & RestrictionsFragment;
};
export declare type SalesStatisticFragment = {
    __typename?: 'SalesStatistic';
} & Pick<SalesStatistic, 'ordersNum' | 'ordersValue'>;
export declare type GetSalesStatisticsQueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type GetSalesStatisticsQuery = {
    __typename?: 'Query';
} & {
    salesStatistics: {
        __typename?: 'SalesStatisticResolver';
    } & {
        monthly: {
            __typename?: 'SalesStatistic';
        } & SalesStatisticFragment;
        weekly: {
            __typename?: 'SalesStatistic';
        } & SalesStatisticFragment;
        yearly: {
            __typename?: 'SalesStatistic';
        } & SalesStatisticFragment;
        mtd: {
            __typename?: 'SalesStatistic';
        } & SalesStatisticFragment;
        wtd: {
            __typename?: 'SalesStatistic';
        } & SalesStatisticFragment;
        ytd: {
            __typename?: 'SalesStatistic';
        } & SalesStatisticFragment;
    };
};
export declare type BalanceFragment = {
    __typename?: 'Balance';
} & Pick<Balance, 'currency' | 'value' | 'var'>;
export declare type SystemSettingFragment = {
    __typename?: 'SystemSetting';
} & Pick<SystemSetting, 'var' | 'value'>;
export declare type SystemSettingsGroupFragment = {
    __typename?: 'SystemSettingsGroup';
} & {
    balances: Array<{
        __typename?: 'Balance';
    } & BalanceFragment>;
    settings: Array<{
        __typename?: 'SystemSetting';
    } & SystemSettingFragment>;
};
export declare type DeployCommentBoosterMutationVariables = Exact<{
    [key: string]: never;
}>;
export declare type DeployCommentBoosterMutation = {
    __typename?: 'Mutation';
} & {
    deployCommentBoosterContract?: Maybe<{
        __typename?: 'DeployCommentBoosterMutationPayload';
    } & {
        systemSetting: {
            __typename?: 'SystemSetting';
        } & SystemSettingFragment;
    }>;
};
export declare type DeployContentBoosterMutationVariables = Exact<{
    [key: string]: never;
}>;
export declare type DeployContentBoosterMutation = {
    __typename?: 'Mutation';
} & {
    deployContentBoosterContract?: Maybe<{
        __typename?: 'DeployContentBoosterMutationPayload';
    } & {
        systemSetting: {
            __typename?: 'SystemSetting';
        } & SystemSettingFragment;
    }>;
};
export declare type DeployProposalBoosterMutationVariables = Exact<{
    [key: string]: never;
}>;
export declare type DeployProposalBoosterMutation = {
    __typename?: 'Mutation';
} & {
    deployProposalBoosterContract?: Maybe<{
        __typename?: 'DeployProposalBoosterMutationPayload';
    } & {
        systemSetting: {
            __typename?: 'SystemSetting';
        } & SystemSettingFragment;
    }>;
};
export declare type DistributeCommentBoosterMutationVariables = Exact<{
    [key: string]: never;
}>;
export declare type DistributeCommentBoosterMutation = {
    __typename?: 'Mutation';
} & {
    distributeCommentBoosterContract?: Maybe<{
        __typename?: 'DistributeCommentBoosterMutationPayload';
    } & Pick<DistributeCommentBoosterMutationPayload, 'message' | 'status'>>;
};
export declare type DistributeContentBoosterMutationVariables = Exact<{
    [key: string]: never;
}>;
export declare type DistributeContentBoosterMutation = {
    __typename?: 'Mutation';
} & {
    distributeContentBoosterContract?: Maybe<{
        __typename?: 'DistributeContentBoosterMutationPayload';
    } & Pick<DistributeContentBoosterMutationPayload, 'message' | 'status'>>;
};
export declare type DistributeProposalBoosterMutationVariables = Exact<{
    [key: string]: never;
}>;
export declare type DistributeProposalBoosterMutation = {
    __typename?: 'Mutation';
} & {
    distributeProposalBoosterContract?: Maybe<{
        __typename?: 'DistributeProposalBoosterMutationPayload';
    } & Pick<DistributeProposalBoosterMutationPayload, 'message' | 'status'>>;
};
export declare type FundFanVaultsMutationVariables = Exact<{
    fanVault: FanVaultTypeEnum;
}>;
export declare type FundFanVaultsMutation = {
    __typename?: 'Mutation';
} & {
    fundFanVaults?: Maybe<{
        __typename?: 'FundFanVaultsMutationPayload';
    } & Pick<FundFanVaultsMutationPayload, 'message' | 'status'>>;
};
export declare type StartAutomaticPeriodsMutationVariables = Exact<{
    [key: string]: never;
}>;
export declare type StartAutomaticPeriodsMutation = {
    __typename?: 'Mutation';
} & {
    startAutomaticPeriods?: Maybe<{
        __typename?: 'StartAutomaticPeriodsPayload';
    } & Pick<StartAutomaticPeriodsPayload, 'message' | 'status'>>;
};
export declare type StopAutomaticPeriodsMutationVariables = Exact<{
    [key: string]: never;
}>;
export declare type StopAutomaticPeriodsMutation = {
    __typename?: 'Mutation';
} & {
    stopAutomaticPeriods?: Maybe<{
        __typename?: 'StopAutomaticPeriodsPayload';
    } & Pick<StopAutomaticPeriodsPayload, 'message' | 'status'>>;
};
export declare type UpsertSystemSettingsMutationVariables = Exact<{
    params: Array<SystemSettingInput> | SystemSettingInput;
}>;
export declare type UpsertSystemSettingsMutation = {
    __typename?: 'Mutation';
} & {
    upsertSystemSettings?: Maybe<{
        __typename?: 'UpsertSystemSettingsMutationPayload';
    } & {
        systemSettings: Array<{
            __typename?: 'SystemSetting';
        } & SystemSettingFragment>;
    }>;
};
export declare type GetCommunityChestSettingsQueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type GetCommunityChestSettingsQuery = {
    __typename?: 'Query';
} & {
    systemSettings: {
        __typename?: 'SystemSettingsResolver';
    } & {
        apDistributionSettings: {
            __typename?: 'SystemSettingsGroup';
        } & SystemSettingsGroupFragment;
        fanVaultSettings: {
            __typename?: 'SystemSettingsGroup';
        } & SystemSettingsGroupFragment;
    };
};
export declare type GetFanGroupSettingsQueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type GetFanGroupSettingsQuery = {
    __typename?: 'Query';
} & {
    systemSettings: {
        __typename?: 'SystemSettingsResolver';
    } & {
        fanGroupSettings: {
            __typename?: 'SystemSettingsGroup';
        } & SystemSettingsGroupFragment;
    };
};
export declare type GetGeneralSettingsQueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type GetGeneralSettingsQuery = {
    __typename?: 'Query';
} & {
    systemSettings: {
        __typename?: 'SystemSettingsResolver';
    } & {
        generalSettings: {
            __typename?: 'SystemSettingsGroup';
        } & SystemSettingsGroupFragment;
        contactAddressSettings: {
            __typename?: 'SystemSettingsGroup';
        } & SystemSettingsGroupFragment;
    };
};
export declare type GetNfcSettingsQueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type GetNfcSettingsQuery = {
    __typename?: 'Query';
} & {
    systemSettings: {
        __typename?: 'SystemSettingsResolver';
    } & {
        nfcSettings: {
            __typename?: 'SystemSettingsGroup';
        } & SystemSettingsGroupFragment;
    };
};
export declare type GetProposalPeriodSettingsQueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type GetProposalPeriodSettingsQuery = {
    __typename?: 'Query';
} & {
    systemSettings: {
        __typename?: 'SystemSettingsResolver';
    } & {
        proposalPeriodSettings: {
            __typename?: 'SystemSettingsGroup';
        } & SystemSettingsGroupFragment;
    };
};
export declare type GetShopSettingsQueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type GetShopSettingsQuery = {
    __typename?: 'Query';
} & {
    systemSettings: {
        __typename?: 'SystemSettingsResolver';
    } & {
        shopSettings: {
            __typename?: 'SystemSettingsGroup';
        } & SystemSettingsGroupFragment;
    };
};
export declare type GetTokenContractSettingsQueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type GetTokenContractSettingsQuery = {
    __typename?: 'Query';
} & {
    systemSettings: {
        __typename?: 'SystemSettingsResolver';
    } & {
        tokenContractSettings: {
            __typename?: 'SystemSettingsGroup';
        } & SystemSettingsGroupFragment;
    };
};
export declare type GetTokenDistributionSettingsQueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type GetTokenDistributionSettingsQuery = {
    __typename?: 'Query';
} & {
    systemSettings: {
        __typename?: 'SystemSettingsResolver';
    } & {
        commentBoosterSettings: {
            __typename?: 'SystemSettingsGroup';
        } & SystemSettingsGroupFragment;
        contentBoosterSettings: {
            __typename?: 'SystemSettingsGroup';
        } & SystemSettingsGroupFragment;
        contentUnlockerSettings: {
            __typename?: 'SystemSettingsGroup';
        } & SystemSettingsGroupFragment;
        proposalBoosterSettings: {
            __typename?: 'SystemSettingsGroup';
        } & SystemSettingsGroupFragment;
        votingBoosterSettings: {
            __typename?: 'SystemSettingsGroup';
        } & SystemSettingsGroupFragment;
        amaSessionSettings: {
            __typename?: 'SystemSettingsGroup';
        } & SystemSettingsGroupFragment;
        ideationMissionSettings: {
            __typename?: 'SystemSettingsGroup';
        } & SystemSettingsGroupFragment;
        groupPostBoosterSettings: {
            __typename?: 'SystemSettingsGroup';
        } & SystemSettingsGroupFragment;
    };
};
export declare type UserOrderLightFragment = {
    __typename?: 'UserOrder';
} & Pick<UserOrder, 'id' | 'orderId' | 'createdAt' | 'updatedAt' | 'invoiceId' | 'invoiceSentAt' | 'orderFulfilledAt' | 'paymentProvider' | 'status' | 'tokenAmount' | 'nftCount' | 'total'> & {
    user: {
        __typename?: 'User';
    } & Pick<User, 'id' | 'displayName' | 'verified'>;
    shopProduct: {
        __typename?: 'ShopProduct';
    } & {
        nft?: Maybe<{
            __typename?: 'Nft';
        } & Pick<Nft, 'id' | 'name'> & {
            nftMedium: {
                __typename?: 'NftMedium';
            } & NftMediumFragment;
        }>;
        productMedium?: Maybe<{
            __typename?: 'ContentMedium';
        } & ContentMediumFragment>;
    } & ShopProductMinimumFragment;
};
export declare type UserOrderFragment = {
    __typename?: 'UserOrder';
} & {
    payments: Array<{
        __typename?: 'Payment';
    } & PaymentFragment>;
    nfts: Array<{
        __typename?: 'Nft';
    } & NftLightFragment>;
} & UserOrderLightFragment;
export declare type PaymentFragment = {
    __typename?: 'Payment';
} & Pick<Payment, 'id' | 'userOrderId' | 'provider' | 'transactionId' | 'amount' | 'status'>;
export declare type ShopProductLightFragment = {
    __typename?: 'ShopProduct';
} & Pick<ShopProduct, 'id' | 'createdAt' | 'updatedAt' | 'webPrice' | 'androidPrice' | 'iosPrice' | 'productType' | 'webSku' | 'androidSku' | 'iosSku' | 'tokenPrice' | 'tokens' | 'tokensBonus' | 'amountSold' | 'userOrdersCount' | 'webTargetVisible' | 'androidTargetVisible' | 'iosTargetVisible' | 'isWeb' | 'isAndroid' | 'isIos' | 'productMediumId' | 'nftId'> & {
    translations: Array<{
        __typename?: 'ShopProductTranslation';
    } & ShopProductTranslationFragment>;
    bucketsCapacity: Array<{
        __typename?: 'NftBucketCapacity';
    } & Pick<NftBucketCapacity, 'id' | 'capacity'>>;
    productMedium?: Maybe<{
        __typename?: 'ContentMedium';
    } & ContentMediumFragment>;
    nft?: Maybe<{
        __typename?: 'Nft';
    } & Pick<Nft, 'id' | 'name'> & {
        nftMedium: {
            __typename?: 'NftMedium';
        } & NftMediumFragment;
    }>;
};
export declare type ShopProductTranslationFragment = {
    __typename?: 'ShopProductTranslation';
} & Pick<ShopProductTranslation, 'id' | 'locale' | 'title' | 'description'>;
export declare type ShopProductMinimumFragment = {
    __typename?: 'ShopProduct';
} & Pick<ShopProduct, 'id' | 'isWeb' | 'isAndroid' | 'isIos' | 'webPrice' | 'androidPrice' | 'iosPrice' | 'productType'> & {
    translations: Array<{
        __typename?: 'ShopProductTranslation';
    } & Pick<ShopProductTranslation, 'id' | 'locale' | 'title'>>;
};
export declare type ShopProductFragment = {
    __typename?: 'ShopProduct';
} & Pick<ShopProduct, 'nftId' | 'amountSoldInTokens' | 'amountSoldInFiat' | 'nftOutOfStock' | 'maxSellable' | 'webPriceTierId' | 'androidPriceTierId' | 'iosPriceTierId' | 'maxPerDay' | 'maxPerDayReached'> & {
    nftBuckets: Array<{
        __typename?: 'NftBucket';
    } & Pick<NftBucket, 'id' | 'amount' | 'name' | 'bucketCapacity' | 'createdAt' | 'updatedAt'> & {
        nftBucketNfts: Array<{
            __typename?: 'NftBucketNft';
        } & Pick<NftBucketNft, 'id' | 'amountLimit' | 'nftId'> & {
            nft: {
                __typename?: 'Nft';
            } & NftLightFragment;
        }>;
    }>;
    nft?: Maybe<{
        __typename?: 'Nft';
    } & NftLightFragment>;
    webPriceTier?: Maybe<{
        __typename?: 'ShopProductTier';
    } & ShopProductTierFragment>;
    androidPriceTier?: Maybe<{
        __typename?: 'ShopProductTier';
    } & ShopProductTierFragment>;
    iosPriceTier?: Maybe<{
        __typename?: 'ShopProductTier';
    } & ShopProductTierFragment>;
    translations: Array<{
        __typename?: 'ShopProductTranslation';
    } & Pick<ShopProductTranslation, 'content' | 'successMessage'>>;
} & ShopProductLightFragment;
export declare type ShopProductTierFragment = {
    __typename?: 'ShopProductTier';
} & Pick<ShopProductTier, 'id' | 'createdAt' | 'updatedAt' | 'name' | 'price' | 'sku' | 'targetShop' | 'shopProductsCount'>;
export declare type CreateShopProductMutationVariables = Exact<{
    params: ShopProductInput;
}>;
export declare type CreateShopProductMutation = {
    __typename?: 'Mutation';
} & {
    createShopProduct?: Maybe<{
        __typename?: 'AddShopProductMutationPayload';
    } & {
        shopProduct: {
            __typename?: 'ShopProduct';
        } & ShopProductFragment;
    }>;
};
export declare type CreateShopProductTierMutationVariables = Exact<{
    params: ShopProductTierInput;
}>;
export declare type CreateShopProductTierMutation = {
    __typename?: 'Mutation';
} & {
    createShopProductTier?: Maybe<{
        __typename?: 'AddShopProductTierMutationPayload';
    } & {
        shopProductTier: {
            __typename?: 'ShopProductTier';
        } & ShopProductTierFragment;
    }>;
};
export declare type DeleteShopProductsMutationVariables = Exact<{
    ids: Array<Scalars['ID']> | Scalars['ID'];
}>;
export declare type DeleteShopProductsMutation = {
    __typename?: 'Mutation';
} & {
    deleteShopProducts?: Maybe<{
        __typename?: 'DeleteShopProductsMutationPayload';
    } & Pick<DeleteShopProductsMutationPayload, 'deletedIds' | 'status'>>;
};
export declare type DeleteShopProductTiersMutationVariables = Exact<{
    ids: Array<Scalars['ID']> | Scalars['ID'];
}>;
export declare type DeleteShopProductTiersMutation = {
    __typename?: 'Mutation';
} & {
    deleteShopProductTiers?: Maybe<{
        __typename?: 'DeleteShopProductTiersMutationPayload';
    } & Pick<DeleteShopProductTiersMutationPayload, 'deletedIds' | 'status'>>;
};
export declare type UpdateShopProductMutationVariables = Exact<{
    id: Scalars['ID'];
    params: ShopProductInput;
}>;
export declare type UpdateShopProductMutation = {
    __typename?: 'Mutation';
} & {
    updateShopProduct?: Maybe<{
        __typename?: 'UpdateShopProductMutationPayload';
    } & {
        shopProduct: {
            __typename?: 'ShopProduct';
        } & ShopProductFragment;
    }>;
};
export declare type UpdateShopProductTierMutationVariables = Exact<{
    id: Scalars['ID'];
    params: ShopProductTierInput;
}>;
export declare type UpdateShopProductTierMutation = {
    __typename?: 'Mutation';
} & {
    updateShopProductTier?: Maybe<{
        __typename?: 'UpdateShopProductTierMutationPayload';
    } & {
        shopProductTier: {
            __typename?: 'ShopProductTier';
        } & ShopProductTierFragment;
    }>;
};
export declare type GetLowNftBucketsQueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type GetLowNftBucketsQuery = {
    __typename?: 'Query';
} & {
    shopProducts: {
        __typename?: 'ShopProductResolver';
    } & Pick<ShopProductResolver, 'total'> & {
        shopProducts: Array<{
            __typename?: 'ShopProduct';
        } & {
            bucketsCapacity: Array<{
                __typename?: 'NftBucketCapacity';
            } & Pick<NftBucketCapacity, 'id' | 'capacity'>>;
        }>;
    };
};
export declare type GetUserOrderQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetUserOrderQuery = {
    __typename?: 'Query';
} & {
    userOrder: {
        __typename?: 'UserOrder';
    } & UserOrderFragment;
};
export declare type GetUserOrdersQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<UserOrderFilterInput>;
    sort?: Maybe<UserOrderSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetUserOrdersQuery = {
    __typename?: 'Query';
} & {
    userOrders: {
        __typename?: 'UserOrderResolver';
    } & Pick<UserOrderResolver, 'total'> & {
        userOrders: Array<{
            __typename?: 'UserOrder';
        } & UserOrderLightFragment>;
    };
};
export declare type GetShopProductQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetShopProductQuery = {
    __typename?: 'Query';
} & {
    shopProduct: {
        __typename?: 'ShopProduct';
    } & ShopProductFragment;
};
export declare type GetShopProductsQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<ShopProductFilterInput>;
    sort?: Maybe<ShopProductSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetShopProductsQuery = {
    __typename?: 'Query';
} & {
    shopProducts: {
        __typename?: 'ShopProductResolver';
    } & Pick<ShopProductResolver, 'total'> & {
        shopProducts: Array<{
            __typename?: 'ShopProduct';
        } & ShopProductLightFragment>;
    };
};
export declare type GetShopProductTierQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetShopProductTierQuery = {
    __typename?: 'Query';
} & {
    shopProductTier: {
        __typename?: 'ShopProductTier';
    } & ShopProductTierFragment;
};
export declare type GetShopProductTiersQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<ShopProductTierFilterInput>;
    sort?: Maybe<ShopProductTierSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetShopProductTiersQuery = {
    __typename?: 'Query';
} & {
    shopProductTiers: {
        __typename?: 'ShopProductTierResolver';
    } & Pick<ShopProductTierResolver, 'total'> & {
        shopProductTiers: Array<{
            __typename?: 'ShopProductTier';
        } & ShopProductTierFragment>;
    };
};
export declare type GetVisibleProductsWithNftBucketsQueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type GetVisibleProductsWithNftBucketsQuery = {
    __typename?: 'Query';
} & {
    shopProducts: {
        __typename?: 'ShopProductResolver';
    } & Pick<ShopProductResolver, 'total'>;
};
export declare type SponsorForSelectFragment = {
    __typename?: 'Sponsor';
} & Pick<Sponsor, 'id' | 'name'>;
export declare type SponsorLightFragment = {
    __typename?: 'Sponsor';
} & Pick<Sponsor, 'id' | 'name' | 'createdAt' | 'updatedAt'> & {
    tokenGiveawaysStatistics?: Maybe<{
        __typename?: 'SponsorStats';
    } & SponsorStatsFragment>;
    nftGiveawaysStatistics?: Maybe<{
        __typename?: 'SponsorStats';
    } & SponsorStatsFragment>;
    tokenHandoutsStatistics?: Maybe<{
        __typename?: 'SponsorStats';
    } & SponsorStatsFragment>;
    nftHandoutsStatistics?: Maybe<{
        __typename?: 'SponsorStats';
    } & SponsorStatsFragment>;
    customNotificationsStatistics?: Maybe<{
        __typename?: 'SponsorStats';
    } & SponsorStatsFragment>;
};
export declare type SponsorStatsFragment = {
    __typename?: 'SponsorStats';
} & Pick<SponsorStats, 'totalActive' | 'totalAmount' | 'totalCount' | 'totalTimes' | 'uniqueSponsorUsers'>;
export declare type SponsorFragment = {
    __typename?: 'Sponsor';
} & SponsorLightFragment;
export declare type CreateSponsorMutationVariables = Exact<{
    params: SponsorInput;
}>;
export declare type CreateSponsorMutation = {
    __typename?: 'Mutation';
} & {
    createSponsor?: Maybe<{
        __typename?: 'AddSponsorMutationPayload';
    } & {
        sponsor: {
            __typename?: 'Sponsor';
        } & SponsorFragment;
    }>;
};
export declare type DeleteSponsorsMutationVariables = Exact<{
    ids: Array<Scalars['ID']> | Scalars['ID'];
}>;
export declare type DeleteSponsorsMutation = {
    __typename?: 'Mutation';
} & {
    deleteSponsors?: Maybe<{
        __typename?: 'DeleteSponsorsMutationPayload';
    } & Pick<DeleteSponsorsMutationPayload, 'deletedIds' | 'status'>>;
};
export declare type UpdateSponsorMutationVariables = Exact<{
    id: Scalars['ID'];
    params: SponsorInput;
}>;
export declare type UpdateSponsorMutation = {
    __typename?: 'Mutation';
} & {
    updateSponsor?: Maybe<{
        __typename?: 'UpdateSponsorMutationPayload';
    } & {
        sponsor: {
            __typename?: 'Sponsor';
        } & SponsorFragment;
    }>;
};
export declare type GetSponsorStatisticsQueryVariables = Exact<{
    id: Scalars['ID'];
    filter?: Maybe<SponsorStatisticsFilterInput>;
}>;
export declare type GetSponsorStatisticsQuery = {
    __typename?: 'Query';
} & {
    sponsorStatistics: {
        __typename?: 'SponsorStatsCollection';
    } & {
        nftGiveawaysStatistics: {
            __typename?: 'SponsorStats';
        } & SponsorStatsFragment;
        tokenGiveawaysStatistics: {
            __typename?: 'SponsorStats';
        } & SponsorStatsFragment;
        tokenHandoutsStatistics: {
            __typename?: 'SponsorStats';
        } & SponsorStatsFragment;
        nftHandoutsStatistics: {
            __typename?: 'SponsorStats';
        } & SponsorStatsFragment;
        customNotificationsStatistics: {
            __typename?: 'SponsorStats';
        } & SponsorStatsFragment;
    };
};
export declare type GetSponsorQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetSponsorQuery = {
    __typename?: 'Query';
} & {
    sponsor: {
        __typename?: 'Sponsor';
    } & SponsorFragment;
};
export declare type GetSponsorsForSelectQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<SponsorFilterInput>;
    sort?: Maybe<SponsorSortInput>;
}>;
export declare type GetSponsorsForSelectQuery = {
    __typename?: 'Query';
} & {
    sponsors: {
        __typename?: 'SponsorResolver';
    } & Pick<SponsorResolver, 'total'> & {
        sponsors: Array<{
            __typename?: 'Sponsor';
        } & SponsorForSelectFragment>;
    };
};
export declare type GetSponsorsQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<SponsorFilterInput>;
    sort?: Maybe<SponsorSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetSponsorsQuery = {
    __typename?: 'Query';
} & {
    sponsors: {
        __typename?: 'SponsorResolver';
    } & Pick<SponsorResolver, 'total'> & {
        sponsors: Array<{
            __typename?: 'Sponsor';
        } & SponsorLightFragment>;
    };
};
export declare type StaticPageLightFragment = {
    __typename?: 'StaticPage';
} & Pick<StaticPage, 'id' | 'createdAt' | 'updatedAt' | 'status' | 'previewToken' | 'previewUrl' | 'commentsCount' | 'isCommentable'> & {
    previewUrls: Array<{
        __typename?: 'PreviewUrl';
    } & PreviewUrlFragment>;
    translations: Array<{
        __typename?: 'StaticPageTranslation';
    } & StaticPageTranslationFragment>;
};
export declare type StaticPageTranslationFragment = {
    __typename?: 'StaticPageTranslation';
} & Pick<StaticPageTranslation, 'id' | 'locale' | 'title' | 'slug' | 'metaTitle' | 'metaDescription' | 'body'>;
export declare type StaticPageFragment = {
    __typename?: 'StaticPage';
} & Pick<StaticPage, 'onlyForAvailables' | 'availabilityType'> & {
    comments: Array<{
        __typename?: 'Comment';
    } & CommentLightFragment>;
    availabilities?: Maybe<Array<{
        __typename?: 'Availability';
    } & AvailabilityFragment>>;
} & StaticPageLightFragment;
export declare type ArchiveStaticPageMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type ArchiveStaticPageMutation = {
    __typename?: 'Mutation';
} & {
    archiveStaticPage?: Maybe<{
        __typename?: 'ArchiveStaticPageMutationPayload';
    } & {
        staticPage: {
            __typename?: 'StaticPage';
        } & StaticPageFragment;
    }>;
};
export declare type CreateStaticPageMutationVariables = Exact<{
    params: StaticPageInput;
}>;
export declare type CreateStaticPageMutation = {
    __typename?: 'Mutation';
} & {
    createStaticPage?: Maybe<{
        __typename?: 'AddStaticPageMutationPayload';
    } & {
        staticPage: {
            __typename?: 'StaticPage';
        } & StaticPageFragment;
    }>;
};
export declare type DeleteStaticPagesMutationVariables = Exact<{
    ids: Array<Scalars['ID']> | Scalars['ID'];
}>;
export declare type DeleteStaticPagesMutation = {
    __typename?: 'Mutation';
} & {
    deleteStaticPages?: Maybe<{
        __typename?: 'DeleteStaticPagesMutationPayload';
    } & Pick<DeleteStaticPagesMutationPayload, 'deletedIds' | 'status'>>;
};
export declare type PublishStaticPageMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type PublishStaticPageMutation = {
    __typename?: 'Mutation';
} & {
    publishStaticPage?: Maybe<{
        __typename?: 'PublishStaticPageMutationPayload';
    } & {
        staticPage: {
            __typename?: 'StaticPage';
        } & StaticPageFragment;
    }>;
};
export declare type UpdateStaticPageMutationVariables = Exact<{
    id: Scalars['ID'];
    params: StaticPageInput;
}>;
export declare type UpdateStaticPageMutation = {
    __typename?: 'Mutation';
} & {
    updateStaticPage?: Maybe<{
        __typename?: 'UpdateStaticPageMutationPayload';
    } & {
        staticPage: {
            __typename?: 'StaticPage';
        } & StaticPageFragment;
    }>;
};
export declare type GetStaticPageQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetStaticPageQuery = {
    __typename?: 'Query';
} & {
    staticPage: {
        __typename?: 'StaticPage';
    } & StaticPageFragment;
};
export declare type GetStaticPagesQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<StaticPageFilterInput>;
    sort?: Maybe<StaticPageSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetStaticPagesQuery = {
    __typename?: 'Query';
} & {
    staticPages: {
        __typename?: 'StaticPageResolver';
    } & Pick<StaticPageResolver, 'total'> & {
        staticPages: Array<{
            __typename?: 'StaticPage';
        } & StaticPageLightFragment>;
    };
};
export declare type TokenHandoutLightFragment = {
    __typename?: 'TokenHandout';
} & Pick<TokenHandout, 'id' | 'createdAt' | 'updatedAt' | 'handoutAt' | 'skipNotification' | 'promptDialog' | 'tokenAmount' | 'status' | 'heroMediumId' | 'sponsorId' | 'tokenHandoutUsersCount'> & {
    heroMedium?: Maybe<{
        __typename?: 'ContentMedium';
    } & ContentMediumFragment>;
    translations: Array<{
        __typename?: 'TokenHandoutTranslation';
    } & Pick<TokenHandoutTranslation, 'id' | 'locale' | 'title'>>;
    sponsor?: Maybe<{
        __typename?: 'Sponsor';
    } & Pick<Sponsor, 'id' | 'name'>>;
    statistics?: Maybe<{
        __typename?: 'TokenHandoutStats';
    } & Pick<TokenHandoutStats, 'amount' | 'countTrigger' | 'id' | 'numberOfUsers' | 'times'>>;
};
export declare type TokenHandoutTranslationFragment = {
    __typename?: 'TokenHandoutTranslation';
} & Pick<TokenHandoutTranslation, 'id' | 'locale' | 'title' | 'message' | 'content' | 'externalLink' | 'ctaText'>;
export declare type TokenHandoutUserFragment = {
    __typename?: 'TokenHandoutUser';
} & Pick<TokenHandoutUser, 'id' | 'createdAt' | 'updatedAt' | 'userId' | 'tokenHandoutId'> & {
    user: {
        __typename?: 'User';
    } & UserLightFragment;
};
export declare type TokenHandoutFragment = {
    __typename?: 'TokenHandout';
} & Pick<TokenHandout, 'userSearch'> & {
    translations: Array<{
        __typename?: 'TokenHandoutTranslation';
    } & TokenHandoutTranslationFragment>;
    userFilter?: Maybe<{
        __typename?: 'UserFilter';
    } & UserFilterFragment>;
} & TokenHandoutLightFragment;
export declare type CreateTokenHandoutMutationVariables = Exact<{
    params: TokenHandoutInput;
    userFilter: UserFilterInput;
    userSearch?: Maybe<Scalars['String']>;
}>;
export declare type CreateTokenHandoutMutation = {
    __typename?: 'Mutation';
} & {
    createTokenHandout?: Maybe<{
        __typename?: 'AddTokenHandoutMutationPayload';
    } & {
        tokenHandout: {
            __typename?: 'TokenHandout';
        } & TokenHandoutFragment;
    }>;
};
export declare type DeleteTokenHandoutsMutationVariables = Exact<{
    ids: Array<Scalars['ID']> | Scalars['ID'];
}>;
export declare type DeleteTokenHandoutsMutation = {
    __typename?: 'Mutation';
} & {
    deleteTokenHandouts?: Maybe<{
        __typename?: 'DeleteTokenHandoutsMutationPayload';
    } & Pick<DeleteTokenHandoutsMutationPayload, 'status' | 'deletedIds'>>;
};
export declare type DraftTokenHandoutMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type DraftTokenHandoutMutation = {
    __typename?: 'Mutation';
} & {
    draftTokenHandout?: Maybe<{
        __typename?: 'DraftTokenHandoutMutationPayload';
    } & {
        tokenHandout: {
            __typename?: 'TokenHandout';
        } & TokenHandoutFragment;
    }>;
};
export declare type PublishTokenHandoutMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type PublishTokenHandoutMutation = {
    __typename?: 'Mutation';
} & {
    publishTokenHandout?: Maybe<{
        __typename?: 'PublishTokenHandoutMutationPayload';
    } & {
        tokenHandout: {
            __typename?: 'TokenHandout';
        } & TokenHandoutFragment;
    }>;
};
export declare type UpdateTokenHandoutMutationVariables = Exact<{
    id: Scalars['ID'];
    params: TokenHandoutInput;
    userFilter?: Maybe<UserFilterInput>;
    userSearch?: Maybe<Scalars['String']>;
}>;
export declare type UpdateTokenHandoutMutation = {
    __typename?: 'Mutation';
} & {
    updateTokenHandout?: Maybe<{
        __typename?: 'UpdateTokenHandoutMutationPayload';
    } & {
        tokenHandout: {
            __typename?: 'TokenHandout';
        } & TokenHandoutFragment;
    }>;
};
export declare type GetTokenHandoutUsersQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<TokenHandoutUserFilterInput>;
    sort?: Maybe<TokenHandoutUserSortInput>;
}>;
export declare type GetTokenHandoutUsersQuery = {
    __typename?: 'Query';
} & {
    tokenHandoutUsers: {
        __typename?: 'TokenHandoutUserResolver';
    } & Pick<TokenHandoutUserResolver, 'total'> & {
        tokenHandoutUsers: Array<{
            __typename?: 'TokenHandoutUser';
        } & TokenHandoutUserFragment>;
    };
};
export declare type GetTokenHandoutQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetTokenHandoutQuery = {
    __typename?: 'Query';
} & {
    tokenHandout: {
        __typename?: 'TokenHandout';
    } & TokenHandoutFragment;
};
export declare type GetTokenHandoutsQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<TokenHandoutFilterInput>;
    sort?: Maybe<TokenHandoutSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetTokenHandoutsQuery = {
    __typename?: 'Query';
} & {
    tokenHandouts: {
        __typename?: 'TokenHandoutResolver';
    } & Pick<TokenHandoutResolver, 'total'> & {
        tokenHandouts: Array<{
            __typename?: 'TokenHandout';
        } & TokenHandoutLightFragment>;
    };
};
export declare type GetTokenStatisticsQueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type GetTokenStatisticsQuery = {
    __typename?: 'Query';
} & {
    tokenStatistics: {
        __typename?: 'TokenStatistic';
    } & Pick<TokenStatistic, 'tokenUsed' | 'tokenIncluded' | 'startDate' | 'endDate'> & {
        months: Array<{
            __typename?: 'TokenStatisticMonth';
        } & Pick<TokenStatisticMonth, 'month' | 'year' | 'tokenBalance' | 'tokenUsed' | 'tokenIncluded' | 'transactionCount'>>;
    };
};
export declare type TransactionLightFragment = {
    __typename?: 'Transaction';
} & Pick<Transaction, 'id' | 'amount' | 'eventName' | 'info' | 'createdAt' | 'updatedAt' | 'userId' | 'txStatus' | 'transactableType' | 'nftCount'> & {
    user: {
        __typename?: 'User';
    } & UserLightFragment;
    transactable?: Maybe<{
        __typename?: 'AmaQuestion';
    } | {
        __typename?: 'AmaSession';
    } | {
        __typename?: 'Comment';
    } | {
        __typename?: 'Content';
    } | {
        __typename?: 'Giveaway';
    } | {
        __typename?: 'GroupPost';
    } | {
        __typename?: 'Idea';
    } | {
        __typename?: 'IdeationMission';
    } | {
        __typename?: 'Proposal';
    } | ({
        __typename?: 'ShopProduct';
    } & ShopProductLightFragment) | {
        __typename?: 'TokenHandout';
    } | {
        __typename?: 'Voting';
    }>;
};
export declare type TransactionFragment = {
    __typename?: 'Transaction';
} & {
    nfts: Array<{
        __typename?: 'Nft';
    } & NftLightFragment>;
} & TransactionLightFragment;
export declare type GetTransactionQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetTransactionQuery = {
    __typename?: 'Query';
} & {
    transaction: {
        __typename?: 'Transaction';
    } & TransactionFragment;
};
export declare type GetTransactionsQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<TransactionFilterInput>;
    sort?: Maybe<TransactionSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetTransactionsQuery = {
    __typename?: 'Query';
} & {
    transactions: {
        __typename?: 'TransactionResolver';
    } & Pick<TransactionResolver, 'total'> & {
        transactions: Array<{
            __typename?: 'Transaction';
        } & TransactionLightFragment>;
    };
};
export declare type TriggerEventFragment = {
    __typename?: 'TriggerEvent';
} & Pick<TriggerEvent, 'forResource' | 'name' | 'supportsThreshold' | 'supportsUserLimit' | 'forceGiveaway' | 'priority'>;
export declare type GetTriggerEventsQueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type GetTriggerEventsQuery = {
    __typename?: 'Query';
} & {
    triggerEvents: Array<{
        __typename?: 'TriggerEvent';
    } & TriggerEventFragment>;
};
export declare type UserGiveawayFragment = {
    __typename?: 'UserGiveaway';
} & Pick<UserGiveaway, 'id' | 'createdAt' | 'tokens'> & {
    giveaway: {
        __typename?: 'Giveaway';
    } & Pick<Giveaway, 'id' | 'giveawayType'> & {
        translations: Array<{
            __typename?: 'GiveawayTranslation';
        } & Pick<GiveawayTranslation, 'id' | 'locale' | 'title'>>;
    };
    nft?: Maybe<{
        __typename?: 'Nft';
    } & Pick<Nft, 'id' | 'name'> & {
        nftMedium: {
            __typename?: 'NftMedium';
        } & NftMediumFragment;
    }>;
    user: {
        __typename?: 'User';
    } & Pick<User, 'id' | 'displayName'>;
    giveawayEvent: {
        __typename?: 'GiveawayEvent';
    } & Pick<GiveawayEvent, 'id' | 'eventType'>;
};
export declare type GetUserGiveawaysQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<UserGiveawayFilterInput>;
    sort?: Maybe<UserGiveawaySortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetUserGiveawaysQuery = {
    __typename?: 'Query';
} & {
    userGiveaways: {
        __typename?: 'UserGiveawayResolver';
    } & Pick<UserGiveawayResolver, 'total'> & {
        userGiveaways: Array<{
            __typename?: 'UserGiveaway';
        } & UserGiveawayFragment>;
    };
};
export declare type UserMediumFragment = {
    __typename?: 'UserMedium';
} & Pick<UserMedium, 'id' | 'createdAt' | 'updatedAt' | 'image' | 'thumbnail' | 'original' | 'mediaType' | 'fanGroupsCount' | 'resourcesCount'>;
export declare type FilterDateFragment = {
    __typename?: 'FilterDate';
} & Pick<FilterDate, 'from' | 'isNotNull' | 'isNull' | 'until'>;
export declare type FilterIdFragment = {
    __typename?: 'FilterId';
} & Pick<FilterId, 'eq' | 'gt' | 'in' | 'isNotNull' | 'isNull' | 'lt' | 'notEq' | 'notIn'>;
export declare type FilterNumberFragment = {
    __typename?: 'FilterNumber';
} & Pick<FilterNumber, 'eq' | 'gt' | 'in' | 'isNotNull' | 'isNull' | 'lt' | 'notEq' | 'notIn'>;
export declare type FilterTextFragment = {
    __typename?: 'FilterText';
} & Pick<FilterText, 'eq' | 'ilike' | 'isNotNull' | 'isNull' | 'like' | 'notLike'>;
export declare type ProfileFieldOptionFragment = {
    __typename?: 'ProfileFieldOption';
} & Pick<ProfileFieldOption, 'id' | 'createdAt' | 'updatedAt' | 'order' | 'profileFieldId'> & {
    translations: Array<{
        __typename?: 'ProfileFieldOptionTranslation';
    } & Pick<ProfileFieldOptionTranslation, 'id' | 'label' | 'locale'>>;
};
export declare type ProfileFieldFragment = {
    __typename?: 'ProfileField';
} & Pick<ProfileField, 'id' | 'createdAt' | 'updatedAt' | 'inputType' | 'isMulti' | 'order' | 'publiclyVisible' | 'status' | 'formKey'> & {
    profileFieldOptions: Array<{
        __typename?: 'ProfileFieldOption';
    } & ProfileFieldOptionFragment>;
    translations: Array<{
        __typename?: 'ProfileFieldTranslation';
    } & Pick<ProfileFieldTranslation, 'hint' | 'id' | 'locale' | 'name'>>;
};
export declare type UserFilterFragment = {
    __typename?: 'UserFilter';
} & Pick<UserFilter, 'locale' | 'reportStatus' | 'status' | 'withReportStatus' | 'verified'> & {
    allowPasswordChange?: Maybe<{
        __typename?: 'FilterNumber';
    } & FilterNumberFragment>;
    biography?: Maybe<{
        __typename?: 'FilterText';
    } & FilterTextFragment>;
    birthdate?: Maybe<{
        __typename?: 'FilterDate';
    } & FilterDateFragment>;
    city?: Maybe<{
        __typename?: 'FilterText';
    } & FilterTextFragment>;
    confirmationSentAt?: Maybe<{
        __typename?: 'FilterDate';
    } & FilterDateFragment>;
    confirmationToken?: Maybe<{
        __typename?: 'FilterText';
    } & FilterTextFragment>;
    confirmedAt?: Maybe<{
        __typename?: 'FilterDate';
    } & FilterDateFragment>;
    country?: Maybe<{
        __typename?: 'FilterText';
    } & FilterTextFragment>;
    createdAt?: Maybe<{
        __typename?: 'FilterDate';
    } & FilterDateFragment>;
    displayName?: Maybe<{
        __typename?: 'FilterText';
    } & FilterTextFragment>;
    email?: Maybe<{
        __typename?: 'FilterText';
    } & FilterTextFragment>;
    fastbillId?: Maybe<{
        __typename?: 'FilterText';
    } & FilterTextFragment>;
    gender?: Maybe<{
        __typename?: 'FilterText';
    } & FilterTextFragment>;
    id?: Maybe<{
        __typename?: 'FilterId';
    } & FilterIdFragment>;
    initiallyFundedAt?: Maybe<{
        __typename?: 'FilterDate';
    } & FilterDateFragment>;
    notificationToken?: Maybe<{
        __typename?: 'FilterText';
    } & FilterTextFragment>;
    nftId?: Maybe<{
        __typename?: 'FilterId';
    } & FilterIdFragment>;
    rememberCreatedAt?: Maybe<{
        __typename?: 'FilterDate';
    } & FilterDateFragment>;
    resetPasswordSentAt?: Maybe<{
        __typename?: 'FilterDate';
    } & FilterDateFragment>;
    resetPasswordToken?: Maybe<{
        __typename?: 'FilterText';
    } & FilterTextFragment>;
    slug?: Maybe<{
        __typename?: 'FilterText';
    } & FilterTextFragment>;
    state?: Maybe<{
        __typename?: 'FilterText';
    } & FilterTextFragment>;
    tokens?: Maybe<{
        __typename?: 'FilterText';
    } & FilterTextFragment>;
    ugcReportsCount?: Maybe<{
        __typename?: 'FilterNumber';
    } & FilterNumberFragment>;
    uid?: Maybe<{
        __typename?: 'FilterText';
    } & FilterTextFragment>;
    unconfirmedEmail?: Maybe<{
        __typename?: 'FilterText';
    } & FilterTextFragment>;
    updatedAt?: Maybe<{
        __typename?: 'FilterDate';
    } & FilterDateFragment>;
    walletAddress?: Maybe<{
        __typename?: 'FilterText';
    } & FilterTextFragment>;
    website?: Maybe<{
        __typename?: 'FilterText';
    } & FilterTextFragment>;
    welcomedAt?: Maybe<{
        __typename?: 'FilterDate';
    } & FilterDateFragment>;
    verifiedAt?: Maybe<{
        __typename?: 'FilterDate';
    } & FilterDateFragment>;
};
export declare type UserLightFragment = {
    __typename?: 'User';
} & Pick<User, 'id' | 'email' | 'displayName' | 'createdAt' | 'updatedAt' | 'lastDayActive' | 'subscriptionAutorenewalActive' | 'subscriptionValidUntil' | 'status' | 'slug' | 'reportStatus' | 'ugcReportsCount' | 'deviceTypes' | 'verified'> & {
    avatar?: Maybe<{
        __typename?: 'UserMedium';
    } & Pick<UserMedium, 'image' | 'thumbnail'>>;
};
export declare type UserProfileFieldFragment = {
    __typename?: 'UserProfileField';
} & Pick<UserProfileField, 'id' | 'createdAt' | 'updatedAt' | 'profileFieldId' | 'userPubliclyVisible' | 'value' | 'valueType'> & {
    profileField: {
        __typename?: 'ProfileField';
    } & ProfileFieldFragment;
};
export declare type UserFragment = {
    __typename?: 'User';
} & Pick<User, 'unconfirmedEmail' | 'walletAddress' | 'confirmedAt' | 'locale' | 'gender' | 'country' | 'city' | 'countryName' | 'state' | 'stateName' | 'biography' | 'website' | 'phoneNumber' | 'birthdate' | 'previewUrl' | 'verified' | 'verifiedAt' | 'initiallyFundedAt'> & {
    heroMedium?: Maybe<{
        __typename?: 'UserMedium';
    } & Pick<UserMedium, 'image' | 'thumbnail'>>;
    blockedUsers: Array<{
        __typename?: 'User';
    } & UserLightFragment>;
    blockingUsers: Array<{
        __typename?: 'User';
    } & UserLightFragment>;
    currentBalance: {
        __typename?: 'Balance';
    } & Pick<Balance, 'currency' | 'var' | 'value'>;
    currentEthBalance: {
        __typename?: 'Balance';
    } & Pick<Balance, 'currency' | 'var' | 'value'>;
    subscriptionCurrentUserOrder?: Maybe<{
        __typename?: 'UserOrder';
    } & UserOrderLightFragment>;
    subscriptionProduct?: Maybe<{
        __typename?: 'ShopProduct';
    } & ShopProductFragment>;
    audits: Array<{
        __typename?: 'Audit';
    } & AuditFragment>;
    ugcReportTypes?: Maybe<Array<{
        __typename?: 'UgcReportTyp';
    } & UgcReportTypeFragment>>;
    ugcReports: Array<{
        __typename?: 'UgcReport';
    } & UgcReportFragment>;
    nftUsers: Array<{
        __typename?: 'NftUser';
    } & Pick<NftUser, 'id' | 'createdAt' | 'updatedAt' | 'amount' | 'amountFrozen' | 'amountBurnt' | 'nftId' | 'publiclyVisible'> & {
        nft: {
            __typename?: 'Nft';
        } & Pick<Nft, 'id' | 'name'>;
    }>;
    userProfileFields: Array<{
        __typename?: 'UserProfileField';
    } & UserProfileFieldFragment>;
    fanGroupUsers: Array<{
        __typename?: 'FanGroupUser';
    } & {
        fanGroup: {
            __typename?: 'FanGroup';
        } & FanGroupLightFragment;
    } & FanGroupUserFragment>;
} & UserLightFragment;
export declare type ArchiveProfileFieldMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type ArchiveProfileFieldMutation = {
    __typename?: 'Mutation';
} & {
    archiveProfileField?: Maybe<{
        __typename?: 'ArchiveProfileFieldMutationPayload';
    } & {
        profileField: {
            __typename?: 'ProfileField';
        } & ProfileFieldFragment;
    }>;
};
export declare type CreateProfileFieldMutationVariables = Exact<{
    params: ProfileFieldInput;
}>;
export declare type CreateProfileFieldMutation = {
    __typename?: 'Mutation';
} & {
    createProfileField?: Maybe<{
        __typename?: 'AddProfileFieldMutationPayload';
    } & {
        profileField: {
            __typename?: 'ProfileField';
        } & ProfileFieldFragment;
    }>;
};
export declare type DeleteProfileFieldsMutationVariables = Exact<{
    ids: Array<Scalars['ID']> | Scalars['ID'];
}>;
export declare type DeleteProfileFieldsMutation = {
    __typename?: 'Mutation';
} & {
    deleteProfileFields?: Maybe<{
        __typename?: 'DeleteProfileFieldsMutationPayload';
    } & Pick<DeleteProfileFieldsMutationPayload, 'deletedIds' | 'status'>>;
};
export declare type DraftProfileFieldMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type DraftProfileFieldMutation = {
    __typename?: 'Mutation';
} & {
    draftProfileField?: Maybe<{
        __typename?: 'DraftProfileFieldMutationPayload';
    } & {
        profileField: {
            __typename?: 'ProfileField';
        } & ProfileFieldFragment;
    }>;
};
export declare type PublishProfileFieldMutationVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type PublishProfileFieldMutation = {
    __typename?: 'Mutation';
} & {
    publishProfileField?: Maybe<{
        __typename?: 'PublishProfileFieldMutationPayload';
    } & {
        profileField: {
            __typename?: 'ProfileField';
        } & ProfileFieldFragment;
    }>;
};
export declare type UpdateProfileFieldMutationVariables = Exact<{
    id: Scalars['ID'];
    params: ProfileFieldInput;
}>;
export declare type UpdateProfileFieldMutation = {
    __typename?: 'Mutation';
} & {
    updateProfileField?: Maybe<{
        __typename?: 'UpdateProfileFieldMutationPayload';
    } & {
        profileField: {
            __typename?: 'ProfileField';
        } & ProfileFieldFragment;
    }>;
};
export declare type UpdateProfileFieldsMutationVariables = Exact<{
    params: Array<ProfileFieldInput> | ProfileFieldInput;
}>;
export declare type UpdateProfileFieldsMutation = {
    __typename?: 'Mutation';
} & {
    updateProfileFields?: Maybe<{
        __typename?: 'UpdateProfileFieldsMutationPayload';
    } & {
        profileFields: Array<{
            __typename?: 'ProfileField';
        } & ProfileFieldFragment>;
    }>;
};
export declare type UpdateUserMutationVariables = Exact<{
    id: Scalars['ID'];
    params: UserInput;
}>;
export declare type UpdateUserMutation = {
    __typename?: 'Mutation';
} & {
    updateUser?: Maybe<{
        __typename?: 'UpdateUserMutationPayload';
    } & {
        user: {
            __typename?: 'User';
        } & UserFragment;
    }>;
};
export declare type GetProfileFieldQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetProfileFieldQuery = {
    __typename?: 'Query';
} & {
    profileField: {
        __typename?: 'ProfileField';
    } & ProfileFieldFragment;
};
export declare type GetProfileFieldsQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<ProfileFieldFilterInput>;
    sort?: Maybe<ProfileFieldSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetProfileFieldsQuery = {
    __typename?: 'Query';
} & {
    profileFields: {
        __typename?: 'ProfileFieldResolver';
    } & Pick<ProfileFieldResolver, 'total'> & {
        profileFields: Array<{
            __typename?: 'ProfileField';
        } & ProfileFieldFragment>;
    };
};
export declare type GetUserDeviceStatisticsQueryVariables = Exact<{
    [key: string]: never;
}>;
export declare type GetUserDeviceStatisticsQuery = {
    __typename?: 'Query';
} & {
    userDeviceStatistics: {
        __typename?: 'UserDeviceStatistics';
    } & Pick<UserDeviceStatistics, 'iosUsers' | 'androidUsers' | 'pwaOrWebUsers' | 'iosAndAndroidUsers' | 'total'>;
};
export declare type GetUserQueryVariables = Exact<{
    id: Scalars['ID'];
}>;
export declare type GetUserQuery = {
    __typename?: 'Query';
} & {
    user: {
        __typename?: 'User';
    } & UserFragment;
};
export declare type GetUsersQueryVariables = Exact<{
    limit?: Maybe<Scalars['Int']>;
    offset?: Maybe<Scalars['Int']>;
    filter?: Maybe<UserFilterInput>;
    sort?: Maybe<UserSortInput>;
    search?: Maybe<Scalars['String']>;
}>;
export declare type GetUsersQuery = {
    __typename?: 'Query';
} & {
    users: {
        __typename?: 'UserResolver';
    } & Pick<UserResolver, 'total'> & {
        users: Array<{
            __typename?: 'User';
        } & UserLightFragment>;
    };
};
export declare type TriggerGiveawayEventMutationVariables = Exact<{
    apiUuid: Scalars['ID'];
    userFilter?: Maybe<UserFilterInput>;
    userSearch?: Maybe<Scalars['String']>;
}>;
export declare type TriggerGiveawayEventMutation = {
    __typename?: 'Mutation';
} & {
    triggerGiveawayEvent?: Maybe<{
        __typename?: 'TriggerGiveawayEventMutationPayload';
    } & {
        giveaway: {
            __typename?: 'Giveaway';
        } & GiveawayFragment;
    }>;
};
export declare type InviteUserMutationVariables = Exact<{
    inviterId: Scalars['ID'];
    emailAddress: Scalars['String'];
}>;
export declare type InviteUserMutation = {
    __typename?: 'Mutation';
} & {
    inviteUser?: Maybe<{
        __typename?: 'InviteUserMutationPayload';
    } & Pick<InviteUserMutationPayload, 'ok'>>;
};
export declare type GetUserByUidQueryVariables = Exact<{
    uid: Scalars['ID'];
    provider: Scalars['String'];
}>;
export declare type GetUserByUidQuery = {
    __typename?: 'Query';
} & {
    userByUid: {
        __typename?: 'User';
    } & UserFragment;
};
export declare const UserLightFragmentDoc: DocumentNode;
export declare const ActivityNotificationFragmentDoc: DocumentNode;
export declare const AdminUserFragmentDoc: DocumentNode;
export declare const ContentForSelectFragmentDoc: DocumentNode;
export declare const OembedPhotoFragmentDoc: DocumentNode;
export declare const OembedVideoFragmentDoc: DocumentNode;
export declare const OembedRichFragmentDoc: DocumentNode;
export declare const OembedLinkFragmentDoc: DocumentNode;
export declare const ContentMediumFragmentDoc: DocumentNode;
export declare const ContentCategoryFragmentDoc: DocumentNode;
export declare const ContentLightFragmentDoc: DocumentNode;
export declare const PreviewUrlFragmentDoc: DocumentNode;
export declare const NftMediumFragmentDoc: DocumentNode;
export declare const CommentLightFragmentDoc: DocumentNode;
export declare const UgcReportTypeFragmentDoc: DocumentNode;
export declare const UgcReportFragmentDoc: DocumentNode;
export declare const AuditLightFragmentDoc: DocumentNode;
export declare const AuditFragmentDoc: DocumentNode;
export declare const NftLightFragmentDoc: DocumentNode;
export declare const CommentFragmentDoc: DocumentNode;
export declare const ContentTranslationFragmentDoc: DocumentNode;
export declare const AvailabilityFragmentDoc: DocumentNode;
export declare const ContentFragmentDoc: DocumentNode;
export declare const CustomNotificationLightFragmentDoc: DocumentNode;
export declare const CustomNotificationTranslationFragmentDoc: DocumentNode;
export declare const FilterNumberFragmentDoc: DocumentNode;
export declare const FilterTextFragmentDoc: DocumentNode;
export declare const FilterDateFragmentDoc: DocumentNode;
export declare const FilterIdFragmentDoc: DocumentNode;
export declare const UserFilterFragmentDoc: DocumentNode;
export declare const CustomNotificationFragmentDoc: DocumentNode;
export declare const FeedPinFragmentDoc: DocumentNode;
export declare const GiveawayLightFragmentDoc: DocumentNode;
export declare const GiveawayEventFragmentDoc: DocumentNode;
export declare const GiveawayFragmentDoc: DocumentNode;
export declare const MenuItemTranslationFragmentDoc: DocumentNode;
export declare const MenuItemBasicFragmentDoc: DocumentNode;
export declare const MenuItemParentFragmentDoc: DocumentNode;
export declare const MenuItemChildFragmentDoc: DocumentNode;
export declare const MenuItemFragmentDoc: DocumentNode;
export declare const FanGroupForSelectFragmentDoc: DocumentNode;
export declare const UserMediumFragmentDoc: DocumentNode;
export declare const FanGroupLightFragmentDoc: DocumentNode;
export declare const FanGroupFragmentDoc: DocumentNode;
export declare const GroupPostLightFragmentDoc: DocumentNode;
export declare const GroupPostFragmentDoc: DocumentNode;
export declare const IdeationMissionTranslationFragmentDoc: DocumentNode;
export declare const IdeaLightFragmentDoc: DocumentNode;
export declare const ProposalPeriodLightFragmentDoc: DocumentNode;
export declare const ProposalLightFragmentDoc: DocumentNode;
export declare const ProposalPeriodFragmentDoc: DocumentNode;
export declare const AnnouncementTranslationFragmentDoc: DocumentNode;
export declare const AnnouncementFragmentDoc: DocumentNode;
export declare const ProposalFragmentDoc: DocumentNode;
export declare const NftBenefitRedemptionFragmentDoc: DocumentNode;
export declare const NftHandoutUserFragmentDoc: DocumentNode;
export declare const NftHandoutLightFragmentDoc: DocumentNode;
export declare const NftHandoutTranslationFragmentDoc: DocumentNode;
export declare const NftHandoutFragmentDoc: DocumentNode;
export declare const NftUserFragmentDoc: DocumentNode;
export declare const NftTransferNetworkFragmentDoc: DocumentNode;
export declare const NftCollectionDeploymentFragmentDoc: DocumentNode;
export declare const NftCollectionForSelectFragmentDoc: DocumentNode;
export declare const NftCollectionTranslationFragmentDoc: DocumentNode;
export declare const NftCollectionFragmentDoc: DocumentNode;
export declare const NftForSelectFragmentDoc: DocumentNode;
export declare const NftRarityFragmentDoc: DocumentNode;
export declare const ShopProductMinimumFragmentDoc: DocumentNode;
export declare const ShopProductTranslationFragmentDoc: DocumentNode;
export declare const ShopProductLightFragmentDoc: DocumentNode;
export declare const NftBenefitFragmentDoc: DocumentNode;
export declare const NftFragmentDoc: DocumentNode;
export declare const AmaSessionForSelectFragmentDoc: DocumentNode;
export declare const AmaSessionTranslationFragmentDoc: DocumentNode;
export declare const AmaSessionLightFragmentDoc: DocumentNode;
export declare const AmaQuestionLightFragmentDoc: DocumentNode;
export declare const AmaQuestionFragmentDoc: DocumentNode;
export declare const AmaSessionFragmentDoc: DocumentNode;
export declare const IdeationMissionForSelectFragmentDoc: DocumentNode;
export declare const IdeationMissionLightFragmentDoc: DocumentNode;
export declare const IdeaFragmentDoc: DocumentNode;
export declare const IdeationMissionFragmentDoc: DocumentNode;
export declare const VotingForSelectFragmentDoc: DocumentNode;
export declare const VotingTranslationFragmentDoc: DocumentNode;
export declare const VotingLightFragmentDoc: DocumentNode;
export declare const VotingOptionTranslationFragmentDoc: DocumentNode;
export declare const VotingOptionFragmentDoc: DocumentNode;
export declare const VotingFragmentDoc: DocumentNode;
export declare const RestrictionsFragmentDoc: DocumentNode;
export declare const SalesStatisticFragmentDoc: DocumentNode;
export declare const BalanceFragmentDoc: DocumentNode;
export declare const SystemSettingFragmentDoc: DocumentNode;
export declare const SystemSettingsGroupFragmentDoc: DocumentNode;
export declare const UserOrderLightFragmentDoc: DocumentNode;
export declare const PaymentFragmentDoc: DocumentNode;
export declare const UserOrderFragmentDoc: DocumentNode;
export declare const SponsorForSelectFragmentDoc: DocumentNode;
export declare const SponsorStatsFragmentDoc: DocumentNode;
export declare const SponsorLightFragmentDoc: DocumentNode;
export declare const SponsorFragmentDoc: DocumentNode;
export declare const StaticPageTranslationFragmentDoc: DocumentNode;
export declare const StaticPageLightFragmentDoc: DocumentNode;
export declare const StaticPageFragmentDoc: DocumentNode;
export declare const TokenHandoutUserFragmentDoc: DocumentNode;
export declare const TokenHandoutLightFragmentDoc: DocumentNode;
export declare const TokenHandoutTranslationFragmentDoc: DocumentNode;
export declare const TokenHandoutFragmentDoc: DocumentNode;
export declare const TransactionLightFragmentDoc: DocumentNode;
export declare const TransactionFragmentDoc: DocumentNode;
export declare const TriggerEventFragmentDoc: DocumentNode;
export declare const UserGiveawayFragmentDoc: DocumentNode;
export declare const ShopProductTierFragmentDoc: DocumentNode;
export declare const ShopProductFragmentDoc: DocumentNode;
export declare const ProfileFieldOptionFragmentDoc: DocumentNode;
export declare const ProfileFieldFragmentDoc: DocumentNode;
export declare const UserProfileFieldFragmentDoc: DocumentNode;
export declare const FanGroupUserFragmentDoc: DocumentNode;
export declare const UserFragmentDoc: DocumentNode;
export declare const GetActivityNotificationsDocument: DocumentNode;
export declare const CreateAdminUserDocument: DocumentNode;
export declare const DeleteAdminUserDocument: DocumentNode;
export declare const UpdateAdminUserDocument: DocumentNode;
export declare const GetAdminUserDocument: DocumentNode;
export declare const GetAdminUsersDocument: DocumentNode;
export declare const CreateAnnouncementDocument: DocumentNode;
export declare const DeleteAnnouncementsDocument: DocumentNode;
export declare const UpdateAnnouncementDocument: DocumentNode;
export declare const GetAnnouncementDocument: DocumentNode;
export declare const LoginDocument: DocumentNode;
export declare const ArchiveContentDocument: DocumentNode;
export declare const CreateContentCategoryDocument: DocumentNode;
export declare const CreateContentDocument: DocumentNode;
export declare const DeleteContentCategoriesDocument: DocumentNode;
export declare const DeleteContentsDocument: DocumentNode;
export declare const DraftContentDocument: DocumentNode;
export declare const PublishContentDocument: DocumentNode;
export declare const UpdateContentCategoryDocument: DocumentNode;
export declare const UpdateContentDocument: DocumentNode;
export declare const GetContentCategoriesDocument: DocumentNode;
export declare const GetContentCategoryDocument: DocumentNode;
export declare const GetContentDocument: DocumentNode;
export declare const GetContentsForSelectDocument: DocumentNode;
export declare const GetContentsDocument: DocumentNode;
export declare const CreateCustomNotificationDocument: DocumentNode;
export declare const DeleteCustomNotificationsDocument: DocumentNode;
export declare const DraftCustomNotificationDocument: DocumentNode;
export declare const PublishCustomNotificationDocument: DocumentNode;
export declare const UpdateCustomNotificationDocument: DocumentNode;
export declare const GetCustomNotificationDocument: DocumentNode;
export declare const GetCustomNotificationsDocument: DocumentNode;
export declare const GetPinnedItemDocument: DocumentNode;
export declare const ArchiveGiveawayDocument: DocumentNode;
export declare const CreateGiveawayDocument: DocumentNode;
export declare const DeleteGiveawaysDocument: DocumentNode;
export declare const DraftGiveawayDocument: DocumentNode;
export declare const PublishGiveawayDocument: DocumentNode;
export declare const UpdateGiveawayDocument: DocumentNode;
export declare const GetActiveAndPublishedNftGiveawaysDocument: DocumentNode;
export declare const GetGiveawayDocument: DocumentNode;
export declare const GetGiveawaysDocument: DocumentNode;
export declare const GetMeDocument: DocumentNode;
export declare const CreateContentMediumDocument: DocumentNode;
export declare const DeleteContentMediaDocument: DocumentNode;
export declare const RefreshOembedDataDocument: DocumentNode;
export declare const UpdateContentMediumDocument: DocumentNode;
export declare const GetMediaUploadUrlDocument: DocumentNode;
export declare const GetContentMediaDocument: DocumentNode;
export declare const GetContentMediumDocument: DocumentNode;
export declare const CreateMenuItemDocument: DocumentNode;
export declare const DeleteMenuItemsDocument: DocumentNode;
export declare const UpdateMenuItemDocument: DocumentNode;
export declare const UpdateMenuItemsDocument: DocumentNode;
export declare const GetMenuItemsDocument: DocumentNode;
export declare const CreateProposalPeriodDocument: DocumentNode;
export declare const DeleteProposalPeriodsDocument: DocumentNode;
export declare const UpdateAmaQuestionDocument: DocumentNode;
export declare const UpdateCommentDocument: DocumentNode;
export declare const UpdateFanGroupDocument: DocumentNode;
export declare const UpdateGroupPostDocument: DocumentNode;
export declare const UpdateIdeaDocument: DocumentNode;
export declare const UpdateProposalPeriodDocument: DocumentNode;
export declare const UpdateProposalDocument: DocumentNode;
export declare const GetAmaQuestionDocument: DocumentNode;
export declare const GetAmaQuestionsDocument: DocumentNode;
export declare const GetCommentDocument: DocumentNode;
export declare const GetCommentsDocument: DocumentNode;
export declare const GetFanGroupUsersDocument: DocumentNode;
export declare const GetFanGroupDocument: DocumentNode;
export declare const GetFanGroupsForSelectDocument: DocumentNode;
export declare const GetFanGroupsDocument: DocumentNode;
export declare const GetGroupPostDocument: DocumentNode;
export declare const GetGroupPostsDocument: DocumentNode;
export declare const GetIdeaDocument: DocumentNode;
export declare const GetIdeasDocument: DocumentNode;
export declare const GetProposalPeriodDocument: DocumentNode;
export declare const GetProposalPeriodsDocument: DocumentNode;
export declare const GetProposalDocument: DocumentNode;
export declare const GetProposalsDocument: DocumentNode;
export declare const GetUgcReportMetasDocument: DocumentNode;
export declare const GetUgcReportDocument: DocumentNode;
export declare const GetUgcReportsDocument: DocumentNode;
export declare const GetNftBenefitRedemptionsDocument: DocumentNode;
export declare const CreateNftHandoutDocument: DocumentNode;
export declare const DeleteNftHandoutsDocument: DocumentNode;
export declare const DraftNftHandoutDocument: DocumentNode;
export declare const PublishNftHandoutDocument: DocumentNode;
export declare const UpdateNftHandoutDocument: DocumentNode;
export declare const GetNftHandoutUsersDocument: DocumentNode;
export declare const GetNftHandoutDocument: DocumentNode;
export declare const GetNftHandoutsDocument: DocumentNode;
export declare const CreateNftTransferNetworkDocument: DocumentNode;
export declare const UpdateNftTransferNetworkDocument: DocumentNode;
export declare const GetNftTransferNetworkDocument: DocumentNode;
export declare const GetNftTransferNetworksDocument: DocumentNode;
export declare const GetNftUsersDocument: DocumentNode;
export declare const AddNftsToCollectionDocument: DocumentNode;
export declare const ArchiveNftCollectionDocument: DocumentNode;
export declare const CreateNftCollectionDeploymentDocument: DocumentNode;
export declare const CreateNftCollectionDocument: DocumentNode;
export declare const CreateNftMediumDocument: DocumentNode;
export declare const CreateNftDocument: DocumentNode;
export declare const DeleteNftCollectionsDocument: DocumentNode;
export declare const DeleteNftMediaDocument: DocumentNode;
export declare const DeleteNftsDocument: DocumentNode;
export declare const MintNftCollectionDocument: DocumentNode;
export declare const MintNftDocument: DocumentNode;
export declare const PublishNftCollectionDocument: DocumentNode;
export declare const RequestNftCollectionMetadataUriDocument: DocumentNode;
export declare const UpdateNftCollectionDeploymentDocument: DocumentNode;
export declare const UpdateNftCollectionDocument: DocumentNode;
export declare const UpdateNftMediumDocument: DocumentNode;
export declare const UpdateNftDocument: DocumentNode;
export declare const UpdateNftsVisibilityDocument: DocumentNode;
export declare const GetNftCollectionDocument: DocumentNode;
export declare const GetNftCollectionsForSelectDocument: DocumentNode;
export declare const GetNftCollectionsDocument: DocumentNode;
export declare const GetNftMediaDocument: DocumentNode;
export declare const GetNftMediumDocument: DocumentNode;
export declare const GetNftRaritiesDocument: DocumentNode;
export declare const GetNftDocument: DocumentNode;
export declare const GetNftsForSelectDocument: DocumentNode;
export declare const GetNftsDocument: DocumentNode;
export declare const ArchiveAmaSessionDocument: DocumentNode;
export declare const ArchiveIdeationMissionDocument: DocumentNode;
export declare const ArchiveVotingDocument: DocumentNode;
export declare const CreateAmaSessionDocument: DocumentNode;
export declare const CreateIdeationMissionDocument: DocumentNode;
export declare const CreateVotingDocument: DocumentNode;
export declare const DeleteAmaSessionsDocument: DocumentNode;
export declare const DeleteIdeationMissionsDocument: DocumentNode;
export declare const DeleteVotingsDocument: DocumentNode;
export declare const DistributeVotingDocument: DocumentNode;
export declare const DraftAmaSessionDocument: DocumentNode;
export declare const DraftIdeationMissionDocument: DocumentNode;
export declare const DraftVotingDocument: DocumentNode;
export declare const PublishAmaSessionDocument: DocumentNode;
export declare const PublishIdeationMissionDocument: DocumentNode;
export declare const PublishVotingDocument: DocumentNode;
export declare const RefundVotingDocument: DocumentNode;
export declare const UpdateAmaSessionDocument: DocumentNode;
export declare const UpdateIdeationMissionDocument: DocumentNode;
export declare const UpdateVotingDocument: DocumentNode;
export declare const GetAmaSessionDocument: DocumentNode;
export declare const GetAmaSessionsForSelectDocument: DocumentNode;
export declare const GetAmaSessionsDocument: DocumentNode;
export declare const GetIdeationMissionDocument: DocumentNode;
export declare const GetIdeationMissionsForSelectDocument: DocumentNode;
export declare const GetIdeationMissionsDocument: DocumentNode;
export declare const GetVotingDocument: DocumentNode;
export declare const GetVotingsForSelectDocument: DocumentNode;
export declare const GetVotingsDocument: DocumentNode;
export declare const CreateUgcReportTypeDocument: DocumentNode;
export declare const UpdateUgcReportTypeDocument: DocumentNode;
export declare const GetUgcReportTypeDocument: DocumentNode;
export declare const GetUgcReportTypesDocument: DocumentNode;
export declare const GetRestrictionsDocument: DocumentNode;
export declare const GetSalesStatisticsDocument: DocumentNode;
export declare const DeployCommentBoosterDocument: DocumentNode;
export declare const DeployContentBoosterDocument: DocumentNode;
export declare const DeployProposalBoosterDocument: DocumentNode;
export declare const DistributeCommentBoosterDocument: DocumentNode;
export declare const DistributeContentBoosterDocument: DocumentNode;
export declare const DistributeProposalBoosterDocument: DocumentNode;
export declare const FundFanVaultsDocument: DocumentNode;
export declare const StartAutomaticPeriodsDocument: DocumentNode;
export declare const StopAutomaticPeriodsDocument: DocumentNode;
export declare const UpsertSystemSettingsDocument: DocumentNode;
export declare const GetCommunityChestSettingsDocument: DocumentNode;
export declare const GetFanGroupSettingsDocument: DocumentNode;
export declare const GetGeneralSettingsDocument: DocumentNode;
export declare const GetNfcSettingsDocument: DocumentNode;
export declare const GetProposalPeriodSettingsDocument: DocumentNode;
export declare const GetShopSettingsDocument: DocumentNode;
export declare const GetTokenContractSettingsDocument: DocumentNode;
export declare const GetTokenDistributionSettingsDocument: DocumentNode;
export declare const CreateShopProductDocument: DocumentNode;
export declare const CreateShopProductTierDocument: DocumentNode;
export declare const DeleteShopProductsDocument: DocumentNode;
export declare const DeleteShopProductTiersDocument: DocumentNode;
export declare const UpdateShopProductDocument: DocumentNode;
export declare const UpdateShopProductTierDocument: DocumentNode;
export declare const GetLowNftBucketsDocument: DocumentNode;
export declare const GetUserOrderDocument: DocumentNode;
export declare const GetUserOrdersDocument: DocumentNode;
export declare const GetShopProductDocument: DocumentNode;
export declare const GetShopProductsDocument: DocumentNode;
export declare const GetShopProductTierDocument: DocumentNode;
export declare const GetShopProductTiersDocument: DocumentNode;
export declare const GetVisibleProductsWithNftBucketsDocument: DocumentNode;
export declare const CreateSponsorDocument: DocumentNode;
export declare const DeleteSponsorsDocument: DocumentNode;
export declare const UpdateSponsorDocument: DocumentNode;
export declare const GetSponsorStatisticsDocument: DocumentNode;
export declare const GetSponsorDocument: DocumentNode;
export declare const GetSponsorsForSelectDocument: DocumentNode;
export declare const GetSponsorsDocument: DocumentNode;
export declare const ArchiveStaticPageDocument: DocumentNode;
export declare const CreateStaticPageDocument: DocumentNode;
export declare const DeleteStaticPagesDocument: DocumentNode;
export declare const PublishStaticPageDocument: DocumentNode;
export declare const UpdateStaticPageDocument: DocumentNode;
export declare const GetStaticPageDocument: DocumentNode;
export declare const GetStaticPagesDocument: DocumentNode;
export declare const CreateTokenHandoutDocument: DocumentNode;
export declare const DeleteTokenHandoutsDocument: DocumentNode;
export declare const DraftTokenHandoutDocument: DocumentNode;
export declare const PublishTokenHandoutDocument: DocumentNode;
export declare const UpdateTokenHandoutDocument: DocumentNode;
export declare const GetTokenHandoutUsersDocument: DocumentNode;
export declare const GetTokenHandoutDocument: DocumentNode;
export declare const GetTokenHandoutsDocument: DocumentNode;
export declare const GetTokenStatisticsDocument: DocumentNode;
export declare const GetTransactionDocument: DocumentNode;
export declare const GetTransactionsDocument: DocumentNode;
export declare const GetTriggerEventsDocument: DocumentNode;
export declare const GetUserGiveawaysDocument: DocumentNode;
export declare const ArchiveProfileFieldDocument: DocumentNode;
export declare const CreateProfileFieldDocument: DocumentNode;
export declare const DeleteProfileFieldsDocument: DocumentNode;
export declare const DraftProfileFieldDocument: DocumentNode;
export declare const PublishProfileFieldDocument: DocumentNode;
export declare const UpdateProfileFieldDocument: DocumentNode;
export declare const UpdateProfileFieldsDocument: DocumentNode;
export declare const UpdateUserDocument: DocumentNode;
export declare const GetProfileFieldDocument: DocumentNode;
export declare const GetProfileFieldsDocument: DocumentNode;
export declare const GetUserDeviceStatisticsDocument: DocumentNode;
export declare const GetUserDocument: DocumentNode;
export declare const GetUsersDocument: DocumentNode;
export declare const TriggerGiveawayEventDocument: DocumentNode;
export declare const InviteUserDocument: DocumentNode;
export declare const GetUserByUidDocument: DocumentNode;
export declare type Requester<C = {}> = <R, V>(doc: DocumentNode, vars?: V, options?: C) => Promise<R>;
export declare function getSdk<C>(requester: Requester<C>): {
    getActivityNotifications(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<ActivityNotificationFilterInput>;
        sort?: Maybe<ActivityNotificationSortInput>;
    }> | undefined, options?: C | undefined): Promise<GetActivityNotificationsQuery>;
    createAdminUser(variables: CreateAdminUserMutationVariables, options?: C | undefined): Promise<CreateAdminUserMutation>;
    deleteAdminUser(variables: DeleteAdminUserMutationVariables, options?: C | undefined): Promise<DeleteAdminUserMutation>;
    updateAdminUser(variables: UpdateAdminUserMutationVariables, options?: C | undefined): Promise<UpdateAdminUserMutation>;
    getAdminUser(variables: GetAdminUserQueryVariables, options?: C | undefined): Promise<GetAdminUserQuery>;
    getAdminUsers(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<AdminUserFilterInput>;
        sort?: Maybe<AdminUserSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetAdminUsersQuery>;
    createAnnouncement(variables: CreateAnnouncementMutationVariables, options?: C | undefined): Promise<CreateAnnouncementMutation>;
    deleteAnnouncements(variables: DeleteAnnouncementsMutationVariables, options?: C | undefined): Promise<DeleteAnnouncementsMutation>;
    updateAnnouncement(variables: UpdateAnnouncementMutationVariables, options?: C | undefined): Promise<UpdateAnnouncementMutation>;
    getAnnouncement(variables: GetAnnouncementQueryVariables, options?: C | undefined): Promise<GetAnnouncementQuery>;
    login(variables: LoginMutationVariables, options?: C | undefined): Promise<LoginMutation>;
    archiveContent(variables: ArchiveContentMutationVariables, options?: C | undefined): Promise<ArchiveContentMutation>;
    createContentCategory(variables: CreateContentCategoryMutationVariables, options?: C | undefined): Promise<CreateContentCategoryMutation>;
    createContent(variables: CreateContentMutationVariables, options?: C | undefined): Promise<CreateContentMutation>;
    deleteContentCategories(variables: DeleteContentCategoriesMutationVariables, options?: C | undefined): Promise<DeleteContentCategoriesMutation>;
    deleteContents(variables: DeleteContentsMutationVariables, options?: C | undefined): Promise<DeleteContentsMutation>;
    draftContent(variables: DraftContentMutationVariables, options?: C | undefined): Promise<DraftContentMutation>;
    publishContent(variables: PublishContentMutationVariables, options?: C | undefined): Promise<PublishContentMutation>;
    updateContentCategory(variables: UpdateContentCategoryMutationVariables, options?: C | undefined): Promise<UpdateContentCategoryMutation>;
    updateContent(variables: UpdateContentMutationVariables, options?: C | undefined): Promise<UpdateContentMutation>;
    getContentCategories(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<ContentCategoryFilterInput>;
        sort?: Maybe<ContentCategorySortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetContentCategoriesQuery>;
    getContentCategory(variables: GetContentCategoryQueryVariables, options?: C | undefined): Promise<GetContentCategoryQuery>;
    getContent(variables: GetContentQueryVariables, options?: C | undefined): Promise<GetContentQuery>;
    getContentsForSelect(variables: GetContentsForSelectQueryVariables, options?: C | undefined): Promise<GetContentsForSelectQuery>;
    getContents(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<ContentFilterInput>;
        sort?: Maybe<ContentSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetContentsQuery>;
    createCustomNotification(variables: CreateCustomNotificationMutationVariables, options?: C | undefined): Promise<CreateCustomNotificationMutation>;
    deleteCustomNotifications(variables: DeleteCustomNotificationsMutationVariables, options?: C | undefined): Promise<DeleteCustomNotificationsMutation>;
    draftCustomNotification(variables: DraftCustomNotificationMutationVariables, options?: C | undefined): Promise<DraftCustomNotificationMutation>;
    publishCustomNotification(variables: PublishCustomNotificationMutationVariables, options?: C | undefined): Promise<PublishCustomNotificationMutation>;
    updateCustomNotification(variables: UpdateCustomNotificationMutationVariables, options?: C | undefined): Promise<UpdateCustomNotificationMutation>;
    getCustomNotification(variables: GetCustomNotificationQueryVariables, options?: C | undefined): Promise<GetCustomNotificationQuery>;
    getCustomNotifications(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<CustomNotificationFilterInput>;
        sort?: Maybe<CustomNotificationSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetCustomNotificationsQuery>;
    getPinnedItem(variables?: Exact<{
        [key: string]: never;
    }> | undefined, options?: C | undefined): Promise<GetPinnedItemQuery>;
    archiveGiveaway(variables: ArchiveGiveawayMutationVariables, options?: C | undefined): Promise<ArchiveGiveawayMutation>;
    createGiveaway(variables: CreateGiveawayMutationVariables, options?: C | undefined): Promise<CreateGiveawayMutation>;
    deleteGiveaways(variables: DeleteGiveawaysMutationVariables, options?: C | undefined): Promise<DeleteGiveawaysMutation>;
    draftGiveaway(variables: DraftGiveawayMutationVariables, options?: C | undefined): Promise<DraftGiveawayMutation>;
    publishGiveaway(variables: PublishGiveawayMutationVariables, options?: C | undefined): Promise<PublishGiveawayMutation>;
    updateGiveaway(variables: UpdateGiveawayMutationVariables, options?: C | undefined): Promise<UpdateGiveawayMutation>;
    getActiveAndPublishedNftGiveaways(variables?: Exact<{
        [key: string]: never;
    }> | undefined, options?: C | undefined): Promise<GetActiveAndPublishedNftGiveawaysQuery>;
    getGiveaway(variables: GetGiveawayQueryVariables, options?: C | undefined): Promise<GetGiveawayQuery>;
    getGiveaways(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<GiveawayFilterInput>;
        sort?: Maybe<GiveawaySortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetGiveawaysQuery>;
    getMe(variables?: Exact<{
        [key: string]: never;
    }> | undefined, options?: C | undefined): Promise<GetMeQuery>;
    createContentMedium(variables: CreateContentMediumMutationVariables, options?: C | undefined): Promise<CreateContentMediumMutation>;
    deleteContentMedia(variables: DeleteContentMediaMutationVariables, options?: C | undefined): Promise<DeleteContentMediaMutation>;
    refreshOembedData(variables: RefreshOembedDataMutationVariables, options?: C | undefined): Promise<RefreshOembedDataMutation>;
    updateContentMedium(variables: UpdateContentMediumMutationVariables, options?: C | undefined): Promise<UpdateContentMediumMutation>;
    getMediaUploadUrl(variables: GetMediaUploadUrlMutationVariables, options?: C | undefined): Promise<GetMediaUploadUrlMutation>;
    getContentMedia(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<ContentMediumFilterInput>;
        sort?: Maybe<ContentMediumSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetContentMediaQuery>;
    getContentMedium(variables: GetContentMediumQueryVariables, options?: C | undefined): Promise<GetContentMediumQuery>;
    createMenuItem(variables: CreateMenuItemMutationVariables, options?: C | undefined): Promise<CreateMenuItemMutation>;
    deleteMenuItems(variables: DeleteMenuItemsMutationVariables, options?: C | undefined): Promise<DeleteMenuItemsMutation>;
    updateMenuItem(variables: UpdateMenuItemMutationVariables, options?: C | undefined): Promise<UpdateMenuItemMutation>;
    updateMenuItems(variables: UpdateMenuItemsMutationVariables, options?: C | undefined): Promise<UpdateMenuItemsMutation>;
    getMenuItems(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<MenuItemFilterInput>;
    }> | undefined, options?: C | undefined): Promise<GetMenuItemsQuery>;
    createProposalPeriod(variables: CreateProposalPeriodMutationVariables, options?: C | undefined): Promise<CreateProposalPeriodMutation>;
    deleteProposalPeriods(variables: DeleteProposalPeriodsMutationVariables, options?: C | undefined): Promise<DeleteProposalPeriodsMutation>;
    updateAmaQuestion(variables: UpdateAmaQuestionMutationVariables, options?: C | undefined): Promise<UpdateAmaQuestionMutation>;
    updateComment(variables: UpdateCommentMutationVariables, options?: C | undefined): Promise<UpdateCommentMutation>;
    updateFanGroup(variables: UpdateFanGroupMutationVariables, options?: C | undefined): Promise<UpdateFanGroupMutation>;
    updateGroupPost(variables: UpdateGroupPostMutationVariables, options?: C | undefined): Promise<UpdateGroupPostMutation>;
    updateIdea(variables: UpdateIdeaMutationVariables, options?: C | undefined): Promise<UpdateIdeaMutation>;
    updateProposalPeriod(variables: UpdateProposalPeriodMutationVariables, options?: C | undefined): Promise<UpdateProposalPeriodMutation>;
    updateProposal(variables: UpdateProposalMutationVariables, options?: C | undefined): Promise<UpdateProposalMutation>;
    getAmaQuestion(variables: GetAmaQuestionQueryVariables, options?: C | undefined): Promise<GetAmaQuestionQuery>;
    getAmaQuestions(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<AmaQuestionFilterInput>;
        sort?: Maybe<AmaQuestionSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetAmaQuestionsQuery>;
    getComment(variables: GetCommentQueryVariables, options?: C | undefined): Promise<GetCommentQuery>;
    getComments(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<CommentFilterInput>;
        sort?: Maybe<CommentSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetCommentsQuery>;
    getFanGroupUsers(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<FanGroupUserFilterInput>;
        sort?: Maybe<FanGroupUserSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetFanGroupUsersQuery>;
    getFanGroup(variables: GetFanGroupQueryVariables, options?: C | undefined): Promise<GetFanGroupQuery>;
    getFanGroupsForSelect(variables: GetFanGroupsForSelectQueryVariables, options?: C | undefined): Promise<GetFanGroupsForSelectQuery>;
    getFanGroups(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<FanGroupFilterInput>;
        sort?: Maybe<FanGroupSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetFanGroupsQuery>;
    getGroupPost(variables: GetGroupPostQueryVariables, options?: C | undefined): Promise<GetGroupPostQuery>;
    getGroupPosts(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<GroupPostFilterInput>;
        sort?: Maybe<GroupPostSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetGroupPostsQuery>;
    getIdea(variables: GetIdeaQueryVariables, options?: C | undefined): Promise<GetIdeaQuery>;
    getIdeas(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<IdeaFilterInput>;
        sort?: Maybe<IdeaSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetIdeasQuery>;
    getProposalPeriod(variables: GetProposalPeriodQueryVariables, options?: C | undefined): Promise<GetProposalPeriodQuery>;
    getProposalPeriods(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<ProposalPeriodFilterInput>;
        sort?: Maybe<ProposalPeriodSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetProposalPeriodsQuery>;
    getProposal(variables: GetProposalQueryVariables, options?: C | undefined): Promise<GetProposalQuery>;
    getProposals(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<ProposalFilterInput>;
        sort?: Maybe<ProposalSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetProposalsQuery>;
    getUgcReportMetas(variables?: Exact<{
        [key: string]: never;
    }> | undefined, options?: C | undefined): Promise<GetUgcReportMetasQuery>;
    getUgcReport(variables: GetUgcReportQueryVariables, options?: C | undefined): Promise<GetUgcReportQuery>;
    getUgcReports(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<UgcReportFilterInput>;
        sort?: Maybe<UgcReportSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetUgcReportsQuery>;
    getNftBenefitRedemptions(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<NftBenefitRedemptionFilterInput>;
        sort?: Maybe<NftBenefitRedemptionSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetNftBenefitRedemptionsQuery>;
    createNftHandout(variables: CreateNftHandoutMutationVariables, options?: C | undefined): Promise<CreateNftHandoutMutation>;
    deleteNftHandouts(variables: DeleteNftHandoutsMutationVariables, options?: C | undefined): Promise<DeleteNftHandoutsMutation>;
    draftNftHandout(variables: DraftNftHandoutMutationVariables, options?: C | undefined): Promise<DraftNftHandoutMutation>;
    publishNftHandout(variables: PublishNftHandoutMutationVariables, options?: C | undefined): Promise<PublishNftHandoutMutation>;
    updateNftHandout(variables: UpdateNftHandoutMutationVariables, options?: C | undefined): Promise<UpdateNftHandoutMutation>;
    getNftHandoutUsers(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<NftHandoutUserFilterInput>;
        sort?: Maybe<NftHandoutUserSortInput>;
    }> | undefined, options?: C | undefined): Promise<GetNftHandoutUsersQuery>;
    getNftHandout(variables: GetNftHandoutQueryVariables, options?: C | undefined): Promise<GetNftHandoutQuery>;
    getNftHandouts(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<NftHandoutFilterInput>;
        sort?: Maybe<NftHandoutSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetNftHandoutsQuery>;
    createNftTransferNetwork(variables: CreateNftTransferNetworkMutationVariables, options?: C | undefined): Promise<CreateNftTransferNetworkMutation>;
    updateNftTransferNetwork(variables: UpdateNftTransferNetworkMutationVariables, options?: C | undefined): Promise<UpdateNftTransferNetworkMutation>;
    getNftTransferNetwork(variables: GetNftTransferNetworkQueryVariables, options?: C | undefined): Promise<GetNftTransferNetworkQuery>;
    getNftTransferNetworks(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<NftTransferNetworkFilterInput>;
        sort?: Maybe<NftTransferNetworkSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetNftTransferNetworksQuery>;
    getNftUsers(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<NftUserFilterInput>;
        sort?: Maybe<NftUserSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetNftUsersQuery>;
    addNftsToCollection(variables: AddNftsToCollectionMutationVariables, options?: C | undefined): Promise<AddNftsToCollectionMutation>;
    archiveNftCollection(variables: ArchiveNftCollectionMutationVariables, options?: C | undefined): Promise<ArchiveNftCollectionMutation>;
    createNftCollectionDeployment(variables: CreateNftCollectionDeploymentMutationVariables, options?: C | undefined): Promise<CreateNftCollectionDeploymentMutation>;
    createNftCollection(variables: CreateNftCollectionMutationVariables, options?: C | undefined): Promise<CreateNftCollectionMutation>;
    createNftMedium(variables: CreateNftMediumMutationVariables, options?: C | undefined): Promise<CreateNftMediumMutation>;
    createNft(variables: CreateNftMutationVariables, options?: C | undefined): Promise<CreateNftMutation>;
    deleteNftCollections(variables: DeleteNftCollectionsMutationVariables, options?: C | undefined): Promise<DeleteNftCollectionsMutation>;
    deleteNftMedia(variables: DeleteNftMediaMutationVariables, options?: C | undefined): Promise<DeleteNftMediaMutation>;
    deleteNfts(variables: DeleteNftsMutationVariables, options?: C | undefined): Promise<DeleteNftsMutation>;
    mintNftCollection(variables: MintNftCollectionMutationVariables, options?: C | undefined): Promise<MintNftCollectionMutation>;
    mintNft(variables: MintNftMutationVariables, options?: C | undefined): Promise<MintNftMutation>;
    publishNftCollection(variables: PublishNftCollectionMutationVariables, options?: C | undefined): Promise<PublishNftCollectionMutation>;
    requestNftCollectionMetadataUri(variables: RequestNftCollectionMetadataUriMutationVariables, options?: C | undefined): Promise<RequestNftCollectionMetadataUriMutation>;
    updateNftCollectionDeployment(variables: UpdateNftCollectionDeploymentMutationVariables, options?: C | undefined): Promise<UpdateNftCollectionDeploymentMutation>;
    updateNftCollection(variables: UpdateNftCollectionMutationVariables, options?: C | undefined): Promise<UpdateNftCollectionMutation>;
    updateNftMedium(variables: UpdateNftMediumMutationVariables, options?: C | undefined): Promise<UpdateNftMediumMutation>;
    updateNft(variables: UpdateNftMutationVariables, options?: C | undefined): Promise<UpdateNftMutation>;
    updateNftsVisibility(variables: UpdateNftsVisibilityMutationVariables, options?: C | undefined): Promise<UpdateNftsVisibilityMutation>;
    getNftCollection(variables: GetNftCollectionQueryVariables, options?: C | undefined): Promise<GetNftCollectionQuery>;
    getNftCollectionsForSelect(variables: GetNftCollectionsForSelectQueryVariables, options?: C | undefined): Promise<GetNftCollectionsForSelectQuery>;
    getNftCollections(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<NftCollectionFilterInput>;
        sort?: Maybe<NftCollectionSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetNftCollectionsQuery>;
    getNftMedia(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<NftMediumFilterInput>;
        sort?: Maybe<NftMediumSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetNftMediaQuery>;
    getNftMedium(variables: GetNftMediumQueryVariables, options?: C | undefined): Promise<GetNftMediumQuery>;
    getNftRarities(variables?: Exact<{
        [key: string]: never;
    }> | undefined, options?: C | undefined): Promise<GetNftRaritiesQuery>;
    getNft(variables: GetNftQueryVariables, options?: C | undefined): Promise<GetNftQuery>;
    getNftsForSelect(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<NftFilterInput>;
        sort?: Maybe<NftSortInput>;
    }> | undefined, options?: C | undefined): Promise<GetNftsForSelectQuery>;
    getNfts(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<NftFilterInput>;
        sort?: Maybe<NftSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetNftsQuery>;
    archiveAmaSession(variables: ArchiveAmaSessionMutationVariables, options?: C | undefined): Promise<ArchiveAmaSessionMutation>;
    archiveIdeationMission(variables: ArchiveIdeationMissionMutationVariables, options?: C | undefined): Promise<ArchiveIdeationMissionMutation>;
    archiveVoting(variables: ArchiveVotingMutationVariables, options?: C | undefined): Promise<ArchiveVotingMutation>;
    createAmaSession(variables: CreateAmaSessionMutationVariables, options?: C | undefined): Promise<CreateAmaSessionMutation>;
    createIdeationMission(variables: CreateIdeationMissionMutationVariables, options?: C | undefined): Promise<CreateIdeationMissionMutation>;
    createVoting(variables: CreateVotingMutationVariables, options?: C | undefined): Promise<CreateVotingMutation>;
    deleteAmaSessions(variables: DeleteAmaSessionsMutationVariables, options?: C | undefined): Promise<DeleteAmaSessionsMutation>;
    deleteIdeationMissions(variables: DeleteIdeationMissionsMutationVariables, options?: C | undefined): Promise<DeleteIdeationMissionsMutation>;
    deleteVotings(variables: DeleteVotingsMutationVariables, options?: C | undefined): Promise<DeleteVotingsMutation>;
    distributeVoting(variables: DistributeVotingMutationVariables, options?: C | undefined): Promise<DistributeVotingMutation>;
    draftAmaSession(variables: DraftAmaSessionMutationVariables, options?: C | undefined): Promise<DraftAmaSessionMutation>;
    draftIdeationMission(variables: DraftIdeationMissionMutationVariables, options?: C | undefined): Promise<DraftIdeationMissionMutation>;
    draftVoting(variables: DraftVotingMutationVariables, options?: C | undefined): Promise<DraftVotingMutation>;
    publishAmaSession(variables: PublishAmaSessionMutationVariables, options?: C | undefined): Promise<PublishAmaSessionMutation>;
    publishIdeationMission(variables: PublishIdeationMissionMutationVariables, options?: C | undefined): Promise<PublishIdeationMissionMutation>;
    publishVoting(variables: PublishVotingMutationVariables, options?: C | undefined): Promise<PublishVotingMutation>;
    refundVoting(variables: RefundVotingMutationVariables, options?: C | undefined): Promise<RefundVotingMutation>;
    updateAmaSession(variables: UpdateAmaSessionMutationVariables, options?: C | undefined): Promise<UpdateAmaSessionMutation>;
    updateIdeationMission(variables: UpdateIdeationMissionMutationVariables, options?: C | undefined): Promise<UpdateIdeationMissionMutation>;
    updateVoting(variables: UpdateVotingMutationVariables, options?: C | undefined): Promise<UpdateVotingMutation>;
    getAmaSession(variables: GetAmaSessionQueryVariables, options?: C | undefined): Promise<GetAmaSessionQuery>;
    getAmaSessionsForSelect(variables: GetAmaSessionsForSelectQueryVariables, options?: C | undefined): Promise<GetAmaSessionsForSelectQuery>;
    getAmaSessions(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<AmaSessionFilterInput>;
        sort?: Maybe<AmaSessionSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetAmaSessionsQuery>;
    getIdeationMission(variables: GetIdeationMissionQueryVariables, options?: C | undefined): Promise<GetIdeationMissionQuery>;
    getIdeationMissionsForSelect(variables: GetIdeationMissionsForSelectQueryVariables, options?: C | undefined): Promise<GetIdeationMissionsForSelectQuery>;
    getIdeationMissions(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<IdeationMissionFilterInput>;
        sort?: Maybe<IdeationMissionSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetIdeationMissionsQuery>;
    getVoting(variables: GetVotingQueryVariables, options?: C | undefined): Promise<GetVotingQuery>;
    getVotingsForSelect(variables: GetVotingsForSelectQueryVariables, options?: C | undefined): Promise<GetVotingsForSelectQuery>;
    getVotings(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<VotingFilterInput>;
        sort?: Maybe<VotingSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetVotingsQuery>;
    createUgcReportType(variables: CreateUgcReportTypeMutationVariables, options?: C | undefined): Promise<CreateUgcReportTypeMutation>;
    updateUgcReportType(variables: UpdateUgcReportTypeMutationVariables, options?: C | undefined): Promise<UpdateUgcReportTypeMutation>;
    getUgcReportType(variables: GetUgcReportTypeQueryVariables, options?: C | undefined): Promise<GetUgcReportTypeQuery>;
    getUgcReportTypes(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<UgcReportTypeFilterInput>;
        sort?: Maybe<UgcReportTypeSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetUgcReportTypesQuery>;
    getRestrictions(variables?: Exact<{
        [key: string]: never;
    }> | undefined, options?: C | undefined): Promise<GetRestrictionsQuery>;
    getSalesStatistics(variables?: Exact<{
        [key: string]: never;
    }> | undefined, options?: C | undefined): Promise<GetSalesStatisticsQuery>;
    deployCommentBooster(variables?: Exact<{
        [key: string]: never;
    }> | undefined, options?: C | undefined): Promise<DeployCommentBoosterMutation>;
    deployContentBooster(variables?: Exact<{
        [key: string]: never;
    }> | undefined, options?: C | undefined): Promise<DeployContentBoosterMutation>;
    deployProposalBooster(variables?: Exact<{
        [key: string]: never;
    }> | undefined, options?: C | undefined): Promise<DeployProposalBoosterMutation>;
    distributeCommentBooster(variables?: Exact<{
        [key: string]: never;
    }> | undefined, options?: C | undefined): Promise<DistributeCommentBoosterMutation>;
    distributeContentBooster(variables?: Exact<{
        [key: string]: never;
    }> | undefined, options?: C | undefined): Promise<DistributeContentBoosterMutation>;
    distributeProposalBooster(variables?: Exact<{
        [key: string]: never;
    }> | undefined, options?: C | undefined): Promise<DistributeProposalBoosterMutation>;
    fundFanVaults(variables: FundFanVaultsMutationVariables, options?: C | undefined): Promise<FundFanVaultsMutation>;
    startAutomaticPeriods(variables?: Exact<{
        [key: string]: never;
    }> | undefined, options?: C | undefined): Promise<StartAutomaticPeriodsMutation>;
    stopAutomaticPeriods(variables?: Exact<{
        [key: string]: never;
    }> | undefined, options?: C | undefined): Promise<StopAutomaticPeriodsMutation>;
    upsertSystemSettings(variables: UpsertSystemSettingsMutationVariables, options?: C | undefined): Promise<UpsertSystemSettingsMutation>;
    getCommunityChestSettings(variables?: Exact<{
        [key: string]: never;
    }> | undefined, options?: C | undefined): Promise<GetCommunityChestSettingsQuery>;
    getFanGroupSettings(variables?: Exact<{
        [key: string]: never;
    }> | undefined, options?: C | undefined): Promise<GetFanGroupSettingsQuery>;
    getGeneralSettings(variables?: Exact<{
        [key: string]: never;
    }> | undefined, options?: C | undefined): Promise<GetGeneralSettingsQuery>;
    getNfcSettings(variables?: Exact<{
        [key: string]: never;
    }> | undefined, options?: C | undefined): Promise<GetNfcSettingsQuery>;
    getProposalPeriodSettings(variables?: Exact<{
        [key: string]: never;
    }> | undefined, options?: C | undefined): Promise<GetProposalPeriodSettingsQuery>;
    getShopSettings(variables?: Exact<{
        [key: string]: never;
    }> | undefined, options?: C | undefined): Promise<GetShopSettingsQuery>;
    getTokenContractSettings(variables?: Exact<{
        [key: string]: never;
    }> | undefined, options?: C | undefined): Promise<GetTokenContractSettingsQuery>;
    getTokenDistributionSettings(variables?: Exact<{
        [key: string]: never;
    }> | undefined, options?: C | undefined): Promise<GetTokenDistributionSettingsQuery>;
    createShopProduct(variables: CreateShopProductMutationVariables, options?: C | undefined): Promise<CreateShopProductMutation>;
    createShopProductTier(variables: CreateShopProductTierMutationVariables, options?: C | undefined): Promise<CreateShopProductTierMutation>;
    deleteShopProducts(variables: DeleteShopProductsMutationVariables, options?: C | undefined): Promise<DeleteShopProductsMutation>;
    deleteShopProductTiers(variables: DeleteShopProductTiersMutationVariables, options?: C | undefined): Promise<DeleteShopProductTiersMutation>;
    updateShopProduct(variables: UpdateShopProductMutationVariables, options?: C | undefined): Promise<UpdateShopProductMutation>;
    updateShopProductTier(variables: UpdateShopProductTierMutationVariables, options?: C | undefined): Promise<UpdateShopProductTierMutation>;
    getLowNftBuckets(variables?: Exact<{
        [key: string]: never;
    }> | undefined, options?: C | undefined): Promise<GetLowNftBucketsQuery>;
    getUserOrder(variables: GetUserOrderQueryVariables, options?: C | undefined): Promise<GetUserOrderQuery>;
    getUserOrders(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<UserOrderFilterInput>;
        sort?: Maybe<UserOrderSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetUserOrdersQuery>;
    getShopProduct(variables: GetShopProductQueryVariables, options?: C | undefined): Promise<GetShopProductQuery>;
    getShopProducts(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<ShopProductFilterInput>;
        sort?: Maybe<ShopProductSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetShopProductsQuery>;
    getShopProductTier(variables: GetShopProductTierQueryVariables, options?: C | undefined): Promise<GetShopProductTierQuery>;
    getShopProductTiers(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<ShopProductTierFilterInput>;
        sort?: Maybe<ShopProductTierSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetShopProductTiersQuery>;
    getVisibleProductsWithNftBuckets(variables?: Exact<{
        [key: string]: never;
    }> | undefined, options?: C | undefined): Promise<GetVisibleProductsWithNftBucketsQuery>;
    createSponsor(variables: CreateSponsorMutationVariables, options?: C | undefined): Promise<CreateSponsorMutation>;
    deleteSponsors(variables: DeleteSponsorsMutationVariables, options?: C | undefined): Promise<DeleteSponsorsMutation>;
    updateSponsor(variables: UpdateSponsorMutationVariables, options?: C | undefined): Promise<UpdateSponsorMutation>;
    getSponsorStatistics(variables: GetSponsorStatisticsQueryVariables, options?: C | undefined): Promise<GetSponsorStatisticsQuery>;
    getSponsor(variables: GetSponsorQueryVariables, options?: C | undefined): Promise<GetSponsorQuery>;
    getSponsorsForSelect(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<SponsorFilterInput>;
        sort?: Maybe<SponsorSortInput>;
    }> | undefined, options?: C | undefined): Promise<GetSponsorsForSelectQuery>;
    getSponsors(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<SponsorFilterInput>;
        sort?: Maybe<SponsorSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetSponsorsQuery>;
    archiveStaticPage(variables: ArchiveStaticPageMutationVariables, options?: C | undefined): Promise<ArchiveStaticPageMutation>;
    createStaticPage(variables: CreateStaticPageMutationVariables, options?: C | undefined): Promise<CreateStaticPageMutation>;
    deleteStaticPages(variables: DeleteStaticPagesMutationVariables, options?: C | undefined): Promise<DeleteStaticPagesMutation>;
    publishStaticPage(variables: PublishStaticPageMutationVariables, options?: C | undefined): Promise<PublishStaticPageMutation>;
    updateStaticPage(variables: UpdateStaticPageMutationVariables, options?: C | undefined): Promise<UpdateStaticPageMutation>;
    getStaticPage(variables: GetStaticPageQueryVariables, options?: C | undefined): Promise<GetStaticPageQuery>;
    getStaticPages(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<StaticPageFilterInput>;
        sort?: Maybe<StaticPageSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetStaticPagesQuery>;
    createTokenHandout(variables: CreateTokenHandoutMutationVariables, options?: C | undefined): Promise<CreateTokenHandoutMutation>;
    deleteTokenHandouts(variables: DeleteTokenHandoutsMutationVariables, options?: C | undefined): Promise<DeleteTokenHandoutsMutation>;
    draftTokenHandout(variables: DraftTokenHandoutMutationVariables, options?: C | undefined): Promise<DraftTokenHandoutMutation>;
    publishTokenHandout(variables: PublishTokenHandoutMutationVariables, options?: C | undefined): Promise<PublishTokenHandoutMutation>;
    updateTokenHandout(variables: UpdateTokenHandoutMutationVariables, options?: C | undefined): Promise<UpdateTokenHandoutMutation>;
    getTokenHandoutUsers(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<TokenHandoutUserFilterInput>;
        sort?: Maybe<TokenHandoutUserSortInput>;
    }> | undefined, options?: C | undefined): Promise<GetTokenHandoutUsersQuery>;
    getTokenHandout(variables: GetTokenHandoutQueryVariables, options?: C | undefined): Promise<GetTokenHandoutQuery>;
    getTokenHandouts(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<TokenHandoutFilterInput>;
        sort?: Maybe<TokenHandoutSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetTokenHandoutsQuery>;
    getTokenStatistics(variables?: Exact<{
        [key: string]: never;
    }> | undefined, options?: C | undefined): Promise<GetTokenStatisticsQuery>;
    getTransaction(variables: GetTransactionQueryVariables, options?: C | undefined): Promise<GetTransactionQuery>;
    getTransactions(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<TransactionFilterInput>;
        sort?: Maybe<TransactionSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetTransactionsQuery>;
    getTriggerEvents(variables?: Exact<{
        [key: string]: never;
    }> | undefined, options?: C | undefined): Promise<GetTriggerEventsQuery>;
    getUserGiveaways(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<UserGiveawayFilterInput>;
        sort?: Maybe<UserGiveawaySortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetUserGiveawaysQuery>;
    archiveProfileField(variables: ArchiveProfileFieldMutationVariables, options?: C | undefined): Promise<ArchiveProfileFieldMutation>;
    createProfileField(variables: CreateProfileFieldMutationVariables, options?: C | undefined): Promise<CreateProfileFieldMutation>;
    deleteProfileFields(variables: DeleteProfileFieldsMutationVariables, options?: C | undefined): Promise<DeleteProfileFieldsMutation>;
    draftProfileField(variables: DraftProfileFieldMutationVariables, options?: C | undefined): Promise<DraftProfileFieldMutation>;
    publishProfileField(variables: PublishProfileFieldMutationVariables, options?: C | undefined): Promise<PublishProfileFieldMutation>;
    updateProfileField(variables: UpdateProfileFieldMutationVariables, options?: C | undefined): Promise<UpdateProfileFieldMutation>;
    updateProfileFields(variables: UpdateProfileFieldsMutationVariables, options?: C | undefined): Promise<UpdateProfileFieldsMutation>;
    updateUser(variables: UpdateUserMutationVariables, options?: C | undefined): Promise<UpdateUserMutation>;
    getProfileField(variables: GetProfileFieldQueryVariables, options?: C | undefined): Promise<GetProfileFieldQuery>;
    getProfileFields(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<ProfileFieldFilterInput>;
        sort?: Maybe<ProfileFieldSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetProfileFieldsQuery>;
    getUserDeviceStatistics(variables?: Exact<{
        [key: string]: never;
    }> | undefined, options?: C | undefined): Promise<GetUserDeviceStatisticsQuery>;
    getUser(variables: GetUserQueryVariables, options?: C | undefined): Promise<GetUserQuery>;
    getUsers(variables?: Exact<{
        limit?: Maybe<number>;
        offset?: Maybe<number>;
        filter?: Maybe<UserFilterInput>;
        sort?: Maybe<UserSortInput>;
        search?: Maybe<string>;
    }> | undefined, options?: C | undefined): Promise<GetUsersQuery>;
    triggerGiveawayEvent(variables: TriggerGiveawayEventMutationVariables, options?: C | undefined): Promise<TriggerGiveawayEventMutation>;
    inviteUser(variables: InviteUserMutationVariables, options?: C | undefined): Promise<InviteUserMutation>;
    getUserByUid(variables: GetUserByUidQueryVariables, options?: C | undefined): Promise<GetUserByUidQuery>;
};
export declare type Sdk = ReturnType<typeof getSdk>;
//# sourceMappingURL=api-types-and-hooks.d.ts.map